; File generated automatically from setupapi/setupapi.spec; do not edit!

LIBRARY setupapi.dll

EXPORTS
  CM_Connect_MachineW@8 @1
  CM_Disconnect_Machine@4 @2
  InstallHinfSection@16=InstallHinfSectionA@16 @30
  InstallHinfSectionA@16 @31
  InstallHinfSectionW@16 @32
  SetupAddInstallSectionToDiskSpaceListA@24 @53
  SetupCloseFileQueue@4 @64
  SetupCloseInfFile@4 @65
  SetupCommitFileQueueA@16 @67
  SetupCommitFileQueueW@16 @68
  SetupCopyOEMInfA@32 @71
  SetupCreateDiskSpaceListA@12 @73
  SetupCreateDiskSpaceListW@12 @74
  SetupDefaultQueueCallbackA@16 @78
  SetupDefaultQueueCallbackW@16 @79
  SetupDestroyDiskSpaceList@4 @82
  SetupDiBuildClassInfoListExW@24 @85
  SetupDiClassGuidsFromNameExW@24 @91
  SetupDiClassNameFromGuidExW@24 @94
  SetupDiCreateDeviceInfoList@8 @99
  SetupDiCreateDeviceInfoListExW@16 @100
  SetupDiDestroyDeviceInfoList@4 @105
  SetupDiEnumDeviceInfo@12 @108
  SetupDiEnumDeviceInterfaces@20 @109
  SetupDiGetClassDescriptionExW@24 @116
  SetupDiGetClassDevsA@16 @120
  SetupDiGetClassDevsExA@28 @121
  SetupDiGetClassDevsExW@28 @122
  SetupDiGetClassDevsW@16 @123
  SetupDiGetDeviceInfoListDetailA@8 @130
  SetupDiGetDeviceInfoListDetailW@8 @131
  SetupDiGetDeviceRegistryPropertyA@28 @139
  SetupDiGetDeviceInterfaceDetailA@24 @137
  SetupDiGetDeviceInterfaceDetailW@24 @138
  SetupDiOpenClassRegKeyExW@20 @161
  SetupFindFirstLineA@16 @183
  SetupFindFirstLineW@16 @184
  SetupFindNextLine@8 @185
  SetupFindNextMatchLineA@12 @186
  SetupFindNextMatchLineW@12 @187
  SetupGetBinaryField@20 @190
  SetupGetFieldCount@4 @191
  SetupGetFileQueueCount@12 @194
  SetupGetFileQueueFlags@8 @195
  SetupGetInfInformationA@20 @198
  SetupGetIntField@12 @200
  SetupGetLineByIndexA@16 @201
  SetupGetLineByIndexW@16 @202
  SetupGetLineCountA@8 @203
  SetupGetLineCountW@8 @204
  SetupGetLineTextA@28 @205
  SetupGetLineTextW@28 @206
  SetupGetMultiSzFieldA@20 @207
  SetupGetMultiSzFieldW@20 @208
  SetupGetStringFieldA@20 @215
  SetupGetStringFieldW@20 @216
  SetupInitDefaultQueueCallback@4 @219
  SetupInitDefaultQueueCallbackEx@20 @220
  SetupInitializeFileLogA@8 @221
  SetupInitializeFileLogW@8 @222
  SetupInstallFilesFromInfSectionA@24 @227
  SetupInstallFilesFromInfSectionW@24 @228
  SetupInstallFromInfSectionA@44 @229
  SetupInstallFromInfSectionW@44 @230
  SetupIterateCabinetA@16 @233
  SetupIterateCabinetW@16 @234
  SetupOpenAppendInfFileA@12 @237
  SetupOpenAppendInfFileW@12 @238
  SetupOpenFileQueue@0 @239
  SetupOpenInfFileA@16 @240
  SetupOpenInfFileW@16 @241
  SetupQuerySpaceRequiredOnDriveA@20 @257
  SetupQueueCopyA@36 @259
  SetupQueueCopyIndirectA@4 @260
  SetupQueueCopyIndirectW@4 @261
  SetupQueueCopySectionA@24 @262
  SetupQueueCopySectionW@24 @263
  SetupQueueCopyW@36 @264
  SetupQueueDefaultCopyA@24 @265
  SetupQueueDefaultCopyW@24 @266
  SetupQueueDeleteA@12 @267
  SetupQueueDeleteSectionA@16 @268
  SetupQueueDeleteSectionW@16 @269
  SetupQueueDeleteW@12 @270
  SetupQueueRenameA@20 @271
  SetupQueueRenameSectionA@16 @272
  SetupQueueRenameSectionW@16 @273
  SetupQueueRenameW@20 @274
  SetupScanFileQueueA@24 @288
  SetupScanFileQueueW@24 @289
  SetupSetDirectoryIdA@12 @290
  SetupSetDirectoryIdW@12 @293
  SetupSetFileQueueFlags@12 @294
  SetupTermDefaultQueueCallback@4 @299
  SetupTerminateFileLog@4 @300
