; File generated automatically from ddraw/ddraw.spec; do not edit!

LIBRARY ddraw.dll

EXPORTS
  DirectDrawCreate@12 @6
  DirectDrawCreateClipper@12 @7
  DirectDrawCreateEx@16 @8
  DirectDrawEnumerateA@8 @9
  DirectDrawEnumerateW@8 @12
  DirectDrawEnumerateExA@12 @10
  DirectDrawEnumerateExW@12 @11
  DllCanUnloadNow@0=DDRAW_DllCanUnloadNow@0 @13 PRIVATE
  DllGetClassObject@12=DDRAW_DllGetClassObject@12 @14 PRIVATE
  DllRegisterServer@0=DDRAW_DllRegisterServer@0 @15 PRIVATE
  DllUnregisterServer@0=DDRAW_DllUnregisterServer@0 @16 PRIVATE
