; File generated automatically from x11drv/x11drv.spec; do not edit!

LIBRARY x11drv.dll

EXPORTS
  Arc=X11DRV_Arc @3
  BitBlt=X11DRV_BitBlt @6
  ChoosePixelFormat=X11DRV_ChoosePixelFormat @8
  Chord=X11DRV_Chord @9
  CreateBitmap=X11DRV_CreateBitmap @11
  CreateDC=X11DRV_CreateDC @12
  CreateDIBSection=X11DRV_DIB_CreateDIBSection @13
  DeleteBitmap=X11DRV_DeleteBitmap @15
  DeleteDC=X11DRV_DeleteDC @16
  DescribePixelFormat=X11DRV_DescribePixelFormat @17
  Ellipse=X11DRV_Ellipse @19
  EnumDeviceFonts=X11DRV_EnumDeviceFonts @23
  ExtEscape=X11DRV_ExtEscape @25
  ExtFloodFill=X11DRV_ExtFloodFill @26
  ExtTextOut=X11DRV_ExtTextOut @27
  GetBitmapBits=X11DRV_GetBitmapBits @30
  GetCharWidth=X11DRV_GetCharWidth @31
  GetDCOrgEx=X11DRV_GetDCOrgEx @37
  GetDIBColorTable=X11DRV_GetDIBColorTable @38
  GetDIBits=X11DRV_GetDIBits @39
  GetDeviceCaps=X11DRV_GetDeviceCaps @40
  GetDeviceGammaRamp=X11DRV_GetDeviceGammaRamp @41
  GetNearestColor=X11DRV_GetNearestColor @46
  GetPixel=X11DRV_GetPixel @47
  GetPixelFormat=X11DRV_GetPixelFormat @48
  GetSystemPaletteEntries=X11DRV_GetSystemPaletteEntries @50
  GetTextExtentPoint=X11DRV_GetTextExtentPoint @51
  GetTextMetrics=X11DRV_GetTextMetrics @52
  LineTo=X11DRV_LineTo @56
  PaintRgn=X11DRV_PaintRgn @61
  PatBlt=X11DRV_PatBlt @62
  Pie=X11DRV_Pie @63
  PolyPolygon=X11DRV_PolyPolygon @64
  PolyPolyline=X11DRV_PolyPolyline @65
  Polygon=X11DRV_Polygon @66
  Polyline=X11DRV_Polyline @67
  RealizeDefaultPalette=X11DRV_RealizeDefaultPalette @68
  RealizePalette=X11DRV_RealizePalette @69
  Rectangle=X11DRV_Rectangle @70
  RoundRect=X11DRV_RoundRect @74
  SelectBitmap=X11DRV_SelectBitmap @76
  SelectBrush=X11DRV_SelectBrush @77
  SelectFont=X11DRV_SelectFont @78
  SelectPen=X11DRV_SelectPen @79
  SetBitmapBits=X11DRV_SetBitmapBits @80
  SetBkColor=X11DRV_SetBkColor @81
  SetDCBrushColor=X11DRV_SetDCBrushColor @85
  SetDCOrg=X11DRV_SetDCOrg @86
  SetDCPenColor=X11DRV_SetDCPenColor @87
  SetDIBColorTable=X11DRV_SetDIBColorTable @88
  SetDIBits=X11DRV_SetDIBits @89
  SetDIBitsToDevice=X11DRV_SetDIBitsToDevice @90
  SetDeviceClipping=X11DRV_SetDeviceClipping @91
  SetDeviceGammaRamp=X11DRV_SetDeviceGammaRamp @92
  SetPixel=X11DRV_SetPixel @95
  SetPixelFormat=X11DRV_SetPixelFormat @96
  SetTextColor=X11DRV_SetTextColor @98
  StretchBlt=X11DRV_StretchBlt @105
  SwapBuffers=X11DRV_SwapBuffers @106
  InitKeyboard=X11DRV_InitKeyboard @53
  VkKeyScanEx=X11DRV_VkKeyScanEx @110
  MapVirtualKeyEx=X11DRV_MapVirtualKeyEx @59
  GetKeyNameText=X11DRV_GetKeyNameText @42
  ToUnicodeEx=X11DRV_ToUnicodeEx @108
  GetKeyboardLayoutList=X11DRV_GetKeyboardLayoutList @44
  GetKeyboardLayout=X11DRV_GetKeyboardLayout @43
  GetKeyboardLayoutName=X11DRV_GetKeyboardLayoutName @45
  LoadKeyboardLayout=X11DRV_LoadKeyboardLayout @57
  ActivateKeyboardLayout=X11DRV_ActivateKeyboardLayout @2
  UnloadKeyboardLayout=X11DRV_UnloadKeyboardLayout @109
  Beep=X11DRV_Beep @5
  InitMouse=X11DRV_InitMouse @54
  SetCursor=X11DRV_SetCursor @83
  GetCursorPos=X11DRV_GetCursorPos @35
  SetCursorPos=X11DRV_SetCursorPos @84
  GetScreenSaveActive=X11DRV_GetScreenSaveActive @49
  SetScreenSaveActive=X11DRV_SetScreenSaveActive @97
  ChangeDisplaySettingsExW=X11DRV_ChangeDisplaySettingsExW @7
  EnumDisplaySettingsExW=X11DRV_EnumDisplaySettingsExW @24
  AcquireClipboard=X11DRV_AcquireClipboard @1
  CountClipboardFormats=X11DRV_CountClipboardFormats @10
  CreateWindow=X11DRV_CreateWindow @14
  DestroyWindow=X11DRV_DestroyWindow @18
  EmptyClipboard=X11DRV_EmptyClipboard @20
  EndClipboardUpdate=X11DRV_EndClipboardUpdate @21
  EnumClipboardFormats=X11DRV_EnumClipboardFormats @22
  ForceWindowRaise=X11DRV_ForceWindowRaise @28
  GetClipboardData=X11DRV_GetClipboardData @32
  GetClipboardFormatName=X11DRV_GetClipboardFormatName @33
  GetDC=X11DRV_GetDC @36
  IsClipboardFormatAvailable=X11DRV_IsClipboardFormatAvailable @55
  MsgWaitForMultipleObjectsEx=X11DRV_MsgWaitForMultipleObjectsEx @60
  RegisterClipboardFormat=X11DRV_RegisterClipboardFormat @71
  ReleaseDC=X11DRV_ReleaseDC @72
  ResetSelectionOwner=X11DRV_ResetSelectionOwner @73
  ScrollWindowEx=X11DRV_ScrollWindowEx @75
  SetClipboardData=X11DRV_SetClipboardData @82
  SetFocus=X11DRV_SetFocus @93
  SetParent=X11DRV_SetParent @94
  SetWindowIcon=X11DRV_SetWindowIcon @99
  SetWindowPos=X11DRV_SetWindowPos @100
  SetWindowRgn=X11DRV_SetWindowRgn @101
  SetWindowStyle=X11DRV_SetWindowStyle @102
  SetWindowText=X11DRV_SetWindowText @103
  ShowWindow=X11DRV_ShowWindow @104
  SysCommandSizeMove=X11DRV_SysCommandSizeMove @107
  AttachEventQueueToTablet=X11DRV_AttachEventQueueToTablet @4
  GetCurrentPacket=X11DRV_GetCurrentPacket @34
  LoadTabletInfo=X11DRV_LoadTabletInfo @58
  WTInfoA=X11DRV_WTInfoA @111
  wine_tsx11_lock @112
  wine_tsx11_unlock @113
  ForceXIMReset=X11DRV_ForceXIMReset @29
