; File generated automatically from dmsynth/dmsynth.spec; do not edit!

LIBRARY dmsynth.dll

EXPORTS
  DllCanUnloadNow@0=DMSYNTH_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMSYNTH_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMSYNTH_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMSYNTH_DllUnregisterServer@0 @4 PRIVATE
