; File generated automatically from d3d9/d3d9.spec; do not edit!

LIBRARY d3d9.dll

EXPORTS
  D3D9GetSWInfo@0 @1
  DebugSetMute@0 @2
  Direct3DCreate9@4 @3
  ValidatePixelShader@8 @4
  ValidateVertexShader@8 @5
