; File generated automatically from urlmon/urlmon.spec; do not edit!

LIBRARY urlmon.dll

EXPORTS
  CoInternetCombineUrl@28 @8
  CoInternetCompareUrl@12 @9
  CoInternetGetSession@12 @14
  CoInternetQueryInfo@28 @16
  CreateAsyncBindCtx@16 @20
  CreateAsyncBindCtxEx@24 @21
  CreateURLMoniker@12 @23
  DllCanUnloadNow@0=URLMON_DllCanUnloadNow@0 @24 PRIVATE
  DllGetClassObject@12=URLMON_DllGetClassObject@12 @25 PRIVATE
  DllInstall@8=URLMON_DllInstall@8 @26
  DllRegisterServer@0=URLMON_DllRegisterServer@0 @27 PRIVATE
  DllRegisterServerEx@0=URLMON_DllRegisterServerEx@0 @28 PRIVATE
  DllUnregisterServer@0=URLMON_DllUnregisterServer@0 @29 PRIVATE
  Extract@8=cabinet.Extract @30
  FindMimeFromData@32 @34
  IsAsyncMoniker@4 @46
  MkParseDisplayNameEx@16=ole32.MkParseDisplayName @50
  ObtainUserAgentString@12 @51
  RegisterBindStatusCallback@16 @53
  ReleaseBindInfo@4 @57
  RevokeBindStatusCallback@8 @58
  URLDownloadToFileA@20 @64
  URLDownloadToFileW@20 @65
  UrlMkSetSessionOption@16 @75
