; File generated automatically from dxdiagn/dxdiagn.spec; do not edit!

LIBRARY dxdiagn.dll

EXPORTS
  DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0 @4 PRIVATE
