; File generated automatically from ctl3d/ctl3d32.spec; do not edit!

LIBRARY ctl3d32.dll

EXPORTS
  Ctl3dGetVer@0 @1
  Ctl3dSubclassDlg@8 @2
  Ctl3dSubclassCtl@4 @3
  Ctl3dCtlColor@8 @4
  Ctl3dEnabled@0 @5
  Ctl3dColorChange@0 @6
  BtnWndProc3d@16 @7
  EditWndProc3d@16 @8
  ListWndProc3d@16 @9
  ComboWndProc3d@16 @10
  StaticWndProc3d@16 @11
  Ctl3dRegister@4 @12
  Ctl3dUnregister@4 @13
  Ctl3dAutoSubclass@4 @16
  Ctl3dDlgProc@16 @17
  Ctl3dCtlColorEx@12 @18
  Ctl3dDlgFramePaint@16 @20
  Ctl3dSubclassDlgEx@8 @21
  Ctl3dWinIniChange@0 @22
  Ctl3dIsAutoSubclass@0 @23
  Ctl3dUnAutoSubclass@0 @24
  Ctl3dSubclassCtlEx@8 @25
  Ctl3dUnsubclassCtl@4 @26
  Ctl3dAutoSubclassEx@8 @27
