; File generated automatically from unicows/unicows.spec; do not edit!

LIBRARY unicows.dll

EXPORTS
  AddAtomW@4 @2
  AddFontResourceW@4 @3
  AddJobW@20 @4
  AddPrinterDriverW@12 @9
  AddPrinterW@12 @10
  AppendMenuW@16 @12
  BeginUpdateResourceA@8 @13
  BeginUpdateResourceW@8 @14
  BroadcastSystemMessageW@20 @15
  BuildCommDCBAndTimeoutsW@12 @16
  BuildCommDCBW@8 @17
  CallMsgFilterW@8 @18
  CallNamedPipeW@28 @19
  CallWindowProcA@20 @20
  CallWindowProcW@20 @21
  ChangeDisplaySettingsExW@20 @22
  ChangeDisplaySettingsW@8 @23
  ChangeMenuW@20 @24
  CharLowerBuffW@8 @25
  CharLowerW@4 @26
  CharNextW@4 @27
  CharPrevW@8 @28
  CharToOemBuffW@12 @29
  CharToOemW@8 @30
  CharUpperBuffW@8 @31
  CharUpperW@4 @32
  ChooseColorW@4 @33
  ChooseFontW@4 @34
  CommConfigDialogW@12 @35
  CompareStringW@24 @36
  CopyAcceleratorTableW@12 @38
  CopyFileExW@24 @40
  CopyFileW@12 @41
  CopyMetaFileW@8 @42
  CreateAcceleratorTableW@8 @43
  CreateColorSpaceW@4 @44
  CreateDCW@16 @45
  CreateDialogIndirectParamW@20 @46
  CreateDialogParamW@20 @47
  CreateDirectoryExW@12 @48
  CreateDirectoryW@8 @49
  CreateEnhMetaFileW@16 @50
  CreateEventW@16 @51
  CreateFileMappingW@24 @52
  CreateFileW@28 @53
  CreateFontIndirectW@4 @54
  CreateFontW@56 @55
  CreateICW@16 @56
  CreateMDIWindowW@40 @57
  CreateMailslotW@16 @58
  CreateMetaFileW@4 @59
  CreateMutexW@12 @60
  CreateNamedPipeW@32 @61
  CreateProcessW@40 @62
  CreateScalableFontResourceW@16 @63
  CreateSemaphoreW@16 @64
  CreateWaitableTimerW@12 @66
  CreateWindowExW@48 @67
  CryptAcquireContextW@20 @68
  CryptEnumProviderTypesW@24 @69
  CryptEnumProvidersW@24 @70
  CryptGetDefaultProviderW@20 @71
  CryptSetProviderExW@16 @72
  CryptSetProviderW@8 @73
  CryptSignHashW@24 @74
  CryptVerifySignatureW@24 @75
  DdeConnect@16 @76
  DdeConnectList@20 @77
  DdeCreateStringHandleW@12 @78
  DdeInitializeW@16 @79
  DdeQueryConvInfo@12 @80
  DdeQueryStringW@20 @81
  DefDlgProcW@16 @82
  DefFrameProcW@20 @83
  DefMDIChildProcW@16 @84
  DefWindowProcW@16 @85
  DeleteFileW@4 @86
  DeviceCapabilitiesW@20 @92
  DialogBoxIndirectParamW@20 @93
  DialogBoxParamW@20 @94
  DispatchMessageW@4 @95
  DlgDirListComboBoxW@20 @96
  DlgDirListW@20 @97
  DlgDirSelectComboBoxExW@16 @98
  DlgDirSelectExW@16 @99
  DocumentPropertiesW@24 @100
  DragQueryFileW@16 @101
  DrawStateW@40 @102
  DrawTextExW@24 @103
  DrawTextW@20 @104
  EnableWindow@8 @105
  EndUpdateResourceA@8 @106
  EndUpdateResourceW@8 @107
  EnumClipboardFormats@4 @110
  EnumDateFormatsW@12 @112
  EnumDisplayDevicesW@16 @113
  EnumDisplaySettingsExW@16 @114
  EnumDisplaySettingsW@12 @115
  EnumFontFamiliesExW@20 @116
  EnumFontFamiliesW@16 @117
  EnumFontsW@16 @118
  EnumPrinterDriversW@28 @124
  EnumPrintersW@28 @125
  EnumPropsA@8 @126
  EnumPropsExA@12 @127
  EnumPropsExW@12 @128
  EnumPropsW@8 @129
  EnumSystemCodePagesW@8 @130
  EnumSystemLocalesW@8 @131
  EnumTimeFormatsW@12 @132
  ExpandEnvironmentStringsW@12 @134
  ExtTextOutW@32 @135
  ExtractIconExW@20 @136
  ExtractIconW@12 @137
  FatalAppExitW@8 @138
  FillConsoleOutputCharacterW@20 @139
  FindAtomW@4 @140
  FindExecutableW@12 @141
  FindFirstChangeNotificationW@12 @142
  FindFirstFileW@8 @143
  FindNextFileW@8 @144
  FindResourceExW@16 @145
  FindResourceW@12 @146
  FindTextW@4 @147
  FindWindowExW@16 @148
  FindWindowW@8 @149
  FormatMessageW@28 @150
  FreeEnvironmentStringsW@4 @152
  GetAtomNameW@12 @154
  GetCPInfo@8 @155
  GetCPInfoExW@12 @156
  GetCalendarInfoW@24 @157
  GetCharABCWidthsFloatW@16 @158
  GetCharABCWidthsW@16 @159
  GetCharWidth32W@16 @160
  GetCharWidthFloatW@16 @161
  GetCharWidthW@16 @162
  GetCharacterPlacementW@24 @163
  GetClassInfoExW@12 @164
  GetClassInfoW@12 @165
  GetClassLongW@8 @166
  GetClassNameW@12 @167
  GetClipboardData@4 @168
  GetClipboardFormatNameW@12 @169
  GetComputerNameW@8 @170
  GetConsoleTitleW@8 @171
  GetCurrencyFormatW@24 @172
  GetCurrentDirectoryW@8 @173
  GetDateFormatW@24 @175
  GetDefaultCommConfigW@12 @176
  GetDiskFreeSpaceExW@16 @177
  GetDiskFreeSpaceW@20 @178
  GetDlgItemTextW@16 @179
  GetDriveTypeW@4 @180
  GetEnhMetaFileDescriptionW@12 @181
  GetEnhMetaFileW@4 @182
  GetEnvironmentStringsW@0 @183
  GetEnvironmentVariableW@12 @184
  GetFileAttributesExW@12 @185
  GetFileAttributesW@4 @186
  GetFileTitleW@12 @187
  GetFileVersionInfoSizeW@8 @188
  GetFileVersionInfoW@16 @189
  GetFullPathNameW@16 @190
  GetGlyphOutlineW@28 @191
  GetKerningPairsW@12 @194
  GetKeyNameTextW@12 @195
  GetKeyboardLayoutNameW@4 @196
  GetLocaleInfoW@16 @197
  GetLogicalDriveStringsW@8 @199
  GetLongPathNameW@12 @200
  GetMenuItemInfoW@16 @201
  GetMenuStringW@20 @202
  GetMessageW@16 @203
  GetMetaFileW@4 @204
  GetModuleFileNameW@12 @205
  GetModuleHandleW@4 @206
  GetMonitorInfoW@8 @207
  GetNamedPipeHandleStateW@28 @208
  GetNumberFormatW@24 @209
  GetObjectW@12 @210
  GetOpenFileNamePreviewW@4 @211
  GetOpenFileNameW@4 @212
  GetOutlineTextMetricsW@12 @213
  GetPrinterDataW@24 @215
  GetPrinterDriverDirectoryW@24 @216
  GetPrinterDriverW@24 @217
  GetPrinterW@20 @218
  GetPrivateProfileIntW@16 @219
  GetPrivateProfileSectionNamesW@12 @220
  GetPrivateProfileSectionW@16 @221
  GetPrivateProfileStringW@24 @222
  GetPrivateProfileStructW@20 @223
  GetProcAddress@8 @224
  GetProfileIntW@12 @225
  GetProfileSectionW@12 @226
  GetProfileStringW@20 @227
  GetPropA@8 @228
  GetPropW@8 @229
  GetSaveFileNamePreviewW@4 @231
  GetSaveFileNameW@4 @232
  GetShortPathNameW@12 @233
  GetStartupInfoW@4 @234
  GetStringTypeExW@20 @236
  GetStringTypeW@16 @237
  GetSystemDirectoryW@8 @238
  GetSystemWindowsDirectoryW@8 @239
  GetTabbedTextExtentW@20 @240
  GetTempFileNameW@16 @241
  GetTempPathW@8 @242
  GetTextExtentExPointW@28 @243
  GetTextExtentPoint32W@16 @244
  GetTextExtentPointW@16 @245
  GetTextFaceW@12 @246
  GetTextMetricsW@8 @247
  GetTimeFormatW@24 @248
  GetUserNameW@8 @249
  GetVersionExW@4 @250
  GetVolumeInformationW@32 @251
  GetWindowLongA@8 @252
  GetWindowLongW@8 @253
  GetWindowModuleFileNameW@12 @254
  GetWindowTextLengthW@4 @255
  GetWindowTextW@12 @256
  GetWindowsDirectoryW@8 @257
  GlobalAddAtomW@4 @258
  GlobalFindAtomW@4 @259
  GlobalGetAtomNameW@12 @260
  GrayStringW@36 @261
  InsertMenuItemW@16 @264
  InsertMenuW@20 @265
  IsBadStringPtrW@8 @266
  IsCharAlphaNumericW@4 @267
  IsCharAlphaW@4 @268
  IsCharLowerW@4 @269
  IsCharUpperW@4 @270
  IsClipboardFormatAvailable@4 @271
  IsDialogMessageW@8 @273
  IsTextUnicode@12 @274
  IsValidCodePage@4 @275
  IsWindowUnicode@4 @276
  LCMapStringW@24 @277
  LoadAcceleratorsW@8 @278
  LoadBitmapW@8 @279
  LoadCursorFromFileW@4 @280
  LoadCursorW@8 @281
  LoadIconW@8 @282
  LoadImageW@24 @283
  LoadKeyboardLayoutW@8 @284
  LoadLibraryExW@12 @285
  LoadLibraryW@4 @286
  LoadMenuIndirectW@4 @287
  LoadMenuW@8 @288
  LoadStringW@16 @289
  MCIWndCreateW @290
  MapVirtualKeyExW@12 @291
  MapVirtualKeyW@8 @292
  MessageBoxExW@20 @293
  MessageBoxIndirectW@4 @294
  MessageBoxW@16 @295
  ModifyMenuW@20 @296
  MoveFileW@8 @297
  MultiByteToWideChar@24 @298
  MultinetGetConnectionPerformanceW@8 @299
  OemToCharBuffW@12 @300
  OemToCharW@8 @301
  OleUIAddVerbMenuW@36 @302
  OleUIBusyW@4 @303
  OleUIChangeIconW@4 @304
  OleUIChangeSourceW@4 @305
  OleUIConvertW@4 @306
  OleUIEditLinksW@4 @307
  OleUIInsertObjectW@4 @308
  OleUIObjectPropertiesW@4 @309
  OleUIPasteSpecialW@4 @310
  OleUIPromptUserW @311
  OleUIUpdateLinksW@16 @312
  OpenEventW@12 @313
  OpenFileMappingW@12 @314
  OpenMutexW@12 @315
  OpenPrinterW@12 @316
  OpenSemaphoreW@12 @317
  OpenWaitableTimerW@12 @318
  OutputDebugStringW@4 @319
  PageSetupDlgW@4 @320
  PeekConsoleInputW@16 @321
  PeekMessageW@20 @322
  PlaySoundW@12 @323
  PolyTextOutW@12 @324
  PostMessageW@16 @325
  PostThreadMessageW@16 @326
  PrintDlgW@4 @327
  QueryDosDeviceW@12 @330
  RasDeleteEntryW@8 @334
  RasEnumConnectionsW@12 @338
  RasEnumDevicesW@12 @339
  RasEnumEntriesW@20 @340
  RasSetEntryPropertiesW@24 @349
  ReadConsoleInputW@16 @352
  ReadConsoleOutputCharacterW@20 @353
  ReadConsoleOutputW@20 @354
  ReadConsoleW@20 @355
  RegConnectRegistryW@12 @356
  RegCreateKeyExW@36 @357
  RegCreateKeyW@12 @358
  RegDeleteKeyW@8 @359
  RegDeleteValueW@8 @360
  RegEnumKeyExW@32 @361
  RegEnumKeyW@16 @362
  RegEnumValueW@32 @363
  RegLoadKeyW@12 @364
  RegOpenKeyExW@20 @365
  RegOpenKeyW@12 @366
  RegQueryInfoKeyW@48 @367
  RegQueryMultipleValuesW@20 @368
  RegQueryValueExW@24 @369
  RegQueryValueW@16 @370
  RegReplaceKeyW@16 @371
  RegSaveKeyW@12 @372
  RegSetValueExW@24 @373
  RegSetValueW@20 @374
  RegUnLoadKeyW@8 @375
  RegisterClassExW@4 @376
  RegisterClassW@4 @377
  RegisterClipboardFormatW@4 @378
  RegisterWindowMessageW@4 @380
  RemoveDirectoryW@4 @381
  RemoveFontResourceW@4 @382
  RemovePropA@8 @383
  RemovePropW@8 @384
  ReplaceTextW@4 @385
  ResetDCW@8 @386
  ResetPrinterW@8 @387
  SHBrowseForFolderW@4 @388
  SHChangeNotify@16 @389
  SHFileOperationW@4 @390
  SHGetFileInfoW@20 @391
  SHGetPathFromIDListW@8 @393
  ScrollConsoleScreenBufferW@20 @394
  SearchPathW@24 @395
  SendDlgItemMessageW@20 @396
  SendMessageCallbackW@24 @397
  SendMessageTimeoutW@28 @398
  SendMessageW@16 @399
  SendNotifyMessageW@16 @400
  SetCalendarInfoW@16 @401
  SetClassLongW@12 @402
  SetComputerNameW@4 @403
  SetConsoleTitleW@4 @404
  SetCurrentDirectoryW@4 @405
  SetDefaultCommConfigW@12 @406
  SetDlgItemTextW@12 @407
  SetEnvironmentVariableW@8 @408
  SetFileAttributesW@8 @409
  SetJobW@20 @411
  SetLocaleInfoW@12 @412
  SetMenuItemInfoW@16 @413
  SetPrinterDataW@20 @414
  SetPrinterW@16 @415
  SetPropA@12 @416
  SetPropW@12 @417
  SetVolumeLabelW@8 @418
  SetWindowLongA@12 @419
  SetWindowLongW@12 @420
  SetWindowTextW@8 @421
  SetWindowsHookExW@16 @422
  SetWindowsHookW@8 @423
  ShellAboutW@16 @424
  ShellExecuteExW@4 @425
  ShellExecuteW@24 @426
  Shell_NotifyIconW@8 @427
  StartDocPrinterW@12 @428
  StartDocW@8 @429
  SystemParametersInfoW@16 @430
  TabbedTextOutW@32 @431
  TextOutW@20 @432
  TranslateAcceleratorW@12 @433
  UnregisterClassW@8 @434
  UpdateResourceA@24 @436
  UpdateResourceW@24 @437
  VerFindFileW@32 @438
  VerInstallFileW@32 @439
  VerLanguageNameW@12 @440
  VerQueryValueW@16 @441
  VkKeyScanExW@8 @442
  VkKeyScanW@4 @443
  WNetAddConnection2W@16 @444
  WNetAddConnection3W@20 @445
  WNetAddConnectionW@12 @446
  WNetCancelConnection2W@12 @447
  WNetCancelConnectionW@8 @448
  WNetConnectionDialog1W@4 @449
  WNetDisconnectDialog1W@4 @450
  WNetEnumResourceW@16 @451
  WNetGetConnectionW@12 @452
  WNetGetLastErrorW@20 @453
  WNetGetNetworkInformationW@8 @454
  WNetGetProviderNameW@12 @455
  WNetGetResourceInformationW@16 @456
  WNetGetResourceParentW@12 @457
  WNetGetUniversalNameW@16 @458
  WNetGetUserW@12 @459
  WNetOpenEnumW@20 @460
  WNetUseConnectionW@32 @461
  WaitNamedPipeW@8 @462
  WideCharToMultiByte@32 @463
  WinHelpW@16 @464
  WriteConsoleInputW@16 @465
  WriteConsoleOutputCharacterW@20 @466
  WriteConsoleOutputW@20 @467
  WriteConsoleW@20 @468
  WritePrivateProfileSectionW@12 @469
  WritePrivateProfileStringW@16 @470
  WritePrivateProfileStructW@20 @471
  WriteProfileSectionW@8 @472
  WriteProfileStringW@12 @473
  auxGetDevCapsW@12 @475
  capCreateCaptureWindowW@32 @476
  capGetDriverDescriptionW@20 @477
  joyGetDevCapsW@12 @478
  lstrcatW@8 @479
  lstrcmpW@8 @480
  lstrcmpiW@8 @481
  lstrcpyW@8 @482
  lstrcpynW@12 @483
  lstrlenW@4 @484
  mciGetDeviceIDW@4 @485
  mciGetErrorStringW@12 @486
  mciSendCommandW@16 @487
  mciSendStringW@16 @488
  midiInGetDevCapsW@12 @489
  midiInGetErrorTextW@12 @490
  midiOutGetDevCapsW@12 @491
  midiOutGetErrorTextW@12 @492
  mixerGetControlDetailsW@12 @493
  mixerGetDevCapsW@12 @494
  mixerGetLineControlsW@12 @495
  mixerGetLineInfoW@12 @496
  mmioInstallIOProcW@12 @497
  mmioOpenW@12 @498
  mmioRenameW@16 @499
  mmioStringToFOURCCW@8 @500
  sndPlaySoundW@8 @501
  waveInGetDevCapsW@12 @502
  waveInGetErrorTextW@12 @503
  waveOutGetDevCapsW@12 @504
  waveOutGetErrorTextW@12 @505
  wsprintfW @506
  wvsprintfW@12 @507
