; File generated automatically from mapi32/mapi32.spec; do not edit!

LIBRARY mapi32.dll

EXPORTS
  MAPILogonEx@20 @10
  MAPILogonEx@20@20=MAPILogonEx@20 @11
  MAPIAllocateBuffer@8 @12
  MAPIAllocateBuffer@8@8=MAPIAllocateBuffer@8 @13
  MAPIAllocateMore@12 @14
  MAPIAllocateMore@12@12=MAPIAllocateMore@12 @15
  MAPIFreeBuffer@4 @16
  MAPIFreeBuffer@4@4=MAPIFreeBuffer@4 @17
  MAPIInitialize@4 @20
  MAPIInitialize@4@4=MAPIInitialize@4 @21
  MAPIUninitialize@0 @22
  MAPIUninitialize@0@0=MAPIUninitialize@0 @23
  ScInitMapiUtil@4@4=ScInitMapiUtil@4 @33
  DeinitMapiUtil@0@0=DeinitMapiUtil@0 @34
  HrThisThreadAdviseSink@8@8=HrThisThreadAdviseSink@8 @42
  SwapPlong@8@8=SwapPlong@8 @47
  SwapPword@8@8=SwapPword@8 @48
  MNLS_lstrlenW@4@4=MNLS_lstrlenW@4 @62
  MNLS_lstrcmpW@8@8=MNLS_lstrcmpW@8 @63
  MNLS_lstrcpyW@8@8=MNLS_lstrcpyW@8 @64
  MNLS_CompareStringW@24@12=MNLS_CompareStringW@12 @65
  MNLS_MultiByteToWideChar@24@24=kernel32.MultiByteToWideChar @66
  MNLS_WideCharToMultiByte@32@32=kernel32.WideCharToMultiByte @67
  MNLS_IsBadStringPtrW@8@8=kernel32.IsBadStringPtrW @68
  PropCopyMore@16@16=PropCopyMore@16 @76
  UlPropSize@4@4=UlPropSize@4 @77
  FPropContainsProp@12@12=FPropContainsProp@12 @78
  FPropCompareProp@12@12=FPropCompareProp@12 @79
  LPropCompareProp@8@8=LPropCompareProp@8 @80
  FtAddFt@16@16=MAPI32_FtAddFt@16 @121
  FtSubFt@16@16=MAPI32_FtSubFt@16 @123
  FtMulDw@12@12=MAPI32_FtMulDw@12 @124
  FtMulDwDw@8@8=MAPI32_FtMulDwDw@8 @125
  FtNegFt@8@8=MAPI32_FtNegFt@8 @126
  UlAddRef@4@4=UlAddRef@4 @128
  UlRelease@4@4=UlRelease@4 @129
  SzFindCh@8@8=shlwapi.StrChrA @130
  SzFindLastCh@8@12=shlwapi.StrRChrA @131
  SzFindSz@8@8=shlwapi.StrStrA @132
  PpropFindProp@12@12=PpropFindProp@12 @138
  OpenStreamOnFile@24@24=OpenStreamOnFile@24 @147
  OpenStreamOnFile@24 @148
  ScCountProps@12@12=ScCountProps@12 @170
  ScCopyProps@16@16=ScCopyProps@16 @171
  ScRelocProps@20@20=ScRelocProps@20 @172
  LpValFindProp@12@12=LpValFindProp@12 @173
  FBadRglpszA@8@8=FBadRglpszA@8 @175
  FBadRglpszW@8@8=FBadRglpszW@8 @176
  FBadRowSet@4@4=FBadRowSet@4 @177
  FBadPropTag@4@4=FBadPropTag@4 @179
  FBadRow@4@4=FBadRow@4 @180
  FBadProp@4@4=FBadProp@4 @181
  FBadColumnSet@4@4=FBadColumnSet@4 @182
  MAPILogon@24 @209
  cmc_query_configuration@16 @235
