; File generated automatically from dmscript/dmscript.spec; do not edit!

LIBRARY dmscript.dll

EXPORTS
  DllCanUnloadNow@0=DMSCRIPT_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMSCRIPT_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMSCRIPT_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMSCRIPT_DllUnregisterServer@0 @4 PRIVATE
