; File generated automatically from shfolder/shfolder.spec; do not edit!

LIBRARY shfolder.dll

EXPORTS
  SHGetFolderPathA@20=shell32.SHGetFolderPathA @1
  SHGetFolderPathW@20=shell32.SHGetFolderPathW @2
