; File generated automatically from mshtml/mshtml.spec; do not edit!

LIBRARY mshtml.dll

EXPORTS
  DllCanUnloadNow@0=MSHTML_DllCanUnloadNow@0 @2 PRIVATE
  DllGetClassObject@12=MSHTML_DllGetClassObject@12 @4 PRIVATE
  RunHTMLApplication@16 @11
