( cd usr/bin ; rm -rf wineg++ )
( cd usr/bin ; ln -sf winegcc wineg++ )
( cd usr/bin ; rm -rf winecpp )
( cd usr/bin ; ln -sf winegcc winecpp )
( cd usr/lib/wine ; rm -rf msvideo.dll.so )
( cd usr/lib/wine ; ln -sf msvfw32.dll.so msvideo.dll.so )
( cd usr/lib/wine ; rm -rf toolhelp.dll.so )
( cd usr/lib/wine ; ln -sf kernel32.dll.so toolhelp.dll.so )
( cd usr/lib/wine ; rm -rf keyboard.drv.so )
( cd usr/lib/wine ; ln -sf user32.dll.so keyboard.drv.so )
( cd usr/lib/wine ; rm -rf winnls.dll.so )
( cd usr/lib/wine ; ln -sf winnls32.dll.so winnls.dll.so )
( cd usr/lib/wine ; rm -rf setupx.dll.so )
( cd usr/lib/wine ; ln -sf setupapi.dll.so setupx.dll.so )
( cd usr/lib/wine ; rm -rf olecli.dll.so )
( cd usr/lib/wine ; ln -sf olecli32.dll.so olecli.dll.so )
( cd usr/lib/wine ; rm -rf dispdib.dll.so )
( cd usr/lib/wine ; ln -sf gdi32.dll.so dispdib.dll.so )
( cd usr/lib/wine ; rm -rf win87em.dll.so )
( cd usr/lib/wine ; ln -sf kernel32.dll.so win87em.dll.so )
( cd usr/lib/wine ; rm -rf winaspi.dll.so )
( cd usr/lib/wine ; ln -sf wnaspi32.dll.so winaspi.dll.so )
( cd usr/lib/wine ; rm -rf wintab.dll.so )
( cd usr/lib/wine ; ln -sf wintab32.dll.so wintab.dll.so )
( cd usr/lib/wine ; rm -rf msacm.dll.so )
( cd usr/lib/wine ; ln -sf msacm32.dll.so msacm.dll.so )
( cd usr/lib/wine ; rm -rf storage.dll.so )
( cd usr/lib/wine ; ln -sf ole32.dll.so storage.dll.so )
( cd usr/lib/wine ; rm -rf wprocs.dll.so )
( cd usr/lib/wine ; ln -sf winedos.dll.so wprocs.dll.so )
( cd usr/lib/wine ; rm -rf ole2nls.dll.so )
( cd usr/lib/wine ; ln -sf ole32.dll.so ole2nls.dll.so )
( cd usr/lib/wine ; rm -rf ddeml.dll.so )
( cd usr/lib/wine ; ln -sf user32.dll.so ddeml.dll.so )
( cd usr/lib/wine ; rm -rf compobj.dll.so )
( cd usr/lib/wine ; ln -sf ole32.dll.so compobj.dll.so )
( cd usr/lib/wine ; rm -rf win32s16.dll.so )
( cd usr/lib/wine ; ln -sf w32skrnl.dll.so win32s16.dll.so )
( cd usr/lib/wine ; rm -rf typelib.dll.so )
( cd usr/lib/wine ; ln -sf oleaut32.dll.so typelib.dll.so )
( cd usr/lib/wine ; rm -rf ole2conv.dll.so )
( cd usr/lib/wine ; ln -sf ole32.dll.so ole2conv.dll.so )
( cd usr/lib/wine ; rm -rf commdlg.dll.so )
( cd usr/lib/wine ; ln -sf comdlg32.dll.so commdlg.dll.so )
( cd usr/lib/wine ; rm -rf ole2prox.dll.so )
( cd usr/lib/wine ; ln -sf ole32.dll.so ole2prox.dll.so )
( cd usr/lib/wine ; rm -rf user.exe.so )
( cd usr/lib/wine ; ln -sf user32.dll.so user.exe.so )
( cd usr/lib/wine ; rm -rf mmsystem.dll.so )
( cd usr/lib/wine ; ln -sf winmm.dll.so mmsystem.dll.so )
( cd usr/lib/wine ; rm -rf olesvr.dll.so )
( cd usr/lib/wine ; ln -sf olesvr32.dll.so olesvr.dll.so )
( cd usr/lib/wine ; rm -rf sound.dll.so )
( cd usr/lib/wine ; ln -sf winmm.dll.so sound.dll.so )
( cd usr/lib/wine ; rm -rf display.drv.so )
( cd usr/lib/wine ; ln -sf user32.dll.so display.drv.so )
( cd usr/lib/wine ; rm -rf stress.dll.so )
( cd usr/lib/wine ; ln -sf kernel32.dll.so stress.dll.so )
( cd usr/lib/wine ; rm -rf wineps16.drv.so )
( cd usr/lib/wine ; ln -sf wineps.dll.so wineps16.drv.so )
( cd usr/lib/wine ; rm -rf krnl386.exe.so )
( cd usr/lib/wine ; ln -sf kernel32.dll.so krnl386.exe.so )
( cd usr/lib/wine ; rm -rf ctl3d.dll.so )
( cd usr/lib/wine ; ln -sf ctl3d32.dll.so ctl3d.dll.so )
( cd usr/lib/wine ; rm -rf w32sys.dll.so )
( cd usr/lib/wine ; ln -sf w32skrnl.dll.so w32sys.dll.so )
( cd usr/lib/wine ; rm -rf comm.drv.so )
( cd usr/lib/wine ; ln -sf kernel32.dll.so comm.drv.so )
( cd usr/lib/wine ; rm -rf ole2.dll.so )
( cd usr/lib/wine ; ln -sf ole32.dll.so ole2.dll.so )
( cd usr/lib/wine ; rm -rf windebug.dll.so )
( cd usr/lib/wine ; ln -sf kernel32.dll.so windebug.dll.so )
( cd usr/lib/wine ; rm -rf ole2thk.dll.so )
( cd usr/lib/wine ; ln -sf ole32.dll.so ole2thk.dll.so )
( cd usr/lib/wine ; rm -rf wing.dll.so )
( cd usr/lib/wine ; ln -sf gdi32.dll.so wing.dll.so )
( cd usr/lib/wine ; rm -rf ver.dll.so )
( cd usr/lib/wine ; ln -sf version.dll.so ver.dll.so )
( cd usr/lib/wine ; rm -rf system.drv.so )
( cd usr/lib/wine ; ln -sf kernel32.dll.so system.drv.so )
( cd usr/lib/wine ; rm -rf shell.dll.so )
( cd usr/lib/wine ; ln -sf shell32.dll.so shell.dll.so )
( cd usr/lib/wine ; rm -rf mouse.drv.so )
( cd usr/lib/wine ; ln -sf user32.dll.so mouse.drv.so )
( cd usr/lib/wine ; rm -rf ctl3dv2.dll.so )
( cd usr/lib/wine ; ln -sf ctl3d32.dll.so ctl3dv2.dll.so )
( cd usr/lib/wine ; rm -rf rasapi16.dll.so )
( cd usr/lib/wine ; ln -sf rasapi32.dll.so rasapi16.dll.so )
( cd usr/lib/wine ; rm -rf lzexpand.dll.so )
( cd usr/lib/wine ; ln -sf lz32.dll.so lzexpand.dll.so )
( cd usr/lib/wine ; rm -rf winsock.dll.so )
( cd usr/lib/wine ; ln -sf ws2_32.dll.so winsock.dll.so )
( cd usr/lib/wine ; rm -rf imm.dll.so )
( cd usr/lib/wine ; ln -sf imm32.dll.so imm.dll.so )
( cd usr/lib/wine ; rm -rf ole2disp.dll.so )
( cd usr/lib/wine ; ln -sf oleaut32.dll.so ole2disp.dll.so )
( cd usr/lib/wine ; rm -rf avifile.dll.so )
( cd usr/lib/wine ; ln -sf avifil32.dll.so avifile.dll.so )
( cd usr/lib/wine ; rm -rf gdi.exe.so )
( cd usr/lib/wine ; ln -sf gdi32.dll.so gdi.exe.so )
( cd usr/lib ; rm -rf libwine.so )
( cd usr/lib ; ln -sf libwine.so.1 libwine.so )
( cd usr/lib ; rm -rf libwine_unicode.so )
( cd usr/lib ; ln -sf libwine_unicode.so.1 libwine_unicode.so )
