; File generated automatically from winspool/winspool.drv.spec; do not edit!

LIBRARY winspool.drv

EXPORTS
  AddFormA@12 @103
  AddFormW@12 @104
  AddJobA@20 @105
  AddJobW@20 @106
  AddMonitorA@12 @107
  AddPortA@12 @109
  AddPrinterA@12 @117
  AddPrinterDriverA@12 @120
  AddPrinterDriverW@12 @123
  AddPrinterDriverExA@16 @121
  AddPrinterDriverExW@16 @122
  AddPrinterW@12 @124
  ClosePrinter@4 @128
  DeleteFormA@8 @135
  DeleteFormW@8 @136
  DeleteMonitorA@12 @137
  DeletePortA@12 @139
  DeletePrinter@4 @145
  DeletePrinterDataExA@12 @148
  DeletePrinterDataExW@12 @149
  DeletePrinterDriverA@12 @150
  DeletePrinterDriverExA@20 @151
  DeletePrinterDriverExW@20 @152
  DeviceCapabilities@20=DeviceCapabilitiesA@20 @156
  DeviceCapabilitiesA@20 @157
  DeviceCapabilitiesW@20 @158
  DocumentPropertiesA@24 @161
  DocumentPropertiesW@24 @162
  EndDocPrinter@4 @164
  EndPagePrinter@4 @165
  EnumJobsA@32 @168
  EnumJobsW@32 @169
  EnumMonitorsA@24 @170
  EnumMonitorsW@24 @171
  EnumPortsA@24 @172
  EnumPrinterDataExA@24 @179
  EnumPrinterDataExW@24 @180
  EnumPrinterDriversA@28 @182
  EnumPrinterDriversW@28 @183
  EnumPrintersA@28 @184
  EnumPrintersW@28 @185
  GetDefaultPrinterA@8 @191
  GetDefaultPrinterW@8 @192
  GetFormA@24 @193
  GetFormW@24 @194
  GetPrintProcessorDirectoryA@24 @197
  GetPrinterA@20 @199
  GetPrinterDataA@24 @200
  GetPrinterDataExA@28 @201
  GetPrinterDataExW@28 @202
  GetPrinterDataW@24 @203
  GetPrinterDriverA@24 @204
  GetPrinterDriverDirectoryA@24 @205
  GetPrinterDriverDirectoryW@24 @206
  GetPrinterDriverW@24 @207
  GetPrinterW@20 @208
  OpenPrinterA@12 @210
  OpenPrinterW@12 @211
  PrinterProperties@8 @215
  ReadPrinter@16 @216
  ResetPrinterA@8 @217
  ResetPrinterW@8 @218
  SetFormA@16 @221
  SetFormW@16 @222
  SetJobA@20 @223
  SetJobW@20 @224
  SetPrinterA@16 @225
  SetPrinterDataA@20 @226
  SetPrinterDataExA@24 @227
  SetPrinterDataExW@24 @228
  SetPrinterDataW@20 @229
  SetPrinterW@16 @230
  StartDocPrinterA@12 @235
  StartDocPrinterW@12 @236
  StartPagePrinter@4 @237
  WritePrinter@16 @239
  XcvDataW@32 @240
