; File generated automatically from tapi32/tapi32.spec; do not edit!

LIBRARY tapi32.dll

EXPORTS
  lineAccept@12 @1
  lineAddProvider@12 @2
  lineAddToConference@8 @3
  lineAnswer@12 @4
  lineBlindTransfer@12 @5
  lineClose@4 @6
  lineCompleteCall@16 @7
  lineCompleteTransfer@16 @8
  lineConfigDialog@12 @9
  lineConfigDialogEdit@24 @10
  lineConfigProvider@8 @11
  lineDeallocateCall@4 @12
  lineDevSpecific@20 @13
  lineDevSpecificFeature@16 @14
  lineDial@12 @15
  lineDrop@12 @16
  lineForward@28 @17
  lineGatherDigits@28 @18
  lineGenerateDigits@16 @19
  lineGenerateTone@20 @20
  lineGetAddressCaps@24 @21
  lineGetAddressID@20 @22
  lineGetAddressStatus@12 @23
  lineGetAppPriority@24 @24
  lineGetCallInfo@8 @25
  lineGetCallStatus@8 @26
  lineGetConfRelatedCalls@8 @27
  lineGetCountry@12 @28
  lineGetDevCaps@20 @29
  lineGetDevConfig@12 @30
  lineGetID@24 @31
  lineGetIcon@12 @32
  lineGetLineDevStatus@8 @33
  lineGetNewCalls@16 @34
  lineGetNumRings@12 @35
  lineGetProviderList@8 @36
  lineGetRequest@12 @37
  lineGetStatusMessages@12 @38
  lineGetTranslateCaps@12 @39
  lineHandoff@12 @40
  lineHold@4 @41
  lineInitialize@20 @42
  lineMakeCall@20 @43
  lineMonitorDigits@8 @44
  lineMonitorMedia@8 @45
  lineMonitorTones@12 @46
  lineNegotiateAPIVersion@24 @47
  lineNegotiateExtVersion@24 @48
  lineOpen@36 @49
  linePark@16 @50
  linePickup@20 @51
  linePrepareAddToConference@12 @52
  lineRedirect@12 @53
  lineRegisterRequestRecipient@16 @54
  lineReleaseUserUserInfo@4 @55
  lineRemoveFromConference@4 @56
  lineRemoveProvider@8 @57
  lineSecureCall@4 @58
  lineSendUserUserInfo@12 @59
  lineSetAppPriority@24 @60
  lineSetAppSpecific@8 @61
  lineSetCallParams@20 @62
  lineSetCallPrivilege@8 @63
  lineSetCurrentLocation@8 @64
  lineSetDevConfig@16 @65
  lineSetMediaControl@48 @66
  lineSetMediaMode@8 @67
  lineSetNumRings@12 @68
  lineSetStatusMessages@12 @69
  lineSetTerminal@28 @70
  lineSetTollList@16 @71
  lineSetupConference@24 @72
  lineSetupTransfer@12 @73
  lineShutdown@4 @74
  lineSwapHold@8 @75
  lineTranslateAddress@28 @76
  lineTranslateDialog@20 @77
  lineUncompleteCall@8 @78
  lineUnhold@4 @79
  lineUnpark@16 @80
  phoneClose@4 @81
  phoneConfigDialog@12 @82
  phoneDevSpecific@12 @83
  phoneGetButtonInfo@12 @84
  phoneGetData@16 @85
  phoneGetDevCaps@20 @86
  phoneGetDisplay@8 @87
  phoneGetGain@12 @88
  phoneGetHookSwitch@8 @89
  phoneGetID@12 @90
  phoneGetIcon@12 @91
  phoneGetLamp@12 @92
  phoneGetRing@12 @93
  phoneGetStatus@8 @94
  phoneGetStatusMessages@16 @95
  phoneGetVolume@12 @96
  phoneInitialize@20 @97
  phoneNegotiateAPIVersion@24 @98
  phoneNegotiateExtVersion@24 @99
  phoneOpen@28 @100
  phoneSetButtonInfo@12 @101
  phoneSetData@16 @102
  phoneSetDisplay@20 @103
  phoneSetGain@12 @104
  phoneSetHookSwitch@12 @105
  phoneSetLamp@12 @106
  phoneSetRing@12 @107
  phoneSetStatusMessages@16 @108
  phoneSetVolume@12 @109
  phoneShutdown@4 @110
  tapiGetLocationInfo@8 @111
  tapiRequestMakeCall@16 @113
