; File generated automatically from dbghelp/dbghelp.spec; do not edit!

LIBRARY dbghelp.dll

EXPORTS
  EnumerateLoadedModules@12 @3
  FindDebugInfoFile@12 @6
  FindDebugInfoFileEx@20 @7
  FindExecutableImage@12 @8
  GetTimestampForLoadedLibrary@4 @12
  ImageNtHeader@4=ntdll.RtlImageNtHeader @15
  ImageRvaToSection@12=ntdll.RtlImageRvaToSection @16
  ImageRvaToVa@16=ntdll.RtlImageRvaToVa @17
  ImagehlpApiVersion@0 @18
  ImagehlpApiVersionEx@4 @19
  MakeSureDirectoryPathExists@4 @20
  MapDebugInformation@16 @21
  SearchTreeForFile@12 @24
  StackWalk@36 @25
  SymCleanup@4 @27
  SymEnumSourceFiles@20 @28
  SymEnumSymbols@20 @30
  SymEnumTypes@16 @31
  SymEnumerateModules@12 @32
  SymEnumerateSymbols@16 @34
  SymFromAddr@16 @39
  SymFromName@12 @40
  SymFunctionTableAccess@8 @41
  SymGetLineFromAddr@16 @44
  SymGetLineNext@8 @48
  SymGetLinePrev@8 @50
  SymGetModuleBase@8 @52
  SymGetModuleInfo@12 @54
  SymGetOptions@0 @58
  SymGetSearchPath@12 @59
  SymGetSymFromAddr@16 @60
  SymGetSymFromName@12 @62
  SymGetSymNext@8 @64
  SymGetSymPrev@8 @66
  SymGetTypeFromName@16 @68
  SymGetTypeInfo@20 @69
  SymInitialize@12 @70
  SymLoadModule@24 @71
  SymRegisterCallback@12 @76
  SymSetContext@12 @80
  SymSetOptions@4 @81
  SymSetSearchPath@8 @82
  SymUnDName@12 @84
  SymUnloadModule@8 @86
  UnDecorateSymbolName@16 @88
  UnmapDebugInformation@4 @89
