; File generated automatically from kernel/kernel32.spec; do not edit!

LIBRARY kernel32.dll

EXPORTS
  k32CharToOemA@8 @10
  k32CharToOemBuffA@12 @11
  k32OemToCharA@8 @12
  k32OemToCharBuffA@12 @13
  k32LoadStringA@16 @14
  k32wsprintfA @15
  k32wvsprintfA@12 @16
  GetProcessDword@8 @18
  DosFileHandleToWin32Handle@4 @20
  Win32HandleToDosFileHandle@4 @21
  DisposeLZ32Handle@4 @22
  GlobalAlloc16@8 @24
  GlobalLock16@4 @25
  GlobalUnlock16@4 @26
  GlobalFix16@4 @27
  GlobalUnfix16@4 @28
  GlobalWire16@4 @29
  GlobalUnWire16@4 @30
  GlobalFree16@4 @31
  GlobalSize16@4 @32
  HouseCleanLogicallyDeadHandles@0 @33
  GetWin16DOSEnv@0 @34
  LoadLibrary16@4 @35
  FreeLibrary16@4 @36
  GetProcAddress16@8=WIN32_GetProcAddress16@8 @37
  ThunkInitLSF@20 @41
  ThunkInitLS@20 @43
  ThunkInitSL@20 @46
  ReleaseThunkLock@4 @48
  RestoreThunkLock@4 @49
  GetThunkBuff@0 @52
  GetThunkStuff@8 @53
  K32WOWCallback16@8 @54
  K32WOWCallback16Ex@20 @55
  K32WOWGetVDMPointer@12 @56
  K32WOWHandle32@8 @57
  K32WOWHandle16@8 @58
  K32WOWGlobalAlloc16@8 @59
  K32WOWGlobalLock16@4 @60
  K32WOWGlobalUnlock16@4 @61
  K32WOWGlobalFree16@4 @62
  K32WOWGlobalAllocLock16@12 @63
  K32WOWGlobalUnlockFree16@4 @64
  K32WOWGlobalLockSize16@8 @65
  K32WOWYield16@0 @66
  K32WOWDirectedYield16@4 @67
  K32WOWGetVDMPointerFix@12 @68
  K32WOWGetVDMPointerUnfix@4 @69
  K32WOWGetDescriptor@8 @70
  K32RtlLargeIntegerAdd@16=ntdll.RtlLargeIntegerAdd @72
  K32RtlEnlargedIntegerMultiply@8=ntdll.RtlEnlargedIntegerMultiply @73
  K32RtlEnlargedUnsignedMultiply@8=ntdll.RtlEnlargedUnsignedMultiply @74
  K32RtlEnlargedUnsignedDivide@16=ntdll.RtlEnlargedUnsignedDivide @75
  K32RtlExtendedLargeIntegerDivide@16=ntdll.RtlExtendedLargeIntegerDivide @76
  K32RtlExtendedMagicDivide@20=ntdll.RtlExtendedMagicDivide @77
  K32RtlExtendedIntegerMultiply@12=ntdll.RtlExtendedIntegerMultiply @78
  K32RtlLargeIntegerShiftLeft@12=ntdll.RtlLargeIntegerShiftLeft @79
  K32RtlLargeIntegerShiftRight@12=ntdll.RtlLargeIntegerShiftRight @80
  K32RtlLargeIntegerArithmeticShift@12=ntdll.RtlLargeIntegerArithmeticShift @81
  K32RtlLargeIntegerNegate@8=ntdll.RtlLargeIntegerNegate @82
  K32RtlLargeIntegerSubtract@16=ntdll.RtlLargeIntegerSubtract @83
  K32RtlConvertLongToLargeInteger@4=ntdll.RtlConvertLongToLargeInteger @84
  K32RtlConvertUlongToLargeInteger@4=ntdll.RtlConvertUlongToLargeInteger @85
  SSOnBigStack@0 @87
  SSCall @88
  PK16FNF@4 @91
  GetPK16SysVar@0 @92
  GetpWin16Lock@4 @93
  _CheckNotSysLevel@4 @94
  _ConfirmSysLevel@4 @95
  _ConfirmWin16Lock@0 @96
  _EnterSysLevel@4 @97
  _LeaveSysLevel@4 @98
  AddAtomA@4 @118
  AddAtomW@4 @123
  AddVectoredExceptionHandler@8=ntdll.RtlAddVectoredExceptionHandler @127
  AllocConsole@0 @129
  AllocSLCallback@8 @131
  AreFileApisANSI@0 @134
  BackupRead@28 @136
  BackupSeek@24 @137
  BackupWrite@28 @138
  Beep@8 @150
  BeginUpdateResourceA@8 @151
  BeginUpdateResourceW@8 @152
  BuildCommDCBA@8 @153
  BuildCommDCBAndTimeoutsA@12 @154
  BuildCommDCBAndTimeoutsW@12 @155
  BuildCommDCBW@8 @156
  CallNamedPipeA@28 @157
  CallNamedPipeW@28 @158
  ClearCommBreak@4 @179
  ClearCommError@12 @180
  CloseHandle@4 @182
  CloseProfileUserMapping@0 @183
  CommConfigDialogA@12 @186
  CommConfigDialogW@12 @187
  CompareFileTime@8 @188
  CompareStringA@24 @189
  CompareStringW@24 @190
  ConnectNamedPipe@8 @191
  ContinueDebugEvent@12 @194
  ConvertDefaultLocale@4 @195
  ConvertFiberToThread@0 @197
  ConvertThreadToFiber@4 @198
  ConvertThreadToFiberEx@8 @199
  ConvertToGlobalHandle@4 @200
  CopyFileA@12 @201
  CopyFileW@12 @204
  CreateConsoleScreenBuffer@20 @207
  CreateDirectoryA@8 @208
  CreateDirectoryExA@12 @209
  CreateDirectoryExW@12 @210
  CreateDirectoryW@8 @211
  CreateEventA@16 @212
  CreateEventW@16 @213
  CreateFileA@28 @216
  CreateFileMappingA@24 @217
  CreateFileMappingW@24 @218
  CreateFileW@28 @219
  CreateIoCompletionPort@16 @220
  CreateMailslotA@16 @224
  CreateMailslotW@16 @225
  CreateMutexA@12 @226
  CreateMutexW@12 @227
  CreateNamedPipeA@32 @228
  CreateNamedPipeW@32 @229
  CreatePipe@16 @230
  CreateProcessA@40 @231
  CreateProcessW@40 @232
  CreateSemaphoreA@16 @234
  CreateSemaphoreW@16 @235
  CreateSocketHandle@0 @236
  CreateTapePartition@16 @237
  CreateThread@24 @238
  CreateToolhelp32Snapshot@8 @241
  DebugActiveProcess@4 @252
  DebugBreak@0 @254
  DefineDosDeviceA@12 @257
  DefineDosDeviceW@12 @258
  DeleteAtom@4 @260
  DeleteCriticalSection@4=ntdll.RtlDeleteCriticalSection @261
  DeleteFileA@4 @263
  DeleteFileW@4 @264
  DeviceIoControl@32 @267
  DisableThreadLibraryCalls@4 @268
  DisconnectNamedPipe@4 @269
  DosDateTimeToFileTime@12 @272
  DuplicateHandle@28 @274
  EndUpdateResourceA@8 @275
  EndUpdateResourceW@8 @276
  EnterCriticalSection@4=ntdll.RtlEnterCriticalSection @277
  EnumCalendarInfoA@16 @278
  EnumDateFormatsA@12 @282
  EnumDateFormatsW@12 @285
  EnumLanguageGroupLocalesA@16 @286
  EnumLanguageGroupLocalesW@16 @287
  EnumResourceLanguagesA@20 @288
  EnumResourceLanguagesW@20 @289
  EnumResourceNamesA@16 @290
  EnumResourceNamesW@16 @291
  EnumResourceTypesA@12 @292
  EnumResourceTypesW@12 @293
  EnumSystemCodePagesA@8 @294
  EnumSystemCodePagesW@8 @295
  EnumSystemGeoID@12 @296
  EnumSystemLanguageGroupsA@12 @297
  EnumSystemLanguageGroupsW@12 @298
  EnumSystemLocalesA@8 @299
  EnumSystemLocalesW@8 @300
  EnumTimeFormatsA@12 @301
  EnumTimeFormatsW@12 @302
  EraseTape@12 @305
  EscapeCommFunction@8 @306
  ExitProcess@4 @308
  ExitThread@4 @309
  ExpandEnvironmentStringsA@12 @311
  ExpandEnvironmentStringsW@12 @312
  FatalAppExitA@8 @335
  FatalAppExitW@8 @336
  FatalExit@4 @337
  FileTimeToDosDateTime@12 @338
  FileTimeToLocalFileTime@8 @339
  FileTimeToSystemTime@8 @340
  FillConsoleOutputAttribute@20 @341
  FillConsoleOutputCharacterA@20 @342
  FillConsoleOutputCharacterW@20 @343
  FindAtomA@4 @347
  FindAtomW@4 @348
  FindCloseChangeNotification@4 @350
  FindClose@4 @349
  FindFirstChangeNotificationA@12 @351
  FindFirstChangeNotificationW@12 @352
  FindFirstFileA@8 @353
  FindFirstFileW@8 @356
  FindNextChangeNotification@4 @361
  FindNextFileA@8 @362
  FindNextFileW@8 @363
  FindResourceA@12 @369
  FindResourceExA@16 @370
  FindResourceExW@16 @371
  FindResourceW@12 @372
  FlushConsoleInputBuffer@4 @375
  FlushFileBuffers@4 @376
  FlushInstructionCache@12 @377
  FlushViewOfFile@8 @378
  FoldStringA@20 @379
  FoldStringW@20 @380
  FormatMessageA@28 @381
  FormatMessageW@28 @382
  FreeConsole@0 @383
  FreeEnvironmentStringsA@4 @384
  FreeEnvironmentStringsW@4 @385
  FreeLibraryAndExitThread@8 @388
  FreeLibrary@4 @387
  FreeResource@4 @389
  FreeSLCallback@4 @391
  GenerateConsoleCtrlEvent@8 @395
  GetACP@0 @397
  GetAtomNameA@12 @398
  GetAtomNameW@12 @399
  GetBinaryType@8=GetBinaryTypeA@8 @400
  GetBinaryTypeA@8 @401
  GetBinaryTypeW@8 @402
  GetCPInfo@8 @403
  GetCPInfoExA@12 @404
  GetCPInfoExW@12 @405
  GetCommConfig@12 @408
  GetCommMask@8 @409
  GetCommModemStatus@8 @410
  GetCommProperties@8 @411
  GetCommState@8 @412
  GetCommTimeouts@8 @413
  GetCommandLineA@0 @414
  GetCommandLineW@0 @415
  GetCompressedFileSizeA@8 @416
  GetCompressedFileSizeW@8 @417
  GetComputerNameA@8 @418
  GetComputerNameExA@12 @419
  GetComputerNameExW@12 @420
  GetComputerNameW@8 @421
  GetConsoleCP@0 @432
  GetConsoleCursorInfo@8 @438
  GetConsoleMode@8 @449
  GetConsoleOutputCP@0 @451
  GetConsoleScreenBufferInfo@8 @452
  GetConsoleTitleA@8 @453
  GetConsoleTitleW@8 @454
  GetConsoleWindow@0 @455
  GetCurrencyFormatA@24 @456
  GetCurrencyFormatW@24 @457
  GetCurrentDirectoryA@8 @460
  GetCurrentDirectoryW@8 @461
  GetCurrentProcess@0 @463
  GetCurrentProcessId@0 @464
  GetCurrentThread@0 @466
  GetCurrentThreadId@0 @467
  GetDateFormatA@24 @469
  GetDateFormatW@24 @470
  GetDaylightFlag@0 @471
  GetDefaultCommConfigA@12 @472
  GetDefaultCommConfigW@12 @473
  GetDevicePowerState@8 @475
  GetDiskFreeSpaceA@20 @476
  GetDiskFreeSpaceW@20 @479
  GetDriveTypeA@4 @480
  GetDriveTypeW@4 @481
  GetEnvironmentStrings@0=GetEnvironmentStringsA@0 @482
  GetEnvironmentStringsA@0 @483
  GetEnvironmentStringsW@0 @484
  GetEnvironmentVariableA@12 @485
  GetEnvironmentVariableW@12 @486
  GetExitCodeProcess@8 @489
  GetExitCodeThread@8 @490
  GetFileAttributesA@4 @492
  GetFileAttributesW@4 @495
  GetFileInformationByHandle@8 @496
  GetFileSize@8 @497
  GetFileSizeEx@8 @498
  GetFileTime@16 @499
  GetFileType@4 @500
  GetFullPathNameA@16 @501
  GetFullPathNameW@16 @502
  GetHandleContext@4 @505
  GetHandleInformation@8 @506
  GetLargestConsoleWindowSize@4 @509
  GetLastError@0 @510
  GetLocalTime@4 @512
  GetLocaleInfoA@16 @513
  GetLocaleInfoW@16 @514
  GetLogicalDriveStringsA@8 @515
  GetLogicalDriveStringsW@8 @516
  GetLogicalDrives@0 @517
  GetMailslotInfo@20 @520
  GetModuleFileNameA@12 @522
  GetModuleFileNameW@12 @523
  GetModuleHandleA@4 @525
  GetModuleHandleW@4 @526
  GetNamedPipeHandleStateA@28 @528
  GetNamedPipeHandleStateW@28 @529
  GetNamedPipeInfo@20 @530
  GetNumberFormatA@24 @533
  GetNumberFormatW@24 @534
  GetNumberOfConsoleInputEvents@8 @536
  GetNumberOfConsoleMouseButtons@4 @537
  GetOEMCP@0 @538
  GetOverlappedResult@16 @539
  GetPriorityClass@4 @540
  GetPrivateProfileIntA@16 @541
  GetPrivateProfileIntW@16 @542
  GetPrivateProfileSectionA@16 @543
  GetPrivateProfileSectionNamesA@12 @544
  GetPrivateProfileSectionNamesW@12 @545
  GetPrivateProfileSectionW@16 @546
  GetPrivateProfileStringA@24 @547
  GetPrivateProfileStringW@24 @548
  GetPrivateProfileStructA@20 @549
  GetPrivateProfileStructW@20 @550
  GetProcAddress@8 @551
  GetProcessAffinityMask@12 @552
  GetProcessFlags@4 @553
  GetProcessHeap@0 @554
  GetProcessHeaps@8 @555
  GetProcessIoCounters@8 @556
  GetProcessShutdownParameters@8 @558
  GetProcessTimes@20 @559
  GetProcessVersion@4 @560
  GetProcessWorkingSetSize@12 @561
  GetProfileIntA@12 @563
  GetProfileIntW@12 @564
  GetProfileSectionA@12 @565
  GetProfileSectionW@12 @566
  GetProfileStringA@20 @567
  GetProfileStringW@20 @568
  GetQueuedCompletionStatus@20 @569
  GetShortPathNameA@12 @574
  GetShortPathNameW@12 @575
  GetStartupInfoA@4 @576
  GetStartupInfoW@4 @577
  GetStdHandle@4 @578
  GetStringTypeA@20 @579
  GetStringTypeExA@20 @580
  GetStringTypeExW@20 @581
  GetStringTypeW@16 @582
  GetSystemDefaultLCID@0 @583
  GetSystemDefaultLangID@0 @584
  GetSystemDefaultUILanguage@0 @585
  GetSystemDirectoryA@8 @586
  GetSystemDirectoryW@8 @587
  GetSystemInfo@4 @588
  GetSystemPowerStatus@4 @589
  GetSystemTime@4 @590
  GetSystemTimeAdjustment@12 @591
  GetSystemTimeAsFileTime@4 @592
  GetTapeParameters@16 @595
  GetTapePosition@20 @596
  GetTapeStatus@4 @597
  GetTempFileNameA@16 @598
  GetTempFileNameW@16 @599
  GetTempPathA@8 @600
  GetTempPathW@8 @601
  GetThreadContext@8 @602
  GetThreadLocale@0 @603
  GetThreadPriority@4 @604
  GetThreadSelectorEntry@12 @607
  GetThreadTimes@20 @608
  GetTickCount@0 @609
  GetTimeFormatA@24 @610
  GetTimeFormatW@24 @611
  GetTimeZoneInformation@4 @612
  GetUserDefaultLCID@0 @613
  GetUserDefaultLangID@0 @614
  GetUserDefaultUILanguage@0 @615
  GetUserGeoID@4 @616
  GetVersion@0 @618
  GetVersionExA@4 @620
  GetVersionExW@4 @621
  GetVolumeInformationA@32 @622
  GetVolumeInformationW@32 @623
  GetVolumeNameForVolumeMountPointW@12 @625
  GetWindowsDirectoryA@8 @629
  GetWindowsDirectoryW@8 @630
  GlobalAddAtomA@4 @632
  GlobalAddAtomW@4 @633
  GlobalAlloc@8 @634
  GlobalCompact@4 @635
  GlobalDeleteAtom@4 @638
  GlobalFindAtomA@4 @639
  GlobalFindAtomW@4 @640
  GlobalFix@4 @641
  GlobalFlags@4 @642
  GlobalFree@4 @644
  GlobalGetAtomNameA@12 @645
  GlobalGetAtomNameW@12 @646
  GlobalHandle@4 @647
  GlobalLock@4 @648
  GlobalMemoryStatus@4 @649
  GlobalMemoryStatusEx@4 @650
  GlobalReAlloc@12 @651
  GlobalSize@4 @653
  GlobalUnWire@4 @654
  GlobalUnfix@4 @655
  GlobalUnlock@4 @656
  GlobalWire@4 @657
  Heap32ListFirst@8 @659
  HeapAlloc@12=ntdll.RtlAllocateHeap @662
  HeapCompact@8 @663
  HeapCreate@12 @664
  HeapDestroy@4 @666
  HeapFree@12=ntdll.RtlFreeHeap @668
  HeapLock@4 @669
  HeapReAlloc@16=ntdll.RtlReAllocateHeap @671
  HeapSize@12=ntdll.RtlSizeHeap @673
  HeapUnlock@4 @675
  HeapValidate@12 @677
  HeapWalk@8 @678
  InitAtomTable@4 @679
  InitializeCriticalSection@4 @680
  InterlockedDecrement@4 @683
  InterlockedExchange@8 @684
  InterlockedIncrement@4 @686
  InvalidateNLSCache@0 @688
  IsBadCodePtr@4 @689
  IsBadHugeReadPtr@8 @690
  IsBadHugeWritePtr@8 @691
  IsBadReadPtr@8 @692
  IsBadStringPtrA@8 @694
  IsBadStringPtrW@8 @695
  IsBadWritePtr@8 @696
  IsDBCSLeadByte@4 @697
  IsDBCSLeadByteEx@8 @698
  IsSystemResumeAutomatic@0 @703
  IsValidCodePage@4 @705
  IsValidLanguageGroup@8 @706
  IsValidLocale@8 @707
  LCMapStringA@24 @710
  LCMapStringW@24 @711
  LeaveCriticalSection@4=ntdll.RtlLeaveCriticalSection @721
  LoadLibraryA@4 @722
  LoadLibraryExA@12 @723
  LoadLibraryExW@12 @724
  LoadLibraryW@4 @725
  LoadModule@8 @726
  LoadResource@8 @728
  LocalAlloc@8 @730
  LocalCompact@4 @732
  LocalFileTimeToFileTime@8 @733
  LocalFlags@4 @734
  LocalFree@4 @735
  LocalHandle@4 @736
  LocalLock@4 @738
  LocalReAlloc@12 @740
  LocalShrink@8 @741
  LocalSize@4 @742
  LocalUnlock@4 @743
  LockFile@20 @745
  LockFileEx@24 @746
  LockResource@4 @747
  MakeCriticalSectionGlobal@4 @749
  MapHModuleLS@4 @754
  MapHModuleSL@4 @755
  MapLS@4 @756
  MapSL@4 @757
  MapSLFix@4 @758
  MapViewOfFile@20 @759
  MapViewOfFileEx@24 @760
  Module32First@8 @761
  Module32Next@8 @762
  MoveFileA@8 @763
  MoveFileExA@12 @764
  MoveFileExW@12 @765
  MoveFileW@8 @766
  MulDiv@12 @767
  MultiByteToWideChar@24 @768
  OpenEventA@12 @773
  OpenEventW@12 @774
  OpenFile@12 @775
  OpenFileMappingA@12 @776
  OpenFileMappingW@12 @777
  OpenMutexA@12 @780
  OpenMutexW@12 @781
  OpenProcess@12 @782
  OpenSemaphoreA@12 @784
  OpenSemaphoreW@12 @785
  OpenThread@12 @786
  OpenVxDHandle@4 @787
  OutputDebugStringA@4 @790
  OutputDebugStringW@4 @791
  PeekConsoleInputA@16 @792
  PeekConsoleInputW@16 @793
  PeekNamedPipe@24 @794
  PrepareTape@12 @796
  Process32First@8 @801
  Process32Next@8 @803
  PulseEvent@4 @806
  PurgeComm@8 @807
  QueryDosDeviceA@12 @810
  QueryDosDeviceW@12 @811
  QueryPerformanceCounter@4 @815
  QueryPerformanceFrequency@4 @816
  QueueUserAPC@12 @818
  RaiseException@16 @820
  ReadConsoleA@20 @821
  ReadConsoleInputA@16 @822
  ReadConsoleInputW@16 @825
  ReadConsoleOutputA@20 @826
  ReadConsoleOutputAttribute@20 @827
  ReadConsoleOutputCharacterA@20 @828
  ReadConsoleOutputCharacterW@20 @829
  ReadConsoleOutputW@20 @830
  ReadConsoleW@20 @831
  ReadFile@20 @833
  ReadFileEx@20 @834
  ReadProcessMemory@20 @836
  RegisterServiceProcess@8 @840
  RegisterWaitForSingleObject@24 @843
  RegisterWaitForSingleObjectEx@20 @844
  ReinitializeCriticalSection@4 @847
  ReleaseMutex@4 @849
  ReleaseSemaphore@12 @850
  ReplaceFile@24=ReplaceFileW@24 @854
  ReplaceFileA@24 @855
  ReplaceFileW@24 @856
  RemoveDirectoryA@4 @851
  RemoveDirectoryW@4 @852
  RemoveVectoredExceptionHandler@4=ntdll.RtlRemoveVectoredExceptionHandler @853
  RequestWakeupLatency@4 @858
  ResetEvent@4 @859
  ResumeThread@4 @861
  RtlFillMemory@12=ntdll.RtlFillMemory @862
  RtlMoveMemory@12=ntdll.RtlMoveMemory @863
  RtlUnwind@16=ntdll.RtlUnwind @864
  RtlZeroMemory@8=ntdll.RtlZeroMemory @865
  ScrollConsoleScreenBufferA@20 @886
  ScrollConsoleScreenBufferW@20 @887
  SearchPathA@24 @888
  SearchPathW@24 @889
  SetCommBreak@4 @893
  SetCommConfig@12 @894
  SetCommMask@8 @895
  SetCommState@8 @896
  SetCommTimeouts@8 @897
  SetComputerNameA@4 @898
  SetComputerNameW@4 @901
  SetComputerNameExA@8 @899
  SetComputerNameExW@8 @900
  SetConsoleActiveScreenBuffer@4 @902
  SetConsoleCP@4 @903
  SetConsoleCtrlHandler@8 @905
  SetConsoleCursorInfo@8 @907
  SetConsoleCursorPosition@8 @909
  SetConsoleMode@8 @920
  SetConsoleOutputCP@4 @925
  SetConsoleScreenBufferSize@8 @927
  SetConsoleTextAttribute@8 @928
  SetConsoleTitleA@4 @929
  SetConsoleTitleW@4 @930
  SetConsoleWindowInfo@12 @931
  SetCurrentDirectoryA@4 @933
  SetCurrentDirectoryW@4 @934
  SetDefaultCommConfigA@12 @936
  SetDefaultCommConfigW@12 @937
  SetEndOfFile@4 @938
  SetEnvironmentVariableA@8 @939
  SetEnvironmentVariableW@8 @940
  SetErrorMode@4 @941
  SetEvent@4 @942
  SetFileApisToANSI@0 @943
  SetFileApisToOEM@0 @944
  SetFileAttributesA@8 @945
  SetFileAttributesW@8 @946
  SetFilePointer@16 @947
  SetFileTime@16 @949
  SetHandleContext@8 @950
  SetHandleCount@4 @951
  SetHandleInformation@12 @952
  SetLastError@4 @955
  SetLocalTime@4 @956
  SetLocaleInfoA@12 @957
  SetLocaleInfoW@12 @958
  SetMailslotInfo@8 @959
  SetNamedPipeHandleState@16 @961
  SetPriorityClass@8 @962
  SetProcessShutdownParameters@8 @965
  SetProcessWorkingSetSize@12 @966
  SetStdHandle@8 @969
  SetSystemPowerState@8 @970
  SetSystemTime@4 @971
  SetSystemTimeAdjustment@8 @972
  SetTapeParameters@12 @973
  SetTapePosition@24 @974
  SetThreadAffinityMask@8 @976
  SetThreadContext@8 @977
  SetThreadLocale@4 @980
  SetThreadPriority@8 @981
  SetTimeZoneInformation@4 @984
  SetUnhandledExceptionFilter@4 @986
  SetUserGeoID@4 @987
  SetVolumeLabelA@8 @989
  SetVolumeLabelW@8 @990
  SetupComm@12 @994
  SizeofResource@8 @997
  Sleep@4 @999
  SleepEx@8 @1000
  SuspendThread@4 @1001
  SystemTimeToFileTime@8 @1004
  SystemTimeToTzSpecificLocalTime@12 @1005
  TerminateProcess@8 @1007
  TerminateThread@8 @1008
  Thread32First@8 @1010
  Thread32Next@8 @1011
  ThunkConnect32@24 @1012
  TlsAlloc@0 @1013
  TlsFree@4 @1015
  TlsGetValue@4 @1017
  TlsSetValue@8 @1018
  Toolhelp32ReadProcessMemory@20 @1019
  TransactNamedPipe@28 @1020
  TransmitCommChar@8 @1021
  TzSpecificLocalTimeToSystemTime@12 @1024
  UTRegister@28 @1025
  UTUnRegister@4 @1026
  UnMapLS@4 @1027
  UnhandledExceptionFilter@4 @1029
  UninitializeCriticalSection@4 @1030
  UnlockFile@20 @1031
  UnlockFileEx@20 @1032
  UnmapViewOfFile@4 @1033
  UpdateResourceA@24 @1036
  UpdateResourceW@24 @1037
  UnregisterWait@4 @1034
  UnregisterWaitEx@8 @1035
  VerLanguageNameA@12 @1042
  VerLanguageNameW@12 @1043
  VerSetConditionMask@16=ntdll.VerSetConditionMask @1044
  VirtualAlloc@16 @1048
  VirtualFree@12 @1051
  VirtualLock@8 @1053
  VirtualProtect@16 @1054
  VirtualProtectEx@20 @1055
  VirtualQuery@12 @1056
  VirtualQueryEx@16 @1057
  VirtualUnlock@8 @1058
  WaitCommEvent@12 @1059
  WaitForDebugEvent@8 @1060
  WaitForMultipleObjects@16 @1061
  WaitForMultipleObjectsEx@20 @1062
  WaitForSingleObject@8 @1063
  WaitForSingleObjectEx@12 @1064
  WaitNamedPipeA@8 @1065
  WaitNamedPipeW@8 @1066
  WideCharToMultiByte@32 @1067
  WinExec@8 @1068
  WriteConsoleA@20 @1070
  WriteConsoleInputA@16 @1071
  WriteConsoleInputW@16 @1074
  WriteConsoleOutputA@20 @1075
  WriteConsoleOutputAttribute@20 @1076
  WriteConsoleOutputCharacterA@20 @1077
  WriteConsoleOutputCharacterW@20 @1078
  WriteConsoleOutputW@20 @1079
  WriteConsoleW@20 @1080
  WriteFile@20 @1081
  WriteFileEx@20 @1082
  WritePrivateProfileSectionA@12 @1084
  WritePrivateProfileSectionW@12 @1085
  WritePrivateProfileStringA@16 @1086
  WritePrivateProfileStringW@16 @1087
  WritePrivateProfileStructA@20 @1088
  WritePrivateProfileStructW@20 @1089
  WriteProcessMemory@20 @1090
  WriteProfileSectionA@8 @1091
  WriteProfileSectionW@8 @1092
  WriteProfileStringA@12 @1093
  WriteProfileStringW@12 @1094
  WriteTapemark@16 @1095
  _hread@12 @1105
  _hwrite@12 @1106
  _lclose@4 @1107
  _lcreat@8 @1109
  _llseek@12 @1110
  _lopen@8 @1111
  _lread@12 @1112
  _lwrite@12 @1113
  lstrcat@8=lstrcatA@8 @1115
  lstrcatA@8 @1116
  lstrcatW@8 @1117
  lstrcmp@8=lstrcmpA@8 @1118
  lstrcmpA@8 @1119
  lstrcmpW@8 @1120
  lstrcmpi@8=lstrcmpiA@8 @1121
  lstrcmpiA@8 @1122
  lstrcmpiW@8 @1123
  lstrcpy@8=lstrcpyA@8 @1124
  lstrcpyA@8 @1125
  lstrcpyW@8 @1126
  lstrcpyn@12=lstrcpynA@12 @1127
  lstrcpynA@12 @1128
  lstrcpynW@12 @1129
  lstrlen@4=lstrlenA@4 @1130
  lstrlenA@4 @1131
  lstrlenW@4 @1132
  CloseConsoleHandle@4 @181
  GetConsoleInputWaitHandle@0 @446
  IsDebuggerPresent@0 @699
  OpenConsoleW@16 @771
  VerifyConsoleIoHandle@4 @1045
  CancelIo@4 @176
  CancelWaitableTimer@4 @177
  CopyFileExA@24 @202
  CopyFileExW@24 @203
  CreateFiber@12 @214
  CreateFiberEx@20 @215
  CreateWaitableTimerA@12 @243
  CreateWaitableTimerW@12 @244
  DeleteFiber@4 @262
  DuplicateConsoleHandle@16 @273
  FindFirstFileExA@24 @354
  FindFirstFileExW@24 @355
  GetDiskFreeSpaceExA@16 @477
  GetDiskFreeSpaceExW@16 @478
  GetFileAttributesExA@12 @493
  GetFileAttributesExW@12 @494
  GetProcessPriorityBoost@8 @557
  GetThreadPriorityBoost@8 @605
  InterlockedCompareExchange@12 @682
  InterlockedExchangeAdd@8 @685
  IsProcessorFeaturePresent@4 @701
  OpenWaitableTimerA@12 @788
  OpenWaitableTimerW@12 @789
  SetConsoleInputExeNameA@4 @914
  SetConsoleInputExeNameW@4 @915
  SetProcessAffinityMask@8 @963
  SetProcessPriorityBoost@8 @964
  SetThreadIdealProcessor@8 @979
  SetThreadPriorityBoost@8 @982
  SetWaitableTimer@24 @993
  SignalObjectAndWait@16 @996
  SwitchToFiber@4 @1002
  SwitchToThread@0 @1003
  TryEnterCriticalSection@4=ntdll.RtlTryEnterCriticalSection @1023
  VirtualAllocEx@20 @1049
  VirtualFreeEx@16 @1052
  GetLongPathNameA@12 @518
  GetLongPathNameW@12 @519
  PrivateLoadLibrary@4 @800
  PrivateFreeLibrary@4 @799
  Get16DLLAddress@8 @396
  SetThreadExecutionState@4 @978
  AssignProcessToJobObject@8 @135
  CreateJobObjectA@8 @221
  CreateJobObjectW@8 @222
  CreateTimerQueue@0 @239
  CreateTimerQueueTimer@28 @240
  DeleteTimerQueueEx@8 @265
  DeleteTimerQueueTimer@12 @266
  DnsHostnameToComputerNameA@12 @270
  DnsHostnameToComputerNameW@12 @271
  GetCalendarInfoA@24 @406
  GetCalendarInfoW@24 @407
  GetSystemWindowsDirectoryA@8 @593
  GetSystemWindowsDirectoryW@8 @594
  InitializeCriticalSectionAndSpinCount@8 @681
  ProcessIdToSessionId@8 @805
  SetCalendarInfoA@16 @891
  SetCalendarInfoW@16 @892
  SetCriticalSectionSpinCount@8 @932
  VerifyVersionInfoA@16 @1046
  VerifyVersionInfoW@16 @1047
  ActivateActCtx@8 @50
  AddRefActCtx@4 @126
  CreateActCtxA@4 @205
  CreateActCtxW@4 @206
  DeactivateActCtx@8 @251
  DebugActiveProcessStop@4 @253
  DebugBreakProcess@4 @255
  DebugSetProcessKillOnExit@4 @256
  FindActCtxSectionGuid@20 @344
  FindActCtxSectionStringA@20 @345
  FindActCtxSectionStringW@20 @346
  GetCurrentActCtx@4 @458
  QueryActCtxW@28 @809
  ReleaseActCtx@4 @848
  ZombifyActCtx@4 @1096
  _lclose16@4 @1108
  AllocCStoDSAlias16@4 @128
  AllocSelectorArray16@4 @132
  ConvertDialog32To16@12 @196
  ExitKernel16@0 @307
  FarGetOwner16@4 @333
  FarSetOwner16@8 @334
  FindResource16@12 @368
  FreeResource16@4 @390
  FreeSelector16@4 @392
  GetCurrentPDB16@0 @462
  GetCurrentTask@0 @465
  GetDOSEnvironment16@0 @468
  GetExePtr@4 @488
  GetExpWinVer16@4 @491
  GetModuleFileName16@12 @521
  GetModuleHandle16@4 @524
  GetModuleName16@12 @527
  GetSelectorBase@4 @572
  GetSelectorLimit16@4 @573
  GetThreadQueue16@4 @606
  GetVersion16@0 @619
  GetWinFlags16@0 @628
  GlobalDOSAlloc16@4 @636
  GlobalDOSFree16@4 @637
  GlobalFlags16@4 @643
  GlobalReAlloc16@12 @652
  IsBadReadPtr16@8 @693
  IsTask16@4 @704
  LoadModule16@8 @727
  LoadResource16@8 @729
  LocalAlloc16@8 @731
  LocalInit16@12 @737
  LocalLock16@4 @739
  LocalUnlock16@4 @744
  LockResource16@4 @748
  SelectorAccessRights16@12 @890
  SetSelectorBase@8 @967
  SetSelectorLimit16@8 @968
  SetThreadQueue16@8 @983
  SizeofResource16@8 @998
  WinExec16@8 @1069
  __wine_register_dll_16 @1103
  __wine_unregister_dll_16 @1104
  __wine_call_from_16_word @1101
  __wine_call_from_16_long @1099
  __wine_call_from_16_regs @1100
  wine_get_unix_file_name @1133
  __wine_kernel_init @1102
  DOSMEM_AllocSelector @245
  DOSMEM_Available @246
  DOSMEM_FreeBlock @247
  DOSMEM_GetBlock @248
  DOSMEM_Init @249
  DOSMEM_ResizeBlock @250
  LOCAL_Alloc @712
  LOCAL_Compact @713
  LOCAL_CountFree @714
  LOCAL_Free @715
  LOCAL_HeapSize @716
  LOCAL_Lock @717
  LOCAL_ReAlloc @718
  LOCAL_Size @719
  LOCAL_Unlock @720
  NE_DefResourceHandler@12 @769
