; File generated automatically from secur32/secur32.spec; do not edit!

LIBRARY secur32.dll

EXPORTS
  AcceptSecurityContext@36 @3
  AcquireCredentialsHandleA@36 @4
  AcquireCredentialsHandleW@36 @5
  AddCredentialsA@32 @6
  AddCredentialsW@32 @7
  ApplyControlToken@8 @10
  CompleteAuthToken@8 @11
  DecryptMessage@16 @12
  DeleteSecurityContext@4 @13
  EncryptMessage@16 @16
  EnumerateSecurityPackagesA@8 @17
  EnumerateSecurityPackagesW@8 @18
  ExportSecurityContext@16 @19
  FreeContextBuffer@4 @20
  FreeCredentialsHandle@4 @21
  ImpersonateSecurityContext@4 @27
  ImportSecurityContextA@16 @28
  ImportSecurityContextW@16 @29
  InitSecurityInterfaceA@0 @30
  InitSecurityInterfaceW@0 @31
  InitializeSecurityContextA@48 @32
  InitializeSecurityContextW@48 @33
  MakeSignature@16 @45
  QueryContextAttributesA@12 @46
  QueryContextAttributesW@12 @47
  QueryCredentialsAttributesA@12 @48
  QueryCredentialsAttributesW@12 @49
  QuerySecurityContextToken@8 @50
  QuerySecurityPackageInfoA@8 @51
  QuerySecurityPackageInfoW@8 @52
  RevertSecurityContext@4 @53
  VerifySignature@16 @72
