; File generated automatically from shdocvw/shdocvw.spec; do not edit!

LIBRARY shdocvw.dll

EXPORTS
  WinList_Init@0 @110 NONAME
  ShellDDEInit@4 @118 NONAME
  RunInstallUninstallStubs@0 @125 NONAME
  DllCanUnloadNow@0=SHDOCVW_DllCanUnloadNow@0 @109 PRIVATE
  DllGetClassObject@12=SHDOCVW_DllGetClassObject@12 @112 PRIVATE
  DllGetVersion@4=SHDOCVW_DllGetVersion@4 @113
  DllInstall@8=SHDOCVW_DllInstall@8 @114
  DllRegisterServer@0=SHDOCVW_DllRegisterServer@0 @124 PRIVATE
  DllUnregisterServer@0=SHDOCVW_DllUnregisterServer@0 @127 PRIVATE
