; File generated automatically from dswave/dswave.spec; do not edit!

LIBRARY dswave.dll

EXPORTS
  DllCanUnloadNow@0=DSWAVE_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DSWAVE_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DSWAVE_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DSWAVE_DllUnregisterServer@0 @4 PRIVATE
