; File generated automatically from rasapi32/rasapi32.spec; do not edit!

LIBRARY rasapi32.dll

EXPORTS
  RasDeleteEntryA@8 @544
  RasDeleteEntryW@8 @545
  RasEnumAutodialAddressesA@12 @553
  RasEnumAutodialAddressesW@12 @554
  RasEnumConnectionsA@12 @555
  RasEnumConnectionsW@12 @556
  RasEnumDevicesA@12 @558
  RasEnumDevicesW@12 @559
  RasEnumEntriesA@20 @570
  RasEnumEntriesW@20 @571
  RasGetAutodialAddressA@20 @573
  RasGetAutodialAddressW@20 @574
  RasGetAutodialEnableA@8 @575
  RasGetAutodialEnableW@8 @576
  RasGetAutodialParamA@12 @577
  RasGetAutodialParamW@12 @578
  RasGetEntryDialParamsA@12 @587
  RasGetEntryPropertiesA@24 @589
  RasHangUpA@4 @601
  RasSetAutodialAddressA@20 @606
  RasSetAutodialAddressW@20 @607
  RasSetAutodialEnableA@8 @608
  RasSetAutodialEnableW@8 @609
  RasSetAutodialParamA@12 @610
  RasSetAutodialParamW@12 @611
  RasSetEntryPropertiesA@24 @616
  RasSetEntryPropertiesW@24 @617
  RasValidateEntryNameA@8 @621
  RasValidateEntryNameW@8 @622
