; File generated automatically from ttydrv/ttydrv.spec; do not edit!

LIBRARY ttydrv.dll

EXPORTS
  Arc=TTYDRV_DC_Arc @2
  BitBlt=TTYDRV_DC_BitBlt @4
  Chord=TTYDRV_DC_Chord @5
  CreateDC=TTYDRV_DC_CreateDC @6
  DeleteDC=TTYDRV_DC_DeleteDC @8
  Ellipse=TTYDRV_DC_Ellipse @10
  ExtFloodFill=TTYDRV_DC_ExtFloodFill @11
  ExtTextOut=TTYDRV_DC_ExtTextOut @12
  GetBitmapBits=TTYDRV_GetBitmapBits @13
  GetCharWidth=TTYDRV_DC_GetCharWidth @14
  GetDCOrgEx=TTYDRV_GetDCOrgEx @17
  GetDeviceCaps=TTYDRV_GetDeviceCaps @18
  GetPixel=TTYDRV_DC_GetPixel @20
  GetSystemPaletteEntries=TTYDRV_GetSystemPaletteEntries @22
  GetTextExtentPoint=TTYDRV_DC_GetTextExtentPoint @23
  GetTextMetrics=TTYDRV_DC_GetTextMetrics @24
  LineTo=TTYDRV_DC_LineTo @27
  PaintRgn=TTYDRV_DC_PaintRgn @29
  PatBlt=TTYDRV_DC_PatBlt @30
  Pie=TTYDRV_DC_Pie @31
  PolyPolygon=TTYDRV_DC_PolyPolygon @32
  PolyPolyline=TTYDRV_DC_PolyPolyline @33
  Polygon=TTYDRV_DC_Polygon @34
  Polyline=TTYDRV_DC_Polyline @35
  Rectangle=TTYDRV_DC_Rectangle @36
  RoundRect=TTYDRV_DC_RoundRect @39
  SelectFont=TTYDRV_SelectFont @40
  SetBitmapBits=TTYDRV_SetBitmapBits @41
  SetDCOrg=TTYDRV_SetDCOrg @44
  SetDIBitsToDevice=TTYDRV_DC_SetDIBitsToDevice @45
  SetPixel=TTYDRV_DC_SetPixel @46
  StretchBlt=TTYDRV_DC_StretchBlt @50
  VkKeyScanEx=TTYDRV_VkKeyScanEx @52
  MapVirtualKeyEx=TTYDRV_MapVirtualKeyEx @28
  GetKeyNameText=TTYDRV_GetKeyNameText @19
  ToUnicodeEx=TTYDRV_ToUnicodeEx @51
  Beep=TTYDRV_Beep @3
  SetCursor=TTYDRV_SetCursor @43
  GetScreenSaveActive=TTYDRV_GetScreenSaveActive @21
  SetScreenSaveActive=TTYDRV_SetScreenSaveActive @47
  CreateWindow=TTYDRV_CreateWindow @7
  DestroyWindow=TTYDRV_DestroyWindow @9
  GetDC=TTYDRV_GetDC @16
  SetWindowPos=TTYDRV_SetWindowPos @48
  AcquireClipboard=TTYDRV_AcquireClipboard @1
  ReleaseClipboard=TTYDRV_ReleaseClipboard @38
  SetClipboardData=TTYDRV_SetClipboardData @42
  GetClipboardData=TTYDRV_GetClipboardData @15
  IsClipboardFormatAvailable=TTYDRV_IsClipboardFormatAvailable @25
  RegisterClipboardFormat=TTYDRV_RegisterClipboardFormat @37
  IsSelectionOwner=TTYDRV_IsSelectionOwner @26
  ShowWindow=TTYDRV_ShowWindow @49
