; File generated automatically from dmstyle/dmstyle.spec; do not edit!

LIBRARY dmstyle.dll

EXPORTS
  DllCanUnloadNow@0=DMSTYLE_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMSTYLE_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMSTYLE_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMSTYLE_DllUnregisterServer@0 @4 PRIVATE
