; File generated automatically from wininet/wininet.spec; do not edit!

LIBRARY wininet.dll

EXPORTS
  InternetInitializeAutoProxyDll@4 @233
  CommitUrlCacheEntryA@44 @106
  CreateUrlCacheEntryA@20 @115
  CreateUrlCacheGroup@8 @124
  DeleteUrlCacheEntry@4=DeleteUrlCacheEntryA@4 @128
  DeleteUrlCacheEntryA@4 @129
  DeleteUrlCacheGroup@16 @131
  DetectAutoProxyUrl@12 @132
  DllInstall@8=WININET_DllInstall@8 @133
  FindFirstUrlCacheEntryA@12 @137
  FindFirstUrlCacheEntryW@12 @140
  FtpCreateDirectoryA@8 @151
  FtpCreateDirectoryW@8 @152
  FtpDeleteFileA@8 @153
  FtpFindFirstFileA@20 @155
  FtpFindFirstFileW@20 @156
  FtpGetCurrentDirectoryA@12 @157
  FtpGetCurrentDirectoryW@12 @158
  FtpGetFileA@28 @159
  FtpGetFileW@28 @160
  FtpOpenFileA@20 @161
  FtpOpenFileW@20 @162
  FtpPutFileA@20 @163
  FtpRemoveDirectoryA@8 @165
  FtpRenameFileA@12 @167
  FtpSetCurrentDirectoryA@8 @169
  FtpSetCurrentDirectoryW@8 @170
  GetUrlCacheConfigInfoA@12 @171
  GetUrlCacheConfigInfoW@12 @172
  GetUrlCacheEntryInfoA@12 @173
  GetUrlCacheEntryInfoExA@28 @174
  GetUrlCacheEntryInfoExW@28 @175
  GetUrlCacheEntryInfoW@12 @176
  GopherCreateLocatorA@28 @178
  GopherCreateLocatorW@28 @179
  GopherFindFirstFileA@24 @180
  GopherFindFirstFileW@24 @181
  GopherGetAttributeA@32 @182
  GopherGetAttributeW@32 @183
  GopherGetLocatorTypeA@8 @184
  GopherGetLocatorTypeW@8 @185
  GopherOpenFileA@20 @186
  GopherOpenFileW@20 @187
  HttpAddRequestHeadersA@16 @188
  HttpAddRequestHeadersW@16 @189
  HttpEndRequestA@16 @190
  HttpEndRequestW@16 @191
  HttpOpenRequestA@32 @192
  HttpOpenRequestW@32 @193
  HttpQueryInfoA@20 @194
  HttpQueryInfoW@20 @195
  HttpSendRequestA@20 @196
  HttpSendRequestExA@20 @197
  HttpSendRequestW@20 @199
  InternetAttemptConnect@4 @201
  InternetAutodial@8 @202
  InternetAutodialHangup@4 @204
  InternetCanonicalizeUrlA@16 @205
  InternetCanonicalizeUrlW@16 @206
  InternetCheckConnectionA@12 @207
  InternetCheckConnectionW@12 @208
  InternetCloseHandle@4 @209
  InternetCombineUrlA@20 @210
  InternetCombineUrlW@20 @211
  InternetConnectA@32 @213
  InternetConnectW@32 @214
  InternetCrackUrlA@16 @215
  InternetCrackUrlW@16 @216
  InternetCreateUrlA@16 @217
  InternetCreateUrlW@16 @218
  InternetErrorDlg@20 @221
  InternetFindNextFileA@8 @222
  InternetGetConnectedState@8 @225
  InternetGetConnectedStateExW@16 @226
  InternetGetCookieA@16 @227
  InternetGetCookieW@16 @228
  InternetGetLastResponseInfoA@12 @229
  InternetLockRequestFile@8 @234
  InternetOpenA@20 @235
  InternetOpenW@20 @239
  InternetOpenUrlA@24 @237
  InternetOpenUrlW@24 @238
  InternetQueryDataAvailable@16 @240
  InternetQueryOptionA@16 @241
  InternetQueryOptionW@16 @242
  InternetReadFile@16 @243
  InternetReadFileExA@16 @244
  InternetReadFileExW@16 @245
  InternetSetCookieA@12 @247
  InternetSetCookieW@12 @248
  InternetSetFilePointer@20 @250
  InternetSetOptionA@16 @251
  InternetSetOptionW@16 @254
  InternetSetOptionExA@20 @252
  InternetSetOptionExW@20 @253
  InternetSetStatusCallback@8=InternetSetStatusCallbackA@8 @255
  InternetSetStatusCallbackA@8 @256
  InternetUnlockRequestFile@4 @261
  InternetWriteFile@16 @262
  IsHostInProxyBypassList@12 @265
  ReadUrlCacheEntryStream@20 @268
  RetrieveUrlCacheEntryFileA@16 @269
  RetrieveUrlCacheEntryStreamA@20 @271
  SetUrlCacheEntryGroup@28 @276
  SetUrlCacheEntryInfoA@12 @277
  SetUrlCacheEntryInfoW@12 @278
  UnlockUrlCacheEntryFile@8=UnlockUrlCacheEntryFileA@8 @284
  UnlockUrlCacheEntryFileA@8 @285
  UnlockUrlCacheEntryStream@8 @287
