; File generated automatically from shell32/shell32.spec; do not edit!

LIBRARY shell32.dll

EXPORTS
  SHChangeNotifyRegister@24 @2
  SHChangeNotifyDeregister@4 @4
  SHChangeNotifyUpdateEntryList@16 @5
  ILGetDisplayName@8 @15
  ILFindLastID@4 @16
  ILRemoveLastID@4 @17
  ILClone@4 @18
  ILCloneFirst@4 @19
  ILGlobalClone@4 @20
  ILIsEqual@8 @21
  ILIsParent@12 @23
  ILFindChild@8 @24
  ILCombine@8 @25
  ILLoadFromStream@8 @26
  ILSaveToStream@8 @27
  SHILCreateFromPath@12=SHILCreateFromPathAW@12 @28
  PathIsRoot@4=PathIsRootAW@4 @29
  PathBuildRoot@8=PathBuildRootAW@8 @30
  PathFindExtension@4=PathFindExtensionAW@4 @31
  PathAddBackslash@4=PathAddBackslashAW@4 @32
  PathRemoveBlanks@4=PathRemoveBlanksAW@4 @33
  PathFindFileName@4=PathFindFileNameAW@4 @34
  PathRemoveFileSpec@4=PathRemoveFileSpecAW@4 @35
  PathAppend@8=PathAppendAW@8 @36
  PathCombine@12=PathCombineAW@12 @37
  PathStripPath@4=PathStripPathAW@4 @38
  PathIsUNC@4=PathIsUNCAW@4 @39
  PathIsRelative@4=PathIsRelativeAW@4 @40
  IsLFNDriveA@4 @41
  IsLFNDriveW@4 @42
  PathIsExe@4=PathIsExeAW@4 @43
  PathFileExists@4=PathFileExistsAW@4 @45
  PathMatchSpec@8=PathMatchSpecAW@8 @46
  PathMakeUniqueName@20=PathMakeUniqueNameAW@20 @47
  PathSetDlgItemPath@12=PathSetDlgItemPathAW@12 @48
  PathQualify@4=PathQualifyAW@4 @49
  PathStripToRoot@4=PathStripToRootAW@4 @50
  PathResolve@12=PathResolveAW@12 @51
  PathGetArgs@4=PathGetArgsAW@4 @52
  DoEnvironmentSubst@8=DoEnvironmentSubstAW@8 @53
  DragAcceptFiles@8 @54
  PathQuoteSpaces@4=PathQuoteSpacesAW@4 @55
  PathUnquoteSpaces@4=PathUnquoteSpacesAW@4 @56
  PathGetDriveNumber@4=PathGetDriveNumberAW@4 @57
  ParseField@16=ParseFieldAW@16 @58
  ExitWindowsDialog@4 @60
  RunFileDlg@24 @61
  PickIconDlg@16 @62
  GetFileNameFromBrowse@28 @63
  DriveType@4 @64
  IsNetDrive@4 @66
  Shell_MergeMenus@24 @67
  SHGetSetSettings@12 @68
  SHCreateDefClassObject@20 @70
  Shell_GetImageList@8 @71
  Shell_GetCachedImageIndex@12=Shell_GetCachedImageIndexAW@12 @72
  SHShellFolderView_Message@12 @73
  SHCreateStdEnumFmtEtc@12 @74
  PathYetAnotherMakeUniqueName@16 @75
  SHMapPIDLToSystemImageListIndex@12 @77
  OleStrToStrN@16=OleStrToStrNAW@16 @78
  StrToOleStrN@16=StrToOleStrNAW@16 @79
  DragFinish@4 @80
  DragQueryFile@16=DragQueryFileA@16 @81
  DragQueryFileA@16 @82
  CIDLData_CreateFromIDArray@16 @83
  OpenRegStream@16=shlwapi.SHOpenRegStreamA @85
  SHRegisterDragDrop@8 @86
  SHRevokeDragDrop@4 @87
  SHDoDragDrop@20 @88
  SHCloneSpecialIDList@12 @89
  SHFindFiles@8 @90
  PathGetShortPath@4=PathGetShortPathAW@4 @92
  Win32CreateDirectory@8=Win32CreateDirectoryAW@8 @93
  Win32RemoveDirectory@4=Win32RemoveDirectoryAW@4 @94
  SHLogILFromFSIL@4 @95
  StrRetToStrN@16=StrRetToStrNAW@16 @96
  SHWaitForFileToOpen@12 @97
  SHGetRealIDL@12 @98
  SetAppStartingCursor@8 @99
  SHRestricted@4 @100
  SHCoCreateInstance@20 @102
  SignalFileOpen@4 @103
  FileMenu_DeleteAllItems@4 @104
  FileMenu_DrawItem@8 @105
  FileMenu_FindSubMenuByPidl@8 @106
  FileMenu_GetLastSelectedItemPidls@12 @107
  FileMenu_HandleMenuChar@8 @108
  FileMenu_InitMenuPopup@4 @109
  FileMenu_InsertUsingPidl@24 @110
  FileMenu_Invalidate@4 @111
  FileMenu_MeasureItem@8 @112
  FileMenu_ReplaceUsingPidl@20 @113
  FileMenu_Create@20 @114
  FileMenu_AppendItem@24=FileMenu_AppendItemAW@24 @115
  FileMenu_TrackPopupMenuEx@24 @116
  FileMenu_DeleteItemByCmd@8 @117
  FileMenu_Destroy@4 @118
  IsLFNDrive@4=IsLFNDriveAW@4 @119
  FileMenu_AbortInitMenu@0 @120
  SHFlushClipboard@0 @121
  RunDLL_CallEntry16@20 @122 NONAME
  SHFreeUnusedLibraries@0 @123
  FileMenu_AppendFilesForPidl@12 @124
  FileMenu_AddFilesForPidl@28 @125
  SHOutOfMemoryMessageBox@12 @126
  SHWinHelp@16 @127
  DllGetClassObject@12=SHELL32_DllGetClassObject@12 @128 PRIVATE
  DAD_AutoScroll@12 @129
  DAD_DragEnter@4 @130
  DAD_DragEnterEx@12 @131
  DAD_DragLeave@0 @132
  DragQueryFileW@16 @133
  DAD_DragMove@8 @134
  DragQueryPoint@8 @135
  DAD_SetDragImage@8 @136
  DAD_ShowDragImage@4 @137
  FileMenu_DeleteItemByIndex@8 @140
  FileMenu_DeleteItemByFirstID@8 @141
  FileMenu_DeleteSeparator@4 @142
  FileMenu_EnableItemByCmd@12 @143
  FileMenu_GetItemExtent@8 @144
  PathFindOnPath@8=PathFindOnPathAW@8 @145
  RLBuildListOfPaths@0 @146
  SHCLSIDFromString@8=SHCLSIDFromStringAW@8 @147
  SHFind_InitMenuPopup@16 @149
  SHLoadOLE@4 @151
  ILGetSize@4 @152
  ILGetNext@4 @153
  ILAppend@12 @154
  ILFree@4 @155
  ILGlobalFree@4 @156
  ILCreateFromPath@4=ILCreateFromPathAW@4 @157
  PathGetExtension@12=PathGetExtensionAW@12 @158
  PathIsDirectory@4=PathIsDirectoryAW@4 @159
  SHRunControlPanel@8 @161
  SHSimpleIDListFromPath@4=SHSimpleIDListFromPathAW@4 @162
  StrToOleStr@8=StrToOleStrAW@8 @163
  Win32DeleteFile@4=Win32DeleteFileAW@4 @164
  SHCreateDirectory@8 @165
  CallCPLEntry16@24 @166
  SHAddFromPropSheetExtArray@12 @167
  SHCreatePropSheetExtArray@12 @168
  SHDestroyPropSheetExtArray@4 @169
  SHReplaceFromPropSheetExtArray@16 @170
  PathCleanupSpec@8=PathCleanupSpecAW@8 @171
  SHCreateLinks@20 @172
  SHValidateUNC@12 @173
  SHCreateShellFolderViewEx@8 @174
  SHGetSpecialFolderPath@16=SHGetSpecialFolderPathAW@16 @175
  SHSetInstanceExplorer@4 @176
  RegisterShellHook@8 @181
  ShellMessageBoxW @182
  ShellMessageBoxA @183
  ArrangeWindows@20 @184
  ILGetDisplayNameEx@16 @186
  ShellDDEInit@4 @188
  ILCreateFromPathA@4 @189
  ILCreateFromPathW@4 @190
  SHFree@4 @195
  SHAlloc@4 @196
  SHAbortInvokeCommand@0 @198
  SHInitRestricted@8 @244
  SHGetDataFromIDListA@20 @247
  SHGetDataFromIDListW@20 @248
  PathParseIconLocation@4=PathParseIconLocationAW@4 @249
  PathRemoveExtension@4=PathRemoveExtensionAW@4 @250
  PathRemoveArgs@4=PathRemoveArgsAW@4 @251
  SheChangeDirW@4 @274
  SheGetDirW@8 @281
  ShellAboutA@16 @288
  ShellAboutW@16 @289
  ShellExecuteA@24 @290
  ShellExecuteEx@4=ShellExecuteExAW@4 @291
  ShellExecuteExA@4 @292
  ShellExecuteExW@4 @293
  ShellExecuteW@24 @294
  Shell_NotifyIcon@8=Shell_NotifyIconA@8 @296
  Shell_NotifyIconA@8 @297
  Shell_NotifyIconW@8 @298
  StrChrA@8=shlwapi.StrChrA @301
  StrChrIA@8=shlwapi.StrChrIA @302
  StrChrIW@8=shlwapi.StrChrIW @303
  StrChrW@8=shlwapi.StrChrW @304
  StrCmpNA@12=shlwapi.StrCmpNA @305
  StrCmpNIA@12=shlwapi.StrCmpNIA @306
  StrCmpNIW@12=shlwapi.StrCmpNIW @307
  StrCmpNW@12=shlwapi.StrCmpNW @308
  StrCpyNA@12=lstrcpynA@12 @309
  StrCpyNW@12=shlwapi.StrCpyNW @310
  StrNCmpA@12=shlwapi.StrCmpNA @311
  StrNCmpIA@12=shlwapi.StrCmpNIA @312
  StrNCmpIW@12=shlwapi.StrCmpNIW @313
  StrNCmpW@12=shlwapi.StrCmpNW @314
  StrNCpyA@12=lstrcpynA@12 @315
  StrNCpyW@12=shlwapi.StrCpyNW @316
  StrRChrA@12=shlwapi.StrRChrA @317
  StrRChrIA@12=shlwapi.StrRChrIA @318
  StrRChrIW@12=shlwapi.StrRChrIW @319
  StrRChrW@12=shlwapi.StrRChrW @320
  StrRStrIA@12=shlwapi.StrRStrIA @322
  StrRStrIW@12=shlwapi.StrRStrIW @323
  StrStrA@8=shlwapi.StrStrA @325
  StrStrIA@8=shlwapi.StrStrIA @326
  StrStrIW@8=shlwapi.StrStrIW @327
  StrStrW@8=shlwapi.StrStrW @328
  SHRegCloseKey@4 @505
  SHRegOpenKeyA@12 @506
  SHRegOpenKeyW@12 @507
  SHRegQueryValueExA@24 @509
  SHRegQueryValueW@16 @510
  SHRegQueryValueExW@24 @511
  SHRegDeleteKeyW@8 @512
  SHAllocShared@12 @520
  SHLockShared@8 @521
  SHUnlockShared@4 @522
  SHFreeShared@8 @523
  NTSHChangeNotifyRegister@24 @640
  NTSHChangeNotifyDeregister@4 @641
  SHChangeNotification_Lock@16 @644
  SHChangeNotification_Unlock@4 @645
  PathIsSameRoot@8=PathIsSameRootAW@8 @650
  ReadCabinetState@8 @651
  WriteCabinetState@4 @652
  PathProcessCommand@16=PathProcessCommandAW@16 @653
  FileIconInit@4 @660
  IsUserAdmin@0 @680
  CheckEscapesA@8 @3
  CheckEscapesW@8 @6
  CommandLineToArgvW@8 @7
  Control_FillCache_RunDLL@16=Control_FillCache_RunDLLA@16 @8
  Control_FillCache_RunDLLA@16 @12
  Control_FillCache_RunDLLW@16 @14
  Control_RunDLL@16=Control_RunDLLA@16 @22
  Control_RunDLLA@16 @44
  Control_RunDLLW@16 @101
  DllCanUnloadNow@0=SHELL32_DllCanUnloadNow@0 @138 PRIVATE
  DllInstall@8=SHELL32_DllInstall@8 @150
  DllRegisterServer@0=SHELL32_DllRegisterServer@0 @191 PRIVATE
  DllUnregisterServer@0=SHELL32_DllUnregisterServer@0 @192 PRIVATE
  DoEnvironmentSubstA@8 @193
  DoEnvironmentSubstW@8 @194
  DuplicateIcon@8 @217
  ExtractAssociatedIconA@12 @218
  ExtractAssociatedIconExA@16 @219
  ExtractAssociatedIconExW@16 @220
  ExtractIconA@12 @222
  ExtractIconEx@20=ExtractIconExAW@20 @223
  ExtractIconExA@20 @224
  ExtractIconExW@20 @225
  ExtractIconW@12 @228
  FindExecutableA@12 @231
  FindExecutableW@12 @232
  FreeIconList@4 @233
  SHAddToRecentDocs@8 @254
  SHAppBarMessage@8 @255
  SHBrowseForFolder@4=SHBrowseForFolderA@4 @258
  SHBrowseForFolderA@4 @259
  SHBrowseForFolderW@4 @260
  SHChangeNotify@16 @261
  SHCreateDirectoryExA@12 @262
  SHCreateDirectoryExW@12 @263
  SHFileOperation@4=SHFileOperationAW@4 @268
  SHFileOperationA@4 @269
  SHFileOperationW@4 @270
  SHGetDesktopFolder@4 @330
  SHGetFileInfo@20=SHGetFileInfoAW@20 @334
  SHGetFileInfoA@20 @335
  SHGetFileInfoW@20 @336
  SHGetInstanceExplorer@4 @341
  SHGetMalloc@4 @342
  SHGetPathFromIDList@8=SHGetPathFromIDListAW@8 @344
  SHGetPathFromIDListA@8 @345
  SHGetPathFromIDListW@8 @346
  SHGetSettings@8 @347
  SHGetSpecialFolderLocation@12 @348
  SHHelpShortcuts_RunDLL@16 @351
  SHLoadInProc@4 @354
  DllGetVersion@4=SHELL32_DllGetVersion@4 @148
  SHGetSpecialFolderPathA@16 @349
  SHGetSpecialFolderPathW@16 @350
  SHBindToParent@16 @257
  SHGetDiskFreeSpaceA@16=kernel32.GetDiskFreeSpaceExA @331
  SHGetDiskFreeSpaceExA@16=kernel32.GetDiskFreeSpaceExA @332
  SHGetDiskFreeSpaceExW@16=kernel32.GetDiskFreeSpaceExW @333
  SHGetFolderPathA@20 @338
  SHGetFolderPathW@20 @339
  SHGetFolderLocation@20 @337
  SHDefExtractIconA@24 @264
  SHDefExtractIconW@24 @265
