; File generated automatically from dmcompos/dmcompos.spec; do not edit!

LIBRARY dmcompos.dll

EXPORTS
  DllCanUnloadNow@0=DMCOMPOS_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMCOMPOS_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMCOMPOS_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMCOMPOS_DllUnregisterServer@0 @4 PRIVATE
