; File generated automatically from winedos/winedos.spec; do not edit!

LIBRARY winedos.dll

EXPORTS
  wine_load_dos_exe@8 @5
  EmulateInterruptPM@8=DOSVM_EmulateInterruptPM@8 @2
  CallBuiltinHandler@8=DOSVM_CallBuiltinHandler@8 @1
  inport@8=DOSVM_inport@8 @3
  outport@12=DOSVM_outport@12 @4
