; File generated automatically from msvcrtd/msvcrtd.spec; do not edit!

LIBRARY msvcrtd.dll

EXPORTS
  $I10_OUTPUT=msvcrt.$I10_OUTPUT @1
  ??0__non_rtti_object@@QAE@ABV0@@Z=msvcrt.??0__non_rtti_object@@QAE@ABV0@@Z @2
  ??0__non_rtti_object@@QAE@PBD@Z=msvcrt.??0__non_rtti_object@@QAE@PBD@Z @3
  ??0bad_cast@@QAE@ABQBD@Z=msvcrt.??0bad_cast@@QAE@ABQBD@Z @4
  ??0bad_cast@@QAE@ABV0@@Z=msvcrt.??0bad_cast@@QAE@ABV0@@Z @5
  ??0bad_typeid@@QAE@ABV0@@Z=msvcrt.??0bad_typeid@@QAE@ABV0@@Z @6
  ??0bad_typeid@@QAE@PBD@Z=msvcrt.??0bad_typeid@@QAE@PBD@Z @7
  ??0exception@@QAE@ABQBD@Z=msvcrt.??0exception@@QAE@ABQBD@Z @8
  ??0exception@@QAE@ABV0@@Z=msvcrt.??0exception@@QAE@ABV0@@Z @9
  ??0exception@@QAE@XZ=msvcrt.??0exception@@QAE@XZ @10
  ??1__non_rtti_object@@UAE@XZ=msvcrt.??1__non_rtti_object@@UAE@XZ @11
  ??1bad_cast@@UAE@XZ=msvcrt.??1bad_cast@@UAE@XZ @12
  ??1bad_typeid@@UAE@XZ=msvcrt.??1bad_typeid@@UAE@XZ @13
  ??1exception@@UAE@XZ=msvcrt.??1exception@@UAE@XZ @14
  ??1type_info@@UAE@XZ=msvcrt.??1type_info@@UAE@XZ @15
  ??2@YAPAXI@Z=msvcrt.??2@YAPAXI@Z @16
  ??2@YAPAXIHPBDH@Z=msvcrt.??2@YAPAXIHPBDH@Z @17
  ??3@YAXPAX@Z=msvcrt.??3@YAXPAX@Z @18
  ??4__non_rtti_object@@QAEAAV0@ABV0@@Z=msvcrt.??4__non_rtti_object@@QAEAAV0@ABV0@@Z @19
  ??4bad_cast@@QAEAAV0@ABV0@@Z=msvcrt.??4bad_cast@@QAEAAV0@ABV0@@Z @20
  ??4bad_typeid@@QAEAAV0@ABV0@@Z=msvcrt.??4bad_typeid@@QAEAAV0@ABV0@@Z @21
  ??4exception@@QAEAAV0@ABV0@@Z=msvcrt.??4exception@@QAEAAV0@ABV0@@Z @22
  ??8type_info@@QBEHABV0@@Z=msvcrt.??8type_info@@QBEHABV0@@Z @23
  ??9type_info@@QBEHABV0@@Z=msvcrt.??9type_info@@QBEHABV0@@Z @24
  ??_7__non_rtti_object@@6B@=msvcrt.??_7__non_rtti_object@@6B@ @25 DATA
  ??_7bad_cast@@6B@=msvcrt.??_7bad_cast@@6B@ @26 DATA
  ??_7bad_typeid@@6B@=msvcrt.??_7bad_typeid@@6B@ @27 DATA
  ??_7exception@@6B@=msvcrt.??_7exception@@6B@ @28 DATA
  ??_E__non_rtti_object@@UAEPAXI@Z=msvcrt.??_E__non_rtti_object@@UAEPAXI@Z @29
  ??_Ebad_cast@@UAEPAXI@Z=msvcrt.??_Ebad_cast@@UAEPAXI@Z @30
  ??_Ebad_typeid@@UAEPAXI@Z=msvcrt.??_Ebad_typeid@@UAEPAXI@Z @31
  ??_Eexception@@UAEPAXI@Z=msvcrt.??_Eexception@@UAEPAXI@Z @32
  ??_G__non_rtti_object@@UAEPAXI@Z=msvcrt.??_G__non_rtti_object@@UAEPAXI@Z @33
  ??_Gbad_cast@@UAEPAXI@Z=msvcrt.??_Gbad_cast@@UAEPAXI@Z @34
  ??_Gbad_typeid@@UAEPAXI@Z=msvcrt.??_Gbad_typeid@@UAEPAXI@Z @35
  ??_Gexception@@UAEPAXI@Z=msvcrt.??_Gexception@@UAEPAXI@Z @36
  ?_query_new_handler@@YAP6AHI@ZXZ=msvcrt.?_query_new_handler@@YAP6AHI@ZXZ @37
  ?_query_new_mode@@YAHXZ=msvcrt.?_query_new_mode@@YAHXZ @38
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=msvcrt.?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z @39
  ?_set_new_mode@@YAHH@Z=msvcrt.?_set_new_mode@@YAHH@Z @40
  ?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z=msvcrt.?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z @41
  ?before@type_info@@QBEHABV1@@Z=msvcrt.?before@type_info@@QBEHABV1@@Z @42
  ?name@type_info@@QBEPBDXZ=msvcrt.?name@type_info@@QBEPBDXZ @43
  ?raw_name@type_info@@QBEPBDXZ=msvcrt.?raw_name@type_info@@QBEPBDXZ @44
  ?set_new_handler@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_new_handler@@YAP6AXXZP6AXXZ@Z @45
  ?set_terminate@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_terminate@@YAP6AXXZP6AXXZ@Z @46
  ?set_unexpected@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_unexpected@@YAP6AXXZP6AXXZ@Z @47
  ?terminate@@YAXXZ=msvcrt.?terminate@@YAXXZ @48
  ?unexpected@@YAXXZ=msvcrt.?unexpected@@YAXXZ @49
  ?what@exception@@UBEPBDXZ=msvcrt.?what@exception@@UBEPBDXZ @50
  _CIacos=msvcrt._CIacos @51
  _CIasin=msvcrt._CIasin @52
  _CIatan=msvcrt._CIatan @53
  _CIatan2=msvcrt._CIatan2 @54
  _CIcos=msvcrt._CIcos @55
  _CIcosh=msvcrt._CIcosh @56
  _CIexp=msvcrt._CIexp @57
  _CIfmod=msvcrt._CIfmod @58
  _CIlog=msvcrt._CIlog @59
  _CIlog10=msvcrt._CIlog10 @60
  _CIpow=msvcrt._CIpow @61
  _CIsin=msvcrt._CIsin @62
  _CIsinh=msvcrt._CIsinh @63
  _CIsqrt=msvcrt._CIsqrt @64
  _CItan=msvcrt._CItan @65
  _CItanh=msvcrt._CItanh @66
  _CrtDbgReport @69
  _CrtDumpMemoryLeaks @71
  _CrtSetBreakAlloc @80
  _CrtSetDbgFlag @82
  _CrtSetDumpClient @83
  _CrtSetReportHook @85
  _CrtSetReportMode @86
  _CxxThrowException=msvcrt._CxxThrowException @87
  _EH_prolog=msvcrt._EH_prolog @88
  _Getdays=msvcrt._Getdays @89
  _Getmonths=msvcrt._Getmonths @90
  _Getnames=msvcrt._Getnames @91
  _HUGE=msvcrt._HUGE @93 DATA
  _Strftime=msvcrt._Strftime @94
  _XcptFilter=msvcrt._XcptFilter @95
  __CxxFrameHandler=msvcrt.__CxxFrameHandler @96
  __CxxLongjmpUnwind@4=msvcrt.__CxxLongjmpUnwind @97
  __RTCastToVoid=msvcrt.__RTCastToVoid @98
  __RTDynamicCast=msvcrt.__RTDynamicCast @99
  __RTtypeid=msvcrt.__RTtypeid @100
  __STRINGTOLD=msvcrt.__STRINGTOLD @101
  __argc=msvcrt.__argc @102 DATA
  __argv=msvcrt.__argv @103 DATA
  __badioinfo=msvcrt.__badioinfo @104 DATA
  __crtCompareStringA=msvcrt.__crtCompareStringA @105
  __crtGetLocaleInfoW=msvcrt.__crtGetLocaleInfoW @106
  __crtLCMapStringA=msvcrt.__crtLCMapStringA @107
  __dllonexit=msvcrt.__dllonexit @108
  __doserrno=msvcrt.__doserrno @109
  __fpecode=msvcrt.__fpecode @110
  __getmainargs=msvcrt.__getmainargs @111
  __initenv=msvcrt.__initenv @112 DATA
  __isascii=msvcrt.__isascii @113
  __iscsym=msvcrt.__iscsym @114
  __iscsymf=msvcrt.__iscsymf @115
  __lc_codepage=msvcrt.__lc_codepage @116 DATA
  __lc_collate_cp=msvcrt.__lc_collate_cp @117 DATA
  __lc_handle=msvcrt.__lc_handle @118 DATA
  __lconv_init=msvcrt.__lconv_init @119
  __mb_cur_max=msvcrt.__mb_cur_max @120 DATA
  __p___argc=msvcrt.__p___argc @121
  __p___argv=msvcrt.__p___argv @122
  __p___initenv=msvcrt.__p___initenv @123
  __p___mb_cur_max=msvcrt.__p___mb_cur_max @124
  __p___wargv=msvcrt.__p___wargv @125
  __p___winitenv=msvcrt.__p___winitenv @126
  __p__acmdln=msvcrt.__p__acmdln @127
  __p__amblksiz=msvcrt.__p__amblksiz @128
  __p__commode=msvcrt.__p__commode @129
  __p__crtAssertBusy @130
  __p__crtBreakAlloc @131
  __p__crtDbgFlag @132
  __p__daylight=msvcrt.__p__daylight @133
  __p__dstbias=msvcrt.__p__dstbias @134
  __p__environ=msvcrt.__p__environ @135
  __p__fileinfo=msvcrt.__p__fileinfo @136
  __p__fmode=msvcrt.__p__fmode @137
  __p__iob=msvcrt.__p__iob @138
  __p__mbcasemap=msvcrt.__p__mbcasemap @139
  __p__mbctype=msvcrt.__p__mbctype @140
  __p__osver=msvcrt.__p__osver @141
  __p__pctype=msvcrt.__p__pctype @142
  __p__pgmptr=msvcrt.__p__pgmptr @143
  __p__pwctype=msvcrt.__p__pwctype @144
  __p__timezone=msvcrt.__p__timezone @145
  __p__tzname=msvcrt.__p__tzname @146
  __p__wcmdln=msvcrt.__p__wcmdln @147
  __p__wenviron=msvcrt.__p__wenviron @148
  __p__winmajor=msvcrt.__p__winmajor @149
  __p__winminor=msvcrt.__p__winminor @150
  __p__winver=msvcrt.__p__winver @151
  __p__wpgmptr=msvcrt.__p__wpgmptr @152
  __pioinfo=msvcrt.__pioinfo @153 DATA
  __pxcptinfoptrs=msvcrt.__pxcptinfoptrs @154
  __set_app_type=msvcrt.__set_app_type @155
  __setlc_active=msvcrt.__setlc_active @156 DATA
  __setusermatherr=msvcrt.__setusermatherr @157
  __threadhandle=kernel32.GetCurrentThread @158
  __threadid=kernel32.GetCurrentThreadId @159
  __toascii=msvcrt.__toascii @160
  __unDName=msvcrt.__unDName @161
  __unDNameEx=msvcrt.__unDNameEx @162
  __unguarded_readlc_active=msvcrt.__unguarded_readlc_active @163 DATA
  __wargv=msvcrt.__wargv @164 DATA
  __wgetmainargs=msvcrt.__wgetmainargs @165
  __winitenv=msvcrt.__winitenv @166 DATA
  _abnormal_termination=msvcrt._abnormal_termination @167
  _access=msvcrt._access @168
  _acmdln=msvcrt._acmdln @169 DATA
  _adj_fdiv_m16i=msvcrt._adj_fdiv_m16i @170
  _adj_fdiv_m32=msvcrt._adj_fdiv_m32 @171
  _adj_fdiv_m32i=msvcrt._adj_fdiv_m32i @172
  _adj_fdiv_m64=msvcrt._adj_fdiv_m64 @173
  _adj_fdiv_r=msvcrt._adj_fdiv_r @174
  _adj_fdivr_m16i=msvcrt._adj_fdivr_m16i @175
  _adj_fdivr_m32=msvcrt._adj_fdivr_m32 @176
  _adj_fdivr_m32i=msvcrt._adj_fdivr_m32i @177
  _adj_fdivr_m64=msvcrt._adj_fdivr_m64 @178
  _adj_fpatan=msvcrt._adj_fpatan @179
  _adj_fprem=msvcrt._adj_fprem @180
  _adj_fprem1=msvcrt._adj_fprem1 @181
  _adj_fptan=msvcrt._adj_fptan @182
  _adjust_fdiv=msvcrt._adjust_fdiv @183
  _aexit_rtn=msvcrt._aexit_rtn @184 DATA
  _amsg_exit=msvcrt._amsg_exit @185
  _assert=msvcrt._assert @186
  _atodbl=msvcrt._atodbl @187
  _atoi64=ntdll._atoi64 @188
  _atoldbl=msvcrt._atoldbl @189
  _beep=msvcrt._beep @190
  _beginthread=msvcrt._beginthread @191
  _beginthreadex=msvcrt._beginthreadex @192
  _c_exit=msvcrt._c_exit @193
  _cabs=msvcrt._cabs @194
  _callnewh=msvcrt._callnewh @195
  _calloc_dbg=msvcrt.calloc @196
  _cexit=msvcrt._cexit @197
  _cgets=msvcrt._cgets @198
  _chdir=msvcrt._chdir @199
  _chdrive=msvcrt._chdrive @200
  _chgsign=msvcrt._chgsign @201
  _chkesp=msvcrt._chkesp @202
  _chmod=msvcrt._chmod @203
  _chsize=msvcrt._chsize @204
  _clearfp=msvcrt._clearfp @205
  _close=msvcrt._close @206
  _commit=msvcrt._commit @207
  _commode=msvcrt._commode @208 DATA
  _control87=msvcrt._control87 @209
  _controlfp=msvcrt._controlfp @210
  _copysign=msvcrt._copysign @211
  _cprintf=msvcrt._cprintf @212
  _cputs=msvcrt._cputs @213
  _creat=msvcrt._creat @214
  _crtAssertBusy @215 DATA
  _crtBreakAlloc @216 DATA
  _crtDbgFlag @217 DATA
  _cscanf=msvcrt._cscanf @218
  _ctype=msvcrt._ctype @219 DATA
  _cwait=msvcrt._cwait @220
  _daylight=msvcrt._daylight @221 DATA
  _dstbias=msvcrt._dstbias @222 DATA
  _dup=msvcrt._dup @223
  _dup2=msvcrt._dup2 @224
  _ecvt=msvcrt._ecvt @225
  _endthread=msvcrt._endthread @226
  _endthreadex=msvcrt._endthreadex @227
  _environ=msvcrt._environ @228 DATA
  _eof=msvcrt._eof @229
  _errno=msvcrt._errno @230
  _except_handler2=msvcrt._except_handler2 @231
  _except_handler3=msvcrt._except_handler3 @232
  _execl=msvcrt._execl @233
  _execle=msvcrt._execle @234
  _execlp=msvcrt._execlp @235
  _execlpe=msvcrt._execlpe @236
  _execv=msvcrt._execv @237
  _execve=msvcrt._execve @238
  _execvp=msvcrt._execvp @239
  _execvpe=msvcrt._execvpe @240
  _exit=msvcrt._exit @241
  _expand=msvcrt._expand @242
  _expand_dbg=msvcrt._expand @243
  _fcloseall=msvcrt._fcloseall @244
  _fcvt=msvcrt._fcvt @245
  _fdopen=msvcrt._fdopen @246
  _fgetchar=msvcrt._fgetchar @247
  _fgetwchar=msvcrt._fgetwchar @248
  _filbuf=msvcrt._filbuf @249
  _fileinfo=msvcrt._fileinfo @250 DATA
  _filelength=msvcrt._filelength @251
  _filelengthi64=msvcrt._filelengthi64 @252
  _fileno=msvcrt._fileno @253
  _findclose=msvcrt._findclose @254
  _findfirst=msvcrt._findfirst @255
  _findfirsti64=msvcrt._findfirsti64 @256
  _findnext=msvcrt._findnext @257
  _findnexti64=msvcrt._findnexti64 @258
  _finite=msvcrt._finite @259
  _flsbuf=msvcrt._flsbuf @260
  _flushall=msvcrt._flushall @261
  _fmode=msvcrt._fmode @262 DATA
  _fpclass=msvcrt._fpclass @263
  _fpieee_flt=msvcrt._fpieee_flt @264
  _fpreset=msvcrt._fpreset @265
  _fputchar=msvcrt._fputchar @266
  _free_dbg=msvcrt.free @268
  _fputwchar=msvcrt._fputwchar @267
  _fsopen=msvcrt._fsopen @269
  _fstat=msvcrt._fstat @270
  _fstati64=msvcrt._fstati64 @271
  _ftime=msvcrt._ftime @272
  _ftol=ntdll._ftol @273
  _fullpath=msvcrt._fullpath @274
  _futime=msvcrt._futime @275
  _gcvt=msvcrt._gcvt @276
  _get_osfhandle=msvcrt._get_osfhandle @277
  _get_sbh_threshold=msvcrt._get_sbh_threshold @278
  _getch=msvcrt._getch @279
  _getche=msvcrt._getche @280
  _getcwd=msvcrt._getcwd @281
  _getdcwd=msvcrt._getdcwd @282
  _getdiskfree=msvcrt._getdiskfree @283
  _getdllprocaddr=msvcrt._getdllprocaddr @284
  _getdrive=msvcrt._getdrive @285
  _getdrives=kernel32.GetLogicalDrives @286
  _getmaxstdio=msvcrt._getmaxstdio @287
  _getmbcp=msvcrt._getmbcp @288
  _getpid=kernel32.GetCurrentProcessId @289
  _getsystime=msvcrt._getsystime @290
  _getw=msvcrt._getw @291
  _getws=msvcrt._getws @292
  _global_unwind2=msvcrt._global_unwind2 @293
  _heapadd=msvcrt._heapadd @294
  _heapchk=msvcrt._heapchk @295
  _heapmin=msvcrt._heapmin @296
  _heapset=msvcrt._heapset @297
  _heapused=msvcrt._heapused @298
  _heapwalk=msvcrt._heapwalk @299
  _hypot=hypot @300
  _i64toa=ntdll._i64toa @301
  _i64tow=ntdll._i64tow @302
  _initterm=msvcrt._initterm @303
  _inp=msvcrt._inp @304
  _inpd=msvcrt._inpd @305
  _inpw=msvcrt._inpw @306
  _iob=msvcrt._iob @307 DATA
  _isatty=msvcrt._isatty @308
  _isctype=msvcrt._isctype @309
  _ismbbalnum=msvcrt._ismbbalnum @310
  _ismbbalpha=msvcrt._ismbbalpha @311
  _ismbbgraph=msvcrt._ismbbgraph @312
  _ismbbkalnum=msvcrt._ismbbkalnum @313
  _ismbbkana=msvcrt._ismbbkana @314
  _ismbbkprint=msvcrt._ismbbkprint @315
  _ismbbkpunct=msvcrt._ismbbkpunct @316
  _ismbblead=msvcrt._ismbblead @317
  _ismbbprint=msvcrt._ismbbprint @318
  _ismbbpunct=msvcrt._ismbbpunct @319
  _ismbbtrail=msvcrt._ismbbtrail @320
  _ismbcalnum=msvcrt._ismbcalnum @321
  _ismbcalpha=msvcrt._ismbcalpha @322
  _ismbcdigit=msvcrt._ismbcdigit @323
  _ismbcgraph=msvcrt._ismbcgraph @324
  _ismbchira=msvcrt._ismbchira @325
  _ismbckata=msvcrt._ismbckata @326
  _ismbcl0=msvcrt._ismbcl0 @327
  _ismbcl1=msvcrt._ismbcl1 @328
  _ismbcl2=msvcrt._ismbcl2 @329
  _ismbclegal=msvcrt._ismbclegal @330
  _ismbclower=msvcrt._ismbclower @331
  _ismbcprint=msvcrt._ismbcprint @332
  _ismbcpunct=msvcrt._ismbcpunct @333
  _ismbcspace=msvcrt._ismbcspace @334
  _ismbcsymbol=msvcrt._ismbcsymbol @335
  _ismbcupper=msvcrt._ismbcupper @336
  _ismbslead=msvcrt._ismbslead @337
  _ismbstrail=msvcrt._ismbstrail @338
  _isnan=msvcrt._isnan @339
  _itoa=ntdll._itoa @340
  _itow=ntdll._itow @341
  _j0=j0 @342
  _j1=j1 @343
  _jn=jn @344
  _kbhit=msvcrt._kbhit @345
  _lfind=msvcrt._lfind @346
  _loaddll=msvcrt._loaddll @347
  _local_unwind2=msvcrt._local_unwind2 @348
  _lock=msvcrt._lock @349
  _locking=msvcrt._locking @350
  _logb=msvcrt._logb @351
  _longjmpex=msvcrt._longjmpex @352
  _lrotl=msvcrt._lrotl @353
  _lrotr=msvcrt._lrotr @354
  _lsearch=msvcrt._lsearch @355
  _lseek=msvcrt._lseek @356
  _lseeki64=msvcrt._lseeki64 @357
  _ltoa=ntdll._ltoa @358
  _ltow=ntdll._ltow @359
  _makepath=msvcrt._makepath @360
  _malloc_dbg=msvcrt.malloc @361
  _mbbtombc=msvcrt._mbbtombc @362
  _mbbtype=msvcrt._mbbtype @363
  _mbcasemap=msvcrt._mbcasemap @364 DATA
  _mbccpy=strcpy @365
  _mbcjistojms=msvcrt._mbcjistojms @366
  _mbcjmstojis=msvcrt._mbcjmstojis @367
  _mbclen=msvcrt._mbclen @368
  _mbctohira=msvcrt._mbctohira @369
  _mbctokata=msvcrt._mbctokata @370
  _mbctolower=msvcrt._mbctolower @371
  _mbctombb=msvcrt._mbctombb @372
  _mbctoupper=msvcrt._mbctoupper @373
  _mbctype=msvcrt._mbctype @374 DATA
  _mbsbtype=msvcrt._mbsbtype @375
  _mbscat=strcat @376
  _mbschr=msvcrt._mbschr @377
  _mbscmp=msvcrt._mbscmp @378
  _mbscoll=msvcrt._mbscoll @379
  _mbscpy=strcpy @380
  _mbscspn=msvcrt._mbscspn @381
  _mbsdec=msvcrt._mbsdec @382
  _mbsdup=msvcrt._strdup @383
  _mbsicmp=msvcrt._mbsicmp @384
  _mbsicoll=msvcrt._mbsicoll @385
  _mbsinc=msvcrt._mbsinc @386
  _mbslen=msvcrt._mbslen @387
  _mbslwr=msvcrt._mbslwr @388
  _mbsnbcat=msvcrt._mbsnbcat @389
  _mbsnbcmp=msvcrt._mbsnbcmp @390
  _mbsnbcnt=msvcrt._mbsnbcnt @391
  _mbsnbcoll=msvcrt._mbsnbcoll @392
  _mbsnbcpy=msvcrt._mbsnbcpy @393
  _mbsnbicmp=msvcrt._mbsnbicmp @394
  _mbsnbicoll=msvcrt._mbsnbicoll @395
  _mbsnbset=msvcrt._mbsnbset @396
  _mbsncat=msvcrt._mbsncat @397
  _mbsnccnt=msvcrt._mbsnccnt @398
  _mbsncmp=msvcrt._mbsncmp @399
  _mbsncoll=msvcrt._mbsncoll @400
  _mbsncpy=msvcrt._mbsncpy @401
  _mbsnextc=msvcrt._mbsnextc @402
  _mbsnicmp=msvcrt._mbsnicmp @403
  _mbsnicoll=msvcrt._mbsnicoll @404
  _mbsninc=msvcrt._mbsninc @405
  _mbsnset=msvcrt._mbsnset @406
  _mbspbrk=msvcrt._mbspbrk @407
  _mbsrchr=msvcrt._mbsrchr @408
  _mbsrev=msvcrt._mbsrev @409
  _mbsset=msvcrt._mbsset @410
  _mbsspn=msvcrt._mbsspn @411
  _mbsspnp=msvcrt._mbsspnp @412
  _mbsstr=strstr @413
  _mbstok=msvcrt._mbstok @414
  _mbstrlen=msvcrt._mbstrlen @415
  _mbsupr=msvcrt._mbsupr @416
  _memccpy=memccpy @417
  _memicmp=ntdll._memicmp @418
  _mkdir=msvcrt._mkdir @419
  _mktemp=msvcrt._mktemp @420
  _msize=msvcrt._msize @421
  _msize_dbg=msvcrt._msize @422
  _nextafter=msvcrt._nextafter @423
  _onexit=msvcrt._onexit @424
  _open=msvcrt._open @425
  _open_osfhandle=msvcrt._open_osfhandle @426
  _osver=msvcrt._osver @427 DATA
  _outp=msvcrt._outp @428
  _outpd=msvcrt._outpd @429
  _outpw=msvcrt._outpw @430
  _pclose=msvcrt._pclose @431
  _pctype=msvcrt._pctype @432 DATA
  _pgmptr=msvcrt._pgmptr @433 DATA
  _pipe=msvcrt._pipe @434
  _popen=msvcrt._popen @435
  _purecall=msvcrt._purecall @436
  _putch=msvcrt._putch @437
  _putenv=msvcrt._putenv @438
  _putw=msvcrt._putw @439
  _putws=msvcrt._putws @440
  _pwctype=msvcrt._pwctype @441 DATA
  _read=msvcrt._read @442
  _realloc_dbg=msvcrt.realloc @443
  _rmdir=msvcrt._rmdir @444
  _rmtmp=msvcrt._rmtmp @445
  _rotl=msvcrt._rotl @446
  _rotr=msvcrt._rotr @447
  _safe_fdiv=msvcrt._safe_fdiv @448
  _safe_fdivr=msvcrt._safe_fdivr @449
  _safe_fprem=msvcrt._safe_fprem @450
  _safe_fprem1=msvcrt._safe_fprem1 @451
  _scalb=msvcrt._scalb @452
  _searchenv=msvcrt._searchenv @453
  _seh_longjmp_unwind@4=msvcrt._seh_longjmp_unwind @454
  _set_error_mode=msvcrt._set_error_mode @455
  _set_sbh_threshold=msvcrt._set_sbh_threshold @456
  _seterrormode=msvcrt._seterrormode @457
  _setjmp=msvcrt._setjmp @458
  _setjmp3=msvcrt._setjmp3 @459
  _setmaxstdio=msvcrt._setmaxstdio @460
  _setmbcp=msvcrt._setmbcp @461
  _setmode=msvcrt._setmode @462
  _setsystime=msvcrt._setsystime @463
  _sleep=msvcrt._sleep @464
  _snprintf=snprintf @465
  _snwprintf=ntdll._snwprintf @466
  _sopen=msvcrt._sopen @467
  _spawnl=msvcrt._spawnl @468
  _spawnle=msvcrt._spawnle @469
  _spawnlp=msvcrt._spawnlp @470
  _spawnlpe=msvcrt._spawnlpe @471
  _spawnv=msvcrt._spawnv @472
  _spawnve=msvcrt._spawnve @473
  _spawnvp=msvcrt._spawnvp @474
  _spawnvpe=msvcrt._spawnvpe @475
  _splitpath=ntdll._splitpath @476
  _stat=msvcrt._stat @477
  _stati64=msvcrt._stati64 @478
  _statusfp=msvcrt._statusfp @479
  _strcmpi=strcasecmp @480
  _strdate=msvcrt._strdate @481
  _strdup=msvcrt._strdup @482
  _strerror=msvcrt._strerror @483
  _stricmp=strcasecmp @484
  _stricoll=msvcrt._stricoll @485
  _strlwr=ntdll._strlwr @486
  _strncoll=msvcrt._strncoll @487
  _strnicmp=strncasecmp @488
  _strnicoll=msvcrt._strnicoll @489
  _strnset=msvcrt._strnset @490
  _strrev=msvcrt._strrev @491
  _strset=msvcrt._strset @492
  _strtime=msvcrt._strtime @493
  _strupr=ntdll._strupr @494
  _swab=msvcrt._swab @495
  _sys_errlist=msvcrt._sys_errlist @496 DATA
  _sys_nerr=msvcrt._sys_nerr @497 DATA
  _tell=msvcrt._tell @498
  _telli64=msvcrt._telli64 @499
  _tempnam=msvcrt._tempnam @500
  _timezone=msvcrt._timezone @501 DATA
  _tolower=msvcrt._tolower @502
  _toupper=msvcrt._toupper @503
  _tzname=msvcrt._tzname @504 DATA
  _tzset=tzset @505
  _ui64toa=ntdll._ui64toa @506
  _ui64tow=ntdll._ui64tow @507
  _ultoa=ntdll._ultoa @508
  _ultow=ntdll._ultow @509
  _umask=msvcrt._umask @510
  _ungetch=msvcrt._ungetch @511
  _unlink=msvcrt._unlink @512
  _unloaddll=msvcrt._unloaddll @513
  _unlock=msvcrt._unlock @514
  _utime=msvcrt._utime @515
  _vsnprintf=vsnprintf @516
  _vsnwprintf=msvcrt._vsnwprintf @517
  _waccess=msvcrt._waccess @518
  _wasctime=msvcrt._wasctime @519
  _wchdir=msvcrt._wchdir @520
  _wchmod=msvcrt._wchmod @521
  _wcmdln=msvcrt._wcmdln @522 DATA
  _wcreat=msvcrt._wcreat @523
  _wcsdup=msvcrt._wcsdup @524
  _wcsicmp=ntdll._wcsicmp @525
  _wcsicoll=msvcrt._wcsicoll @526
  _wcslwr=ntdll._wcslwr @527
  _wcsncoll=msvcrt._wcsncoll @528
  _wcsnicmp=ntdll._wcsnicmp @529
  _wcsnicoll=msvcrt._wcsnicoll @530
  _wcsnset=msvcrt._wcsnset @531
  _wcsrev=msvcrt._wcsrev @532
  _wcsset=msvcrt._wcsset @533
  _wcsupr=ntdll._wcsupr @534
  _wctime=msvcrt._wctime @535
  _wenviron=msvcrt._wenviron @536 DATA
  _wexecl=msvcrt._wexecl @537
  _wexecle=msvcrt._wexecle @538
  _wexeclp=msvcrt._wexeclp @539
  _wexeclpe=msvcrt._wexeclpe @540
  _wexecv=msvcrt._wexecv @541
  _wexecve=msvcrt._wexecve @542
  _wexecvp=msvcrt._wexecvp @543
  _wexecvpe=msvcrt._wexecvpe @544
  _wfdopen=msvcrt._wfdopen @545
  _wfindfirst=msvcrt._wfindfirst @546
  _wfindfirsti64=msvcrt._wfindfirsti64 @547
  _wfindnext=msvcrt._wfindnext @548
  _wfindnexti64=msvcrt._wfindnexti64 @549
  _wfopen=msvcrt._wfopen @550
  _wfreopen=msvcrt._wfreopen @551
  _wfsopen=msvcrt._wfsopen @552
  _wfullpath=msvcrt._wfullpath @553
  _wgetcwd=msvcrt._wgetcwd @554
  _wgetdcwd=msvcrt._wgetdcwd @555
  _wgetenv=msvcrt._wgetenv @556
  _winmajor=msvcrt._winmajor @557 DATA
  _winminor=msvcrt._winminor @558 DATA
  _winver=msvcrt._winver @559 DATA
  _wmakepath=msvcrt._wmakepath @560
  _wmkdir=msvcrt._wmkdir @561
  _wmktemp=msvcrt._wmktemp @562
  _wopen=msvcrt._wopen @563
  _wperror=msvcrt._wperror @564
  _wpgmptr=msvcrt._wpgmptr @565 DATA
  _wpopen=msvcrt._wpopen @566
  _wputenv=msvcrt._wputenv @567
  _wremove=msvcrt._wremove @568
  _wrename=msvcrt._wrename @569
  _write=msvcrt._write @570
  _wrmdir=msvcrt._wrmdir @571
  _wsearchenv=msvcrt._wsearchenv @572
  _wsetlocale=msvcrt._wsetlocale @573
  _wsopen=msvcrt._wsopen @574
  _wspawnl=msvcrt._wspawnl @575
  _wspawnle=msvcrt._wspawnle @576
  _wspawnlp=msvcrt._wspawnlp @577
  _wspawnlpe=msvcrt._wspawnlpe @578
  _wspawnv=msvcrt._wspawnv @579
  _wspawnve=msvcrt._wspawnve @580
  _wspawnvp=msvcrt._wspawnvp @581
  _wspawnvpe=msvcrt._wspawnvpe @582
  _wsplitpath=msvcrt._wsplitpath @583
  _wstat=msvcrt._wstat @584
  _wstati64=msvcrt._wstati64 @585
  _wstrdate=msvcrt._wstrdate @586
  _wstrtime=msvcrt._wstrtime @587
  _wsystem=msvcrt._wsystem @588
  _wtempnam=msvcrt._wtempnam @589
  _wtmpnam=msvcrt._wtmpnam @590
  _wtoi=ntdll._wtoi @591
  _wtoi64=ntdll._wtoi64 @592
  _wtol=ntdll._wtol @593
  _wunlink=msvcrt._wunlink @594
  _wutime=msvcrt._wutime @595
  _y0=msvcrt._y0 @596
  _y1=msvcrt._y1 @597
  _yn=msvcrt._yn @598
  abort=msvcrt.abort @599
  abs @600
  acos @601
  asctime @602
  asin @603
  atan @604
  atan2 @605
  atexit=msvcrt.atexit @606
  atof @607
  atoi @608
  atol @609
  bsearch @610
  calloc=msvcrt.calloc @611
  ceil @612
  clearerr=msvcrt.clearerr @613
  clock=msvcrt.clock @614
  cos @615
  cosh @616
  ctime @617
  difftime=msvcrt.difftime @618
  div=msvcrt.div @619
  exit=msvcrt.exit @620
  exp @621
  fabs @622
  fclose=msvcrt.fclose @623
  feof=msvcrt.feof @624
  ferror=msvcrt.ferror @625
  fflush=msvcrt.fflush @626
  fgetc=msvcrt.fgetc @627
  fgetpos=msvcrt.fgetpos @628
  fgets=msvcrt.fgets @629
  fgetwc=msvcrt.fgetwc @630
  fgetws=msvcrt.fgetws @631
  floor @632
  fmod @633
  fopen=msvcrt.fopen @634
  fprintf=msvcrt.fprintf @635
  fputc=msvcrt.fputc @636
  fputs=msvcrt.fputs @637
  fputwc=msvcrt.fputwc @638
  fputws=msvcrt.fputws @639
  fread=msvcrt.fread @640
  free=msvcrt.free @641
  freopen=msvcrt.freopen @642
  frexp @643
  fscanf=msvcrt.fscanf @644
  fseek=msvcrt.fseek @645
  fsetpos=msvcrt.fsetpos @646
  ftell=msvcrt.ftell @647
  fwprintf=msvcrt.fwprintf @648
  fwrite=msvcrt.fwrite @649
  fwscanf=msvcrt.fwscanf @650
  getc=msvcrt.getc @651
  getchar=msvcrt.getchar @652
  getenv=msvcrt.getenv @653
  gets=msvcrt.gets @654
  getwc=msvcrt.getwc @655
  getwchar=msvcrt.getwchar @656
  gmtime @657
  is_wctype=ntdll.iswctype @658
  isalnum=msvcrt.isalnum @659
  isalpha=msvcrt.isalpha @660
  iscntrl=msvcrt.iscntrl @661
  isdigit=msvcrt.isdigit @662
  isgraph=msvcrt.isgraph @663
  isleadbyte=msvcrt.isleadbyte @664
  islower=msvcrt.islower @665
  isprint=msvcrt.isprint @666
  ispunct=msvcrt.ispunct @667
  isspace=msvcrt.isspace @668
  isupper=msvcrt.isupper @669
  iswalnum=msvcrt.iswalnum @670
  iswalpha=ntdll.iswalpha @671
  iswascii=msvcrt.iswascii @672
  iswcntrl=msvcrt.iswcntrl @673
  iswctype=ntdll.iswctype @674
  iswdigit=msvcrt.iswdigit @675
  iswgraph=msvcrt.iswgraph @676
  iswlower=msvcrt.iswlower @677
  iswprint=msvcrt.iswprint @678
  iswpunct=msvcrt.iswpunct @679
  iswspace=msvcrt.iswspace @680
  iswupper=msvcrt.iswupper @681
  iswxdigit=msvcrt.iswxdigit @682
  isxdigit=msvcrt.isxdigit @683
  labs @684
  ldexp=msvcrt.ldexp @685
  ldiv=msvcrt.ldiv @686
  localeconv=msvcrt.localeconv @687
  localtime @688
  log @689
  log10 @690
  longjmp=msvcrt.longjmp @691
  malloc=msvcrt.malloc @692
  mblen=msvcrt.mblen @693
  mbstowcs=ntdll.mbstowcs @694
  mbtowc=msvcrt.mbtowc @695
  memchr @696
  memcmp @697
  memcpy @698
  memmove @699
  memset @700
  mktime=msvcrt.mktime @701
  modf @702
  perror=msvcrt.perror @703
  pow @704
  printf=msvcrt.printf @705
  putc=msvcrt.putc @706
  putchar=msvcrt.putchar @707
  puts=msvcrt.puts @708
  putwc=msvcrt.putwc @709
  putwchar=msvcrt._fputwchar @710
  qsort @711
  raise=msvcrt.raise @712
  rand=msvcrt.rand @713
  realloc=msvcrt.realloc @714
  remove=msvcrt.remove @715
  rename=msvcrt.rename @716
  rewind=msvcrt.rewind @717
  scanf=msvcrt.scanf @718
  setbuf=msvcrt.setbuf @719
  setlocale=msvcrt.setlocale @720
  setvbuf=msvcrt.setvbuf @721
  signal=msvcrt.signal @722
  sin @723
  sinh @724
  sprintf @725
  sqrt @726
  srand @727
  sscanf=msvcrt.sscanf @728
  strcat @729
  strchr @730
  strcmp @731
  strcoll @732
  strcpy @733
  strcspn @734
  strerror=msvcrt.strerror @735
  strftime @736
  strlen @737
  strncat @738
  strncmp @739
  strncpy @740
  strpbrk @741
  strrchr @742
  strspn @743
  strstr @744
  strtod @745
  strtok @746
  strtol @747
  strtoul @748
  strxfrm @749
  swprintf=ntdll.swprintf @750
  swscanf=msvcrt.swscanf @751
  system=msvcrt.system @752
  tan @753
  tanh @754
  time=msvcrt.time @755
  tmpfile=msvcrt.tmpfile @756
  tmpnam=msvcrt.tmpnam @757
  tolower @758
  toupper @759
  towlower=ntdll.towlower @760
  towupper=ntdll.towupper @761
  ungetc=msvcrt.ungetc @762
  ungetwc=msvcrt.ungetwc @763
  vfprintf=msvcrt.vfprintf @764
  vfwprintf=msvcrt.vfwprintf @765
  vprintf=msvcrt.vprintf @766
  vsprintf @767
  vswprintf=msvcrt.vswprintf @768
  vwprintf=msvcrt.vwprintf @769
  wcscat=ntdll.wcscat @770
  wcschr=ntdll.wcschr @771
  wcscmp=ntdll.wcscmp @772
  wcscoll=msvcrt.wcscoll @773
  wcscpy=ntdll.wcscpy @774
  wcscspn=ntdll.wcscspn @775
  wcsftime=msvcrt.wcsftime @776
  wcslen=ntdll.wcslen @777
  wcsncat=ntdll.wcsncat @778
  wcsncmp=ntdll.wcsncmp @779
  wcsncpy=ntdll.wcsncpy @780
  wcspbrk=msvcrt.wcspbrk @781
  wcsrchr=ntdll.wcsrchr @782
  wcsspn=ntdll.wcsspn @783
  wcsstr=ntdll.wcsstr @784
  wcstod=msvcrt.wcstod @785
  wcstok=ntdll.wcstok @786
  wcstol=ntdll.wcstol @787
  wcstombs=ntdll.wcstombs @788
  wcstoul=ntdll.wcstoul @789
  wcsxfrm=msvcrt.wcsxfrm @790
  wctomb=msvcrt.wctomb @791
  wprintf=msvcrt.wprintf @792
  wscanf=msvcrt.wscanf @793
  _Gettnames=msvcrt._Gettnames @92
