; File generated automatically from msvcrt20/msvcrt20.spec; do not edit!

LIBRARY msvcrt20.dll

EXPORTS
  ??2@YAPAXI@Z=msvcrt.??2@YAPAXI@Z @80
  ??3@YAXPAX@Z=msvcrt.??3@YAXPAX@Z @81
  ?_query_new_handler@@YAP6AHI@ZXZ=msvcrt.?_query_new_handler@@YAP6AHI@ZXZ @227
  ?_query_new_mode@@YAHXZ=msvcrt.?_query_new_mode@@YAHXZ @228
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=msvcrt.?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z @229
  ?_set_new_mode@@YAHH@Z=msvcrt.?_set_new_mode@@YAHH@Z @230
  ?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z=msvcrt.?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z @231
  ?set_terminate@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_terminate@@YAP6AXXZP6AXXZ@Z @366
  ?set_unexpected@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_unexpected@@YAP6AXXZP6AXXZ@Z @367
  ?terminate@@YAXXZ=msvcrt.?terminate@@YAXXZ @410
  ?unexpected@@YAXXZ=msvcrt.?unexpected@@YAXXZ @419
  _CIacos=msvcrt._CIacos @439
  _CIasin=msvcrt._CIasin @440
  _CIatan=msvcrt._CIatan @441
  _CIatan2=msvcrt._CIatan2 @442
  _CIcos=msvcrt._CIcos @443
  _CIcosh=msvcrt._CIcosh @444
  _CIexp=msvcrt._CIexp @445
  _CIfmod=msvcrt._CIfmod @446
  _CIlog=msvcrt._CIlog @447
  _CIlog10=msvcrt._CIlog10 @448
  _CIpow=msvcrt._CIpow @449
  _CIsin=msvcrt._CIsin @450
  _CIsinh=msvcrt._CIsinh @451
  _CIsqrt=msvcrt._CIsqrt @452
  _CItan=msvcrt._CItan @453
  _CItanh=msvcrt._CItanh @454
  _CxxThrowException=msvcrt._CxxThrowException @455
  _HUGE=msvcrt._HUGE @456 DATA
  _XcptFilter=msvcrt._XcptFilter @457
  __CxxFrameHandler=msvcrt.__CxxFrameHandler @458
  __CxxLongjmpUnwind@4=msvcrt.__CxxLongjmpUnwind @459
  __STRINGTOLD=msvcrt.__STRINGTOLD @460
  __argc=msvcrt.__argc @461 DATA
  __argv=msvcrt.__argv @462 DATA
  __dllonexit=msvcrt.__dllonexit @463
  __doserrno=msvcrt.__doserrno @464
  __fpecode=msvcrt.__fpecode @465
  __getmainargs=MSVCRT20__getmainargs @466
  __initenv=msvcrt.__initenv @467 DATA
  __isascii=msvcrt.__isascii @468
  __iscsym=msvcrt.__iscsym @469
  __iscsymf=msvcrt.__iscsymf @470
  __lconv_init=msvcrt.__lconv_init @471
  __mb_cur_max=msvcrt.__mb_cur_max @472 DATA
  __p___argc=msvcrt.__p___argc @473
  __p___argv=msvcrt.__p___argv @474
  __p___initenv=msvcrt.__p___initenv @475
  __p___mb_cur_max=msvcrt.__p___mb_cur_max @476
  __p___wargv=msvcrt.__p___wargv @477
  __p___winitenv=msvcrt.__p___winitenv @478
  __p__acmdln=msvcrt.__p__acmdln @479
  __p__amblksiz=msvcrt.__p__amblksiz @480
  __p__commode=msvcrt.__p__commode @481
  __p__daylight=msvcrt.__p__daylight @482
  __p__environ=msvcrt.__p__environ @483
  __p__fmode=msvcrt.__p__fmode @484
  __p__iob=msvcrt.__p__iob @485
  __p__mbctype=msvcrt.__p__mbctype @486
  __p__osver=msvcrt.__p__osver @487
  __p__pctype=msvcrt.__p__pctype @488
  __p__pgmptr=msvcrt.__p__pgmptr @489
  __p__pwctype=msvcrt.__p__pwctype @490
  __p__timezone=msvcrt.__p__timezone @491
  __p__tzname=msvcrt.__p__tzname @492
  __p__wcmdln=msvcrt.__p__wcmdln @493
  __p__wenviron=msvcrt.__p__wenviron @494
  __p__winmajor=msvcrt.__p__winmajor @495
  __p__winminor=msvcrt.__p__winminor @496
  __p__winver=msvcrt.__p__winver @497
  __p__wpgmptr=msvcrt.__p__wpgmptr @498
  __pxcptinfoptrs=msvcrt.__pxcptinfoptrs @499
  __threadhandle=msvcrt.__threadhandle @501
  __threadid=msvcrt.__threadid @502
  __toascii=msvcrt.__toascii @503
  __wargv=msvcrt.__wargv @504 DATA
  __wgetmainargs=MSVCRT20__wgetmainargs @505
  __winitenv=msvcrt.__winitenv @506 DATA
  _abnormal_termination=msvcrt._abnormal_termination @507
  _access=msvcrt._access @508
  _acmdln=msvcrt._acmdln @509 DATA
  _adj_fdiv_m16i=msvcrt._adj_fdiv_m16i @510
  _adj_fdiv_m32=msvcrt._adj_fdiv_m32 @511
  _adj_fdiv_m32i=msvcrt._adj_fdiv_m32i @512
  _adj_fdiv_m64=msvcrt._adj_fdiv_m64 @513
  _adj_fdiv_r=msvcrt._adj_fdiv_r @514
  _adj_fdivr_m16i=msvcrt._adj_fdivr_m16i @515
  _adj_fdivr_m32=msvcrt._adj_fdivr_m32 @516
  _adj_fdivr_m32i=msvcrt._adj_fdivr_m32i @517
  _adj_fdivr_m64=msvcrt._adj_fdivr_m64 @518
  _adj_fpatan=msvcrt._adj_fpatan @519
  _adj_fprem=msvcrt._adj_fprem @520
  _adj_fprem1=msvcrt._adj_fprem1 @521
  _adj_fptan=msvcrt._adj_fptan @522
  _adjust_fdiv=msvcrt._adjust_fdiv @523
  _aexit_rtn=msvcrt._aexit_rtn @524 DATA
  _amsg_exit=msvcrt._amsg_exit @525
  _assert=msvcrt._assert @526
  _atodbl=msvcrt._atodbl @527
  _atoi64=msvcrt._atoi64 @528
  _atoldbl=msvcrt._atoldbl @529
  _beep=msvcrt._beep @530
  _beginthread=msvcrt._beginthread @531
  _beginthreadex=msvcrt._beginthreadex @532
  _c_exit=msvcrt._c_exit @533
  _cabs=msvcrt._cabs @534
  _cexit=msvcrt._cexit @535
  _cgets=msvcrt._cgets @536
  _chdir=msvcrt._chdir @537
  _chdrive=msvcrt._chdrive @538
  _chgsign=msvcrt._chgsign @539
  _chmod=msvcrt._chmod @540
  _chsize=msvcrt._chsize @541
  _clearfp=msvcrt._clearfp @542
  _close=msvcrt._close @543
  _commit=msvcrt._commit @544
  _commode=msvcrt._commode @545 DATA
  _control87=msvcrt._control87 @546
  _controlfp=msvcrt._controlfp @547
  _copysign=msvcrt._copysign @548
  _cprintf=msvcrt._cprintf @549
  _cputs=msvcrt._cputs @550
  _creat=msvcrt._creat @551
  _cscanf=msvcrt._cscanf @552
  _ctype=msvcrt._ctype @553 DATA
  _cwait=msvcrt._cwait @554
  _daylight=msvcrt._daylight @555 DATA
  _dup=msvcrt._dup @556
  _dup2=msvcrt._dup2 @557
  _ecvt=msvcrt._ecvt @558
  _endthread=msvcrt._endthread @559
  _endthreadex=msvcrt._endthreadex @560
  _environ=msvcrt._environ @561 DATA
  _eof=msvcrt._eof @562
  _errno=msvcrt._errno @563
  _except_handler2=msvcrt._except_handler2 @564
  _except_handler3=msvcrt._except_handler3 @565
  _execl=msvcrt._execl @566
  _execle=msvcrt._execle @567
  _execlp=msvcrt._execlp @568
  _execlpe=msvcrt._execlpe @569
  _execv=msvcrt._execv @570
  _execve=msvcrt._execve @571
  _execvp=msvcrt._execvp @572
  _execvpe=msvcrt._execvpe @573
  _exit=msvcrt._exit @574
  _expand=msvcrt._expand @575
  _fcloseall=msvcrt._fcloseall @576
  _fcvt=msvcrt._fcvt @577
  _fdopen=msvcrt._fdopen @578
  _fgetchar=msvcrt._fgetchar @579
  _fgetwchar=msvcrt._fgetwchar @580
  _filbuf=msvcrt._filbuf @581
  _fileinfo=msvcrt._fileinfo @582 DATA
  _filelength=msvcrt._filelength @583
  _fileno=msvcrt._fileno @584
  _findclose=msvcrt._findclose @585
  _findfirst=msvcrt._findfirst @586
  _findnext=msvcrt._findnext @587
  _finite=msvcrt._finite @588
  _flsbuf=msvcrt._flsbuf @589
  _flushall=msvcrt._flushall @590
  _fmode=msvcrt._fmode @591 DATA
  _fpclass=msvcrt._fpclass @592
  _fpieee_flt=msvcrt._fpieee_flt @593
  _fpreset=msvcrt._fpreset @594
  _fputchar=msvcrt._fputchar @595
  _fputwchar=msvcrt._fputwchar @596
  _fsopen=msvcrt._fsopen @597
  _fstat=msvcrt._fstat @598
  _ftime=msvcrt._ftime @599
  _ftol=msvcrt._ftol @600
  _fullpath=msvcrt._fullpath @601
  _futime=msvcrt._futime @602
  _gcvt=msvcrt._gcvt @603
  _get_osfhandle=msvcrt._get_osfhandle @604
  _getch=msvcrt._getch @605
  _getche=msvcrt._getche @606
  _getcwd=msvcrt._getcwd @607
  _getdcwd=msvcrt._getdcwd @608
  _getdiskfree=msvcrt._getdiskfree @609
  _getdllprocaddr=msvcrt._getdllprocaddr @610
  _getdrive=msvcrt._getdrive @611
  _getdrives=msvcrt._getdrives @612
  _getmbcp=msvcrt._getmbcp @613
  _getpid=msvcrt._getpid @614
  _getsystime=msvcrt._getsystime @615
  _getw=msvcrt._getw @616
  _getws=msvcrt._getws @617
  _global_unwind2=msvcrt._global_unwind2 @618
  _heapadd=msvcrt._heapadd @619
  _heapchk=msvcrt._heapchk @620
  _heapmin=msvcrt._heapmin @621
  _heapset=msvcrt._heapset @622
  _heapused=msvcrt._heapused @623
  _heapwalk=msvcrt._heapwalk @624
  _hypot=msvcrt._hypot @625
  _i64toa=msvcrt._i64toa @626
  _i64tow=msvcrt._i64tow @627
  _initterm=msvcrt._initterm @628
  _iob=msvcrt._iob @629 DATA
  _isatty=msvcrt._isatty @630
  _isctype=msvcrt._isctype @631
  _ismbbalnum=msvcrt._ismbbalnum @632
  _ismbbalpha=msvcrt._ismbbalpha @633
  _ismbbgraph=msvcrt._ismbbgraph @634
  _ismbbkalnum=msvcrt._ismbbkalnum @635
  _ismbbkana=msvcrt._ismbbkana @636
  _ismbbkprint=msvcrt._ismbbkprint @637
  _ismbbkpunct=msvcrt._ismbbkpunct @638
  _ismbblead=msvcrt._ismbblead @639
  _ismbbprint=msvcrt._ismbbprint @640
  _ismbbpunct=msvcrt._ismbbpunct @641
  _ismbbtrail=msvcrt._ismbbtrail @642
  _ismbcalnum=msvcrt._ismbcalnum @643
  _ismbcalpha=msvcrt._ismbcalpha @644
  _ismbcdigit=msvcrt._ismbcdigit @645
  _ismbcgraph=msvcrt._ismbcgraph @646
  _ismbchira=msvcrt._ismbchira @647
  _ismbckata=msvcrt._ismbckata @648
  _ismbcl0=msvcrt._ismbcl0 @649
  _ismbcl1=msvcrt._ismbcl1 @650
  _ismbcl2=msvcrt._ismbcl2 @651
  _ismbclegal=msvcrt._ismbclegal @652
  _ismbclower=msvcrt._ismbclower @653
  _ismbcprint=msvcrt._ismbcprint @654
  _ismbcpunct=msvcrt._ismbcpunct @655
  _ismbcspace=msvcrt._ismbcspace @656
  _ismbcsymbol=msvcrt._ismbcsymbol @657
  _ismbcupper=msvcrt._ismbcupper @658
  _ismbslead=msvcrt._ismbslead @659
  _ismbstrail=msvcrt._ismbstrail @660
  _isnan=msvcrt._isnan @661
  _itoa=msvcrt._itoa @662
  _itow=msvcrt._itow @663
  _j0=msvcrt._j0 @664
  _j1=msvcrt._j1 @665
  _jn=msvcrt._jn @666
  _kbhit=msvcrt._kbhit @667
  _lfind=msvcrt._lfind @668
  _loaddll=msvcrt._loaddll @669
  _local_unwind2=msvcrt._local_unwind2 @670
  _locking=msvcrt._locking @671
  _logb=msvcrt._logb @672
  _longjmpex=msvcrt._longjmpex @673
  _lrotl=msvcrt._lrotl @674
  _lrotr=msvcrt._lrotr @675
  _lsearch=msvcrt._lsearch @676
  _lseek=msvcrt._lseek @677
  _ltoa=msvcrt._ltoa @678
  _ltow=msvcrt._ltow @679
  _makepath=msvcrt._makepath @680
  _matherr=msvcrt._matherr @681
  _mbbtombc=msvcrt._mbbtombc @682
  _mbbtype=msvcrt._mbbtype @683
  _mbccpy=msvcrt._mbccpy @684
  _mbcjistojms=msvcrt._mbcjistojms @685
  _mbcjmstojis=msvcrt._mbcjmstojis @686
  _mbclen=msvcrt._mbclen @687
  _mbctohira=msvcrt._mbctohira @688
  _mbctokata=msvcrt._mbctokata @689
  _mbctolower=msvcrt._mbctolower @690
  _mbctombb=msvcrt._mbctombb @691
  _mbctoupper=msvcrt._mbctoupper @692
  _mbctype=msvcrt._mbctype @693 DATA
  _mbsbtype=msvcrt._mbsbtype @694
  _mbscat=msvcrt._mbscat @695
  _mbschr=msvcrt._mbschr @696
  _mbscmp=msvcrt._mbscmp @697
  _mbscoll=msvcrt._mbscoll @698
  _mbscpy=msvcrt._mbscpy @699
  _mbscspn=msvcrt._mbscspn @700
  _mbsdec=msvcrt._mbsdec @701
  _mbsdup=msvcrt._mbsdup @702
  _mbsicmp=msvcrt._mbsicmp @703
  _mbsicoll=msvcrt._mbsicoll @704
  _mbsinc=msvcrt._mbsinc @705
  _mbslen=msvcrt._mbslen @706
  _mbslwr=msvcrt._mbslwr @707
  _mbsnbcat=msvcrt._mbsnbcat @708
  _mbsnbcmp=msvcrt._mbsnbcmp @709
  _mbsnbcnt=msvcrt._mbsnbcnt @710
  _mbsnbcoll=msvcrt._mbsnbcoll @711
  _mbsnbcpy=msvcrt._mbsnbcpy @712
  _mbsnbicmp=msvcrt._mbsnbicmp @713
  _mbsnbicoll=msvcrt._mbsnbicoll @714
  _mbsnbset=msvcrt._mbsnbset @715
  _mbsncat=msvcrt._mbsncat @716
  _mbsnccnt=msvcrt._mbsnccnt @717
  _mbsncmp=msvcrt._mbsncmp @718
  _mbsncoll=msvcrt._mbsncoll @719
  _mbsncpy=msvcrt._mbsncpy @720
  _mbsnextc=msvcrt._mbsnextc @721
  _mbsnicmp=msvcrt._mbsnicmp @722
  _mbsnicoll=msvcrt._mbsnicoll @723
  _mbsninc=msvcrt._mbsninc @724
  _mbsnset=msvcrt._mbsnset @725
  _mbspbrk=msvcrt._mbspbrk @726
  _mbsrchr=msvcrt._mbsrchr @727
  _mbsrev=msvcrt._mbsrev @728
  _mbsset=msvcrt._mbsset @729
  _mbsspn=msvcrt._mbsspn @730
  _mbsspnp=msvcrt._mbsspnp @731
  _mbsstr=msvcrt._mbsstr @732
  _mbstok=msvcrt._mbstok @733
  _mbstrlen=msvcrt._mbstrlen @734
  _mbsupr=msvcrt._mbsupr @735
  _memccpy=msvcrt._memccpy @736
  _memicmp=msvcrt._memicmp @737
  _mkdir=msvcrt._mkdir @738
  _mktemp=msvcrt._mktemp @739
  _msize=msvcrt._msize @740
  _nextafter=msvcrt._nextafter @743
  _onexit=msvcrt._onexit @744
  _open=msvcrt._open @745
  _open_osfhandle=msvcrt._open_osfhandle @746
  _osver=msvcrt._osver @747 DATA
  _pclose=msvcrt._pclose @748
  _pctype=msvcrt._pctype @749 DATA
  _pgmptr=msvcrt._pgmptr @750 DATA
  _pipe=msvcrt._pipe @751
  _popen=msvcrt._popen @752
  _purecall=msvcrt._purecall @753
  _putch=msvcrt._putch @754
  _putenv=msvcrt._putenv @755
  _putw=msvcrt._putw @756
  _putws=msvcrt._putws @757
  _pwctype=msvcrt._pwctype @758 DATA
  _read=msvcrt._read @759
  _rmdir=msvcrt._rmdir @760
  _rmtmp=msvcrt._rmtmp @761
  _rotl=msvcrt._rotl @762
  _rotr=msvcrt._rotr @763
  _safe_fdiv=msvcrt._safe_fdiv @764
  _safe_fdivr=msvcrt._safe_fdivr @765
  _safe_fprem=msvcrt._safe_fprem @766
  _safe_fprem1=msvcrt._safe_fprem1 @767
  _scalb=msvcrt._scalb @768
  _searchenv=msvcrt._searchenv @769
  __seh_longjmp_unwind@4=msvcrt._seh_longjmp_unwind @500
  _seterrormode=msvcrt._seterrormode @770
  _setjmp=msvcrt._setjmp @771
  _setjmp3=msvcrt._setjmp3 @772
  _setmbcp=msvcrt._setmbcp @773
  _setmode=msvcrt._setmode @774
  _setsystime=msvcrt._setsystime @775
  _sleep=msvcrt._sleep @776
  _snprintf=msvcrt._snprintf @777
  _snwprintf=msvcrt._snwprintf @778
  _sopen=msvcrt._sopen @779
  _spawnl=msvcrt._spawnl @780
  _spawnle=msvcrt._spawnle @781
  _spawnlp=msvcrt._spawnlp @782
  _spawnlpe=msvcrt._spawnlpe @783
  _spawnv=msvcrt._spawnv @784
  _spawnve=msvcrt._spawnve @785
  _spawnvp=msvcrt._spawnvp @786
  _spawnvpe=msvcrt._spawnvpe @787
  _splitpath=msvcrt._splitpath @788
  _stat=msvcrt._stat @789
  _statusfp=msvcrt._statusfp @790
  _strcmpi=msvcrt._strcmpi @791
  _strdate=msvcrt._strdate @792
  _strdup=msvcrt._strdup @793
  _strerror=msvcrt._strerror @794
  _stricmp=msvcrt._stricmp @795
  _stricoll=msvcrt._stricoll @796
  _strlwr=msvcrt._strlwr @797
  _strncoll=msvcrt._strncoll @798
  _strnicmp=msvcrt._strnicmp @799
  _strnicoll=msvcrt._strnicoll @800
  _strnset=msvcrt._strnset @801
  _strrev=msvcrt._strrev @802
  _strset=msvcrt._strset @803
  _strtime=msvcrt._strtime @804
  _strupr=msvcrt._strupr @805
  _swab=msvcrt._swab @806
  _sys_errlist=msvcrt._sys_errlist @807 DATA
  _sys_nerr=msvcrt._sys_nerr @808 DATA
  _tccpy=msvcrt._mbccpy @809
  _tclen=msvcrt._mbclen @810
  _tcschr=msvcrt._mbschr @811
  _tcsclen=msvcrt._mbslen @812
  _tcscmp=msvcrt._mbscmp @813
  _tcscspn=msvcrt._mbscspn @814
  _tcsdec=msvcrt._mbsdec @815
  _tcsicmp=msvcrt._mbsicmp @816
  _tcsinc=msvcrt._mbsinc @817
  _tcslwr=msvcrt._mbslwr @818
  _tcsnbcnt=msvcrt._mbsnbcnt @819
  _tcsncat=msvcrt._mbsnbcat @820
  _tcsnccat=msvcrt._mbsncat @821
  _tcsnccmp=msvcrt._mbsncmp @822
  _tcsnccnt=msvcrt._mbsnccnt @823
  _tcsnccpy=msvcrt._mbsncpy @824
  _tcsncicmp=msvcrt._mbsnicmp @825
  _tcsncmp=msvcrt._mbsnbcmp @826
  _tcsncpy=msvcrt._mbsnbcpy @827
  _tcsncset=msvcrt._mbsnset @828
  _tcsnextc=msvcrt._mbsnextc @829
  _tcsnicmp=msvcrt._mbsnbicmp @830
  _tcsninc=msvcrt._mbsninc @831
  _tcsnset=msvcrt._mbsnbset @832
  _tcspbrk=msvcrt._mbspbrk @833
  _tcsrchr=msvcrt._mbsrchr @834
  _tcsrev=msvcrt._mbsrev @835
  _tcsset=msvcrt._mbsset @836
  _tcsspn=msvcrt._mbsspn @837
  _tcsspnp=msvcrt._mbsspnp @838
  _tcsstr=msvcrt._mbsstr @839
  _tcstok=msvcrt._mbstok @840
  _tcsupr=msvcrt._mbsupr @841
  _tell=msvcrt._tell @842
  _tempnam=msvcrt._tempnam @843
  _timezone=msvcrt._timezone @844 DATA
  _tolower=msvcrt._tolower @845
  _toupper=msvcrt._toupper @846
  _tzname=msvcrt._tzname @847 DATA
  _tzset=msvcrt._tzset @848
  _ui64toa=msvcrt._ui64toa @849
  _ui64tow=msvcrt._ui64tow @850
  _ultoa=msvcrt._ultoa @851
  _ultow=msvcrt._ultow @852
  _umask=msvcrt._umask @853
  _ungetch=msvcrt._ungetch @854
  _unlink=msvcrt._unlink @855
  _unloaddll=msvcrt._unloaddll @856
  _utime=msvcrt._utime @857
  _vsnprintf=msvcrt._vsnprintf @858
  _vsnwprintf=msvcrt._vsnwprintf @859
  _waccess=msvcrt._waccess @860
  _wasctime=msvcrt._wasctime @861
  _wchdir=msvcrt._wchdir @862
  _wchmod=msvcrt._wchmod @863
  _wcmdln=msvcrt._wcmdln @864 DATA
  _wcreat=msvcrt._wcreat @865
  _wcsdup=msvcrt._wcsdup @866
  _wcsicmp=msvcrt._wcsicmp @867
  _wcsicoll=msvcrt._wcsicoll @868
  _wcslwr=msvcrt._wcslwr @869
  _wcsncoll=msvcrt._wcsncoll @870
  _wcsnicmp=msvcrt._wcsnicmp @871
  _wcsnicoll=msvcrt._wcsnicoll @872
  _wcsnset=msvcrt._wcsnset @873
  _wcsrev=msvcrt._wcsrev @874
  _wcsset=msvcrt._wcsset @875
  _wcsupr=msvcrt._wcsupr @876
  _wctime=msvcrt._wctime @877
  _wenviron=msvcrt._wenviron @878 DATA
  _wexecl=msvcrt._wexecl @879
  _wexecle=msvcrt._wexecle @880
  _wexeclp=msvcrt._wexeclp @881
  _wexeclpe=msvcrt._wexeclpe @882
  _wexecv=msvcrt._wexecv @883
  _wexecve=msvcrt._wexecve @884
  _wexecvp=msvcrt._wexecvp @885
  _wexecvpe=msvcrt._wexecvpe @886
  _wfdopen=msvcrt._wfdopen @887
  _wfindfirst=msvcrt._wfindfirst @888
  _wfindnext=msvcrt._wfindnext @889
  _wfopen=msvcrt._wfopen @890
  _wfreopen=msvcrt._wfreopen @891
  _wfsopen=msvcrt._wfsopen @892
  _wfullpath=msvcrt._wfullpath @893
  _wgetcwd=msvcrt._wgetcwd @894
  _wgetdcwd=msvcrt._wgetdcwd @895
  _wgetenv=msvcrt._wgetenv @896
  _winmajor=msvcrt._winmajor @897 DATA
  _winminor=msvcrt._winminor @898 DATA
  _winver=msvcrt._winver @899 DATA
  _wmakepath=msvcrt._wmakepath @900
  _wmkdir=msvcrt._wmkdir @901
  _wmktemp=msvcrt._wmktemp @902
  _wopen=msvcrt._wopen @903
  _wperror=msvcrt._wperror @904
  _wpgmptr=msvcrt._wpgmptr @905 DATA
  _wpopen=msvcrt._wpopen @906
  _wputenv=msvcrt._wputenv @907
  _wremove=msvcrt._wremove @908
  _wrename=msvcrt._wrename @909
  _write=msvcrt._write @910
  _wrmdir=msvcrt._wrmdir @911
  _wsearchenv=msvcrt._wsearchenv @912
  _wsetlocale=msvcrt._wsetlocale @913
  _wsopen=msvcrt._wsopen @914
  _wspawnl=msvcrt._wspawnl @915
  _wspawnle=msvcrt._wspawnle @916
  _wspawnlp=msvcrt._wspawnlp @917
  _wspawnlpe=msvcrt._wspawnlpe @918
  _wspawnv=msvcrt._wspawnv @919
  _wspawnve=msvcrt._wspawnve @920
  _wspawnvp=msvcrt._wspawnvp @921
  _wspawnvpe=msvcrt._wspawnvpe @922
  _wsplitpath=msvcrt._wsplitpath @923
  _wstat=msvcrt._wstat @924
  _wstrdate=msvcrt._wstrdate @925
  _wstrtime=msvcrt._wstrtime @926
  _wsystem=msvcrt._wsystem @927
  _wtempnam=msvcrt._wtempnam @928
  _wtmpnam=msvcrt._wtmpnam @929
  _wtoi=msvcrt._wtoi @930
  _wtoi64=msvcrt._wtoi64 @931
  _wtol=msvcrt._wtol @932
  _wunlink=msvcrt._wunlink @933
  _wutime=msvcrt._wutime @934
  _y0=msvcrt._y0 @935
  _y1=msvcrt._y1 @936
  _yn=msvcrt._yn @937
  abort=msvcrt.abort @938
  abs=msvcrt.abs @939
  acos=msvcrt.acos @940
  asctime=msvcrt.asctime @941
  asin=msvcrt.asin @942
  atan=msvcrt.atan @943
  atan2=msvcrt.atan2 @944
  atexit=msvcrt.atexit @945
  atof=msvcrt.atof @946
  atoi=msvcrt.atoi @947
  atol=msvcrt.atol @948
  bsearch=msvcrt.bsearch @949
  calloc=msvcrt.calloc @950
  ceil=msvcrt.ceil @951
  clearerr=msvcrt.clearerr @952
  clock=msvcrt.clock @953
  cos=msvcrt.cos @954
  cosh=msvcrt.cosh @955
  ctime=msvcrt.ctime @956
  difftime=msvcrt.difftime @957
  div=msvcrt.div @958
  exit=msvcrt.exit @959
  exp=msvcrt.exp @960
  fabs=msvcrt.fabs @961
  fclose=msvcrt.fclose @962
  feof=msvcrt.feof @963
  ferror=msvcrt.ferror @964
  fflush=msvcrt.fflush @965
  fgetc=msvcrt.fgetc @966
  fgetpos=msvcrt.fgetpos @967
  fgets=msvcrt.fgets @968
  fgetwc=msvcrt.fgetwc @969
  fgetws=msvcrt.fgetws @970
  floor=msvcrt.floor @971
  fmod=msvcrt.fmod @972
  fopen=msvcrt.fopen @973
  fprintf=msvcrt.fprintf @974
  fputc=msvcrt.fputc @975
  fputs=msvcrt.fputs @976
  fputwc=msvcrt.fputwc @977
  fputws=msvcrt.fputws @978
  fread=msvcrt.fread @979
  free=msvcrt.free @980
  freopen=msvcrt.freopen @981
  frexp=msvcrt.frexp @982
  fscanf=msvcrt.fscanf @983
  fseek=msvcrt.fseek @984
  fsetpos=msvcrt.fsetpos @985
  ftell=msvcrt.ftell @986
  fwprintf=msvcrt.fwprintf @987
  fwrite=msvcrt.fwrite @988
  fwscanf=msvcrt.fwscanf @989
  getc=msvcrt.getc @990
  getchar=msvcrt.getchar @991
  getenv=msvcrt.getenv @992
  gets=msvcrt.gets @993
  getwc=msvcrt.getwc @994
  getwchar=msvcrt.getwchar @995
  gmtime=msvcrt.gmtime @996
  is_wctype=msvcrt.is_wctype @997
  isalnum=msvcrt.isalnum @998
  isalpha=msvcrt.isalpha @999
  iscntrl=msvcrt.iscntrl @1000
  isdigit=msvcrt.isdigit @1001
  isgraph=msvcrt.isgraph @1002
  isleadbyte=msvcrt.isleadbyte @1003
  islower=msvcrt.islower @1004
  isprint=msvcrt.isprint @1005
  ispunct=msvcrt.ispunct @1006
  isspace=msvcrt.isspace @1007
  isupper=msvcrt.isupper @1008
  iswalnum=msvcrt.iswalnum @1009
  iswalpha=msvcrt.iswalpha @1010
  iswascii=msvcrt.iswascii @1011
  iswcntrl=msvcrt.iswcntrl @1012
  iswctype=msvcrt.iswctype @1013
  iswdigit=msvcrt.iswdigit @1014
  iswgraph=msvcrt.iswgraph @1015
  iswlower=msvcrt.iswlower @1016
  iswprint=msvcrt.iswprint @1017
  iswpunct=msvcrt.iswpunct @1018
  iswspace=msvcrt.iswspace @1019
  iswupper=msvcrt.iswupper @1020
  iswxdigit=msvcrt.iswxdigit @1021
  isxdigit=msvcrt.isxdigit @1022
  labs=msvcrt.labs @1023
  ldexp=msvcrt.ldexp @1024
  ldiv=msvcrt.ldiv @1025
  localeconv=msvcrt.localeconv @1026
  localtime=msvcrt.localtime @1027
  log=msvcrt.log @1028
  log10=msvcrt.log10 @1029
  longjmp=msvcrt.longjmp @1030
  malloc=msvcrt.malloc @1031
  mblen=msvcrt.mblen @1032
  mbstowcs=msvcrt.mbstowcs @1033
  mbtowc=msvcrt.mbtowc @1034
  memchr=msvcrt.memchr @1035
  memcmp=msvcrt.memcmp @1036
  memcpy=msvcrt.memcpy @1037
  memmove=msvcrt.memmove @1038
  memset=msvcrt.memset @1039
  mktime=msvcrt.mktime @1040
  modf=msvcrt.modf @1041
  perror=msvcrt.perror @1042
  pow=msvcrt.pow @1043
  printf=msvcrt.printf @1044
  putc=msvcrt.putc @1045
  putchar=msvcrt.putchar @1046
  puts=msvcrt.puts @1047
  putwc=msvcrt.putwc @1048
  putwchar=msvcrt.putwchar @1049
  qsort=msvcrt.qsort @1050
  raise=msvcrt.raise @1051
  rand=msvcrt.rand @1052
  realloc=msvcrt.realloc @1053
  remove=msvcrt.remove @1054
  rename=msvcrt.rename @1055
  rewind=msvcrt.rewind @1056
  scanf=msvcrt.scanf @1057
  setbuf=msvcrt.setbuf @1058
  setlocale=msvcrt.setlocale @1059
  setvbuf=msvcrt.setvbuf @1060
  signal=msvcrt.signal @1061
  sin=msvcrt.sin @1062
  sinh=msvcrt.sinh @1063
  sprintf=msvcrt.sprintf @1064
  sqrt=msvcrt.sqrt @1065
  srand=msvcrt.srand @1066
  sscanf=msvcrt.sscanf @1067
  strcat=msvcrt.strcat @1068
  strchr=msvcrt.strchr @1069
  strcmp=msvcrt.strcmp @1070
  strcoll=msvcrt.strcoll @1071
  strcpy=msvcrt.strcpy @1072
  strcspn=msvcrt.strcspn @1073
  strerror=msvcrt.strerror @1074
  strftime=msvcrt.strftime @1075
  strlen=msvcrt.strlen @1076
  strncat=msvcrt.strncat @1077
  strncmp=msvcrt.strncmp @1078
  strncpy=msvcrt.strncpy @1079
  strpbrk=msvcrt.strpbrk @1080
  strrchr=msvcrt.strrchr @1081
  strspn=msvcrt.strspn @1082
  strstr=msvcrt.strstr @1083
  strtod=msvcrt.strtod @1084
  strtok=msvcrt.strtok @1085
  strtol=msvcrt.strtol @1086
  strtoul=msvcrt.strtoul @1087
  strxfrm=msvcrt.strxfrm @1088
  swprintf=msvcrt.swprintf @1089
  swscanf=msvcrt.swscanf @1090
  system=msvcrt.system @1091
  tan=msvcrt.tan @1092
  tanh=msvcrt.tanh @1093
  time=msvcrt.time @1094
  tmpfile=msvcrt.tmpfile @1095
  tmpnam=msvcrt.tmpnam @1096
  tolower=msvcrt.tolower @1097
  toupper=msvcrt.toupper @1098
  towlower=msvcrt.towlower @1099
  towupper=msvcrt.towupper @1100
  ungetc=msvcrt.ungetc @1101
  ungetwc=msvcrt.ungetwc @1102
  vfprintf=msvcrt.vfprintf @1103
  vfwprintf=msvcrt.vfwprintf @1104
  vprintf=msvcrt.vprintf @1105
  vsprintf=msvcrt.vsprintf @1106
  vswprintf=msvcrt.vswprintf @1107
  vwprintf=msvcrt.vwprintf @1108
  wcscat=msvcrt.wcscat @1109
  wcschr=msvcrt.wcschr @1110
  wcscmp=msvcrt.wcscmp @1111
  wcscoll=msvcrt.wcscoll @1112
  wcscpy=msvcrt.wcscpy @1113
  wcscspn=msvcrt.wcscspn @1114
  wcsftime=msvcrt.wcsftime @1115
  wcslen=msvcrt.wcslen @1116
  wcsncat=msvcrt.wcsncat @1117
  wcsncmp=msvcrt.wcsncmp @1118
  wcsncpy=msvcrt.wcsncpy @1119
  wcspbrk=msvcrt.wcspbrk @1120
  wcsrchr=msvcrt.wcsrchr @1121
  wcsspn=msvcrt.wcsspn @1122
  wcsstr=msvcrt.wcsstr @1123
  wcstod=msvcrt.wcstod @1124
  wcstok=msvcrt.wcstok @1125
  wcstol=msvcrt.wcstol @1126
  wcstombs=msvcrt.wcstombs @1127
  wcstoul=msvcrt.wcstoul @1128
  wcsxfrm=msvcrt.wcsxfrm @1129
  wctomb=msvcrt.wctomb @1130
  wprintf=msvcrt.wprintf @1131
  wscanf=msvcrt.wscanf @1132
