; File generated automatically from dpnhpast/dpnhpast.spec; do not edit!

LIBRARY dpnhpast.dll

EXPORTS
  DllRegisterServer@0=DPNHPAST_DllRegisterServer@0 @2 PRIVATE
  DllCanUnloadNow@0=DPNHPAST_DllCanUnloadNow@0 @3 PRIVATE
  DllGetClassObject@12=DPNHPAST_DllGetClassObject@12 @4 PRIVATE
  DllUnregisterServer@0=DPNHPAST_DllUnregisterServer@0 @5 PRIVATE
