; File generated automatically from oledlg/oledlg.spec; do not edit!

LIBRARY oledlg.dll

EXPORTS
  OleUIAddVerbMenuA@36 @1
  OleUICanConvertOrActivateAs@12 @2
  OleUIInsertObjectA@4 @3
  OleUIPasteSpecialA@4 @4
  OleUIEditLinksA@4 @5
  OleUIChangeIconA@4 @6
  OleUIConvertA@4 @7
  OleUIBusyA@4 @8
  OleUIUpdateLinksA@16 @9
  OleUIPromptUserA @10
  OleUIObjectPropertiesA@4 @11
  OleUIChangeSourceA@4 @12
  OleUIPromptUserW @13
  OleUIAddVerbMenuW@36 @14
  OleUIBusyW@4 @15
  OleUIChangeIconW@4 @16
  OleUIChangeSourceW@4 @17
  OleUIConvertW@4 @18
  OleUIEditLinksW@4 @19
  OleUIInsertObjectW@4 @20
  OleUIObjectPropertiesW@4 @21
  OleUIPasteSpecialW@4 @22
  OleUIUpdateLinksW@16 @23
