; File generated automatically from user/user32.spec; do not edit!

LIBRARY user32.dll

EXPORTS
  ActivateKeyboardLayout@8 @1
  AdjustWindowRect@12 @2
  AdjustWindowRectEx@16 @3
  AnyPopup@0 @7
  AppendMenuA@16 @8
  AppendMenuW@16 @9
  ArrangeIconicWindows@4 @10
  AttachThreadInput@12 @11
  BeginDeferWindowPos@4 @12
  BeginPaint@8 @13
  BringWindowToTop@4 @14
  BroadcastSystemMessage@20=BroadcastSystemMessageA@20 @15
  BroadcastSystemMessageA@20 @16
  BroadcastSystemMessageW@20 @17
  CalcChildScroll@8 @18
  CallMsgFilter@8=CallMsgFilterA@8 @19
  CallMsgFilterA@8 @20
  CallMsgFilterW@8 @21
  CallNextHookEx@16 @22
  CallWindowProcA@20 @24
  CallWindowProcW@20 @25
  CascadeWindows@20 @27
  ChangeClipboardChain@8 @28
  ChangeMenuA@20 @33
  ChangeMenuW@20 @34
  CharLowerA@4 @35
  CharLowerBuffA@8 @36
  CharLowerBuffW@8 @37
  CharLowerW@4 @38
  CharNextA@4 @39
  CharNextExA@12 @40
  CharNextExW@12 @41
  CharNextW@4 @42
  CharPrevA@8 @43
  CharPrevExA@16 @44
  CharPrevExW@16 @45
  CharPrevW@8 @46
  CharToOemA@8 @47
  CharToOemBuffA@12 @48
  CharToOemBuffW@12 @49
  CharToOemW@8 @50
  CharUpperA@4 @51
  CharUpperBuffA@8 @52
  CharUpperBuffW@8 @53
  CharUpperW@4 @54
  CheckDlgButton@12 @55
  CheckMenuItem@12 @56
  CheckMenuRadioItem@20 @57
  CheckRadioButton@16 @58
  ChildWindowFromPoint@12 @59
  ChildWindowFromPointEx@16 @60
  ClientToScreen@8 @64
  ClipCursor@4 @65
  CloseClipboard@0 @66
  CloseDesktop@4 @67
  CloseWindow@4 @69
  CloseWindowStation@4 @70
  CopyAcceleratorTableA@12 @71
  CopyAcceleratorTableW@12 @72
  CopyIcon@4 @73
  CopyImage@20 @74
  CopyRect@8 @75
  CountClipboardFormats@0 @76
  CreateAcceleratorTableA@8 @77
  CreateAcceleratorTableW@8 @78
  CreateCaret@16 @79
  CreateCursor@28 @80
  CreateDesktopA@24 @81
  CreateDesktopW@24 @82
  CreateDialogIndirectParamA@20 @84
  CreateDialogIndirectParamAorW@24 @85
  CreateDialogIndirectParamW@20 @86
  CreateDialogParamA@20 @87
  CreateDialogParamW@20 @88
  CreateIcon@28 @89
  CreateIconFromResource@16 @90
  CreateIconFromResourceEx@28 @91
  CreateIconIndirect@4 @92
  CreateMDIWindowA@40 @93
  CreateMDIWindowW@40 @94
  CreateMenu@0 @95
  CreatePopupMenu@0 @96
  CreateWindowExA@48 @97
  CreateWindowExW@48 @98
  CreateWindowStationW@16 @100
  DdeAbandonTransaction@12 @102
  DdeAccessData@8 @103
  DdeAddData@16 @104
  DdeClientTransaction@32 @105
  DdeCmpStringHandles@8 @106
  DdeConnect@16 @107
  DdeConnectList@20 @108
  DdeCreateDataHandle@28 @109
  DdeCreateStringHandleA@12 @110
  DdeCreateStringHandleW@12 @111
  DdeDisconnect@4 @112
  DdeDisconnectList@4 @113
  DdeEnableCallback@12 @114
  DdeFreeDataHandle@4 @115
  DdeFreeStringHandle@8 @116
  DdeGetData@16 @117
  DdeGetLastError@4 @118
  DdeImpersonateClient@4 @120
  DdeInitializeA@16 @121
  DdeInitializeW@16 @122
  DdeKeepStringHandle@8 @123
  DdeNameService@16 @124
  DdePostAdvise@12 @125
  DdeQueryConvInfo@12 @126
  DdeQueryNextServer@8 @127
  DdeQueryStringA@20 @128
  DdeQueryStringW@20 @129
  DdeReconnect@4 @130
  DdeSetQualityOfService@12 @131
  DdeSetUserHandle@12 @132
  DdeUnaccessData@4 @133
  DdeUninitialize@4 @134
  DefDlgProcA@16 @135
  DefDlgProcW@16 @136
  DefFrameProcA@20 @138
  DefFrameProcW@20 @139
  DefMDIChildProcA@16 @140
  DefMDIChildProcW@16 @141
  DefWindowProcA@16 @143
  DefWindowProcW@16 @144
  DeferWindowPos@32 @145
  DeleteMenu@12 @146
  DestroyAcceleratorTable@4 @148
  DestroyCaret@0 @149
  DestroyCursor@4 @150
  DestroyIcon@4 @151
  DestroyMenu@4 @153
  DestroyWindow@4 @154
  DialogBoxIndirectParamA@20 @156
  DialogBoxIndirectParamAorW@24 @157
  DialogBoxIndirectParamW@20 @158
  DialogBoxParamA@20 @159
  DialogBoxParamW@20 @160
  DispatchMessageA@4 @161
  DispatchMessageW@4 @162
  DlgDirListA@20 @163
  DlgDirListComboBoxA@20 @164
  DlgDirListComboBoxW@20 @165
  DlgDirListW@20 @166
  DlgDirSelectComboBoxExA@16 @167
  DlgDirSelectComboBoxExW@16 @168
  DlgDirSelectExA@16 @169
  DlgDirSelectExW@16 @170
  DragDetect@12 @171
  DrawAnimatedRects@16 @173
  DrawCaption@16 @174
  DrawEdge@16 @177
  DrawFocusRect@8 @178
  DrawFrameControl@16 @180
  DrawIcon@16 @181
  DrawIconEx@36 @182
  DrawMenuBar@4 @183
  DrawStateA@40 @185
  DrawStateW@40 @186
  DrawTextA@20 @187
  DrawTextExA@24 @188
  DrawTextExW@24 @189
  DrawTextW@20 @190
  EditWndProc@16=EditWndProcA@16 @191
  EmptyClipboard@0 @192
  EnableMenuItem@12 @193
  EnableScrollBar@12 @194
  EnableWindow@8 @195
  EndDeferWindowPos@4 @196
  EndDialog@8 @197
  EndMenu@0 @198
  EndPaint@8 @199
  EnumChildWindows@12 @201
  EnumClipboardFormats@4 @202
  EnumDesktopsA@12 @204
  EnumDesktopsW@12 @205
  EnumDisplayDevicesA@16 @208
  EnumDisplayDevicesW@16 @209
  EnumPropsA@8 @215
  EnumPropsExA@12 @216
  EnumPropsExW@12 @217
  EnumPropsW@8 @218
  EnumThreadWindows@12 @219
  EnumWindowStationsA@8 @220
  EnumWindowStationsW@8 @221
  EnumWindows@8 @222
  EqualRect@8 @223
  ExcludeUpdateRgn@8 @224
  ExitWindowsEx@8 @225
  FillRect@12 @226
  FindWindowA@8 @227
  FindWindowExA@16 @228
  FindWindowExW@16 @229
  FindWindowW@8 @230
  FlashWindow@8 @231
  FlashWindowEx@4 @232
  FrameRect@12 @233
  FreeDDElParam@8 @234
  GetActiveWindow@0 @235
  GetAppCompatFlags@4 @237
  GetAsyncKeyState@4 @238
  GetCapture@0 @239
  GetCaretBlinkTime@0 @240
  GetCaretPos@4 @241
  GetClassInfoA@12 @242
  GetClassInfoExA@12 @243
  GetClassInfoExW@12 @244
  GetClassInfoW@12 @245
  GetClassLongA@8 @246
  GetClassLongW@8 @247
  GetClassNameA@12 @248
  GetClassNameW@12 @249
  GetClassWord@8 @250
  GetClientRect@8 @251
  GetClipCursor@4 @252
  GetClipboardData@4 @253
  GetClipboardFormatNameA@12 @254
  GetClipboardFormatNameW@12 @255
  GetClipboardOwner@0 @256
  GetClipboardViewer@0 @258
  GetComboBoxInfo@8 @259
  GetCursor@0 @260
  GetCursorInfo@4 @261
  GetCursorPos@4 @262
  GetDC@4 @263
  GetDCEx@12 @264
  GetDesktopWindow@0 @265
  GetDialogBaseUnits@0 @266
  GetDlgCtrlID@4 @267
  GetDlgItem@8 @268
  GetDlgItemInt@16 @269
  GetDlgItemTextA@16 @270
  GetDlgItemTextW@16 @271
  GetDoubleClickTime@0 @272
  GetFocus@0 @274
  GetForegroundWindow@0 @275
  GetGUIThreadInfo@8 @276
  GetGuiResources@8 @277
  GetIconInfo@8 @278
  GetInputState@0 @280
  GetInternalWindowPos@12 @281
  GetKBCodePage@0 @282
  GetKeyNameTextA@12 @283
  GetKeyNameTextW@12 @284
  GetKeyState@4 @285
  GetKeyboardLayout@4 @286
  GetKeyboardLayoutList@8 @287
  GetKeyboardLayoutNameA@4 @288
  GetKeyboardLayoutNameW@4 @289
  GetKeyboardState@4 @290
  GetKeyboardType@4 @291
  GetLastActivePopup@4 @292
  GetMenu@4 @293
  GetMenuCheckMarkDimensions@0 @294
  GetMenuContextHelpId@4 @295
  GetMenuDefaultItem@12 @296
  GetMenuItemCount@4 @299
  GetMenuItemID@8 @300
  GetMenuItemInfoA@16 @301
  GetMenuItemInfoW@16 @302
  GetMenuItemRect@16 @303
  GetMenuState@12 @304
  GetMenuStringA@20 @305
  GetMenuStringW@20 @306
  GetMessageA@16 @307
  GetMessageExtraInfo@0 @308
  GetMessagePos@0 @309
  GetMessageTime@0 @310
  GetMessageW@16 @311
  GetNextDlgGroupItem@12 @314
  GetNextDlgTabItem@12 @315
  GetOpenClipboardWindow@0 @316
  GetParent@4 @317
  GetPriorityClipboardFormat@8 @318
  GetProcessWindowStation@0 @320
  GetPropA@8 @322
  GetPropW@8 @323
  GetQueueStatus@4 @324
  GetScrollInfo@12 @325
  GetScrollPos@8 @326
  GetScrollRange@16 @327
  GetShellWindow@0 @328
  GetSubMenu@8 @329
  GetSysColor@4 @330
  GetSysColorBrush@4 @331
  GetSystemMenu@8 @332
  GetSystemMetrics@4 @333
  GetTabbedTextExtentA@20 @334
  GetTabbedTextExtentW@20 @335
  GetThreadDesktop@4 @337
  GetTitleBarInfo@8 @338
  GetTopWindow@4 @339
  GetUpdateRect@12 @340
  GetUpdateRgn@12 @341
  GetUserObjectInformationA@20 @342
  GetUserObjectInformationW@20 @343
  GetUserObjectSecurity@20 @344
  GetWindow@8 @345
  GetWindowContextHelpId@4 @346
  GetWindowDC@4 @347
  GetWindowLongA@8 @349
  GetWindowLongW@8 @350
  GetWindowPlacement@8 @353
  GetWindowRect@8 @354
  GetWindowTextA@12 @356
  GetWindowTextLengthA@4 @357
  GetWindowTextLengthW@4 @358
  GetWindowTextW@12 @359
  GetWindowThreadProcessId@8 @360
  GetWindowWord@8 @361
  GetWindowInfo@8 @348
  GrayStringA@36 @362
  GrayStringW@36 @363
  HideCaret@4 @365
  HiliteMenuItem@16 @366
  ImpersonateDdeClientWindow@8 @367
  InSendMessage@0 @368
  InSendMessageEx@4 @369
  InflateRect@12 @370
  InsertMenuA@20 @371
  InsertMenuItemA@16 @372
  InsertMenuItemW@16 @373
  InsertMenuW@20 @374
  InternalGetWindowText@12 @375
  IntersectRect@12 @376
  InvalidateRect@12 @377
  InvalidateRgn@12 @378
  InvertRect@8 @379
  IsCharAlphaA@4 @380
  IsCharAlphaNumericA@4 @381
  IsCharAlphaNumericW@4 @382
  IsCharAlphaW@4 @383
  IsCharLowerA@4 @384
  IsCharLowerW@4 @385
  IsCharUpperA@4 @386
  IsCharUpperW@4 @387
  IsChild@8 @388
  IsClipboardFormatAvailable@4 @389
  IsDialogMessage@8=IsDialogMessageA@8 @390
  IsDialogMessageA@8 @391
  IsDialogMessageW@8 @392
  IsDlgButtonChecked@8 @393
  IsIconic@4 @395
  IsMenu@4 @396
  IsRectEmpty@4 @397
  IsWindow@4 @399
  IsWindowEnabled@4 @400
  IsWindowUnicode@4 @401
  IsWindowVisible@4 @402
  IsZoomed@4 @403
  KillSystemTimer@8 @404
  KillTimer@8 @405
  LoadAcceleratorsA@8 @406
  LoadAcceleratorsW@8 @407
  LoadBitmapA@8 @408
  LoadBitmapW@8 @409
  LoadCursorA@8 @410
  LoadCursorFromFileA@4 @411
  LoadCursorFromFileW@4 @412
  LoadCursorW@8 @413
  LoadIconA@8 @414
  LoadIconW@8 @415
  LoadImageA@24 @416
  LoadImageW@24 @417
  LoadKeyboardLayoutA@8 @418
  LoadKeyboardLayoutW@8 @419
  LoadLocalFonts@0 @420
  LoadMenuA@8 @421
  LoadMenuIndirectA@4 @422
  LoadMenuIndirectW@4 @423
  LoadMenuW@8 @424
  LoadStringA@16 @426
  LoadStringW@16 @427
  LockWindowUpdate@4 @430
  LookupIconIdFromDirectory@8 @432
  LookupIconIdFromDirectoryEx@20 @433
  MapDialogRect@8 @435
  MapVirtualKeyA@8 @436
  MapVirtualKeyExA@12 @437
  MapVirtualKeyW@8 @439
  MapWindowPoints@16 @440
  MenuItemFromPoint@16 @441
  MessageBeep@4 @444
  MessageBoxA@16 @445
  MessageBoxExA@20 @446
  MessageBoxExW@20 @447
  MessageBoxIndirectA@4 @448
  MessageBoxIndirectW@4 @449
  MessageBoxW@16 @450
  ModifyMenuA@20 @451
  ModifyMenuW@20 @452
  MoveWindow@24 @456
  MsgWaitForMultipleObjects@20 @457
  MsgWaitForMultipleObjectsEx@20 @458
  OemKeyScan@4 @463
  OemToCharA@8 @464
  OemToCharBuffA@12 @465
  OemToCharBuffW@12 @466
  OemToCharW@8 @467
  OffsetRect@12 @468
  OpenClipboard@4 @469
  OpenDesktopA@16 @470
  OpenIcon@4 @473
  PackDDElParam@12 @477
  PaintDesktop@4 @478
  PeekMessageA@20 @479
  PeekMessageW@20 @480
  PostMessageA@16 @482
  PostMessageW@16 @483
  PostQuitMessage@4 @484
  PostThreadMessageA@16 @485
  PostThreadMessageW@16 @486
  PtInRect@12 @491
  RealGetWindowClass@12=RealGetWindowClassA@12 @493
  RealGetWindowClassA@12 @494
  RealGetWindowClassW@12 @495
  RedrawWindow@16 @496
  RegisterClassA@4 @497
  RegisterClassExA@4 @498
  RegisterClassExW@4 @499
  RegisterClassW@4 @500
  RegisterClipboardFormatA@4 @501
  RegisterClipboardFormatW@4 @502
  RegisterHotKey@16 @505
  RegisterLogonProcess@8 @506
  RegisterSystemThread@8 @510
  RegisterTasklist@4 @511
  RegisterWindowMessageA@4 @512
  RegisterWindowMessageW@4 @513
  ReleaseCapture@0 @514
  ReleaseDC@8 @515
  RemoveMenu@12 @516
  RemovePropA@8 @517
  RemovePropW@8 @518
  ReplyMessage@4 @519
  ReuseDDElParam@20 @521
  ScreenToClient@8 @522
  ScrollChildren@16 @523
  ScrollDC@28 @524
  ScrollWindow@20 @525
  ScrollWindowEx@32 @526
  SendDlgItemMessageA@20 @527
  SendDlgItemMessageW@20 @528
  SendMessageA@16 @531
  SendMessageCallbackA@24 @532
  SendMessageCallbackW@24 @533
  SendMessageTimeoutA@28 @534
  SendMessageTimeoutW@28 @535
  SendMessageW@16 @536
  SendNotifyMessageA@16 @537
  SendNotifyMessageW@16 @538
  SetActiveWindow@4 @540
  SetCapture@4 @541
  SetCaretBlinkTime@4 @542
  SetCaretPos@8 @543
  SetClassLongA@12 @544
  SetClassLongW@12 @545
  SetClassWord@12 @546
  SetClipboardData@8 @547
  SetClipboardViewer@4 @548
  SetCursor@4 @549
  SetCursorPos@8 @551
  SetDebugErrorLevel@4 @552
  SetDeskWallPaper@4 @553
  SetDlgItemInt@16 @554
  SetDlgItemTextA@12 @555
  SetDlgItemTextW@12 @556
  SetDoubleClickTime@4 @557
  SetFocus@4 @558
  SetForegroundWindow@4 @559
  SetInternalWindowPos@16 @560
  SetKeyboardState@4 @561
  SetLastErrorEx@8 @562
  SetLogonNotifyWindow@8 @563
  SetMenu@8 @564
  SetMenuContextHelpId@8 @565
  SetMenuDefaultItem@12 @566
  SetMenuItemBitmaps@20 @568
  SetMenuItemInfoA@16 @569
  SetMenuItemInfoW@16 @570
  SetMessageExtraInfo@4 @571
  SetMessageQueue@4 @572
  SetParent@8 @573
  SetProcessWindowStation@4 @575
  SetPropA@12 @577
  SetPropW@12 @578
  SetRect@20 @579
  SetRectEmpty@4 @580
  SetScrollInfo@16 @581
  SetScrollPos@16 @582
  SetScrollRange@20 @583
  SetShellWindow@4 @584
  SetSysColors@12 @586
  SetSysColorsTemp@12 @587
  SetSystemCursor@8 @588
  SetSystemMenu@8 @589
  SetSystemTimer@16 @590
  SetThreadDesktop@4 @592
  SetTimer@16 @593
  SetUserObjectInformationA@16 @594
  SetUserObjectSecurity@12 @596
  SetWindowContextHelpId@8 @598
  SetWindowLongA@12 @600
  SetWindowLongW@12 @601
  SetWindowPlacement@8 @602
  SetWindowPos@28 @603
  SetWindowStationUser@8 @605
  SetWindowTextA@8 @607
  SetWindowTextW@8 @608
  SetWindowWord@12 @609
  SetWindowsHookA@8 @610
  SetWindowsHookExA@16 @611
  SetWindowsHookExW@16 @612
  SetWindowsHookW@8 @613
  ShowCaret@4 @614
  ShowCursor@4 @615
  ShowOwnedPopups@8 @616
  ShowScrollBar@12 @617
  ShowWindow@8 @619
  ShowWindowAsync@8 @620
  SubtractRect@12 @621
  SwapMouseButton@4 @622
  SwitchToThisWindow@8 @624
  SystemParametersInfoA@16 @625
  SystemParametersInfoW@16 @626
  TabbedTextOutA@32 @627
  TabbedTextOutW@32 @628
  TileWindows@20 @630
  ToAscii@20 @631
  ToAsciiEx@24 @632
  ToUnicode@24 @633
  TrackPopupMenu@28 @636
  TrackPopupMenuEx@24 @637
  TranslateAccelerator@12=TranslateAcceleratorW@12 @638
  TranslateAcceleratorA@12=TranslateAcceleratorW@12 @639
  TranslateAcceleratorW@12 @640
  TranslateMDISysAccel@8 @641
  TranslateMessage@4 @642
  UnhookWindowsHook@8 @645
  UnhookWindowsHookEx@4 @646
  UnionRect@12 @647
  UnloadKeyboardLayout@4 @648
  UnpackDDElParam@16 @650
  UnregisterClassA@8 @651
  UnregisterClassW@8 @652
  UnregisterHotKey@8 @654
  UpdateWindow@4 @656
  User32InitializeImmEntryTable@4 @657
  UserClientDllInitialize@12=DllMain@12 @658
  UserRealizePalette@4 @660
  ValidateRect@8 @664
  ValidateRgn@8 @665
  VkKeyScanA@4 @666
  VkKeyScanExA@8 @667
  VkKeyScanExW@8 @668
  VkKeyScanW@4 @669
  WaitForInputIdle@8 @687
  WaitMessage@0 @688
  WinHelpA@16 @689
  WinHelpW@16 @690
  WindowFromDC@4 @691
  WindowFromPoint@8 @692
  keybd_event@16 @693
  mouse_event@20 @694
  wsprintfA @695
  wsprintfW @696
  wvsprintfA@12 @697
  wvsprintfW@12 @698
  ChangeDisplaySettingsA@8 @29
  ChangeDisplaySettingsW@8 @32
  EnumDesktopWindows@12 @203
  EnumDisplaySettingsA@12 @211
  EnumDisplaySettingsW@12 @214
  GetWindowRgn@8 @355
  MapVirtualKeyExW@12 @438
  SetWindowRgn@12 @604
  ToUnicodeEx@28 @634
  DrawCaptionTempA@28 @175
  DrawCaptionTempW@28 @176
  IsHungAppWindow@4 @394
  ChangeDisplaySettingsExA@20 @30
  ChangeDisplaySettingsExW@20 @31
  SetWindowText@8=SetWindowTextA@8 @606
  GetMonitorInfoA@8 @312
  GetMonitorInfoW@8 @313
  MonitorFromWindow@8 @455
  MonitorFromRect@8 @454
  MonitorFromPoint@12 @453
  EnumDisplayMonitors@16 @210
  PrivateExtractIconExA@20 @487
  PrivateExtractIconExW@20 @488
  PrivateExtractIconsA@32 @489
  PrivateExtractIconsW@32 @490
  RegisterShellHookWindow@4 @509
  DeregisterShellHookWindow@4 @147
  SetShellWindowEx@8 @585
  SetProgmanWindow@4 @576
  GetTaskmanWindow@0 @336
  SetTaskmanWindow@4 @591
  GetProgmanWindow@0 @321
  UserSignalProc@16 @662
  GetMenuInfo@8 @298
  SetMenuInfo@8 @567
  GetProcessDefaultLayout@4 @319
  SetProcessDefaultLayout@4 @574
  RegisterDeviceNotificationA@12 @503
  RegisterDeviceNotificationW@12 @504
  TrackMouseEvent@4 @635
  AlignRects@16 @4
  AllowSetForegroundWindow@4 @5
  AnimateWindow@12 @6
  DrawMenuBarTemp@20 @184
  EnumDisplaySettingsExA@16 @212
  EnumDisplaySettingsExW@16 @213
  GetAncestor@8 @236
  GetClipboardSequenceNumber@0 @257
  GetWindowModuleFileNameA@12 @351
  GetWindowModuleFileNameW@12 @352
  IsWinEventHookInstalled@4 @398
  LockSetForegroundWindow@4 @428
  NotifyWinEvent@16 @462
  SendInput@12 @530
  SetWinEventHook@28 @597
  UnhookWinEvent@4 @644
  CallWindowProc16@20 @23
  CloseDriver16@12 @68
  CreateDialogIndirectParam16@20 @83
  DefDriverProc16@20 @137
  DefWindowProc16@16 @142
  DestroyIcon32@8 @152
  DialogBoxIndirectParam16@20 @155
  GetDriverModuleHandle16@4 @273
  OpenDriver16@12 @472
  SendDriverMessage16@16 @529
  UserYield16@0 @663
  DCE_InvalidateDCE @101
  HOOK_CallHooks @364
  NC_GetInsideRect @459
  NC_HandleNCHitTest @460
  NC_HandleSetCursor @461
  USER_Unlock @643
  WINPOS_ActivateOtherWindow @671
  WINPOS_GetMinMaxInfo @672
  WINPOS_ShowIconTitle @673
  WIN_FindWndPtr @674
  WIN_GetPtr @675
  WIN_LinkWindow @676
  WIN_ListChildren @677
  WIN_ListParents @678
  WIN_ReleaseWndPtr @679
  WIN_RestoreWndsLock @680
  WIN_SetExStyle @681
  WIN_SetRectangles @682
  WIN_SetStyle @683
  WIN_SuspendWndsLock @684
  WIN_UnlinkWindow @685
