; File generated automatically from devenum/devenum.spec; do not edit!

LIBRARY devenum.dll

EXPORTS
  DllCanUnloadNow@0=DEVENUM_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DEVENUM_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DEVENUM_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DEVENUM_DllUnregisterServer@0 @4 PRIVATE
