; File generated automatically from msvcrt/msvcrt.spec; do not edit!

LIBRARY msvcrt.dll

EXPORTS
  $I10_OUTPUT=MSVCRT_I10_OUTPUT @1
  ??0__non_rtti_object@@QAE@ABV0@@Z=__thiscall_MSVCRT___non_rtti_object_copy_ctor @2
  ??0__non_rtti_object@@QAE@PBD@Z=__thiscall_MSVCRT___non_rtti_object_ctor @3
  ??0bad_cast@@QAE@ABQBD@Z=__thiscall_MSVCRT_bad_cast_ctor @4
  ??0bad_cast@@QAE@ABV0@@Z=__thiscall_MSVCRT_bad_cast_copy_ctor @5
  ??0bad_typeid@@QAE@ABV0@@Z=__thiscall_MSVCRT_bad_typeid_copy_ctor @6
  ??0bad_typeid@@QAE@PBD@Z=__thiscall_MSVCRT_bad_typeid_ctor @7
  ??0exception@@QAE@ABQBD@Z=__thiscall_MSVCRT_exception_ctor @8
  ??0exception@@QAE@ABV0@@Z=__thiscall_MSVCRT_exception_copy_ctor @9
  ??0exception@@QAE@XZ=__thiscall_MSVCRT_exception_default_ctor @10
  ??1__non_rtti_object@@UAE@XZ=__thiscall_MSVCRT___non_rtti_object_dtor @11
  ??1bad_cast@@UAE@XZ=__thiscall_MSVCRT_bad_cast_dtor @12
  ??1bad_typeid@@UAE@XZ=__thiscall_MSVCRT_bad_typeid_dtor @13
  ??1exception@@UAE@XZ=__thiscall_MSVCRT_exception_dtor @14
  ??1type_info@@UAE@XZ=__thiscall_MSVCRT_type_info_dtor @15
  ??2@YAPAXI@Z=MSVCRT_operator_new @16
  ??_U@YAPAXI@Z=MSVCRT_operator_new @36
  ??3@YAXPAX@Z=MSVCRT_operator_delete @17
  ??_V@YAXPAX@Z=MSVCRT_operator_delete @37
  ??4__non_rtti_object@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT___non_rtti_object_opequals @18
  ??4bad_cast@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT_bad_cast_opequals @19
  ??4bad_typeid@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT_bad_typeid_opequals @20
  ??4exception@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT_exception_opequals @21
  ??8type_info@@QBEHABV0@@Z=__thiscall_MSVCRT_type_info_opequals_equals @22
  ??9type_info@@QBEHABV0@@Z=__thiscall_MSVCRT_type_info_opnot_equals @23
  ??_7__non_rtti_object@@6B@=MSVCRT___non_rtti_object_vtable @24 DATA
  ??_7bad_cast@@6B@=MSVCRT_bad_cast_vtable @25 DATA
  ??_7bad_typeid@@6B@=MSVCRT_bad_typeid_vtable @26 DATA
  ??_7exception@@6B@=MSVCRT_exception_vtable @27 DATA
  ??_E__non_rtti_object@@UAEPAXI@Z=__thiscall_MSVCRT___non_rtti_object_vector_dtor @28
  ??_Ebad_cast@@UAEPAXI@Z=__thiscall_MSVCRT_bad_cast_vector_dtor @29
  ??_Ebad_typeid@@UAEPAXI@Z=__thiscall_MSVCRT_bad_typeid_vector_dtor @30
  ??_Eexception@@UAEPAXI@Z=__thiscall_MSVCRT_exception_vector_dtor @31
  ??_G__non_rtti_object@@UAEPAXI@Z=__thiscall_MSVCRT___non_rtti_object_scalar_dtor @32
  ??_Gbad_cast@@UAEPAXI@Z=__thiscall_MSVCRT_bad_cast_scalar_dtor @33
  ??_Gbad_typeid@@UAEPAXI@Z=__thiscall_MSVCRT_bad_typeid_scalar_dtor @34
  ??_Gexception@@UAEPAXI@Z=__thiscall_MSVCRT_exception_scalar_dtor @35
  ?_query_new_handler@@YAP6AHI@ZXZ=MSVCRT__query_new_handler @38
  ?_query_new_mode@@YAHXZ=MSVCRT__query_new_mode @39
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=MSVCRT__set_new_handler @40
  ?_set_new_mode@@YAHH@Z=MSVCRT__set_new_mode @41
  ?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z=MSVCRT__set_se_translator @42
  ?before@type_info@@QBEHABV1@@Z=__thiscall_MSVCRT_type_info_before @43
  ?name@type_info@@QBEPBDXZ=__thiscall_MSVCRT_type_info_name @44
  ?raw_name@type_info@@QBEPBDXZ=__thiscall_MSVCRT_type_info_raw_name @45
  ?set_new_handler@@YAP6AXXZP6AXXZ@Z=MSVCRT__set_new_handler @46
  ?set_terminate@@YAP6AXXZP6AXXZ@Z=MSVCRT_set_terminate @47
  ?set_unexpected@@YAP6AXXZP6AXXZ@Z=MSVCRT_set_unexpected @48
  ?terminate@@YAXXZ=MSVCRT_terminate @49
  ?unexpected@@YAXXZ=MSVCRT_unexpected @50
  ?what@exception@@UBEPBDXZ=__thiscall_MSVCRT_what_exception @51
  _CIacos @52
  _CIasin @53
  _CIatan @54
  _CIatan2 @55
  _CIcos @56
  _CIcosh @57
  _CIexp @58
  _CIfmod @59
  _CIlog @60
  _CIlog10 @61
  _CIpow @62
  _CIsin @63
  _CIsinh @64
  _CIsqrt @65
  _CItan @66
  _CItanh @67
  _CxxThrowException @68
  _EH_prolog @69
  _Getdays @70
  _Getmonths @71
  _Getnames @72
  _HUGE=MSVCRT__HUGE @74 DATA
  _Strftime @75
  _XcptFilter @76
  __CxxFrameHandler @77
  __RTCastToVoid=MSVCRT___RTCastToVoid @79
  __RTDynamicCast=MSVCRT___RTDynamicCast @80
  __RTtypeid=MSVCRT___RTtypeid @81
  __argc=MSVCRT___argc @83 DATA
  __argv=MSVCRT___argv @84 DATA
  __crtLCMapStringA @88
  __dllonexit @89
  __doserrno=MSVCRT___doserrno @90
  __fpecode @91
  __getmainargs @92
  __initenv=MSVCRT___initenv @93 DATA
  __isascii=MSVCRT___isascii @94
  __iscsym=MSVCRT___iscsym @95
  __iscsymf=MSVCRT___iscsymf @96
  __lconv_init @101
  __mb_cur_max=MSVCRT___mb_cur_max @102 DATA
  __p___argc @103
  __p___argv @104
  __p___initenv @105
  __p___mb_cur_max @106
  __p___wargv @107
  __p___winitenv @108
  __p__acmdln @109
  __p__commode @111
  __p__daylight=MSVCRT___p__daylight @112
  __p__environ @114
  __p__fmode @116
  __p__iob @117
  __p__mbctype @119
  __p__osver @120
  __p__pctype @121
  __p__pgmptr @122
  __p__timezone @124
  __p__wcmdln @126
  __p__wenviron @127
  __p__winmajor @128
  __p__winminor @129
  __p__winver @130
  __p__wpgmptr @131
  __set_app_type=MSVCRT___set_app_type @134
  __setlc_active=MSVCRT___setlc_active @135 DATA
  __setusermatherr=MSVCRT___setusermatherr @136
  __threadhandle=kernel32.GetCurrentThread @137
  __threadid=kernel32.GetCurrentThreadId @138
  __toascii=MSVCRT___toascii @139
  __unDName=MSVCRT___unDName @140
  __unDNameEx=MSVCRT___unDNameEx @141
  __unguarded_readlc_active=MSVCRT___unguarded_readlc_active @142 DATA
  __wargv=MSVCRT___wargv @143 DATA
  __wgetmainargs @144
  __winitenv=MSVCRT___winitenv @145 DATA
  _abnormal_termination @146
  _access @147
  _acmdln=MSVCRT__acmdln @148 DATA
  _adj_fdiv_m16i @149
  _adj_fdiv_m32 @150
  _adj_fdiv_m32i @151
  _adj_fdiv_m64 @152
  _adj_fdiv_r @153
  _adj_fdivr_m16i @154
  _adj_fdivr_m32 @155
  _adj_fdivr_m32i @156
  _adj_fdivr_m64 @157
  _adj_fpatan @158
  _adj_fprem @159
  _adj_fprem1 @160
  _adj_fptan @161
  _adjust_fdiv @162
  _aexit_rtn @163 DATA
  _amsg_exit=MSVCRT__amsg_exit @164
  _assert=MSVCRT__assert @165
  _atoi64=ntdll._atoi64 @167
  _beep @169
  _beginthread @170
  _beginthreadex @171
  _c_exit=MSVCRT__c_exit @172
  _cabs=MSVCRT__cabs @173
  _callnewh @174
  _cexit=MSVCRT__cexit @175
  _cgets @176
  _chdir @177
  _chdrive @178
  _chgsign @179
  _chkesp @180
  _chmod @181
  _chsize @182
  _clearfp @183
  _close @184
  _commit @185
  _commode=MSVCRT__commode @186 DATA
  _control87 @187
  _controlfp @188
  _copysign @189
  _cprintf @190
  _cputs @191
  _creat @192
  _cscanf @193
  _ctype=MSVCRT__ctype @194 DATA
  _cwait @195
  _daylight=MSVCRT___daylight @196 DATA
  _dup @198
  _dup2 @199
  _ecvt @200
  _endthread @201
  _endthreadex @202
  _environ=MSVCRT__environ @203 DATA
  _eof @204
  _errno=MSVCRT__errno @205
  _except_handler2 @206
  _except_handler3 @207
  _execl @208
  _execle @209
  _execlp @210
  _execlpe @211
  _execv @212
  _execve @213
  _execvp @214
  _execvpe @215
  _exit=MSVCRT__exit @216
  _expand @217
  _fcloseall=MSVCRT__fcloseall @218
  _fcvt @219
  _fdopen=MSVCRT__fdopen @220
  _fgetchar @221
  _fgetwchar @222
  _filbuf=MSVCRT__filbuf @223
  _filelength @225
  _filelengthi64 @226
  _fileno=MSVCRT__fileno @227
  _findclose @228
  _findfirst=MSVCRT__findfirst @229
  _findfirsti64=MSVCRT__findfirsti64 @230
  _findnext=MSVCRT__findnext @231
  _findnexti64=MSVCRT__findnexti64 @232
  _finite @233
  _flsbuf=MSVCRT__flsbuf @234
  _flushall @235
  _fmode=MSVCRT__fmode @236 DATA
  _fpclass @237
  _fpreset @239
  _fputchar @240
  _fputwchar @241
  _fsopen @242
  _fstat=MSVCRT__fstat @243
  _fstati64=MSVCRT__fstati64 @244
  _ftime @245
  _ftol=ntdll._ftol @246
  _fullpath @247
  _futime @248
  _gcvt @249
  _get_osfhandle @250
  _getch @252
  _getche @253
  _getcwd @254
  _getdcwd @255
  _getdiskfree=MSVCRT__getdiskfree @256
  _getdllprocaddr @257
  _getdrive @258
  _getdrives=kernel32.GetLogicalDrives @259
  _getmbcp @261
  _getpid=kernel32.GetCurrentProcessId @262
  _getw=MSVCRT__getw @264
  _getws=MSVCRT__getws @265
  _global_unwind2 @266
  _heapadd @267
  _heapchk @268
  _heapmin @269
  _heapset @270
  _heapwalk @272
  _hypot=hypot @273
  _i64toa=ntdll._i64toa @274
  _i64tow=ntdll._i64tow @275
  _initterm @276
  _iob=MSVCRT__iob @280 DATA
  _isatty @281
  _isctype @282
  _ismbbkana @287
  _ismbblead @290
  _ismbbtrail @293
  _ismbcalnum @294
  _ismbcalpha @295
  _ismbcdigit @296
  _ismbcgraph @297
  _ismbchira @298
  _ismbckata @299
  _ismbclower @304
  _ismbcprint @305
  _ismbcpunct @306
  _ismbcspace @307
  _ismbcsymbol @308
  _ismbcupper @309
  _ismbslead @310
  _ismbstrail @311
  _isnan @312
  _itoa=ntdll._itoa @313
  _itow=ntdll._itow @314
  _j0=j0 @315
  _j1=j1 @316
  _jn=jn @317
  _kbhit @318
  _lfind @319
  _loaddll @320
  _local_unwind2 @321
  _lock @322
  _locking @323
  _logb @324
  _longjmpex=MSVCRT_longjmp @325
  _lrotl @326
  _lrotr @327
  _lsearch @328
  _lseek @329
  _lseeki64 @330
  _ltoa=ntdll._ltoa @331
  _ltow=ntdll._ltow @332
  _makepath @333
  _matherr=MSVCRT__matherr @334
  _mbbtombc @335
  _mbccpy=strcpy @338
  _mbclen @341
  _mbctolower @344
  _mbctoupper @346
  _mbctype=MSVCRT_mbctype @347 DATA
  _mbscat=strcat @349
  _mbschr @350
  _mbscmp @351
  _mbscpy=strcpy @353
  _mbscspn @354
  _mbsdec @355
  _mbsdup=_strdup @356
  _mbsicmp @357
  _mbsicoll @358
  _mbsinc @359
  _mbslen @360
  _mbslwr @361
  _mbsnbcat @362
  _mbsnbcmp @363
  _mbsnbcnt @364
  _mbsnbcpy @366
  _mbsnbicmp @367
  _mbsnbset @369
  _mbsncat @370
  _mbsnccnt @371
  _mbsncmp @372
  _mbsncpy @374
  _mbsnextc @375
  _mbsnicmp @376
  _mbsninc @378
  _mbsnset @379
  _mbspbrk @380
  _mbsrchr @381
  _mbsrev @382
  _mbsset @383
  _mbsspn @384
  _mbsstr=strstr @386
  _mbstok @387
  _mbstrlen @388
  _mbsupr @389
  _memccpy=memccpy @390
  _memicmp=ntdll._memicmp @391
  _mkdir @392
  _mktemp @393
  _msize @394
  _nextafter @395
  _onexit=MSVCRT__onexit @396
  _open @397
  _open_osfhandle @398
  _osver=MSVCRT__osver @399 DATA
  _pclose=MSVCRT__pclose @403
  _pctype=MSVCRT__pctype @404 DATA
  _pgmptr=MSVCRT__pgmptr @405 DATA
  _popen=MSVCRT__popen @407
  _purecall @408
  _putch @409
  _putenv @410
  _putw=MSVCRT__putw @411
  _putws @412
  _read @414
  _rmdir @415
  _rmtmp @416
  _rotl @417
  _rotr @418
  _safe_fdiv @419
  _safe_fdivr @420
  _safe_fprem @421
  _safe_fprem1 @422
  _scalb @423
  _searchenv @424
  _seh_longjmp_unwind@4 @425
  _set_error_mode @426
  _seterrormode @428
  _setjmp=MSVCRT__setjmp @429
  _setjmp3=MSVCRT__setjmp3 @430
  _setmbcp @432
  _setmode @433
  _sleep @435
  _snprintf=snprintf @436
  _snwprintf=ntdll._snwprintf @437
  _sopen=MSVCRT__sopen @438
  _spawnl @439
  _spawnle @440
  _spawnlp @441
  _spawnlpe @442
  _spawnv @443
  _spawnve @444
  _spawnvp @445
  _spawnvpe @446
  _splitpath=ntdll._splitpath @447
  _stat=MSVCRT__stat @448
  _stati64=MSVCRT__stati64 @449
  _statusfp @450
  _strcmpi=strcasecmp @451
  _strdate @452
  _strdup @453
  _strerror @454
  _stricmp=strcasecmp @455
  _strlwr=ntdll._strlwr @457
  _strnicmp=strncasecmp @459
  _strnset @461
  _strrev @462
  _strset @463
  _strtime @464
  _strupr=ntdll._strupr @465
  _swab=MSVCRT__swab @466
  _sys_errlist=MSVCRT__sys_errlist @467 DATA
  _sys_nerr=MSVCRT__sys_nerr @468 DATA
  _tell @469
  _telli64 @470
  _tempnam @471
  _tolower=MSVCRT__tolower @473
  _toupper=MSVCRT__toupper @474
  _tzset=tzset @476
  _ui64toa=ntdll._ui64toa @477
  _ui64tow=ntdll._ui64tow @478
  _ultoa=ntdll._ultoa @479
  _ultow=ntdll._ultow @480
  _umask @481
  _ungetch @482
  _unlink @483
  _unloaddll @484
  _unlock @485
  _utime @486
  _vsnprintf=vsnprintf @487
  _vsnwprintf @488
  _waccess @489
  _wchdir @491
  _wchmod @492
  _wcmdln=MSVCRT__wcmdln @493 DATA
  _wcreat @494
  _wcsdup @495
  _wcsicmp=ntdll._wcsicmp @496
  _wcsicoll @497
  _wcslwr=ntdll._wcslwr @498
  _wcsnicmp=ntdll._wcsnicmp @500
  _wcsnset @502
  _wcsrev @503
  _wcsset @504
  _wcsupr=ntdll._wcsupr @505
  _wenviron=MSVCRT__wenviron @507 DATA
  _wfdopen=MSVCRT__wfdopen @516
  _wfindfirst=MSVCRT__wfindfirst @517
  _wfindfirsti64=MSVCRT__wfindfirsti64 @518
  _wfindnext=MSVCRT__wfindnext @519
  _wfindnexti64=MSVCRT__wfindnexti64 @520
  _wfopen=MSVCRT__wfopen @521
  _wfsopen=MSVCRT__wfsopen @523
  _wfullpath @524
  _wgetcwd @525
  _wgetdcwd @526
  _wgetenv @527
  _winmajor=MSVCRT__winmajor @528 DATA
  _winminor=MSVCRT__winminor @529 DATA
  _winver=MSVCRT__winver @530 DATA
  _wmakepath @531
  _wmkdir @532
  _wmktemp @533
  _wopen @534
  _wpgmptr=MSVCRT__wpgmptr @536 DATA
  _wpopen=MSVCRT__wpopen @537
  _wputenv @538
  _wremove @539
  _wrename @540
  _write @541
  _wrmdir @542
  _wsopen=MSVCRT__wsopen @545
  _wsplitpath @554
  _wstat=MSVCRT__wstat @555
  _wstati64=MSVCRT__wstati64 @556
  _wtempnam @560
  _wtoi=ntdll._wtoi @562
  _wtoi64=ntdll._wtoi64 @563
  _wtol=ntdll._wtol @564
  _wunlink @565
  _wutime @566
  _y0 @567
  _y1 @568
  _yn @569
  abort=MSVCRT_abort @570
  abs @571
  acos @572
  asctime @573
  asin @574
  atan @575
  atan2 @576
  atexit=MSVCRT_atexit @577
  atof @578
  atoi @579
  atol @580
  bsearch @581
  calloc=MSVCRT_calloc @582
  ceil @583
  clearerr=MSVCRT_clearerr @584
  clock=MSVCRT_clock @585
  cos @586
  cosh @587
  ctime @588
  difftime=MSVCRT_difftime @589
  div=MSVCRT_div @590
  exit=MSVCRT_exit @591
  exp @592
  fabs @593
  fclose=MSVCRT_fclose @594
  feof=MSVCRT_feof @595
  ferror=MSVCRT_ferror @596
  fflush=MSVCRT_fflush @597
  fgetc=MSVCRT_fgetc @598
  fgetpos=MSVCRT_fgetpos @599
  fgets=MSVCRT_fgets @600
  fgetwc=MSVCRT_fgetwc @601
  fgetws=MSVCRT_fgetws @602
  floor @603
  fmod @604
  fopen=MSVCRT_fopen @605
  fprintf=MSVCRT_fprintf @606
  fputc=MSVCRT_fputc @607
  fputs=MSVCRT_fputs @608
  fputwc=MSVCRT_fputwc @609
  fputws=MSVCRT_fputws @610
  fread=MSVCRT_fread @611
  free=MSVCRT_free @612
  freopen=MSVCRT_freopen @613
  frexp @614
  fscanf=MSVCRT_fscanf @615
  fseek=MSVCRT_fseek @616
  fsetpos=MSVCRT_fsetpos @617
  ftell=MSVCRT_ftell @618
  fwprintf=MSVCRT_fwprintf @619
  fwrite=MSVCRT_fwrite @620
  fwscanf=MSVCRT_fwscanf @621
  getc=MSVCRT_getc @622
  getchar=MSVCRT_getchar @623
  getenv=MSVCRT_getenv @624
  gets=MSVCRT_gets @625
  getwc=MSVCRT_getwc @626
  getwchar=MSVCRT_getwchar @627
  gmtime=MSVCRT_gmtime @628
  is_wctype=ntdll.iswctype @629
  isalnum=MSVCRT_isalnum @630
  isalpha=MSVCRT_isalpha @631
  iscntrl=MSVCRT_iscntrl @632
  isdigit=MSVCRT_isdigit @633
  isgraph=MSVCRT_isgraph @634
  isleadbyte=MSVCRT_isleadbyte @635
  islower=MSVCRT_islower @636
  isprint=MSVCRT_isprint @637
  ispunct=MSVCRT_ispunct @638
  isspace=MSVCRT_isspace @639
  isupper=MSVCRT_isupper @640
  iswalnum=MSVCRT_iswalnum @641
  iswalpha=ntdll.iswalpha @642
  iswascii=MSVCRT_iswascii @643
  iswcntrl=MSVCRT_iswcntrl @644
  iswctype=ntdll.iswctype @645
  iswdigit=MSVCRT_iswdigit @646
  iswgraph=MSVCRT_iswgraph @647
  iswlower=MSVCRT_iswlower @648
  iswprint=MSVCRT_iswprint @649
  iswpunct=MSVCRT_iswpunct @650
  iswspace=MSVCRT_iswspace @651
  iswupper=MSVCRT_iswupper @652
  iswxdigit=MSVCRT_iswxdigit @653
  isxdigit=MSVCRT_isxdigit @654
  labs @655
  ldexp=MSVCRT_ldexp @656
  ldiv=MSVCRT_ldiv @657
  localeconv=MSVCRT_localeconv @658
  localtime=MSVCRT_localtime @659
  log @660
  log10 @661
  longjmp=MSVCRT_longjmp @662
  malloc=MSVCRT_malloc @663
  mblen=MSVCRT_mblen @664
  mbstowcs=ntdll.mbstowcs @665
  mbtowc=MSVCRT_mbtowc @666
  memchr @667
  memcmp @668
  memcpy=memmove @669
  memmove @670
  memset @671
  mktime=MSVCRT_mktime @672
  modf @673
  perror=MSVCRT_perror @674
  pow @675
  printf=MSVCRT_printf @676
  putc=MSVCRT_putc @677
  putchar=MSVCRT_putchar @678
  puts=MSVCRT_puts @679
  putwc=MSVCRT_fputwc @680
  putwchar=_fputwchar @681
  qsort @682
  rand=MSVCRT_rand @684
  realloc=MSVCRT_realloc @685
  remove=MSVCRT_remove @686
  rename=MSVCRT_rename @687
  rewind=MSVCRT_rewind @688
  scanf=MSVCRT_scanf @689
  setbuf=MSVCRT_setbuf @690
  setlocale=MSVCRT_setlocale @691
  setvbuf=MSVCRT_setvbuf @692
  signal=MSVCRT_signal @693
  sin @694
  sinh @695
  sprintf @696
  sqrt @697
  srand @698
  sscanf=MSVCRT_sscanf @699
  strcat @700
  strchr @701
  strcmp @702
  strcoll @703
  strcpy @704
  strcspn @705
  strerror=MSVCRT_strerror @706
  strftime @707
  strlen @708
  strncat @709
  strncmp @710
  strncpy @711
  strpbrk @712
  strrchr @713
  strspn @714
  strstr @715
  strtod @716
  strtok @717
  strtol @718
  strtoul @719
  strxfrm @720
  swprintf=ntdll.swprintf @721
  swscanf=MSVCRT_swscanf @722
  system=MSVCRT_system @723
  tan @724
  tanh @725
  time=MSVCRT_time @726
  tmpfile=MSVCRT_tmpfile @727
  tmpnam=MSVCRT_tmpnam @728
  tolower @729
  toupper @730
  towlower=ntdll.towlower @731
  towupper=ntdll.towupper @732
  ungetc=MSVCRT_ungetc @733
  ungetwc=MSVCRT_ungetwc @734
  vfprintf=MSVCRT_vfprintf @735
  vfwprintf=MSVCRT_vfwprintf @736
  vprintf=MSVCRT_vprintf @737
  vsprintf @738
  vswprintf=MSVCRT_vswprintf @739
  vwprintf=MSVCRT_vwprintf @740
  wcscat=ntdll.wcscat @741
  wcschr=ntdll.wcschr @742
  wcscmp=ntdll.wcscmp @743
  wcscoll=MSVCRT_wcscoll @744
  wcscpy=ntdll.wcscpy @745
  wcscspn=ntdll.wcscspn @746
  wcslen=ntdll.wcslen @748
  wcsncat=ntdll.wcsncat @749
  wcsncmp=ntdll.wcsncmp @750
  wcsncpy=ntdll.wcsncpy @751
  wcspbrk=MSVCRT_wcspbrk @752
  wcsrchr=ntdll.wcsrchr @753
  wcsspn=ntdll.wcsspn @754
  wcsstr=ntdll.wcsstr @755
  wcstod=MSVCRT_wcstod @756
  wcstok=ntdll.wcstok @757
  wcstol=ntdll.wcstol @758
  wcstombs=ntdll.wcstombs @759
  wcstoul=ntdll.wcstoul @760
  wctomb=MSVCRT_wctomb @762
  wprintf=MSVCRT_wprintf @763
  wscanf=MSVCRT_wscanf @764
  _Gettnames @73
