; File generated automatically from quartz/quartz.spec; do not edit!

LIBRARY quartz.dll

EXPORTS
  DllCanUnloadNow@0=QUARTZ_DllCanUnloadNow@0 @5 PRIVATE
  DllGetClassObject@12=QUARTZ_DllGetClassObject@12 @6 PRIVATE
  DllRegisterServer@0=QUARTZ_DllRegisterServer@0 @7 PRIVATE
  DllUnregisterServer@0=QUARTZ_DllUnregisterServer@0 @8 PRIVATE
