; File generated automatically from mpr/mpr.spec; do not edit!

LIBRARY mpr.dll

EXPORTS
  DllCanUnloadNow@0 @10 PRIVATE
  MultinetGetConnectionPerformanceA@8 @26
  MultinetGetConnectionPerformanceW@8 @27
  MultinetGetErrorTextA@12 @28
  MultinetGetErrorTextW@12 @29
  NPSAuthenticationDialogA@4 @30
  NPSCopyStringA@12 @31
  NPSDeviceGetNumberA@12 @32
  NPSDeviceGetStringA@16 @33
  NPSGetProviderHandleA@4 @34
  NPSGetProviderNameA@8 @35
  NPSGetSectionNameA@8 @36
  NPSNotifyGetContextA@4 @37
  NPSNotifyRegisterA@8 @38
  NPSSetCustomTextA@4 @39
  NPSSetExtendedErrorA@8 @40
  WNetAddConnection2A@16 @47
  WNetAddConnection2W@16 @48
  WNetAddConnection3A@20 @49
  WNetAddConnection3W@20 @50
  WNetAddConnectionA@12 @51
  WNetAddConnectionW@12 @52
  WNetCachePassword@24 @53
  WNetCancelConnection2A@12 @54
  WNetCancelConnection2W@12 @55
  WNetCancelConnectionA@8 @56
  WNetCancelConnectionW@8 @57
  WNetCloseEnum@4 @58
  WNetConnectionDialog1A@4 @60
  WNetConnectionDialog1W@4 @61
  WNetConnectionDialog@8 @59
  WNetDisconnectDialog1A@4 @63
  WNetDisconnectDialog1W@4 @64
  WNetDisconnectDialog@8 @62
  WNetEnumCachedPasswords@20 @65
  WNetEnumResourceA@16 @66
  WNetEnumResourceW@16 @67
  WNetGetCachedPassword@20 @73
  WNetGetConnectionA@12 @74
  WNetGetConnectionW@12 @75
  WNetGetLastErrorA@20 @79
  WNetGetLastErrorW@20 @80
  WNetGetNetworkInformationA@8 @81
  WNetGetNetworkInformationW@8 @82
  WNetGetProviderNameA@12 @84
  WNetGetProviderNameW@12 @85
  WNetGetResourceInformationA@16 @86
  WNetGetResourceInformationW@16 @87
  WNetGetResourceParentA@12 @88
  WNetGetResourceParentW@12 @89
  WNetGetUniversalNameA@16 @90
  WNetGetUniversalNameW@16 @91
  WNetGetUserA@12 @92
  WNetGetUserW@12 @93
  WNetLogoffA@8 @94
  WNetLogoffW@8 @95
  WNetLogonA@8 @96
  WNetLogonW@8 @98
  WNetOpenEnumA@20 @99
  WNetOpenEnumW@20 @100
  WNetRemoveCachedPassword@12 @103
  WNetRestoreConnectionA@8 @105
  WNetRestoreConnectionW@8 @106
  WNetSetConnectionA@12 @107
  WNetSetConnectionW@12 @108
  WNetUseConnectionA@32 @109
  WNetUseConnectionW@32 @110
  WNetVerifyPasswordA@8 @111
  WNetVerifyPasswordW@8 @112
