; File generated automatically from wsock32/wsock32.spec; do not edit!

LIBRARY wsock32.dll

EXPORTS
  accept@12=ws2_32.accept @1
  bind@12=ws2_32.bind @2
  closesocket@4=ws2_32.closesocket @3
  connect@12=ws2_32.connect @4
  getpeername@12=ws2_32.getpeername @5
  getsockname@12=ws2_32.getsockname @6
  getsockopt@20=WS1_getsockopt@20 @7
  htonl@4=ws2_32.htonl @8
  htons@4=ws2_32.htons @9
  inet_addr@4=ws2_32.inet_addr @10
  inet_ntoa@4=ws2_32.inet_ntoa @11
  ioctlsocket@12=ws2_32.ioctlsocket @12
  listen@8=ws2_32.listen @13
  ntohl@4=ws2_32.ntohl @14
  ntohs@4=ws2_32.ntohs @15
  recv@16=ws2_32.recv @16
  recvfrom@24=ws2_32.recvfrom @17
  select@20=ws2_32.select @18
  send@16=ws2_32.send @19
  sendto@24=ws2_32.sendto @20
  setsockopt@20=WS1_setsockopt@20 @21
  shutdown@8=ws2_32.shutdown @22
  socket@12=ws2_32.socket @23
  gethostbyaddr@12=ws2_32.gethostbyaddr @51
  gethostbyname@4=ws2_32.gethostbyname @52
  getprotobyname@4=ws2_32.getprotobyname @53
  getprotobynumber@4=ws2_32.getprotobynumber @54
  getservbyname@8=ws2_32.getservbyname @55
  getservbyport@8=ws2_32.getservbyport @56
  gethostname@8=ws2_32.gethostname @57
  WSAAsyncSelect@16=ws2_32.WSAAsyncSelect @101
  WSAAsyncGetHostByAddr@28=ws2_32.WSAAsyncGetHostByAddr @102
  WSAAsyncGetHostByName@20=ws2_32.WSAAsyncGetHostByName @103
  WSAAsyncGetProtoByNumber@20=ws2_32.WSAAsyncGetProtoByNumber @104
  WSAAsyncGetProtoByName@20=ws2_32.WSAAsyncGetProtoByName @105
  WSAAsyncGetServByPort@24=ws2_32.WSAAsyncGetServByPort @106
  WSAAsyncGetServByName@24=ws2_32.WSAAsyncGetServByName @107
  WSACancelAsyncRequest@4=ws2_32.WSACancelAsyncRequest @108
  WSASetBlockingHook@4=ws2_32.WSASetBlockingHook @109
  WSAUnhookBlockingHook@0=ws2_32.WSAUnhookBlockingHook @110
  WSAGetLastError@0=ws2_32.WSAGetLastError @111
  WSASetLastError@4=ws2_32.WSASetLastError @112
  WSACancelBlockingCall@0=ws2_32.WSACancelBlockingCall @113
  WSAIsBlocking@0=ws2_32.WSAIsBlocking @114
  WSAStartup@8=ws2_32.WSAStartup @115
  WSACleanup@0=ws2_32.WSACleanup @116
  __WSAFDIsSet@8=ws2_32.__WSAFDIsSet @151
  WEP@0=ws2_32.WEP @500
  WsControl@24 @1001
  inet_network@4=WSOCK32_inet_network@4 @1100
  getnetbyname@4=WSOCK32_getnetbyname@4 @1101
  WSARecvEx@16 @1107
  s_perror@4 @1108
  EnumProtocolsA@12 @1111
  EnumProtocolsW@12 @1112
  GetTypeByNameA@8 @1113
  GetTypeByNameW@8 @1114
  SetServiceA@24 @1117
  SetServiceW@24 @1118
