; File generated automatically from imm32/imm32.spec; do not edit!

LIBRARY imm32.dll

EXPORTS
  ImmAssociateContext@8 @2
  ImmAssociateContextEx@12 @3
  ImmConfigureIMEA@16 @4
  ImmConfigureIMEW@16 @5
  ImmCreateContext@0 @6
  ImmDestroyContext@4 @9
  ImmDisableIME@4 @12
  ImmEnumRegisterWordA@24 @15
  ImmEnumRegisterWordW@24 @16
  ImmEscapeA@16 @17
  ImmEscapeW@16 @18
  ImmGetCandidateListA@16 @21
  ImmGetCandidateListCountA@8 @22
  ImmGetCandidateListCountW@8 @23
  ImmGetCandidateListW@16 @24
  ImmGetCandidateWindow@12 @25
  ImmGetCompositionFontA@8 @26
  ImmGetCompositionFontW@8 @27
  ImmGetCompositionStringA@16 @29
  ImmGetCompositionStringW@16 @30
  ImmGetCompositionString@16=ImmGetCompositionStringA@16 @28
  ImmGetCompositionWindow@8 @31
  ImmGetContext@4 @32
  ImmGetConversionListA@24 @33
  ImmGetConversionListW@24 @34
  ImmGetConversionStatus@12 @35
  ImmGetDefaultIMEWnd@4 @36
  ImmGetDescriptionA@12 @37
  ImmGetDescriptionW@12 @38
  ImmGetGuideLineA@16 @39
  ImmGetGuideLineW@16 @40
  ImmGetIMEFileNameA@12 @45
  ImmGetIMEFileNameW@12 @46
  ImmGetOpenStatus@4 @50
  ImmGetProperty@8 @51
  ImmGetRegisterWordStyleA@12 @52
  ImmGetRegisterWordStyleW@12 @53
  ImmGetStatusWindowPos@8 @54
  ImmGetVirtualKey@4 @55
  ImmInstallIMEA@8 @62
  ImmInstallIMEW@8 @63
  ImmIsIME@4 @64
  ImmIsUIMessageA@16 @65
  ImmIsUIMessageW@16 @66
  ImmNotifyIME@16 @73
  ImmRegisterWordA@16 @79
  ImmRegisterWordW@16 @80
  ImmReleaseContext@8 @81
  ImmSetCandidateWindow@8 @89
  ImmSetCompositionFontA@8 @90
  ImmSetCompositionFontW@8 @91
  ImmSetCompositionStringA@24 @92
  ImmSetCompositionStringW@24 @93
  ImmSetCompositionWindow@8 @94
  ImmSetConversionStatus@12 @95
  ImmSetHotKey@16=user32.CliImmSetHotKey @96
  ImmSetOpenStatus@8 @97
  ImmSetStatusWindowPos@8 @98
  ImmSimulateHotKey@8 @100
  ImmUnregisterWordA@16 @107
  ImmUnregisterWordW@16 @108
