/*** Autogenerated by WIDL 0.1 from shtypes.idl - Do not edit ***/
#include <rpc.h>
#include <rpcndr.h>

#ifndef __WIDL_SHTYPES_H
#define __WIDL_SHTYPES_H
#ifdef __cplusplus
extern "C" {
#endif
#include <wtypes.h>
#include <pshpack1.h>
typedef struct {
    WORD cb;
    BYTE abID[1];
} SHITEMID, *LPSHITEMID;

typedef const SHITEMID *LPCSHITEMID;

typedef struct _ITEMIDLIST {
    SHITEMID mkid;
} ITEMIDLIST, *LPITEMIDLIST;

typedef const ITEMIDLIST *LPCITEMIDLIST;

#include <poppack.h>
#if 0
typedef struct {
    int dummy;
} WIN32_FIND_DATAA, WIN32_FIND_DATAW;

#endif
typedef enum tagSTRRET_TYPE {
    STRRET_WSTR = 0,
    STRRET_OFFSET = 1,
    STRRET_CSTR = 2
} STRRET_TYPE;

#include <pshpack4.h>
typedef struct _STRRET {
    UINT uType;
    union {
        LPWSTR pOleStr;
        UINT uOffset;
        char cStr[260];
    } DUMMYUNIONNAME;
} STRRET, *LPSTRRET;

#include <poppack.h>
#include <pshpack1.h>
typedef struct {
    int fmt;
    int cxChar;
    STRRET str;
} SHELLDETAILS, *LPSHELLDETAILS;

#include <poppack.h>
#ifdef __cplusplus
}
#endif
#endif /* __WIDL_SHTYPES_H */
