; File generated automatically from olepro32/olepro32.spec; do not edit!

LIBRARY olepro32.dll

EXPORTS
  OleIconToCursor@8=oleaut32.OleIconToCursor @248
  OleCreatePropertyFrameIndirect@4=oleaut32.OleCreatePropertyFrameIndirect @249
  OleCreatePropertyFrame@44=oleaut32.OleCreatePropertyFrame @250
  OleLoadPicture@20=oleaut32.OleLoadPicture @251
  OleCreatePictureIndirect@16=oleaut32.OleCreatePictureIndirect @252
  OleCreateFontIndirect@12=oleaut32.OleCreateFontIndirect @253
  OleTranslateColor@12=oleaut32.OleTranslateColor @254
  DllCanUnloadNow@0=OLEPRO32_DllCanUnloadNow@0 @255 PRIVATE
  DllGetClassObject@12=OLEPRO32_DllGetClassObject@12 @256 PRIVATE
  DllRegisterServer@0=OLEPRO32_DllRegisterServer@0 @257 PRIVATE
  DllUnregisterServer@0=OLEPRO32_DllUnregisterServer@0 @258 PRIVATE
