; File generated automatically from msimg32/msimg32.spec; do not edit!

LIBRARY msimg32.dll

EXPORTS
  AlphaBlend@44=gdi32.GdiAlphaBlend @1
  GradientFill@24=gdi32.GdiGradientFill @3
  TransparentBlt@44=gdi32.GdiTransparentBlt @4
  vSetDdrawflag@0 @5
