; File generated automatically from serialui/serialui.spec; do not edit!

LIBRARY serialui.dll

EXPORTS
  EnumPropPages@12=SERIALUI_EnumPropPages@12 @2
  drvCommConfigDialog@12=SERIALUI_CommConfigDialog@12 @3
  drvSetDefaultCommConfig@12=SERIALUI_SetDefaultCommConfig@12 @4
  drvGetDefaultCommConfig@12=SERIALUI_GetDefaultCommConfig@12 @5
