; File generated automatically from d3dx8/d3dx8.spec; do not edit!

LIBRARY d3dx8.dll

EXPORTS
  D3DXCreateBuffer@8 @4
  D3DXCreateFont@12 @5
  D3DXGetFVFVertexSize@4 @6
  D3DXAssembleShader@24 @1
  D3DXAssembleShaderFromFileA@20 @2
  D3DXAssembleShaderFromFileW@20 @3
