; File generated automatically from wineps/wineps.spec; do not edit!

LIBRARY wineps.dll

EXPORTS
  Arc=PSDRV_Arc @1
  Chord=PSDRV_Chord @2
  CreateDC=PSDRV_CreateDC @3
  DeleteDC=PSDRV_DeleteDC @4
  DeviceCapabilities=PSDRV_DeviceCapabilities @5
  Ellipse=PSDRV_Ellipse @6
  EndDoc=PSDRV_EndDoc @7
  EndPage=PSDRV_EndPage @8
  EnumDeviceFonts=PSDRV_EnumDeviceFonts @9
  ExtDeviceMode=PSDRV_ExtDeviceMode @10
  ExtEscape=PSDRV_ExtEscape @11
  ExtTextOut=PSDRV_ExtTextOut @12
  GetCharWidth=PSDRV_GetCharWidth @13
  GetDeviceCaps=PSDRV_GetDeviceCaps @14
  GetTextExtentPoint=PSDRV_GetTextExtentPoint @15
  GetTextMetrics=PSDRV_GetTextMetrics @16
  LineTo=PSDRV_LineTo @17
  PaintRgn=PSDRV_PaintRgn @18
  PatBlt=PSDRV_PatBlt @19
  Pie=PSDRV_Pie @20
  PolyPolygon=PSDRV_PolyPolygon @21
  PolyPolyline=PSDRV_PolyPolyline @22
  Polygon=PSDRV_Polygon @23
  Polyline=PSDRV_Polyline @24
  Rectangle=PSDRV_Rectangle @25
  ResetDC=PSDRV_ResetDC @26
  RoundRect=PSDRV_RoundRect @27
  SelectBitmap=PSDRV_SelectBitmap @28
  SelectBrush=PSDRV_SelectBrush @29
  SelectFont=PSDRV_SelectFont @30
  SelectPen=PSDRV_SelectPen @31
  SetBkColor=PSDRV_SetBkColor @32
  SetDeviceClipping=PSDRV_SetDeviceClipping @33
  SetPixel=PSDRV_SetPixel @34
  SetTextColor=PSDRV_SetTextColor @35
  StartDoc=PSDRV_StartDoc @36
  StartPage=PSDRV_StartPage @37
  StretchDIBits=PSDRV_StretchDIBits @38
