; File generated automatically from msi/msi.spec; do not edit!

LIBRARY msi.dll

EXPORTS
  DllCanUnloadNow@0=MSI_DllCanUnloadNow@0 @1
  DllGetClassObject@12=MSI_DllGetClassObject@12 @2
  DllRegisterServer@0=MSI_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=MSI_DllUnregisterServer@0 @4 PRIVATE
  MsiAdvertiseProductA@16 @5
  MsiAdvertiseProductW@16 @6
  MsiCloseAllHandles@0 @7
  MsiCloseHandle@4 @8
  MsiConfigureProductA@12 @15
  MsiConfigureProductW@12 @16
  MsiCreateRecord@4 @17
  MsiDatabaseApplyTransformA@12 @18
  MsiDatabaseApplyTransformW@12 @19
  MsiDatabaseCommit@4 @20
  MsiDatabaseGenerateTransformA@20 @23
  MsiDatabaseGenerateTransformW@20 @24
  MsiDatabaseGetPrimaryKeysA@12 @25
  MsiDatabaseGetPrimaryKeysW@12 @26
  MsiDatabaseImportA@8 @27
  MsiDatabaseImportW@8 @28
  MsiDatabaseOpenViewA@12 @31
  MsiDatabaseOpenViewW@12 @32
  MsiDoActionA@8 @33
  MsiDoActionW@8 @34
  MsiEnumClientsA@12 @36
  MsiEnumClientsW@12 @37
  MsiEnumComponentQualifiersA@24 @38
  MsiEnumComponentQualifiersW@24 @39
  MsiEnumComponentsA@8 @40
  MsiEnumComponentsW@8 @41
  MsiEnumFeaturesA@16 @42
  MsiEnumFeaturesW@16 @43
  MsiEnumProductsA@8 @44
  MsiEnumProductsW@8 @45
  MsiEvaluateConditionA@8 @46
  MsiEvaluateConditionW@8 @47
  MsiGetComponentStateA@16 @50
  MsiGetComponentStateW@16 @51
  MsiGetFeatureStateA@16 @57
  MsiGetFeatureStateW@16 @58
  MsiGetProductCodeA@8 @65
  MsiGetProductCodeW@8 @66
  MsiGetProductInfoA@16 @67
  MsiGetProductInfoW@16 @70
  MsiGetProductPropertyA@16 @71
  MsiGetProductPropertyW@16 @72
  MsiGetPropertyA@16 @73
  MsiGetPropertyW@16 @74
  MsiGetSummaryInformationA@16 @77
  MsiGetSummaryInformationW@16 @78
  MsiInstallProductA@8 @87
  MsiInstallProductW@8 @88
  MsiLocateComponentA@12 @89
  MsiLocateComponentW@12 @90
  MsiOpenDatabaseA@12 @91
  MsiOpenDatabaseW@12 @92
  MsiOpenPackageA@8 @93
  MsiOpenPackageW@8 @94
  MsiOpenProductA@8 @95
  MsiOpenProductW@8 @96
  MsiProvideComponentFromDescriptorA@16 @105
  MsiProvideComponentFromDescriptorW@16 @106
  MsiQueryProductStateA@4 @112
  MsiQueryProductStateW@4 @113
  MsiRecordDataSize@8 @114
  MsiRecordGetFieldCount@4 @115
  MsiRecordGetInteger@8 @116
  MsiRecordGetStringA@16 @117
  MsiRecordGetStringW@16 @118
  MsiRecordIsNull@8 @119
  MsiRecordReadStream@16 @120
  MsiRecordSetInteger@12 @121
  MsiRecordSetStreamA@12 @122
  MsiRecordSetStreamW@12 @123
  MsiRecordSetStringA@12 @124
  MsiRecordSetStringW@12 @125
  MsiSetInternalUI@8 @141
  MsiSummaryInfoGetPropertyA@28 @148
  MsiSummaryInfoGetPropertyCount@8 @149
  MsiSummaryInfoGetPropertyW@28 @150
  MsiVerifyPackageA@4 @156
  MsiVerifyPackageW@4 @157
  MsiViewClose@4 @158
  MsiViewExecute@8 @159
  MsiViewFetch@8 @160
  MsiDatabaseIsTablePersistentA@8 @164
  MsiDatabaseIsTablePersistentW@8 @165
  MsiViewGetColumnInfo@12 @166
  MsiRecordClearData@4 @167
  MsiEnableLogA@12 @168
  MsiEnableLogW@12 @169
  MsiFormatRecordA@16 @170
  MsiFormatRecordW@16 @171
  DllGetVersion@4=MSI_DllGetVersion@4 @182
  MsiLoadStringA@20 @196
  MsiLoadStringW@20 @197
  MsiMessageBoxA@24 @198
  MsiMessageBoxW@24 @199
  MsiGetFileSignatureInformationA@20 @223
  MsiGetFileSignatureInformationW@20 @224
  MsiProvideAssemblyA@24 @225
  MsiProvideAssemblyW@24 @226
  MsiAdvertiseProductExA@24 @227
  MsiAdvertiseProductExW@24 @228
  MsiOpenPackageExA@12 @231
  MsiOpenPackageExW@12 @232
