; File generated automatically from msvcrt40/msvcrt40.spec; do not edit!

LIBRARY msvcrt40.dll

EXPORTS
  ??0__non_rtti_object@@QAE@ABV0@@Z=msvcrt.??0__non_rtti_object@@QAE@ABV0@@Z @4
  ??0__non_rtti_object@@QAE@PBD@Z=msvcrt.??0__non_rtti_object@@QAE@PBD@Z @5
  ??0bad_cast@@QAE@ABQBD@Z=msvcrt.??0bad_cast@@QAE@ABQBD@Z @6
  ??0bad_cast@@QAE@ABV0@@Z=msvcrt.??0bad_cast@@QAE@ABV0@@Z @7
  ??0bad_typeid@@QAE@ABV0@@Z=msvcrt.??0bad_typeid@@QAE@ABV0@@Z @8
  ??0bad_typeid@@QAE@PBD@Z=msvcrt.??0bad_typeid@@QAE@PBD@Z @9
  ??0exception@@QAE@ABQBD@Z=msvcrt.??0exception@@QAE@ABQBD@Z @10
  ??0exception@@QAE@ABV0@@Z=msvcrt.??0exception@@QAE@ABV0@@Z @11
  ??0exception@@QAE@XZ=msvcrt.??0exception@@QAE@XZ @12
  ??1__non_rtti_object@@UAE@XZ=msvcrt.??1__non_rtti_object@@UAE@XZ @74
  ??1bad_cast@@UAE@XZ=msvcrt.??1bad_cast@@UAE@XZ @75
  ??1bad_typeid@@UAE@XZ=msvcrt.??1bad_typeid@@UAE@XZ @76
  ??1exception@@UAE@XZ=msvcrt.??1exception@@UAE@XZ @77
  ??1type_info@@UAE@XZ=msvcrt.??1type_info@@UAE@XZ @96
  ??2@YAPAXI@Z=msvcrt.??2@YAPAXI@Z @97
  ??3@YAXPAX@Z=msvcrt.??3@YAXPAX@Z @98
  ??4__non_rtti_object@@QAEAAV0@ABV0@@Z=msvcrt.??4__non_rtti_object@@QAEAAV0@ABV0@@Z @100
  ??4bad_cast@@QAEAAV0@ABV0@@Z=msvcrt.??4bad_cast@@QAEAAV0@ABV0@@Z @101
  ??4bad_typeid@@QAEAAV0@ABV0@@Z=msvcrt.??4bad_typeid@@QAEAAV0@ABV0@@Z @102
  ??4exception@@QAEAAV0@ABV0@@Z=msvcrt.??4exception@@QAEAAV0@ABV0@@Z @103
  ??8type_info@@QBEHABV0@@Z=msvcrt.??8type_info@@QBEHABV0@@Z @167
  ??9type_info@@QBEHABV0@@Z=msvcrt.??9type_info@@QBEHABV0@@Z @168
  ??_7__non_rtti_object@@6B@=msvcrt.??_7__non_rtti_object@@6B@ @170 DATA
  ??_7bad_cast@@6B@=msvcrt.??_7bad_cast@@6B@ @171 DATA
  ??_7bad_typeid@@6B@=msvcrt.??_7bad_typeid@@6B@ @172 DATA
  ??_7exception@@6B@=msvcrt.??_7exception@@6B@ @173 DATA
  ??_E__non_rtti_object@@UAEPAXI@Z=msvcrt.??_E__non_rtti_object@@UAEPAXI@Z @221
  ??_Ebad_cast@@UAEPAXI@Z=msvcrt.??_Ebad_cast@@UAEPAXI@Z @222
  ??_Ebad_typeid@@UAEPAXI@Z=msvcrt.??_Ebad_typeid@@UAEPAXI@Z @223
  ??_Eexception@@UAEPAXI@Z=msvcrt.??_Eexception@@UAEPAXI@Z @224
  ??_G__non_rtti_object@@UAEPAXI@Z=msvcrt.??_G__non_rtti_object@@UAEPAXI@Z @244
  ??_Gbad_cast@@UAEPAXI@Z=msvcrt.??_Gbad_cast@@UAEPAXI@Z @245
  ??_Gbad_typeid@@UAEPAXI@Z=msvcrt.??_Gbad_typeid@@UAEPAXI@Z @246
  ??_Gexception@@UAEPAXI@Z=msvcrt.??_Gexception@@UAEPAXI@Z @247
  ?_query_new_handler@@YAP6AHI@ZXZ=msvcrt.?_query_new_handler@@YAP6AHI@ZXZ @266
  ?_query_new_mode@@YAHXZ=msvcrt.?_query_new_mode@@YAHXZ @267
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=msvcrt.?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z @268
  ?_set_new_mode@@YAHH@Z=msvcrt.?_set_new_mode@@YAHH@Z @269
  ?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z=msvcrt.?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z @270
  ?before@type_info@@QBEHABV1@@Z=msvcrt.?before@type_info@@QBEHABV1@@Z @280
  ?name@type_info@@QBEPBDXZ=msvcrt.?name@type_info@@QBEPBDXZ @358
  ?raw_name@type_info@@QBEPBDXZ=msvcrt.?raw_name@type_info@@QBEPBDXZ @386
  ?set_new_handler@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_new_handler@@YAP6AXXZP6AXXZ@Z @409
  ?set_terminate@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_terminate@@YAP6AXXZP6AXXZ@Z @410
  ?set_unexpected@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_unexpected@@YAP6AXXZP6AXXZ@Z @411
  ?terminate@@YAXXZ=msvcrt.?terminate@@YAXXZ @454
  ?unexpected@@YAXXZ=msvcrt.?unexpected@@YAXXZ @463
  ?what@exception@@UBEPBDXZ=msvcrt.?what@exception@@UBEPBDXZ @469
  $I10_OUTPUT=msvcrt.$I10_OUTPUT @1
  _CIacos=msvcrt._CIacos @484
  _CIasin=msvcrt._CIasin @485
  _CIatan=msvcrt._CIatan @486
  _CIatan2=msvcrt._CIatan2 @487
  _CIcos=msvcrt._CIcos @488
  _CIcosh=msvcrt._CIcosh @489
  _CIexp=msvcrt._CIexp @490
  _CIfmod=msvcrt._CIfmod @491
  _CIlog=msvcrt._CIlog @492
  _CIlog10=msvcrt._CIlog10 @493
  _CIpow=msvcrt._CIpow @494
  _CIsin=msvcrt._CIsin @495
  _CIsinh=msvcrt._CIsinh @496
  _CIsqrt=msvcrt._CIsqrt @497
  _CItan=msvcrt._CItan @498
  _CItanh=msvcrt._CItanh @499
  _CxxThrowException=msvcrt._CxxThrowException @500
  _EH_prolog=msvcrt._EH_prolog @501
  _HUGE=msvcrt._HUGE @502 DATA
  _XcptFilter=msvcrt._XcptFilter @503
  __CxxFrameHandler=msvcrt.__CxxFrameHandler @504
  __CxxLongjmpUnwind@4=msvcrt.__CxxLongjmpUnwind @505
  __RTCastToVoid=msvcrt.__RTCastToVoid @506
  __RTDynamicCast=msvcrt.__RTDynamicCast @507
  __RTtypeid=msvcrt.__RTtypeid @508
  __STRINGTOLD=msvcrt.__STRINGTOLD @509
  __argc=msvcrt.__argc @510 DATA
  __argv=msvcrt.__argv @511 DATA
  __dllonexit=msvcrt.__dllonexit @512
  __doserrno=msvcrt.__doserrno @513
  __fpecode=msvcrt.__fpecode @514
  __getmainargs=msvcrt.__getmainargs @515
  __initenv=msvcrt.__initenv @516 DATA
  __isascii=msvcrt.__isascii @517
  __iscsym=msvcrt.__iscsym @518
  __iscsymf=msvcrt.__iscsymf @519
  __lconv_init=msvcrt.__lconv_init @520
  __mb_cur_max=msvcrt.__mb_cur_max @521 DATA
  __p___argc=msvcrt.__p___argc @522
  __p___argv=msvcrt.__p___argv @523
  __p___initenv=msvcrt.__p___initenv @524
  __p___mb_cur_max=msvcrt.__p___mb_cur_max @525
  __p___wargv=msvcrt.__p___wargv @526
  __p___winitenv=msvcrt.__p___winitenv @527
  __p__acmdln=msvcrt.__p__acmdln @528
  __p__amblksiz=msvcrt.__p__amblksiz @529
  __p__commode=msvcrt.__p__commode @530
  __p__daylight=msvcrt.__p__daylight @531
  __p__dstbias=msvcrt.__p__dstbias @532
  __p__environ=msvcrt.__p__environ @533
  __p__fmode=msvcrt.__p__fmode @534
  __p__iob=msvcrt.__p__iob @535
  __p__mbctype=msvcrt.__p__mbctype @536
  __p__osver=msvcrt.__p__osver @537
  __p__pctype=msvcrt.__p__pctype @538
  __p__pgmptr=msvcrt.__p__pgmptr @539
  __p__pwctype=msvcrt.__p__pwctype @540
  __p__timezone=msvcrt.__p__timezone @541
  __p__tzname=msvcrt.__p__tzname @542
  __p__wcmdln=msvcrt.__p__wcmdln @543
  __p__wenviron=msvcrt.__p__wenviron @544
  __p__winmajor=msvcrt.__p__winmajor @545
  __p__winminor=msvcrt.__p__winminor @546
  __p__winver=msvcrt.__p__winver @547
  __p__wpgmptr=msvcrt.__p__wpgmptr @548
  __pxcptinfoptrs=msvcrt.__pxcptinfoptrs @549
  __set_app_type=msvcrt.__set_app_type @550
  __setusermatherr=msvcrt.__setusermatherr @551
  __threadhandle=msvcrt.__threadhandle @552
  __threadid=msvcrt.__threadid @553
  __toascii=msvcrt.__toascii @554
  __unDName=msvcrt.__unDName @555
  __wargv=msvcrt.__wargv @556 DATA
  __wgetmainargs=msvcrt.__wgetmainargs @557
  __winitenv=msvcrt.__winitenv @558 DATA
  _abnormal_termination=msvcrt._abnormal_termination @559
  _access=msvcrt._access @560
  _acmdln=msvcrt._acmdln @561 DATA
  _adj_fdiv_m16i=msvcrt._adj_fdiv_m16i @562
  _adj_fdiv_m32=msvcrt._adj_fdiv_m32 @563
  _adj_fdiv_m32i=msvcrt._adj_fdiv_m32i @564
  _adj_fdiv_m64=msvcrt._adj_fdiv_m64 @565
  _adj_fdiv_r=msvcrt._adj_fdiv_r @566
  _adj_fdivr_m16i=msvcrt._adj_fdivr_m16i @567
  _adj_fdivr_m32=msvcrt._adj_fdivr_m32 @568
  _adj_fdivr_m32i=msvcrt._adj_fdivr_m32i @569
  _adj_fdivr_m64=msvcrt._adj_fdivr_m64 @570
  _adj_fpatan=msvcrt._adj_fpatan @571
  _adj_fprem=msvcrt._adj_fprem @572
  _adj_fprem1=msvcrt._adj_fprem1 @573
  _adj_fptan=msvcrt._adj_fptan @574
  _adjust_fdiv=msvcrt._adjust_fdiv @575
  _aexit_rtn=msvcrt._aexit_rtn @576 DATA
  _amsg_exit=msvcrt._amsg_exit @577
  _assert=msvcrt._assert @578
  _atodbl=msvcrt._atodbl @579
  _atoldbl=msvcrt._atoldbl @580
  _beep=msvcrt._beep @581
  _beginthread=msvcrt._beginthread @582
  _beginthreadex=msvcrt._beginthreadex @583
  _c_exit=msvcrt._c_exit @584
  _cabs=msvcrt._cabs @585
  _cexit=msvcrt._cexit @586
  _cgets=msvcrt._cgets @587
  _chdir=msvcrt._chdir @588
  _chdrive=msvcrt._chdrive @589
  _chgsign=msvcrt._chgsign @590
  _chmod=msvcrt._chmod @591
  _chsize=msvcrt._chsize @592
  _clearfp=msvcrt._clearfp @593
  _close=msvcrt._close @594
  _commit=msvcrt._commit @595
  _commode=msvcrt._commode @596 DATA
  _control87=msvcrt._control87 @597
  _controlfp=msvcrt._controlfp @598
  _copysign=msvcrt._copysign @599
  _cprintf=msvcrt._cprintf @600
  _cputs=msvcrt._cputs @601
  _creat=msvcrt._creat @602
  _cscanf=msvcrt._cscanf @603
  _ctype=msvcrt._ctype @604 DATA
  _cwait=msvcrt._cwait @605
  _daylight=msvcrt._daylight @606 DATA
  _dstbias=msvcrt._dstbias @607 DATA
  _dup=msvcrt._dup @608
  _dup2=msvcrt._dup2 @609
  _ecvt=msvcrt._ecvt @610
  _endthread=msvcrt._endthread @611
  _endthreadex=msvcrt._endthreadex @612
  _environ=msvcrt._environ @613 DATA
  _eof=msvcrt._eof @614
  _errno=msvcrt._errno @615
  _except_handler2=msvcrt._except_handler2 @616
  _except_handler3=msvcrt._except_handler3 @617
  _execl=msvcrt._execl @618
  _execle=msvcrt._execle @619
  _execlp=msvcrt._execlp @620
  _execlpe=msvcrt._execlpe @621
  _execv=msvcrt._execv @622
  _execve=msvcrt._execve @623
  _execvp=msvcrt._execvp @624
  _execvpe=msvcrt._execvpe @625
  _exit=msvcrt._exit @626
  _expand=msvcrt._expand @627
  _fcloseall=msvcrt._fcloseall @628
  _fcvt=msvcrt._fcvt @629
  _fdopen=msvcrt._fdopen @630
  _fgetchar=msvcrt._fgetchar @631
  _fgetwchar=msvcrt._fgetwchar @632
  _filbuf=msvcrt._filbuf @633
  _fileinfo=msvcrt._fileinfo @634 DATA
  _filelength=msvcrt._filelength @635
  _filelengthi64=msvcrt._filelengthi64 @636
  _fileno=msvcrt._fileno @637
  _findclose=msvcrt._findclose @638
  _findfirst=msvcrt._findfirst @639
  _findfirsti64=msvcrt._findfirsti64 @640
  _findnext=msvcrt._findnext @641
  _findnexti64=msvcrt._findnexti64 @642
  _finite=msvcrt._finite @643
  _flsbuf=msvcrt._flsbuf @644
  _flushall=msvcrt._flushall @645
  _fmode=msvcrt._fmode @646 DATA
  _fpclass=msvcrt._fpclass @647
  _fpieee_flt=msvcrt._fpieee_flt @648
  _fpreset=msvcrt._fpreset @649
  _fputchar=msvcrt._fputchar @650
  _fputwchar=msvcrt._fputwchar @651
  _fsopen=msvcrt._fsopen @652
  _fstat=msvcrt._fstat @653
  _fstati64=msvcrt._fstati64 @654
  _ftime=msvcrt._ftime @655
  _ftol=msvcrt._ftol @656
  _fullpath=msvcrt._fullpath @657
  _futime=msvcrt._futime @658
  _gcvt=msvcrt._gcvt @659
  _get_osfhandle=msvcrt._get_osfhandle @660
  _getch=msvcrt._getch @661
  _getche=msvcrt._getche @662
  _getcwd=msvcrt._getcwd @663
  _getdcwd=msvcrt._getdcwd @664
  _getdiskfree=msvcrt._getdiskfree @665
  _getdllprocaddr=msvcrt._getdllprocaddr @666
  _getdrive=msvcrt._getdrive @667
  _getdrives=msvcrt._getdrives @668
  _getmaxstdio=msvcrt._getmaxstdio @669
  _getmbcp=msvcrt._getmbcp @670
  _getpid=msvcrt._getpid @671
  _getsystime=msvcrt._getsystime @672
  _getw=msvcrt._getw @673
  _getws=msvcrt._getws @674
  _global_unwind2=msvcrt._global_unwind2 @675
  _heapadd=msvcrt._heapadd @676
  _heapchk=msvcrt._heapchk @677
  _heapmin=msvcrt._heapmin @678
  _heapset=msvcrt._heapset @679
  _heapused=msvcrt._heapused @680
  _heapwalk=msvcrt._heapwalk @681
  _hypot=msvcrt._hypot @682
  _initterm=msvcrt._initterm @683
  _inp=msvcrt._inp @684
  _inpd=msvcrt._inpd @685
  _inpw=msvcrt._inpw @686
  _iob=msvcrt._iob @687 DATA
  _isatty=msvcrt._isatty @688
  _isctype=msvcrt._isctype @689
  _ismbbalnum=msvcrt._ismbbalnum @690
  _ismbbalpha=msvcrt._ismbbalpha @691
  _ismbbgraph=msvcrt._ismbbgraph @692
  _ismbbkalnum=msvcrt._ismbbkalnum @693
  _ismbbkana=msvcrt._ismbbkana @694
  _ismbbkprint=msvcrt._ismbbkprint @695
  _ismbbkpunct=msvcrt._ismbbkpunct @696
  _ismbblead=msvcrt._ismbblead @697
  _ismbbprint=msvcrt._ismbbprint @698
  _ismbbpunct=msvcrt._ismbbpunct @699
  _ismbbtrail=msvcrt._ismbbtrail @700
  _ismbcalnum=msvcrt._ismbcalnum @701
  _ismbcalpha=msvcrt._ismbcalpha @702
  _ismbcdigit=msvcrt._ismbcdigit @703
  _ismbcgraph=msvcrt._ismbcgraph @704
  _ismbchira=msvcrt._ismbchira @705
  _ismbckata=msvcrt._ismbckata @706
  _ismbcl0=msvcrt._ismbcl0 @707
  _ismbcl1=msvcrt._ismbcl1 @708
  _ismbcl2=msvcrt._ismbcl2 @709
  _ismbclegal=msvcrt._ismbclegal @710
  _ismbclower=msvcrt._ismbclower @711
  _ismbcprint=msvcrt._ismbcprint @712
  _ismbcpunct=msvcrt._ismbcpunct @713
  _ismbcspace=msvcrt._ismbcspace @714
  _ismbcsymbol=msvcrt._ismbcsymbol @715
  _ismbcupper=msvcrt._ismbcupper @716
  _ismbslead=msvcrt._ismbslead @717
  _ismbstrail=msvcrt._ismbstrail @718
  _isnan=msvcrt._isnan @719
  _itoa=msvcrt._itoa @720
  _itow=msvcrt._itow @721
  _j0=msvcrt._j0 @722
  _j1=msvcrt._j1 @723
  _jn=msvcrt._jn @724
  _kbhit=msvcrt._kbhit @725
  _lfind=msvcrt._lfind @726
  _loaddll=msvcrt._loaddll @727
  _local_unwind2=msvcrt._local_unwind2 @728
  _locking=msvcrt._locking @729
  _logb=msvcrt._logb @730
  _longjmpex=msvcrt._longjmpex @731
  _lrotl=msvcrt._lrotl @732
  _lrotr=msvcrt._lrotr @733
  _lsearch=msvcrt._lsearch @734
  _lseek=msvcrt._lseek @735
  _lseeki64=msvcrt._lseeki64 @736
  _ltoa=msvcrt._ltoa @737
  _ltow=msvcrt._ltow @738
  _makepath=msvcrt._makepath @739
  _mbbtombc=msvcrt._mbbtombc @740
  _mbbtype=msvcrt._mbbtype @741
  _mbccpy=msvcrt._mbccpy @742
  _mbcjistojms=msvcrt._mbcjistojms @743
  _mbcjmstojis=msvcrt._mbcjmstojis @744
  _mbclen=msvcrt._mbclen @745
  _mbctohira=msvcrt._mbctohira @746
  _mbctokata=msvcrt._mbctokata @747
  _mbctolower=msvcrt._mbctolower @748
  _mbctombb=msvcrt._mbctombb @749
  _mbctoupper=msvcrt._mbctoupper @750
  _mbctype=msvcrt._mbctype @751 DATA
  _mbsbtype=msvcrt._mbsbtype @752
  _mbscat=msvcrt._mbscat @753
  _mbschr=msvcrt._mbschr @754
  _mbscmp=msvcrt._mbscmp @755
  _mbscoll=msvcrt._mbscoll @756
  _mbscpy=msvcrt._mbscpy @757
  _mbscspn=msvcrt._mbscspn @758
  _mbsdec=msvcrt._mbsdec @759
  _mbsdup=msvcrt._mbsdup @760
  _mbsicmp=msvcrt._mbsicmp @761
  _mbsicoll=msvcrt._mbsicoll @762
  _mbsinc=msvcrt._mbsinc @763
  _mbslen=msvcrt._mbslen @764
  _mbslwr=msvcrt._mbslwr @765
  _mbsnbcat=msvcrt._mbsnbcat @766
  _mbsnbcmp=msvcrt._mbsnbcmp @767
  _mbsnbcnt=msvcrt._mbsnbcnt @768
  _mbsnbcoll=msvcrt._mbsnbcoll @769
  _mbsnbcpy=msvcrt._mbsnbcpy @770
  _mbsnbicmp=msvcrt._mbsnbicmp @771
  _mbsnbicoll=msvcrt._mbsnbicoll @772
  _mbsnbset=msvcrt._mbsnbset @773
  _mbsncat=msvcrt._mbsncat @774
  _mbsnccnt=msvcrt._mbsnccnt @775
  _mbsncmp=msvcrt._mbsncmp @776
  _mbsncoll=msvcrt._mbsncoll @777
  _mbsncpy=msvcrt._mbsncpy @778
  _mbsnextc=msvcrt._mbsnextc @779
  _mbsnicmp=msvcrt._mbsnicmp @780
  _mbsnicoll=msvcrt._mbsnicoll @781
  _mbsninc=msvcrt._mbsninc @782
  _mbsnset=msvcrt._mbsnset @783
  _mbspbrk=msvcrt._mbspbrk @784
  _mbsrchr=msvcrt._mbsrchr @785
  _mbsrev=msvcrt._mbsrev @786
  _mbsset=msvcrt._mbsset @787
  _mbsspn=msvcrt._mbsspn @788
  _mbsspnp=msvcrt._mbsspnp @789
  _mbsstr=msvcrt._mbsstr @790
  _mbstok=msvcrt._mbstok @791
  _mbstrlen=msvcrt._mbstrlen @792
  _mbsupr=msvcrt._mbsupr @793
  _memccpy=msvcrt._memccpy @794
  _memicmp=msvcrt._memicmp @795
  _mkdir=msvcrt._mkdir @796
  _mktemp=msvcrt._mktemp @797
  _msize=msvcrt._msize @798
  _nextafter=msvcrt._nextafter @801
  _onexit=msvcrt._onexit @802
  _open=msvcrt._open @803
  _open_osfhandle=msvcrt._open_osfhandle @804
  _osver=msvcrt._osver @805 DATA
  _outp=msvcrt._outp @806
  _outpd=msvcrt._outpd @807
  _outpw=msvcrt._outpw @808
  _pclose=msvcrt._pclose @809
  _pctype=msvcrt._pctype @810 DATA
  _pgmptr=msvcrt._pgmptr @811 DATA
  _pipe=msvcrt._pipe @812
  _popen=msvcrt._popen @813
  _purecall=msvcrt._purecall @814
  _putch=msvcrt._putch @815
  _putenv=msvcrt._putenv @816
  _putw=msvcrt._putw @817
  _putws=msvcrt._putws @818
  _pwctype=msvcrt._pwctype @819 DATA
  _read=msvcrt._read @820
  _rmdir=msvcrt._rmdir @821
  _rmtmp=msvcrt._rmtmp @822
  _rotl=msvcrt._rotl @823
  _rotr=msvcrt._rotr @824
  _safe_fdiv=msvcrt._safe_fdiv @825
  _safe_fdivr=msvcrt._safe_fdivr @826
  _safe_fprem=msvcrt._safe_fprem @827
  _safe_fprem1=msvcrt._safe_fprem1 @828
  _scalb=msvcrt._scalb @829
  _searchenv=msvcrt._searchenv @830
  _seh_longjmp_unwind@4=msvcrt._seh_longjmp_unwind @831
  _set_error_mode=msvcrt._set_error_mode @832
  _seterrormode=msvcrt._seterrormode @833
  _setjmp=msvcrt._setjmp @834
  _setjmp3=msvcrt._setjmp3 @835
  _setmaxstdio=msvcrt._setmaxstdio @836
  _setmbcp=msvcrt._setmbcp @837
  _setmode=msvcrt._setmode @838
  _setsystime=msvcrt._setsystime @839
  _sleep=msvcrt._sleep @840
  _snprintf=msvcrt._snprintf @841
  _snwprintf=msvcrt._snwprintf @842
  _sopen=msvcrt._sopen @843
  _spawnl=msvcrt._spawnl @844
  _spawnle=msvcrt._spawnle @845
  _spawnlp=msvcrt._spawnlp @846
  _spawnlpe=msvcrt._spawnlpe @847
  _spawnv=msvcrt._spawnv @848
  _spawnve=msvcrt._spawnve @849
  _spawnvp=msvcrt._spawnvp @850
  _spawnvpe=msvcrt._spawnvpe @851
  _splitpath=msvcrt._splitpath @852
  _stat=msvcrt._stat @853
  _stati64=msvcrt._stati64 @854
  _statusfp=msvcrt._statusfp @855
  _strcmpi=msvcrt._strcmpi @856
  _strdate=msvcrt._strdate @857
  _strdup=msvcrt._strdup @858
  _strerror=msvcrt._strerror @859
  _stricmp=msvcrt._stricmp @860
  _stricoll=msvcrt._stricoll @861
  _strlwr=msvcrt._strlwr @862
  _strncoll=msvcrt._strncoll @863
  _strnicmp=msvcrt._strnicmp @864
  _strnicoll=msvcrt._strnicoll @865
  _strnset=msvcrt._strnset @866
  _strrev=msvcrt._strrev @867
  _strset=msvcrt._strset @868
  _strtime=msvcrt._strtime @869
  _strupr=msvcrt._strupr @870
  _swab=msvcrt._swab @871
  _sys_errlist=msvcrt._sys_errlist @872 DATA
  _sys_nerr=msvcrt._sys_nerr @873 DATA
  _tell=msvcrt._tell @874
  _telli64=msvcrt._telli64 @875
  _tempnam=msvcrt._tempnam @876
  _timezone=msvcrt._timezone @877 DATA
  _tolower=msvcrt._tolower @878
  _toupper=msvcrt._toupper @879
  _tzname=msvcrt._tzname @880 DATA
  _tzset=msvcrt._tzset @881
  _ultoa=msvcrt._ultoa @882
  _ultow=msvcrt._ultow @883
  _umask=msvcrt._umask @884
  _ungetch=msvcrt._ungetch @885
  _unlink=msvcrt._unlink @886
  _unloaddll=msvcrt._unloaddll @887
  _utime=msvcrt._utime @888
  _vsnprintf=msvcrt._vsnprintf @889
  _vsnwprintf=msvcrt._vsnwprintf @890
  _waccess=msvcrt._waccess @891
  _wasctime=msvcrt._wasctime @892
  _wchdir=msvcrt._wchdir @893
  _wchmod=msvcrt._wchmod @894
  _wcmdln=msvcrt._wcmdln @895 DATA
  _wcreat=msvcrt._wcreat @896
  _wcsdup=msvcrt._wcsdup @897
  _wcsicmp=msvcrt._wcsicmp @898
  _wcsicoll=msvcrt._wcsicoll @899
  _wcslwr=msvcrt._wcslwr @900
  _wcsncoll=msvcrt._wcsncoll @901
  _wcsnicmp=msvcrt._wcsnicmp @902
  _wcsnicoll=msvcrt._wcsnicoll @903
  _wcsnset=msvcrt._wcsnset @904
  _wcsrev=msvcrt._wcsrev @905
  _wcsset=msvcrt._wcsset @906
  _wcsupr=msvcrt._wcsupr @907
  _wctime=msvcrt._wctime @908
  _wenviron=msvcrt._wenviron @909 DATA
  _wexecl=msvcrt._wexecl @910
  _wexecle=msvcrt._wexecle @911
  _wexeclp=msvcrt._wexeclp @912
  _wexeclpe=msvcrt._wexeclpe @913
  _wexecv=msvcrt._wexecv @914
  _wexecve=msvcrt._wexecve @915
  _wexecvp=msvcrt._wexecvp @916
  _wexecvpe=msvcrt._wexecvpe @917
  _wfdopen=msvcrt._wfdopen @918
  _wfindfirst=msvcrt._wfindfirst @919
  _wfindfirsti64=msvcrt._wfindfirsti64 @920
  _wfindnext=msvcrt._wfindnext @921
  _wfindnexti64=msvcrt._wfindnexti64 @922
  _wfopen=msvcrt._wfopen @923
  _wfreopen=msvcrt._wfreopen @924
  _wfsopen=msvcrt._wfsopen @925
  _wfullpath=msvcrt._wfullpath @926
  _wgetcwd=msvcrt._wgetcwd @927
  _wgetdcwd=msvcrt._wgetdcwd @928
  _wgetenv=msvcrt._wgetenv @929
  _winmajor=msvcrt._winmajor @930 DATA
  _winminor=msvcrt._winminor @931 DATA
  _winver=msvcrt._winver @932 DATA
  _wmakepath=msvcrt._wmakepath @933
  _wmkdir=msvcrt._wmkdir @934
  _wmktemp=msvcrt._wmktemp @935
  _wopen=msvcrt._wopen @936
  _wperror=msvcrt._wperror @937
  _wpgmptr=msvcrt._wpgmptr @938 DATA
  _wpopen=msvcrt._wpopen @939
  _wputenv=msvcrt._wputenv @940
  _wremove=msvcrt._wremove @941
  _wrename=msvcrt._wrename @942
  _write=msvcrt._write @943
  _wrmdir=msvcrt._wrmdir @944
  _wsearchenv=msvcrt._wsearchenv @945
  _wsetlocale=msvcrt._wsetlocale @946
  _wsopen=msvcrt._wsopen @947
  _wspawnl=msvcrt._wspawnl @948
  _wspawnle=msvcrt._wspawnle @949
  _wspawnlp=msvcrt._wspawnlp @950
  _wspawnlpe=msvcrt._wspawnlpe @951
  _wspawnv=msvcrt._wspawnv @952
  _wspawnve=msvcrt._wspawnve @953
  _wspawnvp=msvcrt._wspawnvp @954
  _wspawnvpe=msvcrt._wspawnvpe @955
  _wsplitpath=msvcrt._wsplitpath @956
  _wstat=msvcrt._wstat @957
  _wstati64=msvcrt._wstati64 @958
  _wstrdate=msvcrt._wstrdate @959
  _wstrtime=msvcrt._wstrtime @960
  _wsystem=msvcrt._wsystem @961
  _wtempnam=msvcrt._wtempnam @962
  _wtmpnam=msvcrt._wtmpnam @963
  _wtoi=msvcrt._wtoi @964
  _wtol=msvcrt._wtol @965
  _wunlink=msvcrt._wunlink @966
  _wutime=msvcrt._wutime @967
  _y0=msvcrt._y0 @968
  _y1=msvcrt._y1 @969
  _yn=msvcrt._yn @970
  abort=msvcrt.abort @971
  abs=msvcrt.abs @972
  acos=msvcrt.acos @973
  asctime=msvcrt.asctime @974
  asin=msvcrt.asin @975
  atan=msvcrt.atan @976
  atan2=msvcrt.atan2 @977
  atexit=msvcrt.atexit @978
  atof=msvcrt.atof @979
  atoi=msvcrt.atoi @980
  atol=msvcrt.atol @981
  bsearch=msvcrt.bsearch @982
  calloc=msvcrt.calloc @983
  ceil=msvcrt.ceil @984
  clearerr=msvcrt.clearerr @985
  clock=msvcrt.clock @986
  cos=msvcrt.cos @987
  cosh=msvcrt.cosh @988
  ctime=msvcrt.ctime @989
  difftime=msvcrt.difftime @990
  div=msvcrt.div @991
  exit=msvcrt.exit @992
  exp=msvcrt.exp @993
  fabs=msvcrt.fabs @994
  fclose=msvcrt.fclose @995
  feof=msvcrt.feof @996
  ferror=msvcrt.ferror @997
  fflush=msvcrt.fflush @998
  fgetc=msvcrt.fgetc @999
  fgetpos=msvcrt.fgetpos @1000
  fgets=msvcrt.fgets @1001
  fgetwc=msvcrt.fgetwc @1002
  fgetws=msvcrt.fgetws @1003
  floor=msvcrt.floor @1004
  fmod=msvcrt.fmod @1005
  fopen=msvcrt.fopen @1006
  fprintf=msvcrt.fprintf @1007
  fputc=msvcrt.fputc @1008
  fputs=msvcrt.fputs @1009
  fputwc=msvcrt.fputwc @1010
  fputws=msvcrt.fputws @1011
  fread=msvcrt.fread @1012
  free=msvcrt.free @1013
  freopen=msvcrt.freopen @1014
  frexp=msvcrt.frexp @1015
  fscanf=msvcrt.fscanf @1016
  fseek=msvcrt.fseek @1017
  fsetpos=msvcrt.fsetpos @1018
  ftell=msvcrt.ftell @1019
  fwprintf=msvcrt.fwprintf @1020
  fwrite=msvcrt.fwrite @1021
  fwscanf=msvcrt.fwscanf @1022
  getc=msvcrt.getc @1023
  getchar=msvcrt.getchar @1024
  getenv=msvcrt.getenv @1025
  gets=msvcrt.gets @1026
  getwc=msvcrt.getwc @1027
  getwchar=msvcrt.getwchar @1028
  gmtime=msvcrt.gmtime @1029
  is_wctype=msvcrt.is_wctype @1030
  isalnum=msvcrt.isalnum @1031
  isalpha=msvcrt.isalpha @1032
  iscntrl=msvcrt.iscntrl @1033
  isdigit=msvcrt.isdigit @1034
  isgraph=msvcrt.isgraph @1035
  isleadbyte=msvcrt.isleadbyte @1036
  islower=msvcrt.islower @1037
  isprint=msvcrt.isprint @1038
  ispunct=msvcrt.ispunct @1039
  isspace=msvcrt.isspace @1040
  isupper=msvcrt.isupper @1041
  iswalnum=msvcrt.iswalnum @1042
  iswalpha=msvcrt.iswalpha @1043
  iswascii=msvcrt.iswascii @1044
  iswcntrl=msvcrt.iswcntrl @1045
  iswctype=msvcrt.iswctype @1046
  iswdigit=msvcrt.iswdigit @1047
  iswgraph=msvcrt.iswgraph @1048
  iswlower=msvcrt.iswlower @1049
  iswprint=msvcrt.iswprint @1050
  iswpunct=msvcrt.iswpunct @1051
  iswspace=msvcrt.iswspace @1052
  iswupper=msvcrt.iswupper @1053
  iswxdigit=msvcrt.iswxdigit @1054
  isxdigit=msvcrt.isxdigit @1055
  labs=msvcrt.labs @1056
  ldexp=msvcrt.ldexp @1057
  ldiv=msvcrt.ldiv @1058
  localeconv=msvcrt.localeconv @1059
  localtime=msvcrt.localtime @1060
  log=msvcrt.log @1061
  log10=msvcrt.log10 @1062
  longjmp=msvcrt.longjmp @1063
  malloc=msvcrt.malloc @1064
  mblen=msvcrt.mblen @1065
  mbstowcs=msvcrt.mbstowcs @1066
  mbtowc=msvcrt.mbtowc @1067
  memchr=msvcrt.memchr @1068
  memcmp=msvcrt.memcmp @1069
  memcpy=msvcrt.memcpy @1070
  memmove=msvcrt.memmove @1071
  memset=msvcrt.memset @1072
  mktime=msvcrt.mktime @1073
  modf=msvcrt.modf @1074
  perror=msvcrt.perror @1075
  pow=msvcrt.pow @1076
  printf=msvcrt.printf @1077
  putc=msvcrt.putc @1078
  putchar=msvcrt.putchar @1079
  puts=msvcrt.puts @1080
  putwc=msvcrt.putwc @1081
  putwchar=msvcrt.putwchar @1082
  qsort=msvcrt.qsort @1083
  raise=msvcrt.raise @1084
  rand=msvcrt.rand @1085
  realloc=msvcrt.realloc @1086
  remove=msvcrt.remove @1087
  rename=msvcrt.rename @1088
  rewind=msvcrt.rewind @1089
  scanf=msvcrt.scanf @1090
  setbuf=msvcrt.setbuf @1091
  setlocale=msvcrt.setlocale @1092
  setvbuf=msvcrt.setvbuf @1093
  signal=msvcrt.signal @1094
  sin=msvcrt.sin @1095
  sinh=msvcrt.sinh @1096
  sprintf=msvcrt.sprintf @1097
  sqrt=msvcrt.sqrt @1098
  srand=msvcrt.srand @1099
  sscanf=msvcrt.sscanf @1100
  strcat=msvcrt.strcat @1101
  strchr=msvcrt.strchr @1102
  strcmp=msvcrt.strcmp @1103
  strcoll=msvcrt.strcoll @1104
  strcpy=msvcrt.strcpy @1105
  strcspn=msvcrt.strcspn @1106
  strerror=msvcrt.strerror @1107
  strftime=msvcrt.strftime @1108
  strlen=msvcrt.strlen @1109
  strncat=msvcrt.strncat @1110
  strncmp=msvcrt.strncmp @1111
  strncpy=msvcrt.strncpy @1112
  strpbrk=msvcrt.strpbrk @1113
  strrchr=msvcrt.strrchr @1114
  strspn=msvcrt.strspn @1115
  strstr=msvcrt.strstr @1116
  strtod=msvcrt.strtod @1117
  strtok=msvcrt.strtok @1118
  strtol=msvcrt.strtol @1119
  strtoul=msvcrt.strtoul @1120
  strxfrm=msvcrt.strxfrm @1121
  swprintf=msvcrt.swprintf @1122
  swscanf=msvcrt.swscanf @1123
  system=msvcrt.system @1124
  tan=msvcrt.tan @1125
  tanh=msvcrt.tanh @1126
  time=msvcrt.time @1127
  tmpfile=msvcrt.tmpfile @1128
  tmpnam=msvcrt.tmpnam @1129
  tolower=msvcrt.tolower @1130
  toupper=msvcrt.toupper @1131
  towlower=msvcrt.towlower @1132
  towupper=msvcrt.towupper @1133
  ungetc=msvcrt.ungetc @1134
  ungetwc=msvcrt.ungetwc @1135
  vfprintf=msvcrt.vfprintf @1136
  vfwprintf=msvcrt.vfwprintf @1137
  vprintf=msvcrt.vprintf @1138
  vsprintf=msvcrt.vsprintf @1139
  vswprintf=msvcrt.vswprintf @1140
  vwprintf=msvcrt.vwprintf @1141
  wcscat=msvcrt.wcscat @1142
  wcschr=msvcrt.wcschr @1143
  wcscmp=msvcrt.wcscmp @1144
  wcscoll=msvcrt.wcscoll @1145
  wcscpy=msvcrt.wcscpy @1146
  wcscspn=msvcrt.wcscspn @1147
  wcsftime=msvcrt.wcsftime @1148
  wcslen=msvcrt.wcslen @1149
  wcsncat=msvcrt.wcsncat @1150
  wcsncmp=msvcrt.wcsncmp @1151
  wcsncpy=msvcrt.wcsncpy @1152
  wcspbrk=msvcrt.wcspbrk @1153
  wcsrchr=msvcrt.wcsrchr @1154
  wcsspn=msvcrt.wcsspn @1155
  wcsstr=msvcrt.wcsstr @1156
  wcstod=msvcrt.wcstod @1157
  wcstok=msvcrt.wcstok @1158
  wcstol=msvcrt.wcstol @1159
  wcstombs=msvcrt.wcstombs @1160
  wcstoul=msvcrt.wcstoul @1161
  wcsxfrm=msvcrt.wcsxfrm @1162
  wctomb=msvcrt.wctomb @1163
  wprintf=msvcrt.wprintf @1164
  wscanf=msvcrt.wscanf @1165
