; File generated automatically from dplayx/dplayx.spec; do not edit!

LIBRARY dplayx.dll

EXPORTS
  DirectPlayCreate@12 @1
  DirectPlayEnumerateA@8 @2
  DirectPlayEnumerateW@8 @3
  DirectPlayLobbyCreateA@20 @4
  DirectPlayLobbyCreateW@20 @5
  gdwDPlaySPRefCount @6 DATA
  DirectPlayEnumerate@8=DirectPlayEnumerateA@8 @9
  DllCanUnloadNow@0=DPLAYX_DllCanUnloadNow@0 @10 PRIVATE
  DllGetClassObject@12=DPLAYX_DllGetClassObject@12 @11 PRIVATE
  DllRegisterServer@0=DPLAYX_DllRegisterServer@0 @7 PRIVATE
  DllUnregisterServer@0=DPLAYX_DllUnregisterServer@0 @8 PRIVATE
