; File generated automatically from oleaut32/oleaut32.spec; do not edit!

LIBRARY oleaut32.dll

EXPORTS
  DllGetClassObject@12=OLEAUT32_DllGetClassObject@12 @1 PRIVATE
  SysAllocString@4 @2
  SysReAllocString@8 @3
  SysAllocStringLen@8 @4
  SysReAllocStringLen@12 @5
  SysFreeString@4 @6
  SysStringLen@4 @7
  VariantInit@4 @8
  VariantClear@4 @9
  VariantCopy@8 @10
  VariantCopyInd@8 @11
  VariantChangeType@16 @12
  VariantTimeToDosDateTime@16 @13
  DosDateTimeToVariantTime@12 @14
  SafeArrayCreate@12 @15
  SafeArrayDestroy@4 @16
  SafeArrayGetDim@4 @17
  SafeArrayGetElemsize@4 @18
  SafeArrayGetUBound@12 @19
  SafeArrayGetLBound@12 @20
  SafeArrayLock@4 @21
  SafeArrayUnlock@4 @22
  SafeArrayAccessData@8 @23
  SafeArrayUnaccessData@4 @24
  SafeArrayGetElement@12 @25
  SafeArrayPutElement@12 @26
  SafeArrayCopy@8 @27
  DispGetParam@20 @28
  DispGetIDsOfNames@16 @29
  DispInvoke@32 @30
  CreateDispTypeInfo@12 @31
  CreateStdDispatch@16 @32
  RegisterActiveObject@16 @33
  RevokeActiveObject@8 @34
  GetActiveObject@12 @35
  SafeArrayAllocDescriptor@8 @36
  SafeArrayAllocData@4 @37
  SafeArrayDestroyDescriptor@4 @38
  SafeArrayDestroyData@4 @39
  SafeArrayRedim@8 @40
  SafeArrayAllocDescriptorEx@12 @41
  SafeArrayCreateEx@16 @42
  SafeArrayCreateVectorEx@16 @43
  SafeArraySetRecordInfo@8 @44
  SafeArrayGetRecordInfo@8 @45
  VarParseNumFromStr@20 @46
  VarNumFromParseNum@16 @47
  VarI2FromUI1@8 @48
  VarI2FromI4@8 @49
  VarI2FromR4@8 @50
  VarI2FromR8@12 @51
  VarI2FromCy@12 @52
  VarI2FromDate@12 @53
  VarI2FromStr@16 @54
  VarI2FromDisp@12 @55
  VarI2FromBool@8 @56
  SafeArraySetIID@8 @57
  VarI4FromUI1@8 @58
  VarI4FromI2@8 @59
  VarI4FromR4@8 @60
  VarI4FromR8@12 @61
  VarI4FromCy@12 @62
  VarI4FromDate@12 @63
  VarI4FromStr@16 @64
  VarI4FromDisp@12 @65
  VarI4FromBool@8 @66
  SafeArrayGetIID@8 @67
  VarR4FromUI1@8 @68
  VarR4FromI2@8 @69
  VarR4FromI4@8 @70
  VarR4FromR8@12 @71
  VarR4FromCy@12 @72
  VarR4FromDate@12 @73
  VarR4FromStr@16 @74
  VarR4FromDisp@12 @75
  VarR4FromBool@8 @76
  SafeArrayGetVartype@8 @77
  VarR8FromUI1@8 @78
  VarR8FromI2@8 @79
  VarR8FromI4@8 @80
  VarR8FromR4@8 @81
  VarR8FromCy@12 @82
  VarR8FromDate@12 @83
  VarR8FromStr@16 @84
  VarR8FromDisp@12 @85
  VarR8FromBool@8 @86
  VarFormat@24 @87
  VarDateFromUI1@8 @88
  VarDateFromI2@8 @89
  VarDateFromI4@8 @90
  VarDateFromR4@8 @91
  VarDateFromR8@12 @92
  VarDateFromCy@12 @93
  VarDateFromStr@16 @94
  VarDateFromDisp@12 @95
  VarDateFromBool@8 @96
  VarFormatDateTime@16 @97
  VarCyFromUI1@8 @98
  VarCyFromI2@8 @99
  VarCyFromI4@8 @100
  VarCyFromR4@8 @101
  VarCyFromR8@12 @102
  VarCyFromDate@12 @103
  VarCyFromStr@16 @104
  VarCyFromDisp@12 @105
  VarCyFromBool@8 @106
  VarFormatNumber@28 @107
  VarBstrFromUI1@16 @108
  VarBstrFromI2@16 @109
  VarBstrFromI4@16 @110
  VarBstrFromR4@16 @111
  VarBstrFromR8@20 @112
  VarBstrFromCy@20 @113
  VarBstrFromDate@20 @114
  VarBstrFromBool@16 @116
  VarFormatPercent@28 @117
  VarBoolFromUI1@8 @118
  VarBoolFromI2@8 @119
  VarBoolFromI4@8 @120
  VarBoolFromR4@8 @121
  VarBoolFromR8@12 @122
  VarBoolFromDate@12 @123
  VarBoolFromCy@12 @124
  VarBoolFromStr@16 @125
  VarBoolFromDisp@12 @126
  VarFormatCurrency@28 @127
  VarUI1FromI2@8 @130
  VarUI1FromI4@8 @131
  VarUI1FromR4@8 @132
  VarUI1FromR8@12 @133
  VarUI1FromCy@12 @134
  VarUI1FromDate@12 @135
  VarUI1FromStr@16 @136
  VarUI1FromDisp@12 @137
  VarUI1FromBool@8 @138
  VarFormatFromTokens@24 @139
  VarTokenizeFormatString@28 @140
  VarAdd@12 @141
  VarAnd@12 @142
  VarDiv@12 @143
  DispCallFunc@32 @146
  VariantChangeTypeEx@20 @147
  SafeArrayPtrOfIndex@12 @148
  SysStringByteLen@4 @149
  SysAllocStringByteLen@8 @150
  VarEqv@12 @152
  VarMod@12 @155
  VarMul@12 @156
  VarOr@12 @157
  VarPow@12 @158
  VarSub@12 @159
  CreateTypeLib@12 @160
  LoadTypeLib@8 @161
  LoadRegTypeLib@20 @162
  RegisterTypeLib@12 @163
  QueryPathOfRegTypeLib@20 @164
  LHashValOfNameSys@12 @165
  LHashValOfNameSysA@12 @166
  VarXor@12 @167
  VarAbs@8 @168
  VarFix@8 @169
  OaBuildVersion@0 @170
  ClearCustData@4 @171
  VarInt@8 @172
  VarNeg@8 @173
  VarNot@8 @174
  VarRound@12 @175
  VarCmp@16 @176
  VarDecAdd@12 @177
  VarDecDiv@12 @178
  VarDecMul@12 @179
  CreateTypeLib2@12 @180
  VarDecSub@12 @181
  VarDecAbs@8 @182
  LoadTypeLibEx@12 @183
  SystemTimeToVariantTime@8 @184
  VariantTimeToSystemTime@12 @185
  UnRegisterTypeLib@20 @186
  VarDecFix@8 @187
  VarDecInt@8 @188
  VarDecNeg@8 @189
  VarDecFromUI1@8 @190
  VarDecFromI2@8 @191
  VarDecFromI4@8 @192
  VarDecFromR4@8 @193
  VarDecFromR8@12 @194
  VarDecFromDate@12 @195
  VarDecFromCy@12 @196
  VarDecFromStr@16 @197
  VarDecFromDisp@12 @198
  VarDecFromBool@8 @199
  GetErrorInfo@8=ole32.GetErrorInfo @200
  SetErrorInfo@8=ole32.SetErrorInfo @201
  CreateErrorInfo@4=ole32.CreateErrorInfo @202
  VarDecRound@12 @203
  VarDecCmp@8 @204
  VarI2FromI1@8 @205
  VarI2FromUI2@8 @206
  VarI2FromUI4@8 @207
  VarI2FromDec@8 @208
  VarI4FromI1@8 @209
  VarI4FromUI2@8 @210
  VarI4FromUI4@8 @211
  VarI4FromDec@8 @212
  VarR4FromI1@8 @213
  VarR4FromUI2@8 @214
  VarR4FromUI4@8 @215
  VarR4FromDec@8 @216
  VarR8FromI1@8 @217
  VarR8FromUI2@8 @218
  VarR8FromUI4@8 @219
  VarR8FromDec@8 @220
  VarDateFromI1@8 @221
  VarDateFromUI2@8 @222
  VarDateFromUI4@8 @223
  VarDateFromDec@8 @224
  VarCyFromI1@8 @225
  VarCyFromUI2@8 @226
  VarCyFromUI4@8 @227
  VarCyFromDec@8 @228
  VarBstrFromI1@16 @229
  VarBstrFromUI2@16 @230
  VarBstrFromUI4@16 @231
  VarBstrFromDec@16 @232
  VarBoolFromI1@8 @233
  VarBoolFromUI2@8 @234
  VarBoolFromUI4@8 @235
  VarBoolFromDec@8 @236
  VarUI1FromI1@8 @237
  VarUI1FromUI2@8 @238
  VarUI1FromUI4@8 @239
  VarUI1FromDec@8 @240
  VarDecFromI1@8 @241
  VarDecFromUI2@8 @242
  VarDecFromUI4@8 @243
  VarI1FromUI1@8 @244
  VarI1FromI2@8 @245
  VarI1FromI4@8 @246
  VarI1FromR4@8 @247
  VarI1FromR8@12 @248
  VarI1FromDate@12 @249
  VarI1FromCy@12 @250
  VarI1FromStr@16 @251
  VarI1FromDisp@12 @252
  VarI1FromBool@8 @253
  VarI1FromUI2@8 @254
  VarI1FromUI4@8 @255
  VarI1FromDec@8 @256
  VarUI2FromUI1@8 @257
  VarUI2FromI2@8 @258
  VarUI2FromI4@8 @259
  VarUI2FromR4@8 @260
  VarUI2FromR8@12 @261
  VarUI2FromDate@12 @262
  VarUI2FromCy@12 @263
  VarUI2FromStr@16 @264
  VarUI2FromDisp@12 @265
  VarUI2FromBool@8 @266
  VarUI2FromI1@8 @267
  VarUI2FromUI4@8 @268
  VarUI2FromDec@8 @269
  VarUI4FromUI1@8 @270
  VarUI4FromI2@8 @271
  VarUI4FromI4@8 @272
  VarUI4FromR4@8 @273
  VarUI4FromR8@12 @274
  VarUI4FromDate@12 @275
  VarUI4FromCy@12 @276
  VarUI4FromStr@16 @277
  VarUI4FromDisp@12 @278
  VarUI4FromBool@8 @279
  VarUI4FromI1@8 @280
  VarUI4FromUI2@8 @281
  VarUI4FromDec@8 @282
  BSTR_UserSize@12 @283
  BSTR_UserMarshal@12 @284
  BSTR_UserUnmarshal@12 @285
  BSTR_UserFree@8 @286
  VARIANT_UserSize@12 @287
  VARIANT_UserMarshal@12 @288
  VARIANT_UserUnmarshal@12 @289
  VARIANT_UserFree@8 @290
  VarDecCmpR8@12 @298
  VarCyAdd@20 @299
  VarCyMul@20 @303
  VarCyMulI4@16 @304
  VarCySub@20 @305
  VarCyAbs@12 @306
  VarCyFix@12 @307
  VarCyInt@12 @308
  VarCyNeg@12 @309
  VarCyRound@16 @310
  VarCyCmp@16 @311
  VarCyCmpR8@16 @312
  VarBstrCat@12 @313
  VarBstrCmp@16 @314
  VarR8Pow@20 @315
  VarR4CmpR8@12 @316
  VarR8Round@16 @317
  VarCat@12 @318
  VarDateFromUdateEx@16 @319
  DllRegisterServer@0=OLEAUT32_DllRegisterServer@0 @320 PRIVATE
  DllUnregisterServer@0=OLEAUT32_DllUnregisterServer@0 @321 PRIVATE
  SetOaNoCache@0 @327
  VarCyMulI8@20 @329
  VarDateFromUdate@12 @330
  VarUdateFromDate@16 @331
  VarI8FromUI1@8 @333
  VarI8FromI2@8 @334
  VarI8FromR4@8 @335
  VarI8FromR8@12 @336
  VarI8FromCy@12 @337
  VarI8FromDate@12 @338
  VarI8FromStr@16 @339
  VarI8FromDisp@12 @340
  VarI8FromBool@8 @341
  VarI8FromI1@8 @342
  VarI8FromUI2@8 @343
  VarI8FromUI4@8 @344
  VarI8FromDec@8 @345
  VarI2FromI8@12 @346
  VarI2FromUI8@12 @347
  VarI4FromI8@12 @348
  VarI4FromUI8@12 @349
  VarR4FromI8@12 @360
  VarR4FromUI8@12 @361
  VarR8FromI8@12 @362
  VarR8FromUI8@12 @363
  VarDateFromI8@12 @364
  VarDateFromUI8@12 @365
  VarCyFromI8@12 @366
  VarCyFromUI8@12 @367
  VarBstrFromI8@20 @368
  VarBstrFromUI8@20 @369
  VarBoolFromI8@12 @370
  VarBoolFromUI8@12 @371
  VarUI1FromI8@12 @372
  VarUI1FromUI8@12 @373
  VarDecFromI8@12 @374
  VarDecFromUI8@12 @375
  VarI1FromI8@12 @376
  VarI1FromUI8@12 @377
  VarUI2FromI8@12 @378
  VarUI2FromUI8@12 @379
  OleLoadPictureEx@32 @401
  DllCanUnloadNow@0=OLEAUT32_DllCanUnloadNow@0 @410 PRIVATE
  SafeArrayCreateVector@12 @411
  SafeArrayCopyData@8 @412
  VectorFromBstr@8 @413
  BstrFromVector@8 @414
  OleIconToCursor@8 @415
  OleCreatePropertyFrameIndirect@4 @416
  OleCreatePropertyFrame@44 @417
  OleLoadPicture@20 @418
  OleCreatePictureIndirect@16 @419
  OleCreateFontIndirect@12 @420
  OleTranslateColor@12 @421
  VarUI4FromI8@12 @425
  VarUI4FromUI8@12 @426
  VarI8FromUI8@12 @427
  VarUI8FromI8@12 @428
  VarUI8FromUI1@8 @429
  VarUI8FromI2@8 @430
  VarUI8FromR4@8 @431
  VarUI8FromR8@12 @432
  VarUI8FromCy@12 @433
  VarUI8FromDate@12 @434
  VarUI8FromStr@16 @435
  VarUI8FromDisp@12 @436
  VarUI8FromBool@8 @437
  VarUI8FromI1@8 @438
  VarUI8FromUI2@8 @439
  VarUI8FromUI4@8 @440
  VarUI8FromDec@8 @441
