; File generated automatically from capi2032/capi2032.spec; do not edit!

LIBRARY capi2032.dll

EXPORTS
  CAPI_REGISTER@20=wrapCAPI_REGISTER@20 @1
  CAPI_RELEASE@4=wrapCAPI_RELEASE@4 @2
  CAPI_PUT_MESSAGE@8=wrapCAPI_PUT_MESSAGE@8 @3
  CAPI_GET_MESSAGE@8=wrapCAPI_GET_MESSAGE@8 @4
  CAPI_WAIT_FOR_SIGNAL@4=wrapCAPI_WAIT_FOR_SIGNAL@4 @5
  CAPI_GET_MANUFACTURER@4=wrapCAPI_GET_MANUFACTURER@4 @6
  CAPI_GET_VERSION@16=wrapCAPI_GET_VERSION@16 @7
  CAPI_GET_SERIAL_NUMBER@4=wrapCAPI_GET_SERIAL_NUMBER@4 @8
  CAPI_GET_PROFILE@8=wrapCAPI_GET_PROFILE@8 @9
  CAPI_INSTALLED@0=wrapCAPI_INSTALLED@0 @10
  CAPI_MANUFACTURER@20=wrapCAPI_MANUFACTURER@20 @99
