; File generated automatically from dmime/dmime.spec; do not edit!

LIBRARY dmime.dll

EXPORTS
  DllCanUnloadNow@0=DMIME_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMIME_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMIME_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMIME_DllUnregisterServer@0 @4 PRIVATE
