; File generated automatically from dpnet/dpnet.spec; do not edit!

LIBRARY dpnet.dll

EXPORTS
  DirectPlay8Create@12 @1
  DllCanUnloadNow@0=DPNET_DllCanUnloadNow@0 @2 PRIVATE
  DllGetClassObject@12=DPNET_DllGetClassObject@12 @3 PRIVATE
  DllRegisterServer@0=DPNET_DllRegisterServer@0 @4 PRIVATE
  DllUnregisterServer@0=DPNET_DllUnregisterServer@0 @5 PRIVATE
