; File generated automatically from imagehlp/imagehlp.spec; do not edit!

LIBRARY imagehlp.dll

EXPORTS
  BindImage@12 @1
  BindImageEx@20 @2
  CheckSumMappedFile@16 @3
  EnumerateLoadedModules@12=dbghelp.EnumerateLoadedModules @4
  FindDebugInfoFile@12=dbghelp.FindDebugInfoFile @6
  FindDebugInfoFileEx@20=dbghelp.FindDebugInfoFileEx @7
  FindExecutableImage@12=dbghelp.FindExecutableImage @8
  GetImageConfigInformation@8 @12
  GetImageUnusedHeaderBytes@8 @13
  GetTimestampForLoadedLibrary@4=dbghelp.GetTimestampForLoadedLibrary @14
  ImageAddCertificate@12 @15
  ImageDirectoryEntryToData@16=ntdll.RtlImageDirectoryEntryToData @16
  ImageEnumerateCertificates@20 @18
  ImageGetCertificateData@16 @19
  ImageGetCertificateHeader@12 @20
  ImageGetDigestStream@16 @21
  ImageLoad@8 @22
  ImageNtHeader@4=ntdll.RtlImageNtHeader @23
  ImageRemoveCertificate@8 @24
  ImageRvaToSection@12=ntdll.RtlImageRvaToSection @25
  ImageRvaToVa@16=ntdll.RtlImageRvaToVa @26
  ImageUnload@4 @27
  ImagehlpApiVersion@0=dbghelp.ImagehlpApiVersion @28
  ImagehlpApiVersionEx@4=dbghelp.ImagehlpApiVersionEx @29
  MakeSureDirectoryPathExists@4=dbghelp.MakeSureDirectoryPathExists @30
  MapAndLoad@20 @31
  MapDebugInformation@16=dbghelp.MapDebugInformation @32
  MapFileAndCheckSumA@12 @33
  MapFileAndCheckSumW@12 @34
  ReBaseImage@44 @36
  RemovePrivateCvSymbolic@12 @38
  RemoveRelocations@4 @40
  SearchTreeForFile@12=dbghelp.SearchTreeForFile @41
  SetImageConfigInformation@8 @42
  SplitSymbols@16 @43
  StackWalk@36=dbghelp.StackWalk @44
  SymCleanup@4=dbghelp.SymCleanup @46
  SymEnumSourceFiles@20=dbghelp.SymEnumSourceFiles @47
  SymEnumSymbols@20=dbghelp.SymEnumSymbols @49
  SymEnumTypes@16=dbghelp.SymEnumTypes @50
  SymEnumerateModules@12=dbghelp.SymEnumerateModules @51
  SymEnumerateSymbols@16=dbghelp.SymEnumerateSymbols @53
  SymFromAddr@16=dbghelp.SymFromAddr @58
  SymFromName@12=dbghelp.SymFromName @59
  SymFunctionTableAccess@8=dbghelp.SymFunctionTableAccess @60
  SymGetLineFromAddr@16=dbghelp.SymGetLineFromAddr @62
  SymGetLineNext@8=dbghelp.SymGetLineNext @66
  SymGetLinePrev@8=dbghelp.SymGetLinePrev @68
  SymGetModuleBase@8=dbghelp.SymGetModuleBase @70
  SymGetModuleInfo@12=dbghelp.SymGetModuleInfo @72
  SymGetOptions@0=dbghelp.SymGetOptions @76
  SymGetSearchPath@12=dbghelp.SymGetSearchPath @77
  SymGetSymFromAddr@16=dbghelp.SymGetSymFromAddr @78
  SymGetSymFromName@12=dbghelp.SymGetSymFromName @80
  SymGetSymNext@8=dbgelp.SymGetSymNext @82
  SymGetSymPrev@8=dbgelp.SymGetSymPrev @84
  SymGetTypeFromName@16=dbghelp.SymGetTypeFromName @86
  SymGetTypeInfo@20=dbghelp.SymGetTypeInfo @87
  SymInitialize@12=dbghelp.SymInitialize @88
  SymLoadModule@24=dbghelp.SymLoadModule @89
  SymRegisterCallback@12=dbghelp.SymRegisterCallback @93
  SymSetContext@12=dbghelp.SymSetContext @97
  SymSetOptions@4=dbghelp.SymGetOptions @98
  SymSetSearchPath@8=dbghelp.SymSetSearchPath @99
  SymUnDName@12=dbghelp.SymUnDName @100
  SymUnloadModule@8=dbghelp.SymUnloadModule @102
  TouchFileTimes@8 @104
  UnDecorateSymbolName@16=dbghelp.UnDecorateSymbolName @105
  UnMapAndLoad@4 @106
  UnmapDebugInformation@4=dbghelp.UnmapDebugInformation @107
  UpdateDebugInfoFile@16 @108
  UpdateDebugInfoFileEx@20 @109
