; File generated automatically from crtdll/crtdll.spec; do not edit!

LIBRARY crtdll.dll

EXPORTS
  ??2@YAPAXI@Z=msvcrt.??2@YAPAXI@Z @1
  ??3@YAXPAX@Z=msvcrt.??3@YAXPAX@Z @2
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=msvcrt.?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z @3
  _CIacos=msvcrt._CIacos @4
  _CIasin=msvcrt._CIasin @5
  _CIatan=msvcrt._CIatan @6
  _CIatan2=msvcrt._CIatan2 @7
  _CIcos=msvcrt._CIcos @8
  _CIcosh=msvcrt._CIcosh @9
  _CIexp=msvcrt._CIexp @10
  _CIfmod=msvcrt._CIfmod @11
  _CIlog=msvcrt._CIlog @12
  _CIlog10=msvcrt._CIlog10 @13
  _CIpow=msvcrt._CIpow @14
  _CIsin=msvcrt._CIsin @15
  _CIsinh=msvcrt._CIsinh @16
  _CIsqrt=msvcrt._CIsqrt @17
  _CItan=msvcrt._CItan @18
  _CItanh=msvcrt._CItanh @19
  _HUGE_dll=msvcrt._HUGE @20 DATA
  _XcptFilter=msvcrt._XcptFilter @21
  __GetMainArgs @22
  __argc_dll=msvcrt.__argc @23 DATA
  __argv_dll=msvcrt.__argv @24 DATA
  __dllonexit=msvcrt.__dllonexit @25
  __doserrno=msvcrt.__doserrno @26
  __fpecode=msvcrt.__fpecode @27
  __isascii=msvcrt.__isascii @28
  __iscsym=msvcrt.__iscsym @29
  __iscsymf=msvcrt.__iscsymf @30
  __mb_cur_max_dll=msvcrt.__mb_cur_max @31 DATA
  __pxcptinfoptrs=msvcrt.__pxcptinfoptrs @32
  __threadhandle=msvcrt.__threadhandle @33
  __threadid=msvcrt.__threadid @34
  __toascii=msvcrt.__toascii @35
  _abnormal_termination=msvcrt._abnormal_termination @36
  _access=msvcrt._access @37
  _acmdln_dll=msvcrt._acmdln @38 DATA
  _aexit_rtn_dll=msvcrt._aexit_rtn @39 DATA
  _amsg_exit=msvcrt._amsg_exit @40
  _assert=msvcrt._assert @41
  _basemajor_dll=CRTDLL__basemajor_dll @42 DATA
  _baseminor_dll=CRTDLL__basemajor_dll @43 DATA
  _baseversion_dll=CRTDLL__basemajor_dll @44 DATA
  _beep=msvcrt._beep @45
  _beginthread=msvcrt._beginthread @46
  _c_exit=msvcrt._c_exit @47
  _cabs=msvcrt._cabs @48
  _cexit=msvcrt._cexit @49
  _cgets=msvcrt._cgets @50
  _chdir=msvcrt._chdir @51
  _chdrive=msvcrt._chdrive @52
  _chgsign=msvcrt._chgsign @53
  _chmod=msvcrt._chmod @54
  _chsize=msvcrt._chsize @55
  _clearfp=msvcrt._clearfp @56
  _close=msvcrt._close @57
  _commit=msvcrt._commit @58
  _commode_dll=msvcrt._commode @59 DATA
  _control87=msvcrt._control87 @60
  _controlfp=msvcrt._controlfp @61
  _copysign=msvcrt._copysign @62
  _cprintf=msvcrt._cprintf @63
  _cpumode_dll=CRTDLL__cpumode_dll @64 DATA
  _cputs=msvcrt._cputs @65
  _creat=msvcrt._creat @66
  _cscanf=msvcrt._cscanf @67
  _ctype=msvcrt._ctype @68 DATA
  _cwait=msvcrt._cwait @69
  _daylight_dll=msvcrt._daylight @70 DATA
  _dup=msvcrt._dup @71
  _dup2=msvcrt._dup2 @72
  _ecvt=msvcrt._ecvt @73
  _endthread=msvcrt._endthread @74
  _environ_dll=msvcrt._environ @75 DATA
  _eof=msvcrt._eof @76
  _errno=msvcrt._errno @77
  _except_handler2=msvcrt._except_handler2 @78
  _execl=msvcrt._execl @79
  _execle=msvcrt._execle @80
  _execlp=msvcrt._execlp @81
  _execlpe=msvcrt._execlpe @82
  _execv=msvcrt._execv @83
  _execve=msvcrt._execve @84
  _execvp=msvcrt._execvp @85
  _execvpe=msvcrt._execvpe @86
  _exit=msvcrt._exit @87
  _expand=msvcrt._expand @88
  _fcloseall=msvcrt._fcloseall @89
  _fcvt=msvcrt._fcvt @90
  _fdopen=msvcrt._fdopen @91
  _fgetchar=msvcrt._fgetchar @92
  _fgetwchar=msvcrt._fgetwchar @93
  _filbuf=msvcrt._filbuf @94
  _fileinfo_dll=msvcrt._fileinfo @95 DATA
  _filelength=msvcrt._filelength @96
  _fileno=msvcrt._fileno @97
  _findclose=msvcrt._findclose @98
  _findfirst=msvcrt._findfirst @99
  _findnext=msvcrt._findnext @100
  _finite=msvcrt._finite @101
  _flsbuf=msvcrt._flsbuf @102
  _flushall=msvcrt._flushall @103
  _fmode_dll=msvcrt._fmode @104 DATA
  _fpclass=msvcrt._fpclass @105
  _fpieee_flt=msvcrt._fpieee_flt @106
  _fpreset=msvcrt._fpreset @107
  _fputchar=msvcrt._fputchar @108
  _fputwchar=msvcrt._fputwchar @109
  _fsopen=msvcrt._fsopen @110
  _fstat=CRTDLL__fstat @111
  _ftime=msvcrt._ftime @112
  _ftol=msvcrt._ftol @113
  _fullpath=msvcrt._fullpath @114
  _futime=msvcrt._futime @115
  _gcvt=msvcrt._gcvt @116
  _get_osfhandle=msvcrt._get_osfhandle @117
  _getch=msvcrt._getch @118
  _getche=msvcrt._getche @119
  _getcwd=msvcrt._getcwd @120
  _getdcwd=msvcrt._getdcwd @121
  _getdiskfree=msvcrt._getdiskfree @122
  _getdllprocaddr=msvcrt._getdllprocaddr @123
  _getdrive=msvcrt._getdrive @124
  _getdrives=msvcrt._getdrives @125
  _getpid=msvcrt._getpid @126
  _getsystime=msvcrt._getsystime @127
  _getw=msvcrt._getw @128
  _global_unwind2=msvcrt._global_unwind2 @129
  _heapchk=msvcrt._heapchk @130
  _heapmin=msvcrt._heapmin @131
  _heapset=msvcrt._heapset @132
  _heapwalk=msvcrt._heapwalk @133
  _hypot=msvcrt._hypot @134
  _initterm=msvcrt._initterm @135
  _iob=msvcrt._iob @136 DATA
  _isatty=msvcrt._isatty @137
  _isctype=msvcrt._isctype @138
  _ismbbalnum=msvcrt._ismbbalnum @139
  _ismbbalpha=msvcrt._ismbbalpha @140
  _ismbbgraph=msvcrt._ismbbgraph @141
  _ismbbkalnum=msvcrt._ismbbkalnum @142
  _ismbbkana=msvcrt._ismbbkana @143
  _ismbbkpunct=msvcrt._ismbbkpunct @144
  _ismbblead=msvcrt._ismbblead @145
  _ismbbprint=msvcrt._ismbbprint @146
  _ismbbpunct=msvcrt._ismbbpunct @147
  _ismbbtrail=msvcrt._ismbbtrail @148
  _ismbcalpha=msvcrt._ismbcalpha @149
  _ismbcdigit=msvcrt._ismbcdigit @150
  _ismbchira=msvcrt._ismbchira @151
  _ismbckata=msvcrt._ismbckata @152
  _ismbcl0=msvcrt._ismbcl0 @153
  _ismbcl1=msvcrt._ismbcl1 @154
  _ismbcl2=msvcrt._ismbcl2 @155
  _ismbclegal=msvcrt._ismbclegal @156
  _ismbclower=msvcrt._ismbclower @157
  _ismbcprint=msvcrt._ismbcprint @158
  _ismbcspace=msvcrt._ismbcspace @159
  _ismbcsymbol=msvcrt._ismbcsymbol @160
  _ismbcupper=msvcrt._ismbcupper @161
  _ismbslead=msvcrt._ismbslead @162
  _ismbstrail=msvcrt._ismbstrail @163
  _isnan=msvcrt._isnan @164
  _itoa=msvcrt._itoa @165
  _itow=msvcrt._itow @166
  _j0=msvcrt._j0 @167
  _j1=msvcrt._j1 @168
  _jn=msvcrt._jn @169
  _kbhit=msvcrt._kbhit @170
  _lfind=msvcrt._lfind @171
  _loaddll=msvcrt._loaddll @172
  _local_unwind2=msvcrt._local_unwind2 @173
  _locking=msvcrt._locking @174
  _logb=msvcrt._logb @175
  _lrotl=msvcrt._lrotl @176
  _lrotr=msvcrt._lrotr @177
  _lsearch=msvcrt._lsearch @178
  _lseek=msvcrt._lseek @179
  _ltoa=msvcrt._ltoa @180
  _ltow=msvcrt._ltow @181
  _makepath=msvcrt._makepath @182
  _matherr=msvcrt._matherr @183
  _mbbtombc=msvcrt._mbbtombc @184
  _mbbtype=msvcrt._mbbtype @185
  _mbccpy=msvcrt._mbccpy @186
  _mbcjistojms=msvcrt._mbcjistojms @187
  _mbcjmstojis=msvcrt._mbcjmstojis @188
  _mbclen=msvcrt._mbclen @189
  _mbctohira=msvcrt._mbctohira @190
  _mbctokata=msvcrt._mbctokata @191
  _mbctolower=msvcrt._mbctolower @192
  _mbctombb=msvcrt._mbctombb @193
  _mbctoupper=msvcrt._mbctoupper @194
  _mbctype=msvcrt._mbctype @195 DATA
  _mbsbtype=msvcrt._mbsbtype @196
  _mbscat=msvcrt._mbscat @197
  _mbschr=msvcrt._mbschr @198
  _mbscmp=msvcrt._mbscmp @199
  _mbscpy=msvcrt._mbscpy @200
  _mbscspn=msvcrt._mbscspn @201
  _mbsdec=msvcrt._mbsdec @202
  _mbsdup=msvcrt._mbsdup @203
  _mbsicmp=msvcrt._mbsicmp @204
  _mbsinc=msvcrt._mbsinc @205
  _mbslen=msvcrt._mbslen @206
  _mbslwr=msvcrt._mbslwr @207
  _mbsnbcat=msvcrt._mbsnbcat @208
  _mbsnbcmp=msvcrt._mbsnbcmp @209
  _mbsnbcnt=msvcrt._mbsnbcnt @210
  _mbsnbcpy=msvcrt._mbsnbcpy @211
  _mbsnbicmp=msvcrt._mbsnbicmp @212
  _mbsnbset=msvcrt._mbsnbset @213
  _mbsncat=msvcrt._mbsncat @214
  _mbsnccnt=msvcrt._mbsnccnt @215
  _mbsncmp=msvcrt._mbsncmp @216
  _mbsncpy=msvcrt._mbsncpy @217
  _mbsnextc=msvcrt._mbsnextc @218
  _mbsnicmp=msvcrt._mbsnicmp @219
  _mbsninc=msvcrt._mbsninc @220
  _mbsnset=msvcrt._mbsnset @221
  _mbspbrk=msvcrt._mbspbrk @222
  _mbsrchr=msvcrt._mbsrchr @223
  _mbsrev=msvcrt._mbsrev @224
  _mbsset=msvcrt._mbsset @225
  _mbsspn=msvcrt._mbsspn @226
  _mbsspnp=msvcrt._mbsspnp @227
  _mbsstr=msvcrt._mbsstr @228
  _mbstok=msvcrt._mbstok @229
  _mbstrlen=msvcrt._mbstrlen @230
  _mbsupr=msvcrt._mbsupr @231
  _memccpy=msvcrt._memccpy @232
  _memicmp=msvcrt._memicmp @233
  _mkdir=msvcrt._mkdir @234
  _mktemp=msvcrt._mktemp @235
  _msize=msvcrt._msize @236
  _nextafter=msvcrt._nextafter @237
  _onexit=msvcrt._onexit @238
  _open=msvcrt._open @239
  _open_osfhandle=msvcrt._open_osfhandle @240
  _osmajor_dll=CRTDLL__osmajor_dll @241 DATA
  _osminor_dll=CRTDLL__osminor_dll @242 DATA
  _osmode_dll=CRTDLL__osmode_dll @243 DATA
  _osver_dll=msvcrt._osver @244 DATA
  _osversion_dll=CRTDLL__osversion_dll @245 DATA
  _pclose=msvcrt._pclose @246
  _pctype_dll=msvcrt._pctype @247 DATA
  _pgmptr_dll=msvcrt._pgmptr @248 DATA
  _pipe=msvcrt._pipe @249
  _popen=msvcrt._popen @250
  _purecall=msvcrt._purecall @251
  _putch=msvcrt._putch @252
  _putenv=msvcrt._putenv @253
  _putw=msvcrt._putw @254
  _pwctype_dll=msvcrt._pwctype @255 DATA
  _read=msvcrt._read @256
  _rmdir=msvcrt._rmdir @257
  _rmtmp=msvcrt._rmtmp @258
  _rotl=msvcrt._rotl @259
  _rotr=msvcrt._rotr @260
  _scalb=msvcrt._scalb @261
  _searchenv=msvcrt._searchenv @262
  _seterrormode=msvcrt._seterrormode @263
  _setjmp=msvcrt._setjmp @264
  _setmode=msvcrt._setmode @265
  _setsystime=msvcrt._setsystime @266
  _sleep=msvcrt._sleep @267
  _snprintf=msvcrt._snprintf @268
  _snwprintf=msvcrt._snwprintf @269
  _sopen=msvcrt._sopen @270
  _spawnl=msvcrt._spawnl @271
  _spawnle=msvcrt._spawnle @272
  _spawnlp=msvcrt._spawnlp @273
  _spawnlpe=msvcrt._spawnlpe @274
  _spawnv=msvcrt._spawnv @275
  _spawnve=msvcrt._spawnve @276
  _spawnvp=msvcrt._spawnvp @277
  _spawnvpe=msvcrt._spawnvpe @278
  _splitpath=msvcrt._splitpath @279
  _stat=CRTDLL__stat @280
  _statusfp=msvcrt._statusfp @281
  _strcmpi=msvcrt._strcmpi @282
  _strdate=msvcrt._strdate @283
  _strdec @284
  _strdup=msvcrt._strdup @285
  _strerror=msvcrt._strerror @286
  _stricmp=msvcrt._stricmp @287
  _stricoll=msvcrt._stricoll @288
  _strinc @289
  _strlwr=msvcrt._strlwr @290
  _strncnt @291
  _strnextc @292
  _strnicmp=msvcrt._strnicmp @293
  _strninc @294
  _strnset=msvcrt._strnset @295
  _strrev=msvcrt._strrev @296
  _strset=msvcrt._strset @297
  _strspnp @298
  _strtime=msvcrt._strtime @299
  _strupr=msvcrt._strupr @300
  _swab=msvcrt._swab @301
  _sys_errlist=msvcrt._sys_errlist @302 DATA
  _sys_nerr_dll=msvcrt._sys_nerr @303 DATA
  _tell=msvcrt._tell @304
  _tempnam=msvcrt._tempnam @305
  _timezone_dll=msvcrt._timezone @306 DATA
  _tolower=msvcrt._tolower @307
  _toupper=msvcrt._toupper @308
  _tzname=msvcrt._tzname @309 DATA
  _tzset=msvcrt._tzset @310
  _ultoa=msvcrt._ultoa @311
  _umask=msvcrt._umask @312
  _ungetch=msvcrt._ungetch @313
  _unlink=msvcrt._unlink @314
  _unloaddll=msvcrt._unloaddll @315
  _utime=msvcrt._utime @316
  _vsnprintf=msvcrt._vsnprintf @317
  _vsnwprintf=msvcrt._vsnwprintf @318
  _wcsdup=msvcrt._wcsdup @319
  _wcsicmp=msvcrt._wcsicmp @320
  _wcsicoll=msvcrt._wcsicoll @321
  _wcslwr=msvcrt._wcslwr @322
  _wcsnicmp=msvcrt._wcsnicmp @323
  _wcsnset=msvcrt._wcsnset @324
  _wcsrev=msvcrt._wcsrev @325
  _wcsset=msvcrt._wcsset @326
  _wcsupr=msvcrt._wcsupr @327
  _winmajor_dll=msvcrt._winmajor @328 DATA
  _winminor_dll=msvcrt._winminor @329 DATA
  _winver_dll=msvcrt._winver @330 DATA
  _write=msvcrt._write @331
  _wtoi=msvcrt._wtoi @332
  _wtol=msvcrt._wtol @333
  _y0=msvcrt._y0 @334
  _y1=msvcrt._y1 @335
  _yn=msvcrt._yn @336
  abort=msvcrt.abort @337
  abs=msvcrt.abs @338
  acos=msvcrt.acos @339
  asctime=msvcrt.asctime @340
  asin=msvcrt.asin @341
  atan=msvcrt.atan @342
  atan2=msvcrt.atan2 @343
  atexit=msvcrt.atexit @344
  atof=msvcrt.atof @345
  atoi=msvcrt.atoi @346
  atol=msvcrt.atol @347
  bsearch=msvcrt.bsearch @348
  calloc=msvcrt.calloc @349
  ceil=msvcrt.ceil @350
  clearerr=msvcrt.clearerr @351
  clock=msvcrt.clock @352
  cos=msvcrt.cos @353
  cosh=msvcrt.cosh @354
  ctime=msvcrt.ctime @355
  difftime=msvcrt.difftime @356
  div=msvcrt.div @357
  exit=msvcrt.exit @358
  exp=msvcrt.exp @359
  fabs=msvcrt.fabs @360
  fclose=msvcrt.fclose @361
  feof=msvcrt.feof @362
  ferror=msvcrt.ferror @363
  fflush=msvcrt.fflush @364
  fgetc=msvcrt.fgetc @365
  fgetpos=msvcrt.fgetpos @366
  fgets=msvcrt.fgets @367
  fgetwc=msvcrt.fgetwc @368
  floor=msvcrt.floor @369
  fmod=msvcrt.fmod @370
  fopen=msvcrt.fopen @371
  fprintf=msvcrt.fprintf @372
  fputc=msvcrt.fputc @373
  fputs=msvcrt.fputs @374
  fputwc=msvcrt.fputwc @375
  fread=msvcrt.fread @376
  free=msvcrt.free @377
  freopen=msvcrt.freopen @378
  frexp=msvcrt.frexp @379
  fscanf=msvcrt.fscanf @380
  fseek=msvcrt.fseek @381
  fsetpos=msvcrt.fsetpos @382
  ftell=msvcrt.ftell @383
  fwprintf=msvcrt.fwprintf @384
  fwrite=msvcrt.fwrite @385
  fwscanf=msvcrt.fwscanf @386
  getc=msvcrt.getc @387
  getchar=msvcrt.getchar @388
  getenv=msvcrt.getenv @389
  gets=msvcrt.gets @390
  gmtime=msvcrt.gmtime @391
  is_wctype=msvcrt.is_wctype @392
  isalnum=msvcrt.isalnum @393
  isalpha=msvcrt.isalpha @394
  iscntrl=msvcrt.iscntrl @395
  isdigit=msvcrt.isdigit @396
  isgraph=msvcrt.isgraph @397
  isleadbyte=msvcrt.isleadbyte @398
  islower=msvcrt.islower @399
  isprint=msvcrt.isprint @400
  ispunct=msvcrt.ispunct @401
  isspace=msvcrt.isspace @402
  isupper=msvcrt.isupper @403
  iswalnum=msvcrt.iswalnum @404
  iswalpha=msvcrt.iswalpha @405
  iswascii=msvcrt.iswascii @406
  iswcntrl=msvcrt.iswcntrl @407
  iswctype=msvcrt.iswctype @408
  iswdigit=msvcrt.iswdigit @409
  iswgraph=msvcrt.iswgraph @410
  iswlower=msvcrt.iswlower @411
  iswprint=msvcrt.iswprint @412
  iswpunct=msvcrt.iswpunct @413
  iswspace=msvcrt.iswspace @414
  iswupper=msvcrt.iswupper @415
  iswxdigit=msvcrt.iswxdigit @416
  isxdigit=msvcrt.isxdigit @417
  labs=msvcrt.labs @418
  ldexp=msvcrt.ldexp @419
  ldiv=msvcrt.ldiv @420
  localeconv=msvcrt.localeconv @421
  localtime=msvcrt.localtime @422
  log=msvcrt.log @423
  log10=msvcrt.log10 @424
  longjmp=msvcrt.longjmp @425
  malloc=msvcrt.malloc @426
  mblen=msvcrt.mblen @427
  mbstowcs=msvcrt.mbstowcs @428
  mbtowc=msvcrt.mbtowc @429
  memchr=msvcrt.memchr @430
  memcmp=msvcrt.memcmp @431
  memcpy=msvcrt.memcpy @432
  memmove=msvcrt.memmove @433
  memset=msvcrt.memset @434
  mktime=msvcrt.mktime @435
  modf=msvcrt.modf @436
  perror=msvcrt.perror @437
  pow=msvcrt.pow @438
  printf=msvcrt.printf @439
  putc=msvcrt.putc @440
  putchar=msvcrt.putchar @441
  puts=msvcrt.puts @442
  qsort=msvcrt.qsort @443
  raise=msvcrt.raise @444
  rand=msvcrt.rand @445
  realloc=msvcrt.realloc @446
  remove=msvcrt.remove @447
  rename=msvcrt.rename @448
  rewind=msvcrt.rewind @449
  scanf=msvcrt.scanf @450
  setbuf=msvcrt.setbuf @451
  setlocale=msvcrt.setlocale @452
  setvbuf=msvcrt.setvbuf @453
  signal=msvcrt.signal @454
  sin=msvcrt.sin @455
  sinh=msvcrt.sinh @456
  sprintf=msvcrt.sprintf @457
  sqrt=msvcrt.sqrt @458
  srand=msvcrt.srand @459
  sscanf=msvcrt.sscanf @460
  strcat=msvcrt.strcat @461
  strchr=msvcrt.strchr @462
  strcmp=msvcrt.strcmp @463
  strcoll=msvcrt.strcoll @464
  strcpy=msvcrt.strcpy @465
  strcspn=msvcrt.strcspn @466
  strerror=msvcrt.strerror @467
  strftime=msvcrt.strftime @468
  strlen=msvcrt.strlen @469
  strncat=msvcrt.strncat @470
  strncmp=msvcrt.strncmp @471
  strncpy=msvcrt.strncpy @472
  strpbrk=msvcrt.strpbrk @473
  strrchr=msvcrt.strrchr @474
  strspn=msvcrt.strspn @475
  strstr=msvcrt.strstr @476
  strtod=msvcrt.strtod @477
  strtok=msvcrt.strtok @478
  strtol=msvcrt.strtol @479
  strtoul=msvcrt.strtoul @480
  strxfrm=msvcrt.strxfrm @481
  swprintf=msvcrt.swprintf @482
  swscanf=msvcrt.swscanf @483
  system=msvcrt.system @484
  tan=msvcrt.tan @485
  tanh=msvcrt.tanh @486
  time=msvcrt.time @487
  tmpfile=msvcrt.tmpfile @488
  tmpnam=msvcrt.tmpnam @489
  tolower=msvcrt.tolower @490
  toupper=msvcrt.toupper @491
  towlower=msvcrt.towlower @492
  towupper=msvcrt.towupper @493
  ungetc=msvcrt.ungetc @494
  ungetwc=msvcrt.ungetwc @495
  vfprintf=msvcrt.vfprintf @496
  vfwprintf=msvcrt.vfwprintf @497
  vprintf=msvcrt.vprintf @498
  vsprintf=msvcrt.vsprintf @499
  vswprintf=msvcrt.vswprintf @500
  vwprintf=msvcrt.vwprintf @501
  wcscat=msvcrt.wcscat @502
  wcschr=msvcrt.wcschr @503
  wcscmp=msvcrt.wcscmp @504
  wcscoll=msvcrt.wcscoll @505
  wcscpy=msvcrt.wcscpy @506
  wcscspn=msvcrt.wcscspn @507
  wcsftime=msvcrt.wcsftime @508
  wcslen=msvcrt.wcslen @509
  wcsncat=msvcrt.wcsncat @510
  wcsncmp=msvcrt.wcsncmp @511
  wcsncpy=msvcrt.wcsncpy @512
  wcspbrk=msvcrt.wcspbrk @513
  wcsrchr=msvcrt.wcsrchr @514
  wcsspn=msvcrt.wcsspn @515
  wcsstr=msvcrt.wcsstr @516
  wcstod=msvcrt.wcstod @517
  wcstok=msvcrt.wcstok @518
  wcstol=msvcrt.wcstol @519
  wcstombs=msvcrt.wcstombs @520
  wcstoul=msvcrt.wcstoul @521
  wcsxfrm=msvcrt.wcsxfrm @522
  wctomb=msvcrt.wctomb @523
  wprintf=msvcrt.wprintf @524
  wscanf=msvcrt.wscanf @525
