; File generated automatically from odbc32/odbc32.spec; do not edit!

LIBRARY odbc32.dll

EXPORTS
  SQLAllocConnect@8 @1
  SQLAllocEnv@4 @2
  SQLAllocStmt@8 @3
  SQLBindCol@24 @4
  SQLCancel@4 @5
  SQLColAttributes@28 @6
  SQLConnect@28 @7
  SQLDescribeCol@36 @8
  SQLDisconnect@4 @9
  SQLError@32 @10
  SQLExecDirect@12 @11
  SQLExecute@4 @12
  SQLFetch@4 @13
  SQLFreeConnect@4 @14
  SQLFreeEnv@4 @15
  SQLFreeStmt@8 @16
  SQLGetCursorName@16 @17
  SQLNumResultCols@8 @18
  SQLPrepare@12 @19
  SQLRowCount@8 @20
  SQLSetCursorName@12 @21
  SQLSetParam@32 @22
  SQLTransact@12 @23
  SQLAllocHandle@12 @24
  SQLBindParam@32 @25
  SQLCloseCursor@4 @26
  SQLColAttribute@28 @27
  SQLCopyDesc@8 @28
  SQLEndTran@12 @29
  SQLFetchScroll@12 @30
  SQLFreeHandle@8 @31
  SQLGetConnectAttr@20 @32
  SQLGetDescField@24 @33
  SQLGetDescRec@44 @34
  SQLGetDiagField@28 @35
  SQLGetDiagRec@32 @36
  SQLGetEnvAttr@20 @37
  SQLGetStmtAttr@20 @38
  SQLSetConnectAttr@16 @39
  SQLColumns@36 @40
  SQLDriverConnect@32 @41
  SQLGetConnectOption@12 @42
  SQLGetData@24 @43
  SQLGetFunctions@12 @44
  SQLGetInfo@20 @45
  SQLGetStmtOption@12 @46
  SQLGetTypeInfo@8 @47
  SQLParamData@8 @48
  SQLPutData@12 @49
  SQLSetConnectOption@12 @50
  SQLSetStmtOption@12 @51
  SQLSpecialColumns@40 @52
  SQLStatistics@36 @53
  SQLTables@36 @54
  SQLBrowseConnect@24 @55
  SQLColumnPrivileges@36 @56
  SQLDataSources@32 @57
  SQLDescribeParam@24 @58
  SQLExtendedFetch@20 @59
  SQLForeignKeys@52 @60
  SQLMoreResults@4 @61
  SQLNativeSql@24 @62
  SQLNumParams@8 @63
  SQLParamOptions@12 @64
  SQLPrimaryKeys@28 @65
  SQLProcedureColumns@36 @66
  SQLProcedures@28 @67
  SQLSetPos@16 @68
  SQLSetScrollOptions@16 @69
  SQLTablePrivileges@28 @70
  SQLDrivers@32 @71
  SQLBindParameter@40 @72
  SQLSetDescField@20 @73
  SQLSetDescRec@40 @74
  SQLSetEnvAttr@16 @75
  SQLSetStmtAttr@16 @76
  SQLAllocHandleStd@12 @77
  SQLBulkOperations@8 @78
