; File generated automatically from qcap/qcap.spec; do not edit!

LIBRARY qcap.dll

EXPORTS
  DllGetClassObject@12=QCAP_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=QCAP_DllRegisterServer@0 @3 PRIVATE
