; File generated automatically from wow32/wow32.spec; do not edit!

LIBRARY wow32.dll

EXPORTS
  WOWGetDescriptor@8=kernel32.K32WOWGetDescriptor @1
  WOWCallback16@8=kernel32.K32WOWCallback16 @2
  WOWCallback16Ex@20=kernel32.K32WOWCallback16Ex @3
  WOWDirectedYield16@4=kernel32.K32WOWDirectedYield16 @4
  WOWGetVDMPointer@12=kernel32.K32WOWGetVDMPointer @5
  WOWGetVDMPointerFix@12=kernel32.K32WOWGetVDMPointerFix @6
  WOWGetVDMPointerUnfix@4=kernel32.K32WOWGetVDMPointerUnfix @7
  WOWGlobalAlloc16@8=kernel32.K32WOWGlobalAlloc16 @8
  WOWGlobalAllocLock16@12=kernel32.K32WOWGlobalAllocLock16 @9
  WOWGlobalFree16@4=kernel32.K32WOWGlobalFree16 @10
  WOWGlobalLock16@4=kernel32.K32WOWGlobalLock16 @11
  WOWGlobalLockSize16@8=kernel32.K32WOWGlobalLockSize16 @12
  WOWGlobalUnlock16@4=kernel32.K32WOWGlobalUnlock16 @13
  WOWGlobalUnlockFree16@4=kernel32.K32WOWGlobalUnlockFree16 @14
  WOWHandle16@8=kernel32.K32WOWHandle16 @15
  WOWHandle32@8=kernel32.K32WOWHandle32 @16
  WOWYield16@0=kernel32.K32WOWYield16 @17
