; File generated automatically from netapi32/netapi32.spec; do not edit!

LIBRARY netapi32.dll

EXPORTS
  I_BrowserQueryEmulatedDomains@12 @3
  I_BrowserSetNetlogonState@16 @9
  I_NetNameCompare@20 @36
  I_NetNameValidate@16 @37
  NetApiBufferAllocate@8 @49
  NetApiBufferFree@4 @50
  NetApiBufferReallocate@12 @51
  NetApiBufferSize@8 @52
  NetGetDCName@12 @77
  NetLocalGroupAdd@16 @88
  NetLocalGroupSetMembers@20 @98
  NetQueryDisplayInformation@28 @104
  NetServerEnum@36 @158
  NetServerGetInfo@12 @160
  NetShareEnum@28 @177
  NetStatisticsGet@20 @181
  NetUserEnum@32 @189
  NetUserGetInfo@16 @191
  NetUserModalsGet@12 @193
  NetWkstaGetInfo@12 @197
  NetWkstaTransportEnum@28 @201
  NetWkstaUserGetInfo@12 @203
  NetapipBufferAllocate@8=NetApiBufferAllocate@8 @205
  Netbios@4 @206
  NetpDeleteSecurityObject@4=ntdll.RtlDeleteSecurityObject @222
  NetpGetComputerName@4 @223
  NetpInitOemString@8=ntdll.RtlInitAnsiString @232
  NetpNetBiosStatusToApiStatus@4 @245
