; File generated automatically from glut32/glut32.spec; do not edit!

LIBRARY glut32.dll

EXPORTS
  glutAddMenuEntry@8=wine_glutAddMenuEntry@8 @4
  glutAddSubMenu@8=wine_glutAddSubMenu@8 @5
  glutAttachMenu@4=wine_glutAttachMenu@4 @6
  glutBitmapCharacter@8=wine_glutBitmapCharacter@8 @7
  glutBitmapLength@8=wine_glutBitmapLength@8 @8
  glutBitmapWidth@8=wine_glutBitmapWidth@8 @9
  glutButtonBoxFunc@4=wine_glutButtonBoxFunc@4 @10
  glutChangeToMenuEntry@12=wine_glutChangeToMenuEntry@12 @11
  glutChangeToSubMenu@12=wine_glutChangeToSubMenu@12 @12
  glutCopyColormap@4=wine_glutCopyColormap@4 @13
  glutCreateMenu@4=wine_glutCreateMenu@4 @14
  __glutCreateMenuWithExit@8=wine___glutCreateMenuWithExit@8 @1
  glutCreateSubWindow@20=wine_glutCreateSubWindow@20 @15
  glutCreateWindow@4=wine_glutCreateWindow@4 @16
  __glutCreateWindowWithExit@8=wine___glutCreateWindowWithExit@8 @2
  glutDestroyMenu@4=wine_glutDestroyMenu@4 @17
  glutDestroyWindow@4=wine_glutDestroyWindow@4 @18
  glutDetachMenu@4=wine_glutDetachMenu@4 @19
  glutDeviceGet@4=wine_glutDeviceGet@4 @20
  glutDialsFunc@4=wine_glutDialsFunc@4 @21
  glutDisplayFunc@4=wine_glutDisplayFunc@4 @22
  glutEnterGameMode@0=wine_glutEnterGameMode@0 @23
  glutEntryFunc@4=wine_glutEntryFunc@4 @24
  glutEstablishOverlay@0=wine_glutEstablishOverlay@0 @25
  glutExtensionSupported@4=wine_glutExtensionSupported@4 @26
  glutForceJoystickFunc@0=wine_glutForceJoystickFunc@0 @27
  glutFullScreen@0=wine_glutFullScreen@0 @28
  glutGameModeGet@4=wine_glutGameModeGet@4 @29
  glutGameModeString@4=wine_glutGameModeString@4 @30
  glutGetColor@8=wine_glutGetColor@8 @32
  glutGet@4=wine_glutGet@4 @31
  glutGetMenu@0=wine_glutGetMenu@0 @33
  glutGetModifiers@0=wine_glutGetModifiers@0 @34
  glutGetWindow@0=wine_glutGetWindow@0 @35
  glutHideOverlay@0=wine_glutHideOverlay@0 @36
  glutHideWindow@0=wine_glutHideWindow@0 @37
  glutIconifyWindow@0=wine_glutIconifyWindow@0 @38
  glutIdleFunc@4=wine_glutIdleFunc@4 @39
  glutIgnoreKeyRepeat@4=wine_glutIgnoreKeyRepeat@4 @40
  glutInitDisplayMode@4=wine_glutInitDisplayMode@4 @42
  glutInitDisplayString@4=wine_glutInitDisplayString@4 @43
  glutInit@8=wine_glutInit@8 @41
  glutInitWindowPosition@8=wine_glutInitWindowPosition@8 @44
  glutInitWindowSize@8=wine_glutInitWindowSize@8 @45
  __glutInitWithExit@12=wine___glutInitWithExit@12 @3
  glutJoystickFunc@8=wine_glutJoystickFunc@8 @46
  glutKeyboardFunc@4=wine_glutKeyboardFunc@4 @47
  glutKeyboardUpFunc@4=wine_glutKeyboardUpFunc@4 @48
  glutLayerGet@4=wine_glutLayerGet@4 @49
  glutLeaveGameMode@0=wine_glutLeaveGameMode@0 @50
  glutMainLoop@0=wine_glutMainLoop@0 @51
  glutMenuStateFunc@4=wine_glutMenuStateFunc@4 @52
  glutMenuStatusFunc@4=wine_glutMenuStatusFunc@4 @53
  glutMotionFunc@4=wine_glutMotionFunc@4 @54
  glutMouseFunc@4=wine_glutMouseFunc@4 @55
  glutOverlayDisplayFunc@4=wine_glutOverlayDisplayFunc@4 @56
  glutPassiveMotionFunc@4=wine_glutPassiveMotionFunc@4 @57
  glutPopWindow@0=wine_glutPopWindow@0 @58
  glutPositionWindow@8=wine_glutPositionWindow@8 @59
  glutPostOverlayRedisplay@0=wine_glutPostOverlayRedisplay@0 @60
  glutPostRedisplay@0=wine_glutPostRedisplay@0 @61
  glutPostWindowOverlayRedisplay@4=wine_glutPostWindowOverlayRedisplay@4 @62
  glutPostWindowRedisplay@4=wine_glutPostWindowRedisplay@4 @63
  glutPushWindow@0=wine_glutPushWindow@0 @64
  glutRemoveMenuItem@4=wine_glutRemoveMenuItem@4 @65
  glutRemoveOverlay@0=wine_glutRemoveOverlay@0 @66
  glutReportErrors@0=wine_glutReportErrors@0 @67
  glutReshapeFunc@4=wine_glutReshapeFunc@4 @68
  glutReshapeWindow@8=wine_glutReshapeWindow@8 @69
  glutSetColor@12=wine_glutSetColor@12 @70
  glutSetCursor@4=wine_glutSetCursor@4 @71
  glutSetIconTitle@4=wine_glutSetIconTitle@4 @72
  glutSetKeyRepeat@4=wine_glutSetKeyRepeat@4 @73
  glutSetMenu@4=wine_glutSetMenu@4 @74
  glutSetupVideoResizing@0=wine_glutSetupVideoResizing@0 @77
  glutSetWindow@4=wine_glutSetWindow@4 @75
  glutSetWindowTitle@4=wine_glutSetWindowTitle@4 @76
  glutShowOverlay@0=wine_glutShowOverlay@0 @78
  glutShowWindow@0=wine_glutShowWindow@0 @79
  glutSolidCone@24=wine_glutSolidCone@24 @80
  glutSolidCube@8=wine_glutSolidCube@8 @81
  glutSolidDodecahedron@0=wine_glutSolidDodecahedron@0 @82
  glutSolidIcosahedron@0=wine_glutSolidIcosahedron@0 @83
  glutSolidOctahedron@0=wine_glutSolidOctahedron@0 @84
  glutSolidSphere@16=wine_glutSolidSphere@16 @85
  glutSolidTeapot@8=wine_glutSolidTeapot@8 @86
  glutSolidTetrahedron@0=wine_glutSolidTetrahedron@0 @87
  glutSolidTorus@24=wine_glutSolidTorus@24 @88
  glutSpaceballButtonFunc@4=wine_glutSpaceballButtonFunc@4 @89
  glutSpaceballMotionFunc@4=wine_glutSpaceballMotionFunc@4 @90
  glutSpaceballRotateFunc@4=wine_glutSpaceballRotateFunc@4 @91
  glutSpecialFunc@4=wine_glutSpecialFunc@4 @92
  glutSpecialUpFunc@4=wine_glutSpecialUpFunc@4 @93
  glutStopVideoResizing@0=wine_glutStopVideoResizing@0 @94
  glutStrokeCharacter@8=wine_glutStrokeCharacter@8 @95
  glutStrokeLength@8=wine_glutStrokeLength@8 @96
  glutStrokeWidth@8=wine_glutStrokeWidth@8 @97
  glutSwapBuffers@0=wine_glutSwapBuffers@0 @98
  glutTabletButtonFunc@4=wine_glutTabletButtonFunc@4 @99
  glutTabletMotionFunc@4=wine_glutTabletMotionFunc@4 @100
  glutTimerFunc@12=wine_glutTimerFunc@12 @101
  glutUseLayer@4=wine_glutUseLayer@4 @102
  glutVideoPan@16=wine_glutVideoPan@16 @103
  glutVideoResizeGet@4=wine_glutVideoResizeGet@4 @105
  glutVideoResize@16=wine_glutVideoResize@16 @104
  glutVisibilityFunc@4=wine_glutVisibilityFunc@4 @106
  glutWarpPointer@8=wine_glutWarpPointer@8 @107
  glutWindowStatusFunc@4=wine_glutWindowStatusFunc@4 @108
  glutWireCone@24=wine_glutWireCone@24 @109
  glutWireCube@8=wine_glutWireCube@8 @110
  glutWireDodecahedron@0=wine_glutWireDodecahedron@0 @111
  glutWireIcosahedron@0=wine_glutWireIcosahedron@0 @112
  glutWireOctahedron@0=wine_glutWireOctahedron@0 @113
  glutWireSphere@16=wine_glutWireSphere@16 @114
  glutWireTeapot@8=wine_glutWireTeapot@8 @115
  glutWireTetrahedron@0=wine_glutWireTetrahedron@0 @116
  glutWireTorus@24=wine_glutWireTorus@24 @117
