; File generated automatically from amstream/amstream.spec; do not edit!

LIBRARY amstream.dll

EXPORTS
  DllCanUnloadNow@0=AMSTREAM_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=AMSTREAM_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=AMSTREAM_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=AMSTREAM_DllUnregisterServer@0 @4 PRIVATE
