; File generated automatically from dmusic/dmusic.spec; do not edit!

LIBRARY dmusic.dll

EXPORTS
  DllCanUnloadNow@0=DMUSIC_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMUSIC_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMUSIC_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMUSIC_DllUnregisterServer@0 @4 PRIVATE
