; File generated automatically from comcat/comcat.spec; do not edit!

LIBRARY comcat.dll

EXPORTS
  DllCanUnloadNow@0=COMCAT_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=COMCAT_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=COMCAT_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=COMCAT_DllUnregisterServer@0 @4 PRIVATE
