; File generated automatically from dinput8/dinput8.spec; do not edit!

LIBRARY dinput8.dll

EXPORTS
  DirectInput8Create@20 @1
  DllCanUnloadNow@0=DINPUT8_DllCanUnloadNow@0 @2 PRIVATE
  DllGetClassObject@12=DINPUT8_DllGetClassObject@12 @3 PRIVATE
  DllRegisterServer@0=DINPUT8_DllRegisterServer@0 @4 PRIVATE
  DllUnregisterServer@0=DINPUT8_DllUnregisterServer@0 @5 PRIVATE
