; File generated automatically from msvideo/msvfw32.spec; do not edit!

LIBRARY msvfw32.dll

EXPORTS
  VideoForWindowsVersion@0 @2
  DrawDibBegin@32 @3
  DrawDibClose@4 @5
  DrawDibDraw@52 @6
  DrawDibEnd@4 @7
  DrawDibGetPalette@4 @9
  DrawDibOpen@0 @10
  DrawDibRealize@12 @12
  DrawDibSetPalette@8 @13
  DrawDibStart@8 @14
  DrawDibStop@4 @15
  GetOpenFileNamePreviewA@4 @18
  GetOpenFileNamePreviewW@4 @19
  GetSaveFileNamePreviewA@4 @20
  GetSaveFileNamePreviewW@4 @21
  ICClose@4 @22
  ICCompress @23
  ICCompressorChoose@24 @24
  ICCompressorFree@4 @25
  ICDecompress @26
  ICDraw @27
  ICDrawBegin @28
  ICGetDisplayFormat@24 @29
  ICGetInfo@12 @30
  ICImageCompress@28 @31
  ICImageDecompress@20 @32
  ICInfo@12 @33
  ICInstall@20 @34
  ICLocate@20 @35
  ICOpen@12 @37
  ICOpenFunction@16 @38
  ICRemove@12 @39
  ICSendMessage@16 @40
  MCIWndCreate=MCIWndCreateA @44
  MCIWndCreateA @45
  MCIWndCreateW @46
  MCIWndRegisterClass @47
