; File generated automatically from iphlpapi/iphlpapi.spec; do not edit!

LIBRARY iphlpapi.dll

EXPORTS
  AddIPAddress@20 @1
  AllocateAndGetIfTableFromStack@16 @3
  AllocateAndGetIpAddrTableFromStack@16 @4
  AllocateAndGetIpForwardTableFromStack@16 @5
  AllocateAndGetIpNetTableFromStack@16 @6
  AllocateAndGetTcpTableFromStack@16 @7
  AllocateAndGetUdpTableFromStack@16 @8
  CreateIpForwardEntry@4 @9
  CreateIpNetEntry@4 @10
  CreateProxyArpEntry@12 @11
  DeleteIPAddress@4 @12
  DeleteIpForwardEntry@4 @13
  DeleteIpNetEntry@4 @14
  DeleteProxyArpEntry@12 @15
  EnableRouter@8 @16
  FlushIpNetTable@4 @17
  GetAdapterIndex@8 @19
  GetAdaptersInfo@8 @21
  GetBestInterface@8 @22
  GetBestRoute@12 @24
  GetFriendlyIfIndex@4 @26
  GetIcmpStatistics@4 @27
  GetIfEntry@4 @29
  GetIfTable@12 @31
  GetInterfaceInfo@8 @34
  GetIpAddrTable@12 @35
  GetIpForwardTable@12 @37
  GetIpNetTable@12 @39
  GetIpStatistics@4 @41
  GetNetworkParams@8 @43
  GetNumberOfInterfaces@4 @44
  GetPerAdapterInfo@12 @45
  GetRTTAndHopCount@16 @46
  GetTcpStatistics@4 @47
  GetTcpTable@12 @49
  GetUdpStatistics@4 @51
  GetUdpTable@12 @53
  GetUniDirectionalAdapterInfo@8 @55
  IpReleaseAddress@4 @71
  IpRenewAddress@4 @72
  NotifyAddrChange@8 @80
  NotifyRouteChange@8 @81
  SendARP@16 @83
  SetIfEntry@4 @86
  SetIpForwardEntry@4 @88
  SetIpNetEntry@4 @91
  SetIpStatistics@4 @94
  SetIpTTL@4 @96
  SetTcpEntry@4 @99
  UnenableRouter@8 @101
