; File generated automatically from lzexpand/lz32.spec; do not edit!

LIBRARY lz32.dll

EXPORTS
  CopyLZFile@8 @1
  GetExpandedNameA@8 @2
  GetExpandedNameW@8 @3
  LZClose@4 @4
  LZCopy@8 @5
  LZDone@0 @6
  LZInit@4 @7
  LZOpenFileA@12 @8
  LZOpenFileW@12 @9
  LZRead@12 @10
  LZSeek@12 @11
  LZStart@0 @12
