; File generated automatically from dmloader/dmloader.spec; do not edit!

LIBRARY dmloader.dll

EXPORTS
  DllCanUnloadNow@0=DMLOADER_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMLOADER_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMLOADER_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMLOADER_DllUnregisterServer@0 @4 PRIVATE
