; File generated automatically from version/version.spec; do not edit!

LIBRARY version.dll

EXPORTS
  GetFileVersionInfoA@16 @1
  GetFileVersionInfoSizeA@8 @2
  GetFileVersionInfoSizeW@8 @3
  GetFileVersionInfoW@16 @4
  VerFindFileA@32 @6
  VerFindFileW@32 @7
  VerInstallFileA@32 @8
  VerInstallFileW@32 @9
  VerLanguageNameA@12=kernel32.VerLanguageNameA @10
  VerLanguageNameW@12=kernel32.VerLanguageNameW @11
  VerQueryValueA@16 @12
  VerQueryValueW@16 @13
