; File generated automatically from uxtheme/uxtheme.spec; do not edit!

LIBRARY uxtheme.dll

EXPORTS
  QueryThemeServices@0 @1 NONAME
  OpenThemeFile@20 @2 NONAME
  CloseThemeFile@4 @3 NONAME
  ApplyTheme@12 @4 NONAME
  GetThemeDefaults@20 @7 NONAME
  EnumThemes@12 @8 NONAME
  EnumThemeColors@16 @9 NONAME
  EnumThemeSizes@16 @10 NONAME
  ParseThemeIniFile@16 @11 NONAME
  CheckThemeSignature@4 @29 NONAME
  CloseThemeData@4 @5
  DrawThemeBackground@24 @6
  DrawThemeBackgroundEx@24 @12
  DrawThemeEdge@32 @37
  DrawThemeIcon@28 @38
  DrawThemeParentBackground@12 @39
  DrawThemeText@36 @40
  EnableThemeDialogTexture@8 @41
  EnableTheming@4 @42
  GetCurrentThemeName@24 @47
  GetThemeAppProperties@0 @49
  GetThemeBackgroundContentRect@24 @50
  GetThemeBackgroundExtent@24 @51
  GetThemeBackgroundRegion@24 @52
  GetThemeBool@20 @53
  GetThemeColor@20 @54
  GetThemeDocumentationProperty@16 @55
  GetThemeEnumValue@20 @56
  GetThemeFilename@24 @57
  GetThemeFont@24 @58
  GetThemeInt@20 @59
  GetThemeIntList@20 @64
  GetThemeMargins@28 @65
  GetThemeMetric@24 @66
  GetThemePartSize@28 @67
  GetThemePosition@20 @68
  GetThemePropertyOrigin@20 @69
  GetThemeRect@20 @70
  GetThemeString@24 @71
  GetThemeSysBool@8 @72
  GetThemeSysColor@8 @73
  GetThemeSysColorBrush@8 @74
  GetThemeSysFont@12 @75
  GetThemeSysInt@12 @76
  GetThemeSysSize@8 @77
  GetThemeSysString@16 @78
  GetThemeTextExtent@36 @79
  GetThemeTextMetrics@20 @80
  GetWindowTheme@4 @81
  HitTestThemeBackground@40 @82
  IsAppThemed@0 @83
  IsThemeActive@0 @84
  IsThemeBackgroundPartiallyTransparent@12 @85
  IsThemeDialogTextureEnabled@0 @86
  IsThemePartDefined@12 @87
  OpenThemeData@8 @88
  SetThemeAppProperties@4 @89
  SetWindowTheme@12 @90
