; File generated automatically from opengl32/opengl32.spec; do not edit!

LIBRARY opengl32.dll

EXPORTS
  wglCreateContext@4 @379
  wglCreateLayerContext@8 @380
  wglCopyContext@12 @378
  wglDeleteContext@4 @381
  wglDescribeLayerPlane@20 @382
  wglGetCurrentContext@0 @384
  wglGetCurrentDC@0 @385
  wglGetLayerPaletteEntries@20 @387
  wglGetProcAddress@4 @389
  wglMakeCurrent@8 @390
  wglRealizeLayerPalette@12 @391
  wglSetLayerPaletteEntries@20 @392
  wglShareLists@8 @394
  wglSwapLayerBuffers@8 @396
  wglUseFontBitmapsA@16 @397
  wglUseFontOutlinesA@32 @399
  wglUseFontBitmapsW@16 @398
  wglChoosePixelFormat@8=gdi32.ChoosePixelFormat @377
  wglDescribePixelFormat@16=gdi32.DescribePixelFormat @383
  wglGetPixelFormat@4=gdi32.GetPixelFormat @388
  wglSetPixelFormat@12=gdi32.SetPixelFormat @393
  wglSwapBuffers@4=gdi32.SwapBuffers @395
  glAccum@8=wine_glAccum@8 @1
  glAlphaFunc@8=wine_glAlphaFunc@8 @2
  glAreTexturesResident@12=wine_glAreTexturesResident@12 @3
  glArrayElement@4=wine_glArrayElement@4 @4
  glBegin@4=wine_glBegin@4 @5
  glBindTexture@8=wine_glBindTexture@8 @6
  glBitmap@28=wine_glBitmap@28 @7
  glBlendColor@16=wine_glBlendColor@16 @8
  glBlendEquation@4=wine_glBlendEquation@4 @9
  glBlendFunc@8=wine_glBlendFunc@8 @10
  glCallList@4=wine_glCallList@4 @11
  glCallLists@12=wine_glCallLists@12 @12
  glClear@4=wine_glClear@4 @13
  glClearAccum@16=wine_glClearAccum@16 @14
  glClearColor@16=wine_glClearColor@16 @15
  glClearDepth@8=wine_glClearDepth@8 @16
  glClearIndex@4=wine_glClearIndex@4 @17
  glClearStencil@4=wine_glClearStencil@4 @18
  glClipPlane@8=wine_glClipPlane@8 @19
  glColor3b@12=wine_glColor3b@12 @20
  glColor3bv@4=wine_glColor3bv@4 @21
  glColor3d@24=wine_glColor3d@24 @22
  glColor3dv@4=wine_glColor3dv@4 @23
  glColor3f@12=wine_glColor3f@12 @24
  glColor3fv@4=wine_glColor3fv@4 @25
  glColor3i@12=wine_glColor3i@12 @26
  glColor3iv@4=wine_glColor3iv@4 @27
  glColor3s@12=wine_glColor3s@12 @28
  glColor3sv@4=wine_glColor3sv@4 @29
  glColor3ub@12=wine_glColor3ub@12 @30
  glColor3ubv@4=wine_glColor3ubv@4 @31
  glColor3ui@12=wine_glColor3ui@12 @32
  glColor3uiv@4=wine_glColor3uiv@4 @33
  glColor3us@12=wine_glColor3us@12 @34
  glColor3usv@4=wine_glColor3usv@4 @35
  glColor4b@16=wine_glColor4b@16 @36
  glColor4bv@4=wine_glColor4bv@4 @37
  glColor4d@32=wine_glColor4d@32 @38
  glColor4dv@4=wine_glColor4dv@4 @39
  glColor4f@16=wine_glColor4f@16 @40
  glColor4fv@4=wine_glColor4fv@4 @41
  glColor4i@16=wine_glColor4i@16 @42
  glColor4iv@4=wine_glColor4iv@4 @43
  glColor4s@16=wine_glColor4s@16 @44
  glColor4sv@4=wine_glColor4sv@4 @45
  glColor4ub@16=wine_glColor4ub@16 @46
  glColor4ubv@4=wine_glColor4ubv@4 @47
  glColor4ui@16=wine_glColor4ui@16 @48
  glColor4uiv@4=wine_glColor4uiv@4 @49
  glColor4us@16=wine_glColor4us@16 @50
  glColor4usv@4=wine_glColor4usv@4 @51
  glColorMask@16=wine_glColorMask@16 @52
  glColorMaterial@8=wine_glColorMaterial@8 @53
  glColorPointer@16=wine_glColorPointer@16 @54
  glColorSubTable@24=wine_glColorSubTable@24 @55
  glColorTable@24=wine_glColorTable@24 @56
  glColorTableParameterfv@12=wine_glColorTableParameterfv@12 @57
  glColorTableParameteriv@12=wine_glColorTableParameteriv@12 @58
  glConvolutionFilter1D@24=wine_glConvolutionFilter1D@24 @59
  glConvolutionFilter2D@28=wine_glConvolutionFilter2D@28 @60
  glConvolutionParameterf@12=wine_glConvolutionParameterf@12 @61
  glConvolutionParameterfv@12=wine_glConvolutionParameterfv@12 @62
  glConvolutionParameteri@12=wine_glConvolutionParameteri@12 @63
  glConvolutionParameteriv@12=wine_glConvolutionParameteriv@12 @64
  glCopyColorSubTable@20=wine_glCopyColorSubTable@20 @65
  glCopyColorTable@20=wine_glCopyColorTable@20 @66
  glCopyConvolutionFilter1D@20=wine_glCopyConvolutionFilter1D@20 @67
  glCopyConvolutionFilter2D@24=wine_glCopyConvolutionFilter2D@24 @68
  glCopyPixels@20=wine_glCopyPixels@20 @69
  glCopyTexImage1D@28=wine_glCopyTexImage1D@28 @70
  glCopyTexImage2D@32=wine_glCopyTexImage2D@32 @71
  glCopyTexSubImage1D@24=wine_glCopyTexSubImage1D@24 @72
  glCopyTexSubImage2D@32=wine_glCopyTexSubImage2D@32 @73
  glCopyTexSubImage3D@36=wine_glCopyTexSubImage3D@36 @74
  glCullFace@4=wine_glCullFace@4 @75
  glDeleteLists@8=wine_glDeleteLists@8 @76
  glDeleteTextures@8=wine_glDeleteTextures@8 @77
  glDepthFunc@4=wine_glDepthFunc@4 @78
  glDepthMask@4=wine_glDepthMask@4 @79
  glDepthRange@16=wine_glDepthRange@16 @80
  glDisable@4=wine_glDisable@4 @81
  glDisableClientState@4=wine_glDisableClientState@4 @82
  glDrawArrays@12=wine_glDrawArrays@12 @83
  glDrawBuffer@4=wine_glDrawBuffer@4 @84
  glDrawElements@16=wine_glDrawElements@16 @85
  glDrawPixels@20=wine_glDrawPixels@20 @86
  glDrawRangeElements@24=wine_glDrawRangeElements@24 @87
  glEdgeFlag@4=wine_glEdgeFlag@4 @88
  glEdgeFlagPointer@8=wine_glEdgeFlagPointer@8 @89
  glEdgeFlagv@4=wine_glEdgeFlagv@4 @90
  glEnable@4=wine_glEnable@4 @91
  glEnableClientState@4=wine_glEnableClientState@4 @92
  glEnd@0=wine_glEnd@0 @93
  glEndList@0=wine_glEndList@0 @94
  glEvalCoord1d@8=wine_glEvalCoord1d@8 @95
  glEvalCoord1dv@4=wine_glEvalCoord1dv@4 @96
  glEvalCoord1f@4=wine_glEvalCoord1f@4 @97
  glEvalCoord1fv@4=wine_glEvalCoord1fv@4 @98
  glEvalCoord2d@16=wine_glEvalCoord2d@16 @99
  glEvalCoord2dv@4=wine_glEvalCoord2dv@4 @100
  glEvalCoord2f@8=wine_glEvalCoord2f@8 @101
  glEvalCoord2fv@4=wine_glEvalCoord2fv@4 @102
  glEvalMesh1@12=wine_glEvalMesh1@12 @103
  glEvalMesh2@20=wine_glEvalMesh2@20 @104
  glEvalPoint1@4=wine_glEvalPoint1@4 @105
  glEvalPoint2@8=wine_glEvalPoint2@8 @106
  glFeedbackBuffer@12=wine_glFeedbackBuffer@12 @107
  glFinish@0=wine_glFinish@0 @108
  glFlush@0=wine_glFlush@0 @109
  glFogf@8=wine_glFogf@8 @110
  glFogfv@8=wine_glFogfv@8 @111
  glFogi@8=wine_glFogi@8 @112
  glFogiv@8=wine_glFogiv@8 @113
  glFrontFace@4=wine_glFrontFace@4 @114
  glFrustum@48=wine_glFrustum@48 @115
  glGenLists@4=wine_glGenLists@4 @116
  glGenTextures@8=wine_glGenTextures@8 @117
  glGetBooleanv@8=wine_glGetBooleanv@8 @118
  glGetClipPlane@8=wine_glGetClipPlane@8 @119
  glGetColorTable@16=wine_glGetColorTable@16 @120
  glGetColorTableParameterfv@12=wine_glGetColorTableParameterfv@12 @121
  glGetColorTableParameteriv@12=wine_glGetColorTableParameteriv@12 @122
  glGetConvolutionFilter@16=wine_glGetConvolutionFilter@16 @123
  glGetConvolutionParameterfv@12=wine_glGetConvolutionParameterfv@12 @124
  glGetConvolutionParameteriv@12=wine_glGetConvolutionParameteriv@12 @125
  glGetDoublev@8=wine_glGetDoublev@8 @126
  glGetError@0=wine_glGetError@0 @127
  glGetFloatv@8=wine_glGetFloatv@8 @128
  glGetHistogram@20=wine_glGetHistogram@20 @129
  glGetHistogramParameterfv@12=wine_glGetHistogramParameterfv@12 @130
  glGetHistogramParameteriv@12=wine_glGetHistogramParameteriv@12 @131
  glGetIntegerv@8=wine_glGetIntegerv@8 @132
  glGetLightfv@12=wine_glGetLightfv@12 @135
  glGetLightiv@12=wine_glGetLightiv@12 @136
  glGetMapdv@12=wine_glGetMapdv@12 @137
  glGetMapfv@12=wine_glGetMapfv@12 @138
  glGetMapiv@12=wine_glGetMapiv@12 @139
  glGetMaterialfv@12=wine_glGetMaterialfv@12 @140
  glGetMaterialiv@12=wine_glGetMaterialiv@12 @141
  glGetMinmax@20=wine_glGetMinmax@20 @142
  glGetMinmaxParameterfv@12=wine_glGetMinmaxParameterfv@12 @143
  glGetMinmaxParameteriv@12=wine_glGetMinmaxParameteriv@12 @144
  glGetPixelMapfv@8=wine_glGetPixelMapfv@8 @145
  glGetPixelMapuiv@8=wine_glGetPixelMapuiv@8 @146
  glGetPixelMapusv@8=wine_glGetPixelMapusv@8 @147
  glGetPointerv@8=wine_glGetPointerv@8 @148
  glGetPolygonStipple@4=wine_glGetPolygonStipple@4 @149
  glGetSeparableFilter@24=wine_glGetSeparableFilter@24 @150
  glGetString@4=wine_glGetString@4 @151
  glGetTexEnvfv@12=wine_glGetTexEnvfv@12 @152
  glGetTexEnviv@12=wine_glGetTexEnviv@12 @153
  glGetTexGendv@12=wine_glGetTexGendv@12 @154
  glGetTexGenfv@12=wine_glGetTexGenfv@12 @155
  glGetTexGeniv@12=wine_glGetTexGeniv@12 @156
  glGetTexImage@20=wine_glGetTexImage@20 @157
  glGetTexLevelParameterfv@16=wine_glGetTexLevelParameterfv@16 @158
  glGetTexLevelParameteriv@16=wine_glGetTexLevelParameteriv@16 @159
  glGetTexParameterfv@12=wine_glGetTexParameterfv@12 @160
  glGetTexParameteriv@12=wine_glGetTexParameteriv@12 @161
  glHint@8=wine_glHint@8 @162
  glHistogram@16=wine_glHistogram@16 @163
  glIndexMask@4=wine_glIndexMask@4 @164
  glIndexPointer@12=wine_glIndexPointer@12 @165
  glIndexd@8=wine_glIndexd@8 @166
  glIndexdv@4=wine_glIndexdv@4 @167
  glIndexf@4=wine_glIndexf@4 @168
  glIndexfv@4=wine_glIndexfv@4 @169
  glIndexi@4=wine_glIndexi@4 @170
  glIndexiv@4=wine_glIndexiv@4 @171
  glIndexs@4=wine_glIndexs@4 @172
  glIndexsv@4=wine_glIndexsv@4 @173
  glIndexub@4=wine_glIndexub@4 @174
  glIndexubv@4=wine_glIndexubv@4 @175
  glInitNames@0=wine_glInitNames@0 @176
  glInterleavedArrays@12=wine_glInterleavedArrays@12 @177
  glIsEnabled@4=wine_glIsEnabled@4 @178
  glIsList@4=wine_glIsList@4 @179
  glIsTexture@4=wine_glIsTexture@4 @180
  glLightModelf@8=wine_glLightModelf@8 @181
  glLightModelfv@8=wine_glLightModelfv@8 @182
  glLightModeli@8=wine_glLightModeli@8 @183
  glLightModeliv@8=wine_glLightModeliv@8 @184
  glLightf@12=wine_glLightf@12 @185
  glLightfv@12=wine_glLightfv@12 @186
  glLighti@12=wine_glLighti@12 @187
  glLightiv@12=wine_glLightiv@12 @188
  glLineStipple@8=wine_glLineStipple@8 @189
  glLineWidth@4=wine_glLineWidth@4 @190
  glListBase@4=wine_glListBase@4 @191
  glLoadIdentity@0=wine_glLoadIdentity@0 @192
  glLoadMatrixd@4=wine_glLoadMatrixd@4 @193
  glLoadMatrixf@4=wine_glLoadMatrixf@4 @194
  glLoadName@4=wine_glLoadName@4 @195
  glLogicOp@4=wine_glLogicOp@4 @196
  glMap1d@32=wine_glMap1d@32 @197
  glMap1f@24=wine_glMap1f@24 @198
  glMap2d@56=wine_glMap2d@56 @199
  glMap2f@40=wine_glMap2f@40 @200
  glMapGrid1d@20=wine_glMapGrid1d@20 @201
  glMapGrid1f@12=wine_glMapGrid1f@12 @202
  glMapGrid2d@40=wine_glMapGrid2d@40 @203
  glMapGrid2f@24=wine_glMapGrid2f@24 @204
  glMaterialf@12=wine_glMaterialf@12 @205
  glMaterialfv@12=wine_glMaterialfv@12 @206
  glMateriali@12=wine_glMateriali@12 @207
  glMaterialiv@12=wine_glMaterialiv@12 @208
  glMatrixMode@4=wine_glMatrixMode@4 @209
  glMinmax@12=wine_glMinmax@12 @210
  glMultMatrixd@4=wine_glMultMatrixd@4 @211
  glMultMatrixf@4=wine_glMultMatrixf@4 @212
  glNewList@8=wine_glNewList@8 @213
  glNormal3b@12=wine_glNormal3b@12 @214
  glNormal3bv@4=wine_glNormal3bv@4 @215
  glNormal3d@24=wine_glNormal3d@24 @216
  glNormal3dv@4=wine_glNormal3dv@4 @217
  glNormal3f@12=wine_glNormal3f@12 @218
  glNormal3fv@4=wine_glNormal3fv@4 @219
  glNormal3i@12=wine_glNormal3i@12 @220
  glNormal3iv@4=wine_glNormal3iv@4 @221
  glNormal3s@12=wine_glNormal3s@12 @222
  glNormal3sv@4=wine_glNormal3sv@4 @223
  glNormalPointer@12=wine_glNormalPointer@12 @224
  glOrtho@48=wine_glOrtho@48 @225
  glPassThrough@4=wine_glPassThrough@4 @226
  glPixelMapfv@12=wine_glPixelMapfv@12 @227
  glPixelMapuiv@12=wine_glPixelMapuiv@12 @228
  glPixelMapusv@12=wine_glPixelMapusv@12 @229
  glPixelStoref@8=wine_glPixelStoref@8 @230
  glPixelStorei@8=wine_glPixelStorei@8 @231
  glPixelTransferf@8=wine_glPixelTransferf@8 @232
  glPixelTransferi@8=wine_glPixelTransferi@8 @233
  glPixelZoom@8=wine_glPixelZoom@8 @234
  glPointSize@4=wine_glPointSize@4 @235
  glPolygonMode@8=wine_glPolygonMode@8 @236
  glPolygonOffset@8=wine_glPolygonOffset@8 @237
  glPolygonStipple@4=wine_glPolygonStipple@4 @238
  glPopAttrib@0=wine_glPopAttrib@0 @239
  glPopClientAttrib@0=wine_glPopClientAttrib@0 @240
  glPopMatrix@0=wine_glPopMatrix@0 @241
  glPopName@0=wine_glPopName@0 @242
  glPrioritizeTextures@12=wine_glPrioritizeTextures@12 @243
  glPushAttrib@4=wine_glPushAttrib@4 @244
  glPushClientAttrib@4=wine_glPushClientAttrib@4 @245
  glPushMatrix@0=wine_glPushMatrix@0 @246
  glPushName@4=wine_glPushName@4 @247
  glRasterPos2d@16=wine_glRasterPos2d@16 @248
  glRasterPos2dv@4=wine_glRasterPos2dv@4 @249
  glRasterPos2f@8=wine_glRasterPos2f@8 @250
  glRasterPos2fv@4=wine_glRasterPos2fv@4 @251
  glRasterPos2i@8=wine_glRasterPos2i@8 @252
  glRasterPos2iv@4=wine_glRasterPos2iv@4 @253
  glRasterPos2s@8=wine_glRasterPos2s@8 @254
  glRasterPos2sv@4=wine_glRasterPos2sv@4 @255
  glRasterPos3d@24=wine_glRasterPos3d@24 @256
  glRasterPos3dv@4=wine_glRasterPos3dv@4 @257
  glRasterPos3f@12=wine_glRasterPos3f@12 @258
  glRasterPos3fv@4=wine_glRasterPos3fv@4 @259
  glRasterPos3i@12=wine_glRasterPos3i@12 @260
  glRasterPos3iv@4=wine_glRasterPos3iv@4 @261
  glRasterPos3s@12=wine_glRasterPos3s@12 @262
  glRasterPos3sv@4=wine_glRasterPos3sv@4 @263
  glRasterPos4d@32=wine_glRasterPos4d@32 @264
  glRasterPos4dv@4=wine_glRasterPos4dv@4 @265
  glRasterPos4f@16=wine_glRasterPos4f@16 @266
  glRasterPos4fv@4=wine_glRasterPos4fv@4 @267
  glRasterPos4i@16=wine_glRasterPos4i@16 @268
  glRasterPos4iv@4=wine_glRasterPos4iv@4 @269
  glRasterPos4s@16=wine_glRasterPos4s@16 @270
  glRasterPos4sv@4=wine_glRasterPos4sv@4 @271
  glReadBuffer@4=wine_glReadBuffer@4 @272
  glReadPixels@28=wine_glReadPixels@28 @273
  glRectd@32=wine_glRectd@32 @274
  glRectdv@8=wine_glRectdv@8 @275
  glRectf@16=wine_glRectf@16 @276
  glRectfv@8=wine_glRectfv@8 @277
  glRecti@16=wine_glRecti@16 @278
  glRectiv@8=wine_glRectiv@8 @279
  glRects@16=wine_glRects@16 @280
  glRectsv@8=wine_glRectsv@8 @281
  glRenderMode@4=wine_glRenderMode@4 @282
  glResetHistogram@4=wine_glResetHistogram@4 @283
  glResetMinmax@4=wine_glResetMinmax@4 @284
  glRotated@32=wine_glRotated@32 @285
  glRotatef@16=wine_glRotatef@16 @286
  glScaled@24=wine_glScaled@24 @287
  glScalef@12=wine_glScalef@12 @288
  glScissor@16=wine_glScissor@16 @289
  glSelectBuffer@8=wine_glSelectBuffer@8 @290
  glSeparableFilter2D@32=wine_glSeparableFilter2D@32 @291
  glShadeModel@4=wine_glShadeModel@4 @292
  glStencilFunc@12=wine_glStencilFunc@12 @293
  glStencilMask@4=wine_glStencilMask@4 @294
  glStencilOp@12=wine_glStencilOp@12 @295
  glTexCoord1d@8=wine_glTexCoord1d@8 @296
  glTexCoord1dv@4=wine_glTexCoord1dv@4 @297
  glTexCoord1f@4=wine_glTexCoord1f@4 @298
  glTexCoord1fv@4=wine_glTexCoord1fv@4 @299
  glTexCoord1i@4=wine_glTexCoord1i@4 @300
  glTexCoord1iv@4=wine_glTexCoord1iv@4 @301
  glTexCoord1s@4=wine_glTexCoord1s@4 @302
  glTexCoord1sv@4=wine_glTexCoord1sv@4 @303
  glTexCoord2d@16=wine_glTexCoord2d@16 @304
  glTexCoord2dv@4=wine_glTexCoord2dv@4 @305
  glTexCoord2f@8=wine_glTexCoord2f@8 @306
  glTexCoord2fv@4=wine_glTexCoord2fv@4 @307
  glTexCoord2i@8=wine_glTexCoord2i@8 @308
  glTexCoord2iv@4=wine_glTexCoord2iv@4 @309
  glTexCoord2s@8=wine_glTexCoord2s@8 @310
  glTexCoord2sv@4=wine_glTexCoord2sv@4 @311
  glTexCoord3d@24=wine_glTexCoord3d@24 @312
  glTexCoord3dv@4=wine_glTexCoord3dv@4 @313
  glTexCoord3f@12=wine_glTexCoord3f@12 @314
  glTexCoord3fv@4=wine_glTexCoord3fv@4 @315
  glTexCoord3i@12=wine_glTexCoord3i@12 @316
  glTexCoord3iv@4=wine_glTexCoord3iv@4 @317
  glTexCoord3s@12=wine_glTexCoord3s@12 @318
  glTexCoord3sv@4=wine_glTexCoord3sv@4 @319
  glTexCoord4d@32=wine_glTexCoord4d@32 @320
  glTexCoord4dv@4=wine_glTexCoord4dv@4 @321
  glTexCoord4f@16=wine_glTexCoord4f@16 @322
  glTexCoord4fv@4=wine_glTexCoord4fv@4 @323
  glTexCoord4i@16=wine_glTexCoord4i@16 @324
  glTexCoord4iv@4=wine_glTexCoord4iv@4 @325
  glTexCoord4s@16=wine_glTexCoord4s@16 @326
  glTexCoord4sv@4=wine_glTexCoord4sv@4 @327
  glTexCoordPointer@16=wine_glTexCoordPointer@16 @328
  glTexEnvf@12=wine_glTexEnvf@12 @329
  glTexEnvfv@12=wine_glTexEnvfv@12 @330
  glTexEnvi@12=wine_glTexEnvi@12 @331
  glTexEnviv@12=wine_glTexEnviv@12 @332
  glTexGend@16=wine_glTexGend@16 @333
  glTexGendv@12=wine_glTexGendv@12 @334
  glTexGenf@12=wine_glTexGenf@12 @335
  glTexGenfv@12=wine_glTexGenfv@12 @336
  glTexGeni@12=wine_glTexGeni@12 @337
  glTexGeniv@12=wine_glTexGeniv@12 @338
  glTexImage1D@32=wine_glTexImage1D@32 @339
  glTexImage2D@36=wine_glTexImage2D@36 @340
  glTexImage3D@40=wine_glTexImage3D@40 @341
  glTexParameterf@12=wine_glTexParameterf@12 @342
  glTexParameterfv@12=wine_glTexParameterfv@12 @343
  glTexParameteri@12=wine_glTexParameteri@12 @344
  glTexParameteriv@12=wine_glTexParameteriv@12 @345
  glTexSubImage1D@28=wine_glTexSubImage1D@28 @346
  glTexSubImage2D@36=wine_glTexSubImage2D@36 @347
  glTexSubImage3D@44=wine_glTexSubImage3D@44 @348
  glTranslated@24=wine_glTranslated@24 @349
  glTranslatef@12=wine_glTranslatef@12 @350
  glVertex2d@16=wine_glVertex2d@16 @351
  glVertex2dv@4=wine_glVertex2dv@4 @352
  glVertex2f@8=wine_glVertex2f@8 @353
  glVertex2fv@4=wine_glVertex2fv@4 @354
  glVertex2i@8=wine_glVertex2i@8 @355
  glVertex2iv@4=wine_glVertex2iv@4 @356
  glVertex2s@8=wine_glVertex2s@8 @357
  glVertex2sv@4=wine_glVertex2sv@4 @358
  glVertex3d@24=wine_glVertex3d@24 @359
  glVertex3dv@4=wine_glVertex3dv@4 @360
  glVertex3f@12=wine_glVertex3f@12 @361
  glVertex3fv@4=wine_glVertex3fv@4 @362
  glVertex3i@12=wine_glVertex3i@12 @363
  glVertex3iv@4=wine_glVertex3iv@4 @364
  glVertex3s@12=wine_glVertex3s@12 @365
  glVertex3sv@4=wine_glVertex3sv@4 @366
  glVertex4d@32=wine_glVertex4d@32 @367
  glVertex4dv@4=wine_glVertex4dv@4 @368
  glVertex4f@16=wine_glVertex4f@16 @369
  glVertex4fv@4=wine_glVertex4fv@4 @370
  glVertex4i@16=wine_glVertex4i@16 @371
  glVertex4iv@4=wine_glVertex4iv@4 @372
  glVertex4s@16=wine_glVertex4s@16 @373
  glVertex4sv@4=wine_glVertex4sv@4 @374
  glVertexPointer@16=wine_glVertexPointer@16 @375
  glViewport@16=wine_glViewport@16 @376
