; File generated automatically from ole32/ole32.spec; do not edit!

LIBRARY ole32.dll

EXPORTS
  BindMoniker@16 @1
  CLSIDFromProgID@8 @6
  CLSIDFromString@8 @7
  CoBuildVersion@0 @9
  CoCreateFreeThreadedMarshaler@8 @11
  CoCreateGuid@4 @12
  CoCreateInstance@20 @13
  CoCreateInstanceEx@24 @14
  CoDisconnectObject@8 @15
  CoDosDateTimeToFileTime@12=kernel32.DosDateTimeToFileTime @16
  CoFileTimeNow@4 @17
  CoFileTimeToDosDateTime@12=kernel32.FileTimeToDosDateTime @18
  CoFreeAllLibraries@0 @19
  CoFreeLibrary@4 @20
  CoFreeUnusedLibraries@0 @21
  CoGetClassObject@20 @24
  CoGetCurrentProcess@0 @26
  CoGetInterfaceAndReleaseStream@12 @29
  CoGetMalloc@8 @30
  CoGetMarshalSizeMax@24 @31
  CoGetPSClsid@8 @33
  CoGetStandardMarshal@24 @34
  CoGetState@4 @35
  CoGetTreatAsClass@8 @37
  CoInitialize@4 @39
  CoInitializeEx@8 @40
  CoInitializeSecurity@36 @41
  CoInitializeWOW@8 @42
  CoIsOle1Class@4 @44
  CoLoadLibrary@8 @45
  CoLockObjectExternal@12 @46
  CoMarshalInterThreadInterfaceInStream@12 @48
  CoMarshalInterface@24 @49
  CoRegisterClassObject@20 @55
  CoRegisterMallocSpy@4 @56
  CoRegisterMessageFilter@8 @57
  CoReleaseMarshalData@4 @60
  CoResumeClassObjects@0 @62
  CoRevokeClassObject@4 @64
  CoRevokeMallocSpy@0 @65
  CoSetState@4 @67
  CoTaskMemAlloc@4 @70
  CoTaskMemFree@4 @71
  CoTaskMemRealloc@8 @72
  CoTreatAsClass@8 @73
  CoUninitialize@0 @74
  CoUnmarshalInterface@12 @77
  CreateAntiMoniker@4 @78
  CreateBindCtx@8 @79
  CreateClassMoniker@8 @80
  CreateDataAdviseHolder@4 @81
  CreateDataCache@16 @82
  CreateErrorInfo@4 @83
  CreateFileMoniker@8 @84
  CreateGenericComposite@12 @85
  CreateILockBytesOnHGlobal@12 @86
  CreateItemMoniker@12 @87
  CreateOleAdviseHolder@4 @89
  CreateStreamOnHGlobal@12 @91
  DllDebugObjectRPCHook@8 @92
  DllGetClassObject@12=OLE32_DllGetClassObject@12 @93 PRIVATE
  DllRegisterServer@0=OLE32_DllRegisterServer@0 @95 PRIVATE
  DllUnregisterServer@0=OLE32_DllUnregisterServer@0 @96 PRIVATE
  DoDragDrop@16 @97
  FreePropVariantArray@8 @99
  GetClassFile@8 @100
  GetConvertStg@4 @101
  GetErrorInfo@8 @103
  GetHGlobalFromILockBytes@8 @104
  GetHGlobalFromStream@8 @105
  GetRunningObjectTable@8 @107
  IIDFromString@8=CLSIDFromString@8 @148
  IsAccelerator@16 @150
  IsEqualGUID@8 @151
  IsValidInterface@4 @153
  MkParseDisplayName@16 @156
  MonikerCommonPrefixWith@12 @157
  OleBuildVersion@0 @159
  OleConvertIStorageToOLESTREAM@8 @160
  OleConvertOLESTREAMToIStorage@12 @162
  OleCreate@28 @164
  OleCreateDefaultHandler@16 @165
  OleCreateFromData@28 @168
  OleCreateFromFile@32 @170
  OleCreateLink@28 @172
  OleCreateLinkFromData@28 @174
  OleCreateLinkToFile@28 @176
  OleCreateMenuDescriptor@8 @178
  OleCreateStaticFromData@28 @179
  OleDestroyMenuDescriptor@4 @180
  OleDoAutoConvert@8 @181
  OleDraw@16 @182
  OleDuplicateData@12 @183
  OleFlushClipboard@0 @184
  OleGetAutoConvert@8 @185
  OleGetClipboard@4 @186
  OleGetIconOfClass@12 @187
  OleInitialize@4 @189
  OleInitializeWOW@4 @190
  OleIsCurrentClipboard@4 @191
  OleIsRunning@4 @192
  OleLoad@16 @193
  OleLoadFromStream@12 @194
  OleLockRunning@12 @195
  OleMetafilePictFromIconAndLabel@16 @196
  OleQueryCreateFromData@4 @198
  OleQueryLinkFromData@4 @199
  OleRegEnumFormatEtc@12 @200
  OleRegEnumVerbs@8 @201
  OleRegGetMiscStatus@12 @202
  OleRegGetUserType@12 @203
  OleRun@4 @204
  OleSave@12 @205
  OleSaveToStream@8 @206
  OleSetAutoConvert@8 @207
  OleSetClipboard@4 @208
  OleSetContainedObject@8 @209
  OleSetMenuDescriptor@20 @210
  OleTranslateAccelerator@12 @211
  OleUninitialize@0 @212
  ProgIDFromCLSID@8 @214
  PropVariantClear@4 @217
  PropVariantCopy@8 @218
  ReadClassStg@8 @219
  ReadClassStm@8 @220
  ReadFmtUserTypeStg@12 @221
  RegisterDragDrop@8 @224
  ReleaseStgMedium@4 @225
  RevokeDragDrop@4 @226
  SetConvertStg@8 @235
  SetErrorInfo@8 @237
  StgCreateDocfile@16 @238
  StgCreateDocfileOnILockBytes@16 @239
  StgCreateStorageEx@32 @240
  StgIsStorageFile@4 @243
  StgIsStorageILockBytes@4 @244
  StgOpenStorage@24 @246
  StgOpenStorageOnILockBytes@24 @248
  StgSetTimes@16 @249
  StringFromCLSID@8 @250
  StringFromGUID2@12 @251
  StringFromIID@8=StringFromCLSID@8 @252
  WriteClassStg@8 @262
  WriteClassStm@8 @263
  WriteFmtUserTypeStg@12 @264
