; File generated automatically from win32s/w32skrnl.spec; do not edit!

LIBRARY w32skrnl.dll

EXPORTS
  GetCurrentTask32@0 @3
  _kGetWin32sDirectory@0@0=GetWin32sDirectory@0 @14
  W32S_BackTo32@0=kernel32.W32S_BackTo32 @17
  _RtlNtStatusToDosError@4=ntdll.RtlNtStatusToDosError @30
