; File generated automatically from dinput/dinput.spec; do not edit!

LIBRARY dinput.dll

EXPORTS
  DirectInputCreateA@16 @1
  DirectInputCreateW@16 @3
  DirectInputCreateEx@20 @2
  DllCanUnloadNow@0=DINPUT_DllCanUnloadNow@0 @4 PRIVATE
  DllGetClassObject@12=DINPUT_DllGetClassObject@12 @5 PRIVATE
  DllRegisterServer@0=DINPUT_DllRegisterServer@0 @6 PRIVATE
  DllUnregisterServer@0=DINPUT_DllUnregisterServer@0 @7 PRIVATE
