; File generated automatically from ntdll/ntdll.spec; do not edit!

LIBRARY ntdll.dll

EXPORTS
  DbgBreakPoint@0 @19
  DbgPrint @20
  DbgPrintEx @21
  DbgUserBreakPoint@0 @28
  LdrAccessResource@16 @32
  LdrDisableThreadCalloutsForDll@4 @33
  LdrFindEntryForAddress@8 @35
  LdrFindResourceDirectory_U@16 @36
  LdrFindResource_U@16 @37
  LdrGetDllHandle@16 @39
  LdrGetProcedureAddress@16 @40
  LdrInitializeThunk@16 @42
  LdrLoadDll@16 @44
  LdrLockLoaderLock@12 @45
  LdrQueryProcessModuleInformation@12 @48
  LdrShutdownProcess@0 @51
  LdrShutdownThread@0 @52
  LdrUnloadDll@4 @54
  LdrUnlockLoaderLock@8 @55
  NlsAnsiCodePage @60 DATA
  NlsMbCodePageTag @61 DATA
  NlsMbOemCodePageTag @62 DATA
  NtAcceptConnectPort@24 @63
  NtAccessCheck@32 @64
  NtAdjustPrivilegesToken@24 @68
  NtAllocateLocallyUniqueId@4 @71
  NtAllocateUuids@12 @72
  NtAllocateVirtualMemory@24 @73
  NtCancelTimer@8 @76
  NtClearEvent@4 @77
  NtClose@4 @78
  NtCompleteConnectPort@4 @80
  NtConnectPort@32 @81
  NtCreateDirectoryObject@12 @83
  NtCreateEvent@20 @84
  NtCreateFile@44 @86
  NtCreateKey@28 @88
  NtCreateMailslotFile@32 @89
  NtCreatePagingFile@16 @92
  NtCreatePort@20 @93
  NtCreateSection@28 @96
  NtCreateSemaphore@20 @97
  NtCreateSymbolicLinkObject@16 @98
  NtCreateTimer@16 @100
  NtCurrentTeb@0 @102
  NtDelayExecution@8 @103
  NtDeleteKey@4 @106
  NtDeleteValueKey@8 @107
  NtDeviceIoControlFile@40 @108
  NtDisplayString@4 @109
  NtDuplicateObject@28 @110
  NtDuplicateToken@24 @111
  NtEnumerateKey@24 @113
  NtEnumerateValueKey@24 @114
  NtFlushBuffersFile@8 @117
  NtFlushKey@4 @119
  NtFlushVirtualMemory@16 @120
  NtFreeVirtualMemory@16 @122
  NtFsControlFile@40 @123
  NtGetContextThread@8 @124
  NtListenPort@8 @131
  NtLoadKey@8 @133
  NtLockFile@40 @134
  NtLockVirtualMemory@16 @135
  NtMapViewOfSection@40 @137
  NtNotifyChangeKey@40 @139
  NtOpenDirectoryObject@12 @140
  NtOpenEvent@12 @141
  NtOpenFile@24 @143
  NtOpenKey@12 @145
  NtOpenProcessToken@12 @149
  NtOpenSection@12 @150
  NtOpenSemaphore@12 @151
  NtOpenSymbolicLinkObject@12 @152
  NtOpenThread@16 @153
  NtOpenThreadToken@16 @154
  NtOpenTimer@12 @155
  NtProtectVirtualMemory@20 @161
  NtPulseEvent@8 @162
  NtQueryAttributesFile@8 @163
  NtQueryDefaultLocale@8 @164
  NtQueryDirectoryFile@44 @165
  NtQueryDirectoryObject@28 @166
  NtQueryEvent@20 @168
  NtQueryFullAttributesFile@8 @169
  NtQueryInformationFile@20 @170
  NtQueryInformationProcess@20 @172
  NtQueryInformationThread@20 @173
  NtQueryInformationToken@20 @174
  NtQueryKey@20 @177
  NtQueryObject@20 @179
  NtQueryPerformanceCounter@8 @181
  NtQuerySection@20 @182
  NtQuerySecurityObject@20 @183
  NtQuerySemaphore@20 @184
  NtQuerySymbolicLinkObject@12 @185
  NtQuerySystemInformation@16 @187
  NtQuerySystemTime@4 @188
  NtQueryTimerResolution@12 @190
  NtQueryValueKey@24 @191
  NtQueryVirtualMemory@24 @192
  NtQueryVolumeInformationFile@20 @193
  NtQueueApcThread@20 @194
  NtRaiseException@12 @195
  NtReadFile@36 @197
  NtReadVirtualMemory@20 @200
  NtRegisterThreadTerminatePort@4 @202
  NtReleaseSemaphore@12 @205
  NtReplaceKey@12 @207
  NtReplyWaitReceivePort@16 @209
  NtRequestWaitReplyPort@12 @213
  NtResetEvent@8 @214
  NtRestoreKey@12 @215
  NtResumeThread@8 @216
  NtSaveKey@8 @217
  NtSetContextThread@8 @219
  NtSetDefaultLocale@8 @221
  NtSetEvent@8 @223
  NtSetInformationFile@20 @227
  NtSetInformationKey@16 @228
  NtSetInformationObject@16 @229
  NtSetInformationProcess@16 @230
  NtSetInformationThread@16 @231
  NtSetIntervalProfile@8 @233
  NtSetSecurityObject@12 @239
  NtSetSystemTime@8 @243
  NtSetTimer@28 @244
  NtSetTimerResolution@12 @245
  NtSetValueKey@24 @246
  NtSetVolumeInformationFile@20 @247
  NtSuspendThread@8 @252
  NtTerminateProcess@8 @254
  NtTerminateThread@8 @255
  NtUnloadKey@4 @258
  NtUnlockFile@20 @260
  NtUnlockVirtualMemory@16 @261
  NtUnmapViewOfSection@8 @262
  NtWaitForMultipleObjects@20 @265
  NtWaitForSingleObject@12 @267
  NtWriteFile@36 @270
  NtWriteVirtualMemory@20 @273
  RtlAcquirePebLock@0 @282
  RtlAcquireResourceExclusive@8 @283
  RtlAcquireResourceShared@8 @284
  RtlAddAccessAllowedAce@16 @288
  RtlAddAccessAllowedAceEx@20 @289
  RtlAddAccessDeniedAce@16 @290
  RtlAddAccessDeniedAceEx@20 @291
  RtlAddAce@20 @292
  RtlAddVectoredExceptionHandler@8 @297
  RtlAdjustPrivilege@16 @298
  RtlAllocateAndInitializeSid@44 @299
  RtlAllocateHeap@12 @301
  RtlAnsiStringToUnicodeSize@4 @303
  RtlAnsiStringToUnicodeString@12 @304
  RtlAppendAsciizToString@8 @305
  RtlAppendStringToString@8 @306
  RtlAppendUnicodeStringToString@8 @307
  RtlAppendUnicodeToString@8 @308
  RtlAreAllAccessesGranted@8 @311
  RtlAreAnyAccessesGranted@8 @312
  RtlAreBitsClear@12 @313
  RtlAreBitsSet@12 @314
  RtlAssert@16 @315
  RtlCharToInteger@12 @317
  RtlClearAllBits@4 @319
  RtlClearBits@12 @320
  RtlCompactHeap@8 @322
  RtlCompareMemory@12 @323
  RtlCompareMemoryUlong@12 @324
  RtlCompareString@12 @325
  RtlCompareUnicodeString@12 @326
  RtlComputeCrc32@12 @328
  RtlConvertLongToLargeInteger@4 @331
  RtlConvertSidToUnicodeString@12 @333
  RtlConvertUlongToLargeInteger@4 @335
  RtlCopyLuid@8 @336
  RtlCopyLuidAndAttributesArray@12 @337
  RtlCopySid@12 @339
  RtlCopyString@8 @341
  RtlCopyUnicodeString@8 @342
  RtlCreateAcl@12 @343
  RtlCreateEnvironment@8 @346
  RtlCreateHeap@24 @347
  RtlCreateProcessParameters@40 @348
  RtlCreateQueryDebugBuffer@8 @350
  RtlCreateSecurityDescriptor@8 @352
  RtlCreateUnicodeString@8 @354
  RtlCreateUnicodeStringFromAsciiz@8 @355
  RtlCreateUserThread@40 @358
  RtlDeNormalizeProcessParams@4 @361
  RtlDeleteAce@8 @369
  RtlDeleteCriticalSection@4 @371
  RtlDeleteResource@4 @378
  RtlDeleteSecurityObject@4 @379
  RtlDestroyEnvironment@4 @380
  RtlDestroyHeap@4 @381
  RtlDestroyProcessParameters@4 @382
  RtlDestroyQueryDebugBuffer@4 @383
  RtlDetermineDosPathNameType_U@4 @384
  RtlDoesFileExists_U@4 @385
  RtlDosPathNameToNtPathName_U@16 @386
  RtlDosSearchPath_U@24 @387
  RtlDowncaseUnicodeChar@4 @388
  RtlDowncaseUnicodeString@12 @389
  RtlDumpResource@4 @390
  RtlDuplicateUnicodeString@12 @391
  RtlEnlargedIntegerMultiply@8 @392
  RtlEnlargedUnsignedDivide@16 @393
  RtlEnlargedUnsignedMultiply@8 @394
  RtlEnterCriticalSection@4 @395
  RtlEqualComputerName@8 @400
  RtlEqualDomainName@8 @401
  RtlEqualLuid@8 @402
  RtlEqualPrefixSid@8 @403
  RtlEqualSid@8 @404
  RtlEqualString@12 @405
  RtlEqualUnicodeString@12 @406
  RtlEraseUnicodeString@4 @407
  RtlExpandEnvironmentStrings_U@16 @408
  RtlExtendedIntegerMultiply@12 @410
  RtlExtendedLargeIntegerDivide@16 @411
  RtlExtendedMagicDivide@20 @412
  RtlFillMemory@12 @413
  RtlFillMemoryUlong@12 @414
  RtlFindCharInUnicodeString@16 @418
  RtlFindClearBits@12 @419
  RtlFindClearBitsAndSet@12 @420
  RtlFindClearRuns@16 @421
  RtlFindLastBackwardRunClear@12 @422
  RtlFindLastBackwardRunSet@12 @423
  RtlFindLeastSignificantBit@8 @424
  RtlFindLongestRunClear@8 @425
  RtlFindLongestRunSet@8 @426
  RtlFindMessage@20 @427
  RtlFindMostSignificantBit@8 @428
  RtlFindNextForwardRunClear@12 @429
  RtlFindNextForwardRunSet@12 @430
  RtlFindSetBits@12 @432
  RtlFindSetBitsAndClear@12 @433
  RtlFindSetRuns@16 @434
  RtlFirstFreeAce@8 @436
  RtlFormatCurrentUserKeyPath@4 @438
  RtlFormatMessage@32 @439
  RtlFreeAnsiString@4 @440
  RtlFreeHeap@12 @442
  RtlFreeOemString@4 @443
  RtlFreeSid@4 @444
  RtlFreeUnicodeString@4 @445
  RtlGetAce@12 @449
  RtlGetNtVersionNumbers@12 @462
  RtlGetVersion@4 @467
  RtlGetControlSecurityDescriptor@12 @452
  RtlGetCurrentDirectory_U@8 @453
  RtlGetDaclSecurityDescriptor@16 @454
  RtlGetFullPathName_U@16 @456
  RtlGetGroupSecurityDescriptor@12 @457
  RtlGetLastWin32Error@0 @458
  RtlGetLongestNtPathLength@0 @459
  RtlGetNtProductType@4 @461
  RtlGetOwnerSecurityDescriptor@12 @463
  RtlGetProcessHeaps@8 @464
  RtlGetSaclSecurityDescriptor@16 @465
  RtlGUIDFromString@8 @447
  RtlIdentifierAuthoritySid@4 @469
  RtlImageDirectoryEntryToData@16 @470
  RtlImageNtHeader@4 @471
  RtlImageRvaToSection@12 @472
  RtlImageRvaToVa@16 @473
  RtlImpersonateSelf@4 @474
  RtlInitAnsiString@8 @475
  RtlInitString@8 @478
  RtlInitUnicodeString@8 @479
  RtlInitUnicodeStringEx@8 @480
  RtlInitializeBitMap@12 @481
  RtlInitializeCriticalSection@4 @483
  RtlInitializeCriticalSectionAndSpinCount@8 @484
  RtlInitializeGenericTable@20 @485
  RtlInitializeResource@4 @488
  RtlInitializeSid@12 @489
  RtlInt64ToUnicodeString@16 @491
  RtlIntegerToChar@16 @492
  RtlIntegerToUnicodeString@12 @493
  RtlIsDosDeviceName_U@4 @494
  RtlIsNameLegalDOS8Dot3@12 @496
  RtlIsTextUnicode@12 @497
  RtlLargeIntegerAdd@16 @499
  RtlLargeIntegerArithmeticShift@12 @500
  RtlLargeIntegerDivide@20 @501
  RtlLargeIntegerNegate@8 @502
  RtlLargeIntegerShiftLeft@12 @503
  RtlLargeIntegerShiftRight@12 @504
  RtlLargeIntegerSubtract@16 @505
  RtlLargeIntegerToChar@16 @506
  RtlLeaveCriticalSection@4 @507
  RtlLengthRequiredSid@4 @508
  RtlLengthSecurityDescriptor@4 @509
  RtlLengthSid@4 @510
  RtlLocalTimeToSystemTime@8 @511
  RtlLockHeap@4 @512
  RtlMakeSelfRelativeSD@12 @515
  RtlMapGenericMask@8 @516
  RtlMoveMemory@12 @517
  RtlMultiByteToUnicodeN@20 @518
  RtlMultiByteToUnicodeSize@12 @519
  RtlNewSecurityObject@24 @522
  RtlNormalizeProcessParams@4 @523
  RtlNtStatusToDosError@4 @524
  RtlNtStatusToDosErrorNoTeb@4 @525
  RtlNumberOfClearBits@4 @527
  RtlNumberOfSetBits@4 @528
  RtlOemStringToUnicodeSize@4 @529
  RtlOemStringToUnicodeString@12 @530
  RtlOemToUnicodeN@20 @531
  RtlOpenCurrentUser@8 @532
  RtlPrefixString@12 @534
  RtlPrefixUnicodeString@12 @535
  RtlQueryEnvironmentVariable_U@12 @540
  RtlQueryInformationAcl@16 @542
  RtlQueryProcessDebugInformation@12 @547
  RtlQueryTimeZoneInformation@4 @556
  RtlRaiseException@4 @559
  RtlRaiseStatus@4 @560
  RtlRandom@4 @561
  RtlReAllocateHeap@16 @563
  RtlReleasePebLock@0 @572
  RtlReleaseResource@4 @573
  RtlRemoveVectoredExceptionHandler@4 @575
  RtlRestoreLastWin32Error@4=RtlSetLastWin32Error@4 @577
  RtlSecondsSince1970ToTime@8 @581
  RtlSecondsSince1980ToTime@8 @582
  RtlSelfRelativeToAbsoluteSD@44 @583
  RtlSetAllBits@4 @584
  RtlSetBits@12 @585
  RtlSetCurrentDirectory_U@4 @586
  RtlSetCurrentEnvironment@8 @587
  RtlSetDaclSecurityDescriptor@16 @588
  RtlSetEnvironmentVariable@12 @589
  RtlSetGroupSecurityDescriptor@12 @590
  RtlSetLastWin32Error@4 @592
  RtlSetOwnerSecurityDescriptor@12 @593
  RtlSetSaclSecurityDescriptor@16 @598
  RtlSetTimeZoneInformation@4 @600
  RtlSizeHeap@12 @604
  RtlStringFromGUID@8 @607
  RtlSubAuthorityCountSid@4 @608
  RtlSubAuthoritySid@8 @609
  RtlSystemTimeToLocalTime@8 @612
  RtlTimeFieldsToTime@8 @613
  RtlTimeToElapsedTimeFields@8 @614
  RtlTimeToSecondsSince1970@8 @615
  RtlTimeToSecondsSince1980@8 @616
  RtlTimeToTimeFields@8 @617
  RtlUlongByteSwap=NTDLL_RtlUlongByteSwap @619
  RtlUlonglongByteSwap @620
  RtlUnicodeStringToAnsiSize@4 @621
  RtlUnicodeStringToAnsiString@12 @622
  RtlUnicodeStringToInteger@12 @624
  RtlUnicodeStringToOemSize@4 @625
  RtlUnicodeStringToOemString@12 @626
  RtlUnicodeToMultiByteN@20 @628
  RtlUnicodeToMultiByteSize@12 @629
  RtlUnicodeToOemN@20 @630
  RtlUniform@4 @631
  RtlUnlockHeap@4 @632
  RtlUnwind@16 @633
  RtlUpcaseUnicodeChar@4 @634
  RtlUpcaseUnicodeString@12 @635
  RtlUpcaseUnicodeStringToAnsiString@12 @636
  RtlUpcaseUnicodeStringToCountedOemString@12 @637
  RtlUpcaseUnicodeStringToOemString@12 @638
  RtlUpcaseUnicodeToMultiByteN@20 @640
  RtlUpcaseUnicodeToOemN@20 @641
  RtlUpperChar@4 @642
  RtlUpperString@8 @643
  RtlUshortByteSwap=NTDLL_RtlUshortByteSwap @645
  RtlValidAcl@4 @646
  RtlValidSecurityDescriptor@4 @647
  RtlValidSid@4 @648
  RtlValidateHeap@12 @649
  RtlVerifyVersionInfo@16 @651
  RtlWalkHeap@8 @653
  RtlZeroMemory@8 @657
  RtlpNtCreateKey@28 @659
  RtlpNtEnumerateSubKey@12 @660
  RtlpNtMakeTemporaryKey@4 @661
  RtlpNtOpenKey@12 @662
  RtlpNtQueryValueKey@16 @663
  RtlpNtSetValueKey@16 @664
  RtlpUnWaitCriticalSection@4 @665
  RtlpWaitForCriticalSection@4 @666
  RtlxAnsiStringToUnicodeSize@4=RtlAnsiStringToUnicodeSize@4 @667
  RtlxOemStringToUnicodeSize@4=RtlOemStringToUnicodeSize@4 @668
  RtlxUnicodeStringToAnsiSize@4=RtlUnicodeStringToAnsiSize@4 @669
  RtlxUnicodeStringToOemSize@4=RtlUnicodeStringToOemSize@4 @670
  ZwAcceptConnectPort@24=NtAcceptConnectPort@24 @675
  ZwAccessCheck@32=NtAccessCheck@32 @676
  ZwAdjustGroupsToken@24=NtAdjustPrivilegesToken@24 @678
  ZwAdjustPrivilegesToken@24=NtAdjustPrivilegesToken@24 @679
  ZwAllocateLocallyUniqueId@4=NtAllocateLocallyUniqueId@4 @682
  ZwAllocateUuids@12=NtAllocateUuids@12 @683
  ZwAllocateVirtualMemory@24=NtAllocateVirtualMemory@24 @684
  ZwCancelTimer@8=NtCancelTimer@8 @687
  ZwClearEvent@4=NtClearEvent@4 @688
  ZwClose@4=NtClose@4 @689
  ZwCompleteConnectPort@4=NtCompleteConnectPort@4 @691
  ZwConnectPort@32=NtConnectPort@32 @692
  ZwCreateDirectoryObject@12=NtCreateDirectoryObject@12 @694
  ZwCreateEvent@20=NtCreateEvent@20 @695
  ZwCreateFile@44=NtCreateFile@44 @697
  ZwCreateKey@28=NtCreateKey@28 @699
  ZwCreateMailslotFile@32=NtCreateMailslotFile@32 @700
  ZwCreatePagingFile@16=NtCreatePagingFile@16 @703
  ZwCreatePort@20=NtCreatePort@20 @704
  ZwCreateSection@28=NtCreateSection@28 @707
  ZwCreateSemaphore@20=NtCreateSemaphore@20 @708
  ZwCreateSymbolicLinkObject@16=NtCreateSymbolicLinkObject@16 @709
  ZwCreateTimer@16=NtCreateTimer@16 @711
  ZwDelayExecution@8=NtDelayExecution@8 @713
  ZwDeleteKey@4=NtDeleteKey@4 @715
  ZwDeleteValueKey@8=NtDeleteValueKey@8 @716
  ZwDeviceIoControlFile@40=NtDeviceIoControlFile@40 @717
  ZwDisplayString@4=NtDisplayString@4 @718
  ZwDuplicateObject@28=NtDuplicateObject@28 @719
  ZwDuplicateToken@24=NtDuplicateToken@24 @720
  ZwEnumerateKey@24=NtEnumerateKey@24 @722
  ZwEnumerateValueKey@24=NtEnumerateValueKey@24 @723
  ZwFlushBuffersFile@8=NtFlushBuffersFile@8 @725
  ZwFlushKey@4=NtFlushKey@4 @727
  ZwFlushVirtualMemory@16=NtFlushVirtualMemory@16 @728
  ZwFreeVirtualMemory@16=NtFreeVirtualMemory@16 @730
  ZwFsControlFile@40=NtFsControlFile@40 @731
  ZwGetContextThread@8=NtGetContextThread@8 @732
  ZwListenPort@8=NtListenPort@8 @738
  ZwLoadKey@8=NtLoadKey@8 @740
  ZwLockFile@40=NtLockFile@40 @741
  ZwLockVirtualMemory@16=NtLockVirtualMemory@16 @742
  ZwMapViewOfSection@40=NtMapViewOfSection@40 @744
  ZwNotifyChangeKey@40=NtNotifyChangeKey@40 @746
  ZwOpenDirectoryObject@12=NtOpenDirectoryObject@12 @747
  ZwOpenEvent@12=NtOpenEvent@12 @748
  ZwOpenFile@24=NtOpenFile@24 @750
  ZwOpenKey@12=NtOpenKey@12 @752
  ZwOpenProcessToken@12=NtOpenProcessToken@12 @756
  ZwOpenSection@12=NtOpenSection@12 @757
  ZwOpenSemaphore@12=NtOpenSemaphore@12 @758
  ZwOpenSymbolicLinkObject@12=NtOpenSymbolicLinkObject@12 @759
  ZwOpenThread@16=NtOpenThread@16 @760
  ZwOpenThreadToken@16=NtOpenThreadToken@16 @761
  ZwOpenTimer@12=NtOpenTimer@12 @762
  ZwProtectVirtualMemory@20=NtProtectVirtualMemory@20 @767
  ZwPulseEvent@8=NtPulseEvent@8 @768
  ZwQueryAttributesFile@8=NtQueryAttributesFile@8 @769
  ZwQueryDefaultLocale@8=NtQueryDefaultLocale@8 @770
  ZwQueryDirectoryFile@44=NtQueryDirectoryFile@44 @771
  ZwQueryDirectoryObject@28=NtQueryDirectoryObject@28 @772
  ZwQueryEvent@20=NtQueryEvent@20 @774
  ZwQueryInformationFile@20=NtQueryInformationFile@20 @775
  ZwQueryInformationProcess@20=NtQueryInformationProcess@20 @777
  ZwQueryInformationThread@20=NtQueryInformationThread@20 @778
  ZwQueryInformationToken@20=NtQueryInformationToken@20 @779
  ZwQueryKey@20=NtQueryKey@20 @782
  ZwQueryObject@20=NtQueryObject@20 @784
  ZwQueryPerformanceCounter@8=NtQueryPerformanceCounter@8 @786
  ZwQuerySection@20=NtQuerySection@20 @787
  ZwQuerySecurityObject@20=NtQuerySecurityObject@20 @788
  ZwQuerySemaphore@20=NtQuerySemaphore@20 @789
  ZwQuerySymbolicLinkObject@12=NtQuerySymbolicLinkObject@12 @790
  ZwQuerySystemInformation@16=NtQuerySystemInformation@16 @792
  ZwQuerySystemTime@4=NtQuerySystemTime@4 @793
  ZwQueryTimerResolution@12=NtQueryTimerResolution@12 @795
  ZwQueryValueKey@24=NtQueryValueKey@24 @796
  ZwQueryVirtualMemory@24=NtQueryVirtualMemory@24 @797
  ZwQueryVolumeInformationFile@20=NtQueryVolumeInformationFile@20 @798
  ZwRaiseException@12=NtRaiseException@12 @799
  ZwReadFile@36=NtReadFile@36 @801
  ZwReadVirtualMemory@20=NtReadVirtualMemory@20 @803
  ZwRegisterThreadTerminatePort@4=NtRegisterThreadTerminatePort@4 @805
  ZwReleaseSemaphore@12=NtReleaseSemaphore@12 @808
  ZwReplaceKey@12=NtReplaceKey@12 @810
  ZwReplyWaitReceivePort@16=NtReplyWaitReceivePort@16 @812
  ZwRequestWaitReplyPort@12=NtRequestWaitReplyPort@12 @815
  ZwResetEvent@8=NtResetEvent@8 @816
  ZwRestoreKey@12=NtRestoreKey@12 @817
  ZwResumeThread@8=NtResumeThread@8 @818
  ZwSaveKey@8=NtSaveKey@8 @819
  ZwSetContextThread@8=NtSetContextThread@8 @820
  ZwSetDefaultLocale@8=NtSetDefaultLocale@8 @822
  ZwSetEvent@8=NtSetEvent@8 @824
  ZwSetInformationFile@20=NtSetInformationFile@20 @828
  ZwSetInformationKey@16=NtSetInformationKey@16 @829
  ZwSetInformationObject@16=NtSetInformationObject@16 @830
  ZwSetInformationProcess@16=NtSetInformationProcess@16 @831
  ZwSetInformationThread@16=NtSetInformationThread@16 @832
  ZwSetIntervalProfile@8=NtSetIntervalProfile@8 @834
  ZwSetSecurityObject@12=NtSetSecurityObject@12 @840
  ZwSetSystemTime@8=NtSetSystemTime@8 @844
  ZwSetTimer@28=NtSetTimer@28 @845
  ZwSetTimerResolution@12=NtSetTimerResolution@12 @846
  ZwSetValueKey@24=NtSetValueKey@24 @847
  ZwSetVolumeInformationFile@20=NtSetVolumeInformationFile@20 @848
  ZwSuspendThread@8=NtSuspendThread@8 @852
  ZwTerminateProcess@8=NtTerminateProcess@8 @854
  ZwTerminateThread@8=NtTerminateThread@8 @855
  ZwUnloadKey@4=NtUnloadKey@4 @858
  ZwUnlockFile@20=NtUnlockFile@20 @860
  ZwUnlockVirtualMemory@16=NtUnlockVirtualMemory@16 @861
  ZwUnmapViewOfSection@8=NtUnmapViewOfSection@8 @862
  ZwWaitForMultipleObjects@20=NtWaitForMultipleObjects@20 @865
  ZwWaitForSingleObject@12=NtWaitForSingleObject@12 @867
  ZwWriteFile@36=NtWriteFile@36 @870
  ZwWriteVirtualMemory@20=NtWriteVirtualMemory@20 @872
  _CIpow=NTDLL__CIpow @873
  _alldiv@16 @991
  _allmul@16 @992
  _alloca_probe@0 @993
  _allrem@16 @994
  _atoi64 @995
  _aulldiv@16 @996
  _aullrem@16 @997
  _chkstk@0 @998
  _ftol=NTDLL__ftol @1000
  _i64toa @1001
  _i64tow @1002
  _itoa @1003
  _itow @1004
  _ltoa @1005
  _ltow @1006
  _memccpy=memccpy @1007
  _memicmp=NTDLL__memicmp @1008
  _snprintf=snprintf @1009
  _snwprintf @1010
  _splitpath @1011
  _strcmpi=strcasecmp @1012
  _stricmp=strcasecmp @1013
  _strlwr @1014
  _strnicmp=strncasecmp @1015
  _strupr @1016
  _ui64toa @1017
  _ui64tow @1018
  _ultoa @1019
  _ultow @1020
  _vsnprintf=vsnprintf @1021
  _wcsicmp=NTDLL__wcsicmp @1022
  _wcslwr=NTDLL__wcslwr @1023
  _wcsnicmp=NTDLL__wcsnicmp @1024
  _wcsupr=NTDLL__wcsupr @1025
  _wtoi @1026
  _wtoi64 @1027
  _wtol @1028
  abs @1029
  atan @1030
  atoi @1031
  atol @1032
  ceil @1033
  cos @1034
  fabs @1035
  floor @1036
  isalpha @1037
  isdigit @1038
  islower @1039
  isprint @1040
  isspace @1041
  isupper @1042
  iswalpha=NTDLL_iswalpha @1043
  iswctype=NTDLL_iswctype @1044
  iswdigit=NTDLL_iswdigit @1045
  iswlower=NTDLL_iswlower @1046
  iswspace=NTDLL_iswspace @1047
  iswxdigit=NTDLL_iswxdigit @1048
  isxdigit @1049
  labs @1050
  log @1051
  mbstowcs=NTDLL_mbstowcs @1052
  memchr @1053
  memcmp @1054
  memcpy @1055
  memmove @1056
  memset @1057
  pow @1058
  qsort @1059
  sin @1060
  sprintf @1061
  sqrt @1062
  sscanf @1063
  strcat @1064
  strchr @1065
  strcmp @1066
  strcpy @1067
  strcspn @1068
  strlen @1069
  strncat @1070
  strncmp @1071
  strncpy @1072
  strpbrk @1073
  strrchr @1074
  strspn @1075
  strstr @1076
  strtol @1077
  strtoul @1078
  swprintf=NTDLL_swprintf @1079
  tan @1080
  tolower @1081
  toupper @1082
  towlower=NTDLL_towlower @1083
  towupper=NTDLL_towupper @1084
  vsprintf @1085
  wcscat=NTDLL_wcscat @1086
  wcschr=NTDLL_wcschr @1087
  wcscmp=NTDLL_wcscmp @1088
  wcscpy=NTDLL_wcscpy @1089
  wcscspn=NTDLL_wcscspn @1090
  wcslen=NTDLL_wcslen @1091
  wcsncat=NTDLL_wcsncat @1092
  wcsncmp=NTDLL_wcsncmp @1093
  wcsncpy=NTDLL_wcsncpy @1094
  wcspbrk=NTDLL_wcspbrk @1095
  wcsrchr=NTDLL_wcsrchr @1096
  wcsspn=NTDLL_wcsspn @1097
  wcsstr=NTDLL_wcsstr @1098
  wcstok=NTDLL_wcstok @1099
  wcstol=NTDLL_wcstol @1100
  wcstombs=NTDLL_wcstombs @1101
  wcstoul=NTDLL_wcstoul @1102
  RtlTryEnterCriticalSection@4 @618
  NtPowerInformation@20 @157
  VerSetConditionMask@16 @674
  __wine_exception_handler @987
  __wine_finally_handler @988
  __wine_call_from_32_regs @985
  __wine_enter_vm86 @986
  wine_server_call @1104
  wine_server_fd_to_handle @1105
  wine_server_handle_to_fd @1106
  wine_server_release_fd @1107
  wine_server_send_fd @1108
  __wine_init_codepages @989
  __wine_set_signal_handler @990
  wine_nt_to_unix_file_name @1103
  MODULE_DllThreadAttach @57
  MODULE_GetLoadOrderW @58
  VERSION_Init @672
  VIRTUAL_SetFaultHandler @673
