; File generated automatically from crypt32/crypt32.spec; do not edit!

LIBRARY crypt32.dll

EXPORTS
  CertCloseStore@8 @13
  CertCreateCRLContext@12 @19
  CertEnumCertificatesInStore@8 @34
  CertFreeCertificateContext@4 @45
  CertOpenStore@20 @60
  CertOpenSystemStoreA@8 @61
  CertOpenSystemStoreW@8 @62
  CertSaveStore@24 @66
  CryptGetOIDFunctionValue@28 @108
  CryptProtectData@28 @135
  CryptRegisterDefaultOIDFunction@16 @136
  CryptRegisterOIDFunction@20 @137
  CryptSIPAddProvider@4 @139
  CryptSIPLoad@12 @140
  CryptSIPRemoveProvider@4 @141
  CryptSIPRetrieveSubjectGuid@12 @142
  I_CryptCreateLruCache@8 @164
  I_CryptFindLruEntryData@4 @167
  I_CryptFlushLruCache@4 @168
  I_CryptFreeLruCache@4 @169
