; File generated automatically from rsabase/rsabase.spec; do not edit!

LIBRARY rsabase.dll

EXPORTS
  CPAcquireContext@16=RSA_CPAcquireContext@16 @1
  CPCreateHash@20=RSA_CPCreateHash@20 @2
  CPDecrypt@28=RSA_CPDecrypt@28 @3
  CPDeriveKey@20=RSA_CPDeriveKey@20 @4
  CPDestroyHash@8=RSA_CPDestroyHash@8 @5
  CPDestroyKey@8=RSA_CPDestroyKey@8 @6
  CPDuplicateHash@20=RSA_CPDuplicateHash@20 @7
  CPDuplicateKey@20=RSA_CPDuplicateKey@20 @8
  CPEncrypt@32=RSA_CPEncrypt@32 @9
  CPExportKey@28=RSA_CPExportKey@28 @10
  CPGenKey@16=RSA_CPGenKey@16 @11
  CPGenRandom@12=RSA_CPGenRandom@12 @12
  CPGetHashParam@24=RSA_CPGetHashParam@24 @13
  CPGetKeyParam@24=RSA_CPGetKeyParam@24 @14
  CPGetProvParam@20=RSA_CPGetProvParam@20 @15
  CPGetUserKey@12=RSA_CPGetUserKey@12 @16
  CPHashData@20=RSA_CPHashData@20 @17
  CPHashSessionKey@16=RSA_CPHashSessionKey@16 @18
  CPImportKey@24=RSA_CPImportKey@24 @19
  CPReleaseContext@8=RSA_CPReleaseContext@8 @20
  CPSetHashParam@20=RSA_CPSetHashParam@20 @21
  CPSetKeyParam@20=RSA_CPSetKeyParam@20 @22
  CPSetProvParam@16=RSA_CPSetProvParam@16 @23
  CPSignHash@28=RSA_CPSignHash@28 @24
  CPVerifySignature@28=RSA_CPVerifySignature@28 @25
  DllRegisterServer@0=RSABASE_DllRegisterServer@0 @26 PRIVATE
  DllUnregisterServer@0=RSABASE_DllUnregisterServer@0 @27 PRIVATE
