; File generated automatically from winsock/ws2_32.spec; do not edit!

LIBRARY ws2_32.dll

EXPORTS
  accept@12=WS_accept@12 @1
  bind@12=WS_bind@12 @2
  closesocket@4=WS_closesocket@4 @3
  connect@12=WS_connect@12 @4
  getpeername@12=WS_getpeername@12 @5
  getsockname@12=WS_getsockname@12 @6
  getsockopt@20=WS_getsockopt@20 @7
  htonl@4=WS_htonl@4 @8
  htons@4=WS_htons@4 @9
  ioctlsocket@12=WS_ioctlsocket@12 @10
  inet_addr@4=WS_inet_addr@4 @11
  inet_ntoa@4=WS_inet_ntoa@4 @12
  listen@8=WS_listen@8 @13
  ntohl@4=WS_ntohl@4 @14
  ntohs@4=WS_ntohs@4 @15
  recv@16=WS_recv@16 @16
  recvfrom@24=WS_recvfrom@24 @17
  select@20=WS_select@20 @18
  send@16=WS_send@16 @19
  sendto@24=WS_sendto@24 @20
  setsockopt@20=WS_setsockopt@20 @21
  shutdown@8=WS_shutdown@8 @22
  socket@12=WS_socket@12 @23
  WSApSetPostRoutine@4 @24
  WSAAccept@20 @26
  WSACloseEvent@4 @29
  WSAConnect@28 @30
  WSACreateEvent@0 @31
  WSADuplicateSocketA@12 @32
  WSAEnumNetworkEvents@12 @36
  WSAEnumProtocolsA@12 @37
  WSAEnumProtocolsW@12 @38
  WSAEventSelect@12 @39
  WSAGetOverlappedResult@20 @40
  WSAHtonl@12 @46
  WSAHtons@12 @47
  WSAInstallServiceClassA@4 @48
  WSAInstallServiceClassW@4 @49
  WSAIoctl@36 @50
  gethostbyaddr@12=WS_gethostbyaddr@12 @51
  gethostbyname@4=WS_gethostbyname@4 @52
  getprotobyname@4=WS_getprotobyname@4 @53
  getprotobynumber@4=WS_getprotobynumber@4 @54
  getservbyname@8=WS_getservbyname@8 @55
  getservbyport@8=WS_getservbyport@8 @56
  gethostname@8=WS_gethostname@8 @57
  WSAJoinLeaf@32 @58
  WSALookupServiceBeginA@12 @59
  WSALookupServiceBeginW@12 @60
  WSARecv@28 @67
  WSARecvFrom@36 @69
  WSARemoveServiceClass@4 @70
  WSAResetEvent@4=kernel32.ResetEvent @71
  WSASend@28 @72
  WSASendDisconnect@8 @73
  WSASendTo@36 @74
  WSASetEvent@4=kernel32.SetEvent @75
  WSASocketA@24 @78
  WSAStringToAddressA@20 @80
  WSAWaitForMultipleEvents@20=kernel32.WaitForMultipleObjectsEx @82
  WSCDeinstallProvider@8 @83
  WSCInstallProvider@20 @88
  WSAAsyncSelect@16 @101
  WSAAsyncGetHostByAddr@28 @102
  WSAAsyncGetHostByName@20 @103
  WSAAsyncGetProtoByNumber@20 @104
  WSAAsyncGetProtoByName@20 @105
  WSAAsyncGetServByPort@24 @106
  WSAAsyncGetServByName@24 @107
  WSACancelAsyncRequest@4 @108
  WSASetBlockingHook@4 @109
  WSAUnhookBlockingHook@0 @110
  WSAGetLastError@0 @111
  WSASetLastError@4 @112
  WSACancelBlockingCall@0 @113
  WSAIsBlocking@0 @114
  WSAStartup@8 @115
  WSACleanup@0 @116
  __WSAFDIsSet@8 @151
