; File generated automatically from rpcrt4/rpcrt4.spec; do not edit!

LIBRARY rpcrt4.dll

EXPORTS
  DllRegisterServer@0=RPCRT4_DllRegisterServer@0 @15 PRIVATE
  RpcBindingFree@4 @372
  RpcBindingFromStringBindingA@8 @373
  RpcBindingFromStringBindingW@8 @374
  RpcBindingInqObject@8 @383
  RpcBindingSetObject@8 @391
  RpcBindingToStringBindingA@8 @393
  RpcBindingToStringBindingW@8 @394
  RpcBindingVectorFree@4 @395
  RpcEpRegisterA@16 @402
  RpcEpResolveBinding@8 @406
  RpcEpUnregister@12 @407
  RpcMgmtStopServerListening@4 @445
  RpcMgmtWaitServerListen@0 @446
  RpcNetworkIsProtseqValidA@4 @449
  RpcNetworkIsProtseqValidW@4 @450
  RpcObjectSetType@8 @455
  RpcRaiseException@4 @458
  RpcServerInqBindings@4 @462
  RpcServerListen@12 @468
  RpcServerRegisterAuthInfoA@16 @469
  RpcServerRegisterAuthInfoW@16 @470
  RpcServerRegisterIf@12 @471
  RpcServerRegisterIfEx@24 @473
  RpcServerRegisterIf2@28 @472
  RpcServerUnregisterIf@12 @475
  RpcServerUnregisterIfEx@12 @476
  RpcServerUseProtseqA@12 @481
  RpcServerUseProtseqW@12 @492
  RpcServerUseProtseqEpA@16 @482
  RpcServerUseProtseqEpW@16 @485
  RpcServerUseProtseqEpExA@20 @483
  RpcServerUseProtseqEpExW@20 @484
  RpcStringBindingComposeA@24 @517
  RpcStringBindingComposeW@24 @518
  RpcStringBindingParseA@24 @519
  RpcStringBindingParseW@24 @520
  RpcStringFreeA@4 @521
  RpcStringFreeW@4 @522
  UuidCompare@12 @531
  UuidCreate@4 @532
  UuidCreateSequential@4 @534
  UuidCreateNil@4 @533
  UuidEqual@12 @535
  UuidFromStringA@8 @536
  UuidFromStringW@8 @537
  UuidHash@8 @538
  UuidIsNil@8 @539
  UuidToStringA@8 @540
  UuidToStringW@8 @541
  CStdStubBuffer_QueryInterface@12 @9
  CStdStubBuffer_AddRef@4 @1
  CStdStubBuffer_Connect@8 @2
  CStdStubBuffer_Disconnect@4 @6
  CStdStubBuffer_Invoke@12 @7
  CStdStubBuffer_IsIIDSupported@8 @8
  CStdStubBuffer_CountRefs@4 @3
  CStdStubBuffer_DebugServerQueryInterface@8 @4
  CStdStubBuffer_DebugServerRelease@8 @5
  NdrCStdStubBuffer_Release@8 @157
  IUnknown_QueryInterface_Proxy@12 @19
  IUnknown_AddRef_Proxy@4 @18
  IUnknown_Release_Proxy@4 @20
  NdrDllCanUnloadNow@4 @208
  NdrDllGetClassObject@24 @209
  NdrDllRegisterProxy@12 @210
  NdrDllUnregisterProxy@12 @211
  NdrAllocate@8 @149
  NdrClearOutParameters@12 @158
  NdrClientCall2 @160
  NdrClientInitializeNew@16 @164
  NdrConvert@8 @201
  NdrConvert2@12 @202
  NdrFreeBuffer@4 @222
  NdrGetBuffer@12 @229
  NdrOleAllocate@4 @274
  NdrOleFree@4 @275
  NdrProxyErrorHandler@4 @291
  NdrProxyFreeBuffer@8 @292
  NdrProxyGetBuffer@8 @293
  NdrProxyInitialize@20 @294
  NdrProxySendReceive@8 @295
  NdrSendReceive@8 @304
  NdrStubGetBuffer@12 @328
  NdrStubInitialize@16 @329
  NdrComplexArrayBufferSize@12 @165
  NdrComplexArrayFree@12 @166
  NdrComplexArrayMarshall@12 @167
  NdrComplexArrayMemorySize@8 @168
  NdrComplexArrayUnmarshall@16 @169
  NdrComplexStructBufferSize@12 @170
  NdrComplexStructFree@12 @171
  NdrComplexStructMarshall@12 @172
  NdrComplexStructMemorySize@8 @173
  NdrComplexStructUnmarshall@16 @174
  NdrConformantArrayBufferSize@12 @175
  NdrConformantArrayFree@12 @176
  NdrConformantArrayMarshall@12 @177
  NdrConformantArrayMemorySize@8 @178
  NdrConformantArrayUnmarshall@16 @179
  NdrConformantStringBufferSize@12 @180
  NdrConformantStringMarshall@12 @181
  NdrConformantStringMemorySize@8 @182
  NdrConformantStringUnmarshall@16 @183
  NdrConformantVaryingArrayBufferSize@12 @189
  NdrConformantVaryingArrayFree@12 @190
  NdrConformantVaryingArrayMarshall@12 @191
  NdrConformantVaryingArrayMemorySize@8 @192
  NdrConformantVaryingArrayUnmarshall@16 @193
  NdrInterfacePointerBufferSize@12 @243
  NdrInterfacePointerFree@12 @244
  NdrInterfacePointerMarshall@12 @245
  NdrInterfacePointerMemorySize@8 @246
  NdrInterfacePointerUnmarshall@16 @247
  NdrPointerBufferSize@12 @286
  NdrPointerFree@12 @287
  NdrPointerMarshall@12 @288
  NdrPointerMemorySize@8 @289
  NdrPointerUnmarshall@16 @290
  NdrServerInitializeNew@12 @313
  NdrSimpleStructBufferSize@12 @318
  NdrSimpleStructFree@12 @319
  NdrSimpleStructMarshall@12 @320
  NdrSimpleStructMemorySize@8 @321
  NdrSimpleStructUnmarshall@16 @322
  NdrSimpleTypeMarshall@12 @323
  NdrSimpleTypeUnmarshall@12 @324
  NdrUserMarshalBufferSize@12 @337
  NdrUserMarshalFree@12 @338
  NdrUserMarshalMarshall@12 @339
  NdrUserMarshalMemorySize@8 @340
  NdrUserMarshalUnmarshall@16 @342
  I_RpcBindingSetAsync@8 @38
  I_RpcFreeBuffer@4 @48
  I_RpcGetBuffer@4 @51
  I_RpcReceive@4 @73
  I_RpcSend@4 @75
  I_RpcSendReceive@4 @76
  I_RpcServerStartListening@4 @83
  I_RpcServerStopListening@0 @84
  I_RpcWindowProc@16 @123
