; File generated automatically from dmband/dmband.spec; do not edit!

LIBRARY dmband.dll

EXPORTS
  DllCanUnloadNow@0=DMBAND_DllCanUnloadNow@0 @1 PRIVATE
  DllGetClassObject@12=DMBAND_DllGetClassObject@12 @2 PRIVATE
  DllRegisterServer@0=DMBAND_DllRegisterServer@0 @3 PRIVATE
  DllUnregisterServer@0=DMBAND_DllUnregisterServer@0 @4 PRIVATE
