; File generated automatically from gdi/gdi32.spec; do not edit!

LIBRARY gdi32.dll

EXPORTS
  AbortDoc@4 @105
  AbortPath@4 @106
  AddFontResourceA@4 @107
  AddFontResourceExA@12 @108
  AddFontResourceExW@12 @109
  AddFontResourceW@4 @111
  AngleArc@24 @112
  AnimatePalette@16 @113
  Arc@36 @114
  ArcTo@36 @115
  BeginPath@4 @116
  BitBlt@36 @117
  ChoosePixelFormat@8 @121
  Chord@36 @122
  CloseEnhMetaFile@4 @123
  CloseFigure@4 @124
  CloseMetaFile@4 @126
  CombineRgn@16 @130
  CombineTransform@12 @131
  CopyEnhMetaFileA@8 @132
  CopyEnhMetaFileW@8 @133
  CopyMetaFileA@8 @134
  CopyMetaFileW@8 @135
  CreateBitmap@20 @136
  CreateBitmapIndirect@4 @137
  CreateBrushIndirect@4 @138
  CreateColorSpaceA@4 @139
  CreateColorSpaceW@4 @140
  CreateCompatibleBitmap@12 @141
  CreateCompatibleDC@4 @142
  CreateDCA@16 @143
  CreateDCW@16 @144
  CreateDIBPatternBrush@8 @145
  CreateDIBPatternBrushPt@8 @146
  CreateDIBSection@24 @147
  CreateDIBitmap@24 @148
  CreateDiscardableBitmap@12 @149
  CreateEllipticRgn@16 @150
  CreateEllipticRgnIndirect@4 @151
  CreateEnhMetaFileA@16 @152
  CreateEnhMetaFileW@16 @153
  CreateFontA@56 @154
  CreateFontIndirectA@4 @155
  CreateFontIndirectW@4 @156
  CreateFontW@56 @157
  CreateHalftonePalette@4 @158
  CreateHatchBrush@8 @159
  CreateICA@16 @160
  CreateICW@16 @161
  CreateMetaFileA@4 @162
  CreateMetaFileW@4 @163
  CreatePalette@4 @164
  CreatePatternBrush@4 @165
  CreatePen@12 @166
  CreatePenIndirect@4 @167
  CreatePolyPolygonRgn@16 @168
  CreatePolygonRgn@12 @169
  CreateRectRgn@16 @170
  CreateRectRgnIndirect@4 @171
  CreateRoundRectRgn@24 @172
  CreateScalableFontResourceA@16 @173
  CreateScalableFontResourceW@16 @174
  CreateSolidBrush@4 @175
  DPtoLP@12 @177
  DeleteColorSpace@4 @178
  DeleteDC@4 @179
  DeleteEnhMetaFile@4 @180
  DeleteMetaFile@4 @181
  DeleteObject@4 @183
  DescribePixelFormat@16 @184
  DrawEscape@16 @188
  Ellipse@20 @191
  EndDoc@4 @193
  EndPage@4 @194
  EndPath@4 @195
  EnumEnhMetaFile@20 @196
  EnumFontFamiliesA@16 @197
  EnumFontFamiliesExA@20 @198
  EnumFontFamiliesExW@20 @199
  EnumFontFamiliesW@16 @200
  EnumFontsA@16 @201
  EnumFontsW@16 @202
  EnumICMProfilesA@12 @203
  EnumICMProfilesW@12 @204
  EnumMetaFile@16 @205
  EnumObjects@16 @206
  EqualRgn@8 @207
  Escape@20 @208
  ExcludeClipRect@20 @209
  ExtCreatePen@20 @211
  ExtCreateRegion@12 @212
  ExtEscape@24 @213
  ExtFloodFill@20 @214
  ExtSelectClipRgn@12 @215
  ExtTextOutA@32 @216
  ExtTextOutW@32 @217
  FillPath@4 @218
  FillRgn@12 @219
  FixBrushOrgEx@16 @220
  FlattenPath@4 @221
  FloodFill@16 @222
  FrameRgn@20 @223
  GdiAlphaBlend@44 @227
  GdiComment@12 @230
  GdiConvertToDevmodeW@4 @240
  GdiFlush@0 @262
  GdiGetBatchLimit@0 @263
  GdiGradientFill@24 @268
  GdiSetBatchLimit@4 @275
  GdiTransparentBlt@44 @277
  GetArcDirection@4 @282
  GetAspectRatioFilterEx@8 @283
  GetBitmapBits@12 @284
  GetBitmapDimensionEx@8 @285
  GetBkColor@4 @286
  GetBkMode@4 @287
  GetBoundsRect@12 @288
  GetBrushOrgEx@8 @289
  GetCharABCWidthsA@16 @290
  GetCharABCWidthsFloatA@16 @291
  GetCharABCWidthsFloatW@16 @292
  GetCharABCWidthsW@16 @293
  GetCharWidth32A@16 @294
  GetCharWidth32W@16 @295
  GetCharWidthA@16=GetCharWidth32A@16 @296
  GetCharWidthFloatA@16 @297
  GetCharWidthFloatW@16 @298
  GetCharWidthW@16=GetCharWidth32W@16 @299
  GetCharacterPlacementA@24 @301
  GetCharacterPlacementW@24 @302
  GetClipBox@8 @303
  GetClipRgn@8 @304
  GetColorAdjustment@8 @305
  GetColorSpace@4 @306
  GetCurrentObject@8 @307
  GetCurrentPositionEx@8 @308
  GetDCBrushColor@4 @309
  GetDCOrgEx@8 @310
  GetDCPenColor@4 @311
  GetDIBColorTable@16 @313
  GetDIBits@28 @314
  GetDeviceCaps@8 @315
  GetDeviceGammaRamp@8 @316
  GetEnhMetaFileA@4 @318
  GetEnhMetaFileBits@12 @319
  GetEnhMetaFileDescriptionA@12 @320
  GetEnhMetaFileDescriptionW@12 @321
  GetEnhMetaFileHeader@12 @322
  GetEnhMetaFilePaletteEntries@12 @323
  GetEnhMetaFileW@4 @324
  GetFontData@20 @325
  GetFontLanguageInfo@4 @326
  GetGlyphIndicesA@20 @329
  GetGlyphIndicesW@20 @330
  GetGlyphOutlineA@28 @332
  GetGlyphOutlineW@28 @333
  GetGraphicsMode@4 @335
  GetICMProfileA@12 @336
  GetKerningPairsA@12 @339
  GetKerningPairsW@12 @340
  GetLayout@4 @341
  GetMapMode@4 @344
  GetMetaFileA@4 @345
  GetMetaFileBitsEx@12 @346
  GetMetaFileW@4 @347
  GetMetaRgn@8 @348
  GetMiterLimit@8 @349
  GetNearestColor@8 @350
  GetNearestPaletteIndex@8 @351
  GetObjectA@12 @352
  GetObjectType@4 @353
  GetObjectW@12 @354
  GetOutlineTextMetricsA@12 @355
  GetOutlineTextMetricsW@12 @356
  GetPaletteEntries@16 @357
  GetPath@16 @358
  GetPixel@12 @359
  GetPixelFormat@4 @360
  GetPolyFillMode@4 @361
  GetROP2@4 @362
  GetRandomRgn@12 @363
  GetRasterizerCaps@8 @364
  GetRegionData@12 @365
  GetRelAbs@8 @366
  GetRgnBox@8 @367
  GetStockObject@4 @368
  GetStretchBltMode@4 @369
  GetSystemPaletteEntries@16 @370
  GetSystemPaletteUse@4 @371
  GetTextAlign@4 @372
  GetTextCharacterExtra@4 @373
  GetTextCharset@4 @374
  GetTextCharsetInfo@12 @375
  GetTextColor@4 @376
  GetTextExtentExPointA@28 @377
  GetTextExtentExPointW@28 @378
  GetTextExtentPoint32A@16 @379
  GetTextExtentPoint32W@16 @380
  GetTextExtentPointA@16 @381
  GetTextExtentPointI@16 @382
  GetTextExtentPointW@16 @383
  GetTextFaceA@12 @384
  GetTextFaceW@12 @385
  GetTextMetricsA@8 @386
  GetTextMetricsW@8 @387
  GetTransform@12 @388
  GetViewportExtEx@8 @389
  GetViewportOrgEx@8 @390
  GetWinMetaFileBits@20 @391
  GetWindowExtEx@8 @392
  GetWindowOrgEx@8 @393
  GetWorldTransform@8 @394
  IntersectClipRect@20 @395
  InvertRgn@8 @397
  LPtoDP@12 @399
  LineDDA@24 @400
  LineTo@12 @401
  MaskBlt@48 @404
  ModifyWorldTransform@12 @405
  MoveToEx@16 @406
  OffsetClipRgn@12 @407
  OffsetRgn@12 @408
  OffsetViewportOrgEx@16 @409
  OffsetWindowOrgEx@16 @410
  PaintRgn@8 @412
  PatBlt@24 @413
  PathToRegion@4 @414
  Pie@36 @415
  PlayEnhMetaFile@12 @416
  PlayEnhMetaFileRecord@16 @417
  PlayMetaFile@8 @418
  PlayMetaFileRecord@16 @419
  PlgBlt@40 @420
  PolyBezier@12 @421
  PolyBezierTo@12 @422
  PolyDraw@16 @423
  PolyPolygon@16 @424
  PolyPolyline@16 @425
  PolyTextOutA@12 @426
  PolyTextOutW@12 @427
  Polygon@12 @428
  Polyline@12 @429
  PolylineTo@12 @430
  PtInRegion@12 @431
  PtVisible@12 @432
  RealizePalette@4 @433
  RectInRegion@8 @434
  RectVisible@8 @435
  Rectangle@20 @436
  RemoveFontResourceA@4 @437
  RemoveFontResourceExA@12 @438
  RemoveFontResourceExW@12 @439
  RemoveFontResourceW@4 @441
  ResetDCA@8 @442
  ResetDCW@8 @443
  ResizePalette@8 @444
  RestoreDC@8 @445
  RoundRect@28 @446
  SaveDC@4 @447
  ScaleViewportExtEx@24 @448
  ScaleWindowExtEx@24 @449
  SelectClipPath@8 @451
  SelectClipRgn@8 @452
  SelectObject@8 @454
  SelectPalette@12 @455
  SetAbortProc@8 @457
  SetArcDirection@8 @458
  SetBitmapBits@12 @459
  SetBitmapDimensionEx@16 @460
  SetBkColor@8 @461
  SetBkMode@8 @462
  SetBoundsRect@12 @463
  SetBrushOrgEx@16 @464
  SetColorAdjustment@8 @465
  SetColorSpace@8 @466
  SetDCBrushColor@8 @467
  SetDCPenColor@8 @470
  SetDIBColorTable@16 @472
  SetDIBits@28 @473
  SetDIBitsToDevice@48 @474
  SetDeviceGammaRamp@8 @475
  SetEnhMetaFileBits@8 @476
  SetGraphicsMode@8 @478
  SetICMMode@8 @480
  SetICMProfileA@8 @481
  SetLayout@8 @483
  SetMapMode@8 @485
  SetMapperFlags@8 @486
  SetMetaFileBitsEx@8 @487
  SetMetaRgn@4 @488
  SetMiterLimit@12 @489
  SetObjectOwner@8 @490
  SetPaletteEntries@16 @491
  SetPixel@16 @492
  SetPixelFormat@12 @493
  SetPixelV@16 @494
  SetPolyFillMode@8 @495
  SetROP2@8 @496
  SetRectRgn@20 @497
  SetRelAbs@8 @498
  SetStretchBltMode@8 @499
  SetSystemPaletteUse@8 @500
  SetTextAlign@8 @501
  SetTextCharacterExtra@8 @502
  SetTextColor@8 @503
  SetTextJustification@12 @504
  SetViewportExtEx@16 @505
  SetViewportOrgEx@16 @506
  SetVirtualResolution@20 @507
  SetWinMetaFileBits@16 @508
  SetWindowExtEx@16 @509
  SetWindowOrgEx@16 @510
  SetWorldTransform@8 @511
  StartDocA@8 @512
  StartDocW@8 @513
  StartPage@4 @514
  StretchBlt@44 @515
  StretchDIBits@52 @516
  StrokeAndFillPath@4 @517
  StrokePath@4 @518
  SwapBuffers@4 @519
  TextOutA@20 @520
  TextOutW@20 @521
  TranslateCharsetInfo@12 @522
  UnrealizeObject@4 @524
  UpdateColors@4 @525
  WidenPath@4 @529
  pfnRealizePalette @532 DATA
  pfnSelectPalette @533 DATA
  CloseJob16@4 @125
  CloseMetaFile16@4 @127
  DeleteMetaFile16@4 @182
  DrvGetPrinterData16@24 @189
  DrvSetPrinterData16@20 @190
  ExcludeVisRect16@20 @210
  GetDCState16@4 @312
  IntersectVisRect16@20 @396
  IsDCCurrentPalette16@4 @398
  OpenJob16@12 @411
  SelectVisRgn16@8 @456
  SetDCHook@12 @468
  SetDCOrg16@12 @469
  SetDCState16@8 @471
  SetHookFlags16@8 @479
  WriteSpool16@12 @530
  DIB_CreateDIBSection @176
  GDI_GetObjPtr @225
  GDI_ReleaseObj @226
