; File generated automatically from winmm/winmm.spec; do not edit!

LIBRARY winmm.dll

EXPORTS
  PlaySoundA@12 @18
  CloseDriver@12 @2
  DefDriverProc@20 @5
  DriverCallback@28 @6
  DrvClose@12=CloseDriver@12 @7
  DrvDefDriverProc@20=DefDriverProc@20 @8
  DrvGetModuleHandle@4=GetDriverModuleHandle@4 @9
  DrvOpen@12=OpenDriverW@12 @10
  DrvOpenA@12=OpenDriverA@12 @11
  DrvSendMessage@16=SendDriverMessage@16 @12
  GetDriverFlags@4 @13
  GetDriverModuleHandle@4 @14
  OpenDriver@12=OpenDriverW@12 @15
  OpenDriverA@12 @16
  PlaySound@12=PlaySoundA@12 @17
  PlaySoundW@12 @19
  SendDriverMessage@16 @20
  auxGetDevCapsA@12 @21
  auxGetDevCapsW@12 @22
  auxGetNumDevs@0 @23
  auxGetVolume@8 @24
  auxOutMessage@16 @25
  auxSetVolume@8 @26
  joyGetDevCapsA@12 @28
  joyGetDevCapsW@12 @29
  joyGetNumDevs@0 @30
  joyGetPos@8 @31
  joyGetPosEx@8 @32
  joyGetThreshold@8 @33
  joyReleaseCapture@4 @34
  joySetCapture@16 @35
  joySetThreshold@8 @36
  mciDriverNotify@12 @37
  mciDriverYield@4 @38
  mciExecute@4 @39
  mciFreeCommandResource@4 @40
  mciGetCreatorTask@4 @41
  mciGetDeviceIDA@4 @42
  mciGetDeviceIDFromElementIDW@8 @43
  mciGetDeviceIDW@4 @44
  mciGetDriverData@4 @45
  mciGetErrorStringA@12 @46
  mciGetErrorStringW@12 @47
  mciGetYieldProc@8 @48
  mciLoadCommandResource@12 @49
  mciSendCommandA@16 @50
  mciSendCommandW@16 @51
  mciSendStringA@16 @52
  mciSendStringW@16 @53
  mciSetDriverData@8 @54
  mciSetYieldProc@12 @55
  midiInAddBuffer@12 @58
  midiInClose@4 @59
  midiInGetDevCapsA@12 @60
  midiInGetDevCapsW@12 @61
  midiInGetErrorTextA@12 @62
  midiInGetErrorTextW@12 @63
  midiInGetID@8 @64
  midiInGetNumDevs@0 @65
  midiInMessage@16 @66
  midiInOpen@20 @67
  midiInPrepareHeader@12 @68
  midiInReset@4 @69
  midiInStart@4 @70
  midiInStop@4 @71
  midiInUnprepareHeader@12 @72
  midiOutCacheDrumPatches@16 @73
  midiOutCachePatches@16 @74
  midiOutClose@4 @75
  midiOutGetDevCapsA@12 @76
  midiOutGetDevCapsW@12 @77
  midiOutGetErrorTextA@12 @78
  midiOutGetErrorTextW@12 @79
  midiOutGetID@8 @80
  midiOutGetNumDevs@0 @81
  midiOutGetVolume@8 @82
  midiOutLongMsg@12 @83
  midiOutMessage@16 @84
  midiOutOpen@20 @85
  midiOutPrepareHeader@12 @86
  midiOutReset@4 @87
  midiOutSetVolume@8 @88
  midiOutShortMsg@8 @89
  midiOutUnprepareHeader@12 @90
  midiStreamClose@4 @91
  midiStreamOpen@24 @92
  midiStreamOut@12 @93
  midiStreamPause@4 @94
  midiStreamPosition@12 @95
  midiStreamProperty@12 @96
  midiStreamRestart@4 @97
  midiStreamStop@4 @98
  mixerClose@4 @99
  mixerGetControlDetailsA@12 @100
  mixerGetControlDetailsW@12 @101
  mixerGetDevCapsA@12 @102
  mixerGetDevCapsW@12 @103
  mixerGetID@12 @104
  mixerGetLineControlsA@12 @105
  mixerGetLineControlsW@12 @106
  mixerGetLineInfoA@12 @107
  mixerGetLineInfoW@12 @108
  mixerGetNumDevs@0 @109
  mixerMessage@16 @110
  mixerOpen@20 @111
  mixerSetControlDetails@12 @112
  mmioAdvance@12 @113
  mmioAscend@12 @114
  mmioClose@8 @115
  mmioCreateChunk@12 @116
  mmioDescend@16 @117
  mmioFlush@8 @118
  mmioGetInfo@12 @119
  mmioInstallIOProcA@12 @121
  mmioInstallIOProcW@12 @122
  mmioOpenA@12 @123
  mmioOpenW@12 @124
  mmioRead@12 @125
  mmioRenameA@16 @126
  mmioRenameW@16 @127
  mmioSeek@12 @128
  mmioSendMessage@16 @129
  mmioSetBuffer@16 @130
  mmioSetInfo@12 @131
  mmioStringToFOURCCA@8 @132
  mmioStringToFOURCCW@8 @133
  mmioWrite@12 @134
  mmsystemGetVersion@0 @135
  sndPlaySoundA@8 @136
  sndPlaySoundW@8 @137
  timeBeginPeriod@4 @138
  timeEndPeriod@4 @139
  timeGetDevCaps@8 @140
  timeGetSystemTime@8 @141
  timeGetTime@0 @142
  timeKillEvent@4 @143
  timeSetEvent@20 @144
  waveInAddBuffer@12 @145
  waveInClose@4 @146
  waveInGetDevCapsA@12 @147
  waveInGetDevCapsW@12 @148
  waveInGetErrorTextA@12 @149
  waveInGetErrorTextW@12 @150
  waveInGetID@8 @151
  waveInGetNumDevs@0 @152
  waveInGetPosition@12 @153
  waveInMessage@16 @154
  waveInOpen@24 @155
  waveInPrepareHeader@12 @156
  waveInReset@4 @157
  waveInStart@4 @158
  waveInStop@4 @159
  waveInUnprepareHeader@12 @160
  waveOutBreakLoop@4 @161
  waveOutClose@4 @162
  waveOutGetDevCapsA@12 @163
  waveOutGetDevCapsW@12 @164
  waveOutGetErrorTextA@12 @165
  waveOutGetErrorTextW@12 @166
  waveOutGetID@8 @167
  waveOutGetNumDevs@0 @168
  waveOutGetPitch@8 @169
  waveOutGetPlaybackRate@8 @170
  waveOutGetPosition@12 @171
  waveOutGetVolume@8 @172
  waveOutMessage@16 @173
  waveOutOpen@24 @174
  waveOutPause@4 @175
  waveOutPrepareHeader@12 @176
  waveOutReset@4 @177
  waveOutRestart@4 @178
  waveOutSetPitch@8 @179
  waveOutSetPlaybackRate@8 @180
  waveOutSetVolume@8 @181
  waveOutUnprepareHeader@12 @182
  waveOutWrite@12 @183
