; File generated automatically from advapi32/advapi32.spec; do not edit!

LIBRARY advapi32.dll

EXPORTS
  AbortSystemShutdownA@4 @1
  AbortSystemShutdownW@4 @2
  AccessCheck@32 @3
  AccessCheckAndAuditAlarmA@44 @4
  AccessCheckAndAuditAlarmW@44 @5
  AccessCheckByType@44 @6
  AddAccessAllowedAce@16 @7
  AddAccessAllowedAceEx@20 @8
  AddAccessDeniedAce@16 @9
  AddAccessDeniedAceEx@20 @10
  AddAce@20 @11
  AddAuditAccessAce@24 @12
  AdjustTokenPrivileges@24 @14
  AllocateAndInitializeSid@44 @15
  AllocateLocallyUniqueId@4 @16
  BackupEventLogA@8 @19
  BackupEventLogW@8 @20
  BuildTrusteeWithSidA@8 @21
  BuildTrusteeWithSidW@8 @22
  ChangeServiceConfigA@44 @23
  ChangeServiceConfigW@44 @24
  ClearEventLogA@8 @26
  ClearEventLogW@8 @27
  CloseEventLog@4 @28
  CloseServiceHandle@4 @29
  CommandLineFromMsiDescriptor@12 @30
  ControlService@12 @31
  ConvertStringSecurityDescriptorToSecurityDescriptorW@16 @35
  CopySid@12 @36
  CreateServiceA@52 @40
  CreateServiceW@52 @41
  CryptAcquireContextA@20 @43
  CryptAcquireContextW@20 @44
  CryptContextAddRef@12 @45
  CryptCreateHash@20 @46
  CryptDecrypt@24 @47
  CryptDeriveKey@20 @48
  CryptDestroyHash@4 @49
  CryptDestroyKey@4 @50
  CryptDuplicateHash@16 @51
  CryptDuplicateKey@16 @52
  CryptEncrypt@28 @53
  CryptEnumProvidersA@24 @56
  CryptEnumProvidersW@24 @57
  CryptEnumProviderTypesA@24 @54
  CryptEnumProviderTypesW@24 @55
  CryptExportKey@24 @58
  CryptGenKey@16 @59
  CryptGenRandom@12 @60
  CryptGetDefaultProviderA@20 @61
  CryptGetDefaultProviderW@20 @62
  CryptGetHashParam@20 @63
  CryptGetKeyParam@20 @64
  CryptGetProvParam@20 @65
  CryptGetUserKey@12 @66
  CryptHashData@16 @67
  CryptHashSessionKey@12 @68
  CryptImportKey@24 @69
  CryptReleaseContext@8 @70
  CryptSignHashA@24 @78
  CryptSignHashW@24=CryptSignHashA@24 @79
  CryptSetHashParam@16 @71
  CryptSetKeyParam@16 @72
  CryptSetProviderA@8 @74
  CryptSetProviderW@8 @77
  CryptSetProviderExA@16 @75
  CryptSetProviderExW@16 @76
  CryptSetProvParam@16 @73
  CryptVerifySignatureA@24 @80
  CryptVerifySignatureW@24=CryptVerifySignatureA@24 @81
  DeleteAce@8 @82
  DeleteService@4 @83
  DeregisterEventSource@4 @84
  EnumServicesStatusA@32 @96
  EnumServicesStatusW@32 @97
  EqualPrefixSid@8 @98
  EqualSid@8 @99
  FindFirstFreeAce@8 @100
  FreeSid@4 @101
  GetAce@12 @102
  GetAclInformation@16 @103
  GetCurrentHwProfileA@4 @104
  GetExplicitEntriesFromAclA@12 @106
  GetExplicitEntriesFromAclW@12 @107
  GetFileSecurityA@20 @108
  GetFileSecurityW@20 @109
  GetLengthSid@4 @111
  GetNamedSecurityInfoA@32 @113
  GetNamedSecurityInfoW@32 @114
  GetNumberOfEventLogRecords@8 @115
  GetOldestEventLogRecord@8 @116
  GetSecurityDescriptorControl@12 @118
  GetSecurityDescriptorDacl@16 @119
  GetSecurityDescriptorGroup@12 @120
  GetSecurityDescriptorLength@4 @121
  GetSecurityDescriptorOwner@12 @122
  GetSecurityDescriptorSacl@16 @123
  GetSecurityInfoExW@36 @125
  GetSidIdentifierAuthority@4 @130
  GetSidLengthRequired@4 @131
  GetSidSubAuthority@8 @132
  GetSidSubAuthorityCount@4 @133
  GetTokenInformation@20 @135
  GetUserNameA@8 @136
  GetUserNameW@8 @137
  ImpersonateLoggedOnUser@4 @140
  ImpersonateSelf@4 @142
  InitializeAcl@12 @143
  InitializeSecurityDescriptor@8 @144
  InitializeSid@12 @145
  InitiateSystemShutdownExA@24 @147
  InitiateSystemShutdownExW@24 @148
  IsTextUnicode@12=ntdll.RtlIsTextUnicode @152
  IsValidAcl@4 @154
  IsValidSecurityDescriptor@4 @155
  IsValidSid@4 @156
  LockServiceDatabase@4 @157
  LookupAccountNameA@28 @160
  LookupAccountSidA@28 @162
  LookupAccountSidW@28 @163
  LookupPrivilegeNameA@16 @166
  LookupPrivilegeNameW@16 @167
  LookupPrivilegeValueA@12 @168
  LookupPrivilegeValueW@12 @169
  MakeAbsoluteSD@44 @200
  MakeSelfRelativeSD@12 @201
  NotifyBootConfigStatus@4 @203
  NotifyChangeEventLog@8 @204
  OpenBackupEventLogA@8 @211
  OpenBackupEventLogW@8 @212
  OpenEventLogA@8 @213
  OpenEventLogW@8 @214
  OpenProcessToken@12 @215
  OpenSCManagerA@12 @216
  OpenSCManagerW@12 @217
  OpenServiceA@12 @218
  OpenServiceW@12 @219
  OpenThreadToken@16 @220
  PrivilegeCheck@12 @221
  QueryServiceConfigA@16 @224
  QueryServiceConfigW@16 @225
  QueryServiceStatus@8 @229
  QueryServiceStatusEx@20 @230
  ReadEventLogA@28 @232
  ReadEventLogW@28 @233
  RegCloseKey@4 @234
  RegConnectRegistryA@12 @235
  RegConnectRegistryW@12 @236
  RegCreateKeyA@12 @237
  RegCreateKeyExA@36 @238
  RegCreateKeyExW@36 @239
  RegCreateKeyW@12 @240
  RegDeleteKeyA@8 @241
  RegDeleteKeyW@8 @242
  RegDeleteValueA@8 @243
  RegDeleteValueW@8 @244
  RegEnumKeyA@16 @245
  RegEnumKeyExA@32 @246
  RegEnumKeyExW@32 @247
  RegEnumKeyW@16 @248
  RegEnumValueA@32 @249
  RegEnumValueW@32 @250
  RegFlushKey@4 @251
  RegGetKeySecurity@16 @252
  RegLoadKeyA@12 @253
  RegLoadKeyW@12 @254
  RegNotifyChangeKeyValue@20 @255
  RegOpenCurrentUser@8 @256
  RegOpenKeyA@12 @257
  RegOpenKeyExA@20 @258
  RegOpenKeyExW@20 @259
  RegOpenKeyW@12 @260
  RegOpenUserClassesRoot@16 @261
  RegQueryInfoKeyA@48 @262
  RegQueryInfoKeyW@48 @263
  RegQueryMultipleValuesA@20 @264
  RegQueryMultipleValuesW@20 @265
  RegQueryValueA@16 @266
  RegQueryValueExA@24 @267
  RegQueryValueExW@24 @268
  RegQueryValueW@16 @269
  RegReplaceKeyA@16 @271
  RegReplaceKeyW@16 @272
  RegRestoreKeyA@12 @273
  RegRestoreKeyW@12 @274
  RegSaveKeyA@12 @275
  RegSaveKeyW@12 @276
  RegSetKeySecurity@12 @277
  RegSetValueA@20 @278
  RegSetValueExA@24 @279
  RegSetValueExW@24 @280
  RegSetValueW@20 @281
  RegUnLoadKeyA@8 @282
  RegUnLoadKeyW@8 @283
  RegisterEventSourceA@8 @284
  RegisterEventSourceW@8 @285
  RegisterServiceCtrlHandlerA@8 @286
  RegisterServiceCtrlHandlerW@8 @287
  ReportEventA@36 @288
  ReportEventW@36 @289
  RevertToSelf@0 @290
  SetEntriesInAclA@16 @292
  SetEntriesInAclW@16 @293
  SetFileSecurityA@12 @294
  SetFileSecurityW@12 @295
  SetKernelObjectSecurity@12 @296
  SetNamedSecurityInfoA@28 @297
  SetNamedSecurityInfoW@28 @298
  SetSecurityDescriptorDacl@16 @301
  SetSecurityDescriptorGroup@12 @302
  SetSecurityDescriptorOwner@12 @303
  SetSecurityDescriptorSacl@16 @304
  SetServiceStatus@8 @307
  SetThreadToken@8 @308
  SetTokenInformation@16 @309
  StartServiceA@12 @310
  StartServiceCtrlDispatcherA@4 @311
  StartServiceCtrlDispatcherW@4 @312
  StartServiceW@12 @313
  UnlockServiceDatabase@4 @357
  LsaOpenPolicy@16 @189
  LsaLookupSids@20 @186
  LsaFreeMemory@4 @180
  LsaQueryInformationPolicy@12 @193
  LsaClose@4 @171
  SystemFunction040@12 @351
  SystemFunction041@12 @352
  LsaNtStatusToWinError@4 @187
  SynchronizeWindows31FilesAndWindowsNTRegistry@16 @314
  QueryWindows31FilesMigration@4 @231
  CheckTokenMembership@12 @25
