; File generated automatically from psapi/psapi.spec; do not edit!

LIBRARY psapi.dll

EXPORTS
  EmptyWorkingSet@4 @1
  EnumDeviceDrivers@12 @2
  EnumProcessModules@16 @5
  EnumProcesses@12 @6
  GetDeviceDriverBaseNameA@12 @7
  GetDeviceDriverBaseNameW@12 @8
  GetDeviceDriverFileNameA@12 @9
  GetDeviceDriverFileNameW@12 @10
  GetMappedFileNameA@16 @11
  GetMappedFileNameW@16 @12
  GetModuleBaseNameA@16 @13
  GetModuleBaseNameW@16 @14
  GetModuleFileNameExA@16 @15
  GetModuleFileNameExW@16 @16
  GetModuleInformation@16 @17
  GetProcessMemoryInfo@12 @21
  GetWsChanges@12 @22
  InitializeProcessForWsWatch@4 @23
  QueryWorkingSet@12 @24
